################################################################################
################################################################################
################################################################################
##
## DESCRIPTION : R functions to calculate z-scores from the WHO growth standards
##               and the WHO growth references
##
## AUTHOR      : Mark Myatt, Brixton Health
##
## REVISION    : Revision: 1.01
## DATE        : 26th June 2019
##
## LICENSE     : GPL v3 (or later)
## COPYRIGHT   : Brixton Health (c) 2019
##
## This file contains free software.  You may redistribute it and / or modify it
## under the terms of the  GNU  General  Public  License (version 3 or later) as
## published by the Free Software Foundation:
##
##   http://www.gnu.org/licenses/gpl.html
##
## This file is distributed in the hope that it will be useful,  but WITHOUT ANY
## WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
## ANY PARTICULAR PURPOSE. See the GNU General Public License: for more details.
##
################################################################################
################################################################################
################################################################################


################################################################################
#
#  Function to to add using the WHO Growth Reference z-scores to a data frame
#
################################################################################
#
#  Parameters are :
#
#
#    data         A survey dataset as a data.frame object.
#
#
#    sex          Name of variable specifying the sex of the subject. This must
#                 be coded as 1 = male; 2 = female.
#
#                 Give a quoted variable name as in (e.g.) "sex".
#
#
#    firstPart    Name of variable specifying:
#
#                     Weight (kg) for BMI/A, W/A, W/H, or W/L
#                     Head circumference (cm) for HC/A
#                     Height (cm) for BMI/A or H/A
#                     Length (cm) for L/A
#                     MUAC (cm) for MUAC/A
#                     Sub-scapular skinfold (mm) for SSF/A
#                     Triceps skin fold (mm) for TSF/A
#
#                 Give a quoted variable name as in (e.g.) "weight".
#
#                 Be careful with units (weight in kg; height, length, head
#                 circumference, and MUAC in cm, skinfolds in mm).
#
#
#    secondPart   Name of variable specificying:
#
#                     Age (days) for H/A, HC/A, L/A, MUAC/A, SSF/A, or TSF/A
#                     Height (cm) for BMI/A or W/H
#                     Length (cm) for W/L
#
#                 Give a quoted variable name as in (e.g.) "age".
#
#                 Be careful with units (age in days; height and length in cm).
#
#
#    thirdPart    Name of variable specifying age (in days) for BMI/A
#
#                 Give a quoted variable name as in (e.g.) "age".
#                 Be careful with units (age in days).
#
#
#    index        The index to be calculated and added to 'data'. One of:
#
#                     "bfa"    BMI for age
#                     "hca"    Head circumference for age
#                     "hfa"    Height for age
#                     "lfa"    Length for age
#                     "mfa"    MUAC for age
#                     "ssa"    Sub-scapular skinfold for age
#                     "tsa"    Triceps skinfold for age
#                     "wfa"    Weight for age
#                     "wfh"    Weight for height
#                     "wfl"    Weight for length
#
#                 Give a quoted index name as in (e.g.) "wfh".
#
#
#    standing     Variable specifying how stature was measured. If NULL then
#                 age (for "hfa" or "lfa") or height rules (for "wfh" or "wfl")
#                 will be applied.
#
#                 This must be coded as 1 = Standing, 2 = Supine, 3 = Unknown.
#                 All other values will be recoded to 3 = Unknown.
#
#                 Give a quoted variable name as in (e.g.) "measured" or a
#                 single value (e.g. "measured = 1"). If no value (or NULL) is
#                 specified then height an age rules will be applied.
#
#
#    output       The name of the column containing the specified index to be
#                 added to the dataset. This is an optional parameter. If you
#                 do not specify a value for output then the added column will
#                 take the name of the specified index with a "z" appended.
#
#
#    digits       The number of decimal places for 'output'. Defaults to 2 d.p.
#
#
################################################################################

addWGSR <- function(data, sex, firstPart, secondPart, thirdPart = NA, index = NA, standing = NULL, output = paste(index, "z", sep = ""), digits = 2)
  {
  ## If 'standing' is not specified then create a column in 'data' holding 3 (unknown) for all rows
  addedStanding <- FALSE
  if(is.null(standing))
    {
    ## Random column name for 'standing'
    standing <- paste(sample(c(letters, LETTERS), size = 16, replace = TRUE), collapse = "")
    data[[standing]] <- 3
    addedStanding <- TRUE
    }
  ## Calculate specified index
  z <- vector(mode = "numeric", length = nrow(data))
	pb <- txtProgressBar(min = 0, max = nrow(data), style = 1)
	for(i in 1:nrow(data))
    {
    z[i] <- ifelse(!is.na(thirdPart),
    			getWGSR(sex = data[[sex]][i], firstPart = data[[firstPart]][i], secondPart = data[[secondPart]][i], index = index, standing = data[[standing]][i], thirdPart = data[[thirdPart]][i]),
              getWGSR(sex = data[[sex]][i], firstPart = data[[firstPart]][i], secondPart = data[[secondPart]][i], index = index, standing = data[[standing]][i]))
    setTxtProgressBar(pb, i)
		}
	cat("\n", sep = "")
	## Remove	added 'standing' column from 'data'
	if(addedStanding)
	  {
	  data[[standing]] <- NULL
	  }
	## Add index to 'data' and return 'data'
	data[[output]] <- round(z, digits = digits)
	return(data)
  }


################################################################################
#
#  Function to calculate z-scores. Usually called by the 'addWGSR()' function
#  but could be used as a stand-alone command-line calculator if required.
#
################################################################################

getWGSR <- function(sex, firstPart, secondPart, index = NA, standing, thirdPart = NA)
  {
  ## Avoid missing and impossible values in 'standing' by coding NA and other values to '3'
  if(is.na(standing) | !(standing %in% c(1, 2, 3)))
    {
    standing = 3
    }
  ## Unknown index specified - return NA
  if(!(index %in% c("bfa", "hca", "hfa", "lfa", "mfa", "ssa", "tsa", "wfa", "wfh", "wfl")))
    {
    return(NA)
    }
  ## Missing data for 'sex', 'firstPart', or 'secondPart' - return NA
  if(is.na(sex) | is.na(firstPart) | is.na(secondPart))
    {
    return(NA)
    }
  ## 'sex' must be male (1) or female (2)
  if(!(sex %in% c(1, 2)))
    {
    return(NA)
    }
  ## 'firstPart' or 'secondPart' are not numeric - return NA
  if(!is.numeric(firstPart) | !is.numeric(secondPart))
    {
    return(NA)
    }
  ## Missing 'thirdPart' (age) is missing for BMI-for-age - return NA
  if(index == "bfa" & is.na(thirdPart))
    {
    return(NA)
    }
  ## 'thirdPart' (age) is not numeric for BMI-for-age - return NA
  if(index == "bfa" & !is.numeric(thirdPart))
    {
    return(NA)
    }
  ## 'secondPart' is zero then BMI cannot be calculated
  if(index == "bfa" & secondPart == 0)
    {
    return(NA)
    }
  ## Round lengths to nearest 0.1 cm
  if(index %in% c("wfh", "wfl"))
    {
	  secondPart <- round(secondPart, 1)
	  }
  ## Round ages to the nearest day
  if(index %in% c("hca", "hfa", "lfa", "mfa", "ssa", "tsa", "wfa"))
    {
    secondPart <- round(secondPart, digits = 0)
    }
  if(index == "bfa")
    {
    thirdPart <- round(thirdPart, 0)
    }
  ## Rules for length-for-age and height-for-age indices
  if(standing == 1 & (index == "lfa" | index == "hfa") & secondPart < 731)
    {
    index <- "lfa"
    firstPart <- firstPart + 0.7
    }
  if(standing == 2 & (index == "lfa" | index == "hfa") & secondPart < 731)
    {
    index <- "lfa"
    }
  if(standing == 3 & (index == "lfa" | index == "hfa") & secondPart < 731)
    {
    index <- "lfa"
    }
  if(standing == 1 & (index == "lfa" | index == "hfa") & secondPart >= 731)
    {
    index <- "hfa"
    }
  if(standing == 2 & (index == "lfa" | index == "hfa") & secondPart >= 731)
    {
    index <- "hfa"
    firstPart <- firstPart - 0.7
    }
  if(standing == 3 & (index == "lfa" | index == "hfa") & secondPart >= 731)
    {
    index <- "hfa"
    }
  ## Rules for weight-for-length and weight-for-height indices
  if(standing == 1 & (index == "wfl" | index == "wfh") & secondPart < 65)
    {
    index = "wfl"
    secondPart <- secondPart + 0.7
    }
  if(standing == 1 & (index == "wfl" | index == "wfh") & secondPart >= 65)
    {
    index = "wfh"
    }
  if(standing == 2 & (index == "wfl" | index == "wfh") & secondPart <= 110)
    {
    index = "wfl"
    }
  if(standing == 2 & (index == "wfl" | index == "wfh") & secondPart > 110)
    {
    index = "wfh"
    secondPart <- secondPart - 0.7
    }
    if(standing == 3 & (index == "wfl" | index == "wfh") & secondPart < 87)
    {
    index = "wfl"
    }
  if(standing == 3 & (index == "wfl" | index == "wfh") & secondPart >= 87)
    {
    index = "wfh"
    }
  ## Rules for BMI-for-age index
  if(standing == 1 & index == "bfa" & thirdPart < 731)
    {
    secondPart <- secondPart + 0.7
    }
  if(standing == 2 & index == "bfa" & thirdPart >= 731)
    {
    secondPart <- secondPart - 0.7
    }
  ## Calculate BMI (as 'firstPart') and place age in 'secondPart'
  if(index == "bfa")
    {
    firstPart <- firstPart / (secondPart / 100)^2
    secondPart <- thirdPart
    }
  ## 'secondPart' is out of range for specified 'index' - return NA
  rangeSecondPart <- range(wgsrData$given[wgsrData$index == index])
  if(secondPart < rangeSecondPart[1] | secondPart > rangeSecondPart[2])
    {
    return(NA)
    }
  ## Lookup reference values and calculate z-score
  lkpIndexSex <- wgsrData[wgsrData$index == index & wgsrData$sex == sex, ]
  L <- approx(lkpIndexSex$given, lkpIndexSex$l, xout = secondPart)$y
  M <- approx(lkpIndexSex$given, lkpIndexSex$m, xout = secondPart)$y
  S <- approx(lkpIndexSex$given, lkpIndexSex$s, xout = secondPart)$y
  z <- (((firstPart / M) ^ L) - 1) / (L * S)
  SD3pos <- M * (1 + L * S * (+3))^(1 / L)
  SD2pos <- M * (1 + L * S * (+2))^(1 / L)
  SD23pos <- SD3pos - SD2pos
  SD3neg <- M * (1 + L * S * (-3))^(1 / L)
  SD2neg <- M * (1 + L * S * (-2))^(1 / L)
  SD23neg <- SD2neg - SD3neg
  if(z >  3) z <-  3 + ((firstPart - SD3pos) / SD23pos)
  if(z < -3) z <- -3 + ((firstPart - SD3neg) / SD23neg)
  return(z)
  }

################################################################################
#                                                                              #
#                            Do NOT alter this data                            #
#                                                                              #
################################################################################
#                                                                              #
#                                                                              #
#    #     #   #####    #####   ######       ######                            #
#    #  #  #  #     #  #     #  #     #      #     #    ##    #####    ##      #
#    #  #  #  #        #        #     #      #     #   #  #     #     #  #     #
#    #  #  #  #  ####   #####   ######       #     #  #    #    #    #    #    #
#    #  #  #  #     #        #  #   #        #     #  ######    #    ######    #
#    #  #  #  #     #  #     #  #    #       #     #  #    #    #    #    #    #
#     ## ##    #####    #####   #     #      ######   #    #    #    #    #    #
#                                                                              #
#                                                                              #
################################################################################
#                                                                              #
#                            Do NOT alter this data                            #
#                                                                              #
################################################################################

wgsrData <-
structure(list(index = structure(c(1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L,
3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L,
4L, 4L, 4L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L, 5L,
5L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L,
6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 6L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L,
7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 7L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L, 8L,
8L, 8L, 8L, 8L, 8L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L,
9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 9L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L, 10L,
10L, 10L, 10L, 10L, 10L, 10L), .Label = c("bfa", "hca", "hfa",
"lfa", "mfa", "ssa", "tsa", "wfa", "wfl", "wfh"), class = "factor"),
    sex = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
    1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L,
    2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L),
    given = c(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14,
    15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
    30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44,
    45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
    60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74,
    75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89,
    90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103,
    104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
    116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127,
    128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139,
    140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151,
    152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163,
    164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175,
    176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187,
    188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
    200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211,
    212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223,
    224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235,
    236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247,
    248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259,
    260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271,
    272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283,
    284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295,
    296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307,
    308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319,
    320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331,
    332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343,
    344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355,
    356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367,
    368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379,
    380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391,
    392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403,
    404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415,
    416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427,
    428, 429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439,
    440, 441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451,
    452, 453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463,
    464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475,
    476, 477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487,
    488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499,
    500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511,
    512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523,
    524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535,
    536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547,
    548, 549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559,
    560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571,
    572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583,
    584, 585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595,
    596, 597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607,
    608, 609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619,
    620, 621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631,
    632, 633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643,
    644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655,
    656, 657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667,
    668, 669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679,
    680, 681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691,
    692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703,
    704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715,
    716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727,
    728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739,
    740, 741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751,
    752, 753, 754, 755, 756, 757, 758, 759, 760, 761, 762, 763,
    764, 765, 766, 767, 768, 769, 770, 771, 772, 773, 774, 775,
    776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787,
    788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799,
    800, 801, 802, 803, 804, 805, 806, 807, 808, 809, 810, 811,
    812, 813, 814, 815, 816, 817, 818, 819, 820, 821, 822, 823,
    824, 825, 826, 827, 828, 829, 830, 831, 832, 833, 834, 835,
    836, 837, 838, 839, 840, 841, 842, 843, 844, 845, 846, 847,
    848, 849, 850, 851, 852, 853, 854, 855, 856, 857, 858, 859,
    860, 861, 862, 863, 864, 865, 866, 867, 868, 869, 870, 871,
    872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883,
    884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895,
    896, 897, 898, 899, 900, 901, 902, 903, 904, 905, 906, 907,
    908, 909, 910, 911, 912, 913, 914, 915, 916, 917, 918, 919,
    920, 921, 922, 923, 924, 925, 926, 927, 928, 929, 930, 931,
    932, 933, 934, 935, 936, 937, 938, 939, 940, 941, 942, 943,
    944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955,
    956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967,
    968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
    980, 981, 982, 983, 984, 985, 986, 987, 988, 989, 990, 991,
    992, 993, 994, 995, 996, 997, 998, 999, 1000, 1001, 1002,
    1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012,
    1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022,
    1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032,
    1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042,
    1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052,
    1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062,
    1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072,
    1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082,
    1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 1092,
    1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101, 1102,
    1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112,
    1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122,
    1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132,
    1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142,
    1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152,
    1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162,
    1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172,
    1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182,
    1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192,
    1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202,
    1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212,
    1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221, 1222,
    1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232,
    1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242,
    1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252,
    1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262,
    1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272,
    1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 1282,
    1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292,
    1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302,
    1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312,
    1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321, 1322,
    1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331, 1332,
    1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342,
    1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352,
    1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362,
    1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372,
    1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381, 1382,
    1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391, 1392,
    1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401, 1402,
    1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412,
    1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422,
    1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431, 1432,
    1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441, 1442,
    1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451, 1452,
    1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462,
    1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471, 1472,
    1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482,
    1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491, 1492,
    1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 1502,
    1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512,
    1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521, 1522,
    1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531, 1532,
    1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541, 1542,
    1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552,
    1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562,
    1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571, 1572,
    1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581, 1582,
    1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591, 1592,
    1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601, 1602,
    1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611, 1612,
    1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621, 1622,
    1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631, 1632,
    1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641, 1642,
    1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651, 1652,
    1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661, 1662,
    1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671, 1672,
    1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681, 1682,
    1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691, 1692,
    1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701, 1702,
    1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711, 1712,
    1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721, 1722,
    1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732,
    1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742,
    1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752,
    1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762,
    1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772,
    1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781, 1782,
    1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792,
    1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802,
    1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811, 1812,
    1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822,
    1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832,
    1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842,
    1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852,
    1853, 1854, 1855, 1856, 1857, 1887, 1918, 1948, 1978, 2009,
    2039, 2070, 2100, 2131, 2161, 2192, 2222, 2252, 2283, 2313,
    2344, 2374, 2405, 2435, 2465, 2496, 2526, 2557, 2587, 2618,
    2648, 2678, 2709, 2739, 2770, 2800, 2831, 2861, 2892, 2922,
    2952, 2983, 3013, 3044, 3074, 3105, 3135, 3166, 3196, 3226,
    3257, 3287, 3318, 3348, 3379, 3409, 3439, 3470, 3500, 3531,
    3561, 3592, 3622, 3652, 3683, 3713, 3744, 3774, 3805, 3835,
    3866, 3896, 3926, 3957, 3987, 4018, 4048, 4079, 4109, 4140,
    4170, 4200, 4231, 4261, 4292, 4322, 4353, 4383, 4413, 4444,
    4474, 4505, 4535, 4566, 4596, 4626, 4657, 4687, 4718, 4748,
    4779, 4809, 4840, 4870, 4900, 4931, 4961, 4992, 5022, 5053,
    5083, 5114, 5144, 5174, 5205, 5235, 5266, 5296, 5327, 5357,
    5387, 5418, 5448, 5479, 5509, 5540, 5570, 5600, 5631, 5661,
    5692, 5722, 5753, 5783, 5814, 5844, 5874, 5905, 5935, 5966,
    5996, 6027, 6057, 6088, 6118, 6148, 6179, 6209, 6240, 6270,
    6301, 6331, 6361, 6392, 6422, 6453, 6483, 6514, 6544, 6574,
    6605, 6635, 6666, 6696, 6727, 6757, 6788, 6818, 6848, 6879,
    6909, 6940, 6970, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
    13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27,
    28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42,
    43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57,
    58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72,
    73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87,
    88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101,
    102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
    114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125,
    126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137,
    138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
    150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161,
    162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173,
    174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185,
    186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197,
    198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209,
    210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221,
    222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233,
    234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245,
    246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257,
    258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269,
    270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281,
    282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293,
    294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305,
    306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317,
    318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329,
    330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341,
    342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353,
    354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365,
    366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377,
    378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389,
    390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401,
    402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412, 413,
    414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424, 425,
    426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436, 437,
    438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448, 449,
    450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 461,
    462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473,
    474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484, 485,
    486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496, 497,
    498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509,
    510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521,
    522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533,
    534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545,
    546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 557,
    558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569,
    570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581,
    582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592, 593,
    594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604, 605,
    606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616, 617,
    618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628, 629,
    630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 641,
    642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653,
    654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664, 665,
    666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676, 677,
    678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688, 689,
    690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700, 701,
    702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713,
    714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725,
    726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736, 737,
    738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749,
    750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760, 761,
    762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772, 773,
    774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785,
    786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797,
    798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 809,
    810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820, 821,
    822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832, 833,
    834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844, 845,
    846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 857,
    858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869,
    870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881,
    882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893,
    894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904, 905,
    906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916, 917,
    918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928, 929,
    930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940, 941,
    942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952, 953,
    954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965,
    966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977,
    978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988, 989,
    990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000, 1001,
    1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011,
    1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021,
    1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031,
    1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041,
    1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051,
    1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061,
    1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071,
    1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081,
    1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091,
    1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101,
    1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111,
    1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121,
    1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131,
    1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141,
    1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151,
    1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161,
    1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171,
    1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181,
    1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191,
    1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201,
    1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211,
    1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221,
    1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231,
    1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241,
    1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251,
    1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261,
    1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271,
    1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281,
    1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291,
    1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301,
    1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311,
    1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321,
    1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331,
    1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341,
    1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351,
    1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361,
    1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371,
    1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381,
    1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391,
    1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401,
    1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411,
    1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421,
    1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431,
    1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441,
    1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451,
    1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461,
    1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471,
    1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481,
    1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491,
    1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501,
    1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511,
    1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521,
    1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531,
    1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541,
    1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551,
    1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561,
    1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571,
    1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581,
    1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591,
    1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601,
    1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611,
    1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621,
    1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631,
    1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641,
    1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651,
    1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661,
    1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671,
    1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681,
    1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691,
    1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701,
    1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711,
    1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721,
    1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731,
    1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741,
    1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751,
    1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761,
    1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771,
    1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781,
    1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791,
    1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801,
    1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811,
    1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821,
    1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831,
    1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841,
    1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851,
    1852, 1853, 1854, 1855, 1856, 1857, 1887, 1918, 1948, 1978,
    2009, 2039, 2070, 2100, 2131, 2161, 2192, 2222, 2252, 2283,
    2313, 2344, 2374, 2405, 2435, 2465, 2496, 2526, 2557, 2587,
    2618, 2648, 2678, 2709, 2739, 2770, 2800, 2831, 2861, 2892,
    2922, 2952, 2983, 3013, 3044, 3074, 3105, 3135, 3166, 3196,
    3226, 3257, 3287, 3318, 3348, 3379, 3409, 3439, 3470, 3500,
    3531, 3561, 3592, 3622, 3652, 3683, 3713, 3744, 3774, 3805,
    3835, 3866, 3896, 3926, 3957, 3987, 4018, 4048, 4079, 4109,
    4140, 4170, 4200, 4231, 4261, 4292, 4322, 4353, 4383, 4413,
    4444, 4474, 4505, 4535, 4566, 4596, 4626, 4657, 4687, 4718,
    4748, 4779, 4809, 4840, 4870, 4900, 4931, 4961, 4992, 5022,
    5053, 5083, 5114, 5144, 5174, 5205, 5235, 5266, 5296, 5327,
    5357, 5387, 5418, 5448, 5479, 5509, 5540, 5570, 5600, 5631,
    5661, 5692, 5722, 5753, 5783, 5814, 5844, 5874, 5905, 5935,
    5966, 5996, 6027, 6057, 6088, 6118, 6148, 6179, 6209, 6240,
    6270, 6301, 6331, 6361, 6392, 6422, 6453, 6483, 6514, 6544,
    6574, 6605, 6635, 6666, 6696, 6727, 6757, 6788, 6818, 6848,
    6879, 6909, 6940, 6970, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25,
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
    56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
    71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85,
    86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
    101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112,
    113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
    125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
    137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148,
    149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160,
    161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172,
    173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184,
    185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196,
    197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208,
    209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220,
    221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232,
    233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244,
    245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256,
    257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268,
    269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280,
    281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292,
    293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304,
    305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316,
    317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328,
    329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340,
    341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352,
    353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364,
    365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376,
    377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388,
    389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400,
    401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412,
    413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424,
    425, 426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436,
    437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448,
    449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460,
    461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472,
    473, 474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484,
    485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496,
    497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508,
    509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520,
    521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532,
    533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544,
    545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556,
    557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568,
    569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580,
    581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592,
    593, 594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604,
    605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616,
    617, 618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628,
    629, 630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640,
    641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652,
    653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664,
    665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676,
    677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688,
    689, 690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700,
    701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712,
    713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724,
    725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736,
    737, 738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748,
    749, 750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760,
    761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772,
    773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784,
    785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796,
    797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808,
    809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820,
    821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832,
    833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844,
    845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856,
    857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868,
    869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880,
    881, 882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892,
    893, 894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904,
    905, 906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916,
    917, 918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928,
    929, 930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940,
    941, 942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952,
    953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964,
    965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976,
    977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988,
    989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000,
    1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010,
    1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020,
    1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030,
    1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040,
    1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050,
    1051, 1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060,
    1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070,
    1071, 1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080,
    1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090,
    1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100,
    1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110,
    1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120,
    1121, 1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130,
    1131, 1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140,
    1141, 1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150,
    1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160,
    1161, 1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170,
    1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180,
    1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190,
    1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200,
    1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210,
    1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220,
    1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230,
    1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240,
    1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250,
    1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260,
    1261, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270,
    1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280,
    1281, 1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290,
    1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300,
    1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310,
    1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320,
    1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330,
    1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340,
    1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350,
    1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360,
    1361, 1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370,
    1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380,
    1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390,
    1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400,
    1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410,
    1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420,
    1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430,
    1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440,
    1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450,
    1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460,
    1461, 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470,
    1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480,
    1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490,
    1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500,
    1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510,
    1511, 1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520,
    1521, 1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530,
    1531, 1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540,
    1541, 1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550,
    1551, 1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560,
    1561, 1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570,
    1571, 1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580,
    1581, 1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590,
    1591, 1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600,
    1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610,
    1611, 1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620,
    1621, 1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630,
    1631, 1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640,
    1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650,
    1651, 1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660,
    1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670,
    1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680,
    1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690,
    1691, 1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700,
    1701, 1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710,
    1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720,
    1721, 1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730,
    1731, 1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740,
    1741, 1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750,
    1751, 1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760,
    1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770,
    1771, 1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780,
    1781, 1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790,
    1791, 1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800,
    1801, 1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810,
    1811, 1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820,
    1821, 1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830,
    1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840,
    1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850,
    1851, 1852, 1853, 1854, 1855, 1856, 0, 1, 2, 3, 4, 5, 6,
    7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
    22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36,
    37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
    52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66,
    67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
    82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96,
    97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108,
    109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
    121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132,
    133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144,
    145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156,
    157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
    169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180,
    181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192,
    193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204,
    205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216,
    217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228,
    229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240,
    241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252,
    253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264,
    265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276,
    277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288,
    289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300,
    301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312,
    313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324,
    325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336,
    337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348,
    349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360,
    361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372,
    373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384,
    385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396,
    397, 398, 399, 400, 401, 402, 403, 404, 405, 406, 407, 408,
    409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420,
    421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432,
    433, 434, 435, 436, 437, 438, 439, 440, 441, 442, 443, 444,
    445, 446, 447, 448, 449, 450, 451, 452, 453, 454, 455, 456,
    457, 458, 459, 460, 461, 462, 463, 464, 465, 466, 467, 468,
    469, 470, 471, 472, 473, 474, 475, 476, 477, 478, 479, 480,
    481, 482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492,
    493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504,
    505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
    517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528,
    529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540,
    541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552,
    553, 554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564,
    565, 566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576,
    577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588,
    589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600,
    601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 612,
    613, 614, 615, 616, 617, 618, 619, 620, 621, 622, 623, 624,
    625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 635, 636,
    637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648,
    649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660,
    661, 662, 663, 664, 665, 666, 667, 668, 669, 670, 671, 672,
    673, 674, 675, 676, 677, 678, 679, 680, 681, 682, 683, 684,
    685, 686, 687, 688, 689, 690, 691, 692, 693, 694, 695, 696,
    697, 698, 699, 700, 701, 702, 703, 704, 705, 706, 707, 708,
    709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 719, 720,
    721, 722, 723, 724, 725, 726, 727, 728, 729, 730, 731, 732,
    733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 744,
    745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756,
    757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 768,
    769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780,
    781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 791, 792,
    793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804,
    805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816,
    817, 818, 819, 820, 821, 822, 823, 824, 825, 826, 827, 828,
    829, 830, 831, 832, 833, 834, 835, 836, 837, 838, 839, 840,
    841, 842, 843, 844, 845, 846, 847, 848, 849, 850, 851, 852,
    853, 854, 855, 856, 857, 858, 859, 860, 861, 862, 863, 864,
    865, 866, 867, 868, 869, 870, 871, 872, 873, 874, 875, 876,
    877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 887, 888,
    889, 890, 891, 892, 893, 894, 895, 896, 897, 898, 899, 900,
    901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 912,
    913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924,
    925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 935, 936,
    937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948,
    949, 950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960,
    961, 962, 963, 964, 965, 966, 967, 968, 969, 970, 971, 972,
    973, 974, 975, 976, 977, 978, 979, 980, 981, 982, 983, 984,
    985, 986, 987, 988, 989, 990, 991, 992, 993, 994, 995, 996,
    997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
    1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016,
    1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026,
    1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036,
    1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046,
    1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056,
    1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066,
    1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076,
    1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086,
    1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096,
    1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106,
    1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116,
    1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125, 1126,
    1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135, 1136,
    1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145, 1146,
    1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156,
    1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166,
    1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176,
    1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186,
    1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196,
    1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206,
    1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215, 1216,
    1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225, 1226,
    1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235, 1236,
    1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245, 1246,
    1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255, 1256,
    1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265, 1266,
    1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 1276,
    1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285, 1286,
    1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295, 1296,
    1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305, 1306,
    1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315, 1316,
    1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325, 1326,
    1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335, 1336,
    1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345, 1346,
    1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355, 1356,
    1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365, 1366,
    1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375, 1376,
    1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385, 1386,
    1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395, 1396,
    1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406,
    1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416,
    1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426,
    1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436,
    1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445, 1446,
    1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455, 1456,
    1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465, 1466,
    1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475, 1476,
    1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485, 1486,
    1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495, 1496,
    1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505, 1506,
    1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515, 1516,
    1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525, 1526,
    1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535, 1536,
    1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545, 1546,
    1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555, 1556,
    1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565, 1566,
    1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575, 1576,
    1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585, 1586,
    1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595, 1596,
    1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 1606,
    1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616,
    1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626,
    1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635, 1636,
    1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645, 1646,
    1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655, 1656,
    1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665, 1666,
    1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676,
    1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685, 1686,
    1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695, 1696,
    1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705, 1706,
    1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715, 1716,
    1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725, 1726,
    1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735, 1736,
    1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745, 1746,
    1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755, 1756,
    1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765, 1766,
    1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775, 1776,
    1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785, 1786,
    1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795, 1796,
    1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 1806,
    1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815, 1816,
    1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825, 1826,
    1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835, 1836,
    1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845, 1846,
    1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855, 1856,
    731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 742,
    743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754,
    755, 756, 757, 758, 759, 760, 761, 762, 763, 764, 765, 766,
    767, 768, 769, 770, 771, 772, 773, 774, 775, 776, 777, 778,
    779, 780, 781, 782, 783, 784, 785, 786, 787, 788, 789, 790,
    791, 792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802,
    803, 804, 805, 806, 807, 808, 809, 810, 811, 812, 813, 814,
    815, 816, 817, 818, 819, 820, 821, 822, 823, 824, 825, 826,
    827, 828, 829, 830, 831, 832, 833, 834, 835, 836, 837, 838,
    839, 840, 841, 842, 843, 844, 845, 846, 847, 848, 849, 850,
    851, 852, 853, 854, 855, 856, 857, 858, 859, 860, 861, 862,
    863, 864, 865, 866, 867, 868, 869, 870, 871, 872, 873, 874,
    875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 886,
    887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898,
    899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910,
    911, 912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922,
    923, 924, 925, 926, 927, 928, 929, 930, 931, 932, 933, 934,
    935, 936, 937, 938, 939, 940, 941, 942, 943, 944, 945, 946,
    947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 957, 958,
    959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 970,
    971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 981, 982,
    983, 984, 985, 986, 987, 988, 989, 990, 991, 992, 993, 994,
    995, 996, 997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005,
    1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015,
    1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025,
    1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035,
    1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045,
    1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055,
    1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065,
    1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075,
    1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085,
    1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095,
    1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105,
    1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115,
    1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125,
    1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135,
    1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145,
    1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155,
    1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165,
    1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175,
    1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185,
    1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195,
    1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205,
    1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215,
    1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225,
    1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235,
    1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245,
    1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255,
    1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265,
    1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275,
    1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285,
    1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295,
    1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305,
    1306, 1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315,
    1316, 1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325,
    1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335,
    1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345,
    1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355,
    1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365,
    1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375,
    1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385,
    1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395,
    1396, 1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405,
    1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415,
    1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425,
    1426, 1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435,
    1436, 1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445,
    1446, 1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455,
    1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465,
    1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475,
    1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485,
    1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495,
    1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505,
    1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515,
    1516, 1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525,
    1526, 1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535,
    1536, 1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545,
    1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555,
    1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565,
    1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575,
    1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585,
    1586, 1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595,
    1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605,
    1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615,
    1616, 1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625,
    1626, 1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635,
    1636, 1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645,
    1646, 1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655,
    1656, 1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665,
    1666, 1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675,
    1676, 1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685,
    1686, 1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695,
    1696, 1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705,
    1706, 1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715,
    1716, 1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725,
    1726, 1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735,
    1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745,
    1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755,
    1756, 1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765,
    1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775,
    1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785,
    1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795,
    1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805,
    1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815,
    1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825,
    1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835,
    1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845,
    1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855,
    1856, 1857, 1887, 1918, 1948, 1978, 2009, 2039, 2070, 2100,
    2131, 2161, 2192, 2222, 2252, 2283, 2313, 2344, 2374, 2405,
    2435, 2465, 2496, 2526, 2557, 2587, 2618, 2648, 2678, 2709,
    2739, 2770, 2800, 2831, 2861, 2892, 2922, 2952, 2983, 3013,
    3044, 3074, 3105, 3135, 3166, 3196, 3226, 3257, 3287, 3318,
    3348, 3379, 3409, 3439, 3470, 3500, 3531, 3561, 3592, 3622,
    3652, 3683, 3713, 3744, 3774, 3805, 3835, 3866, 3896, 3926,
    3957, 3987, 4018, 4048, 4079, 4109, 4140, 4170, 4200, 4231,
    4261, 4292, 4322, 4353, 4383, 4413, 4444, 4474, 4505, 4535,
    4566, 4596, 4626, 4657, 4687, 4718, 4748, 4779, 4809, 4840,
    4870, 4900, 4931, 4961, 4992, 5022, 5053, 5083, 5114, 5144,
    5174, 5205, 5235, 5266, 5296, 5327, 5357, 5387, 5418, 5448,
    5479, 5509, 5540, 5570, 5600, 5631, 5661, 5692, 5722, 5753,
    5783, 5814, 5844, 5874, 5905, 5935, 5966, 5996, 6027, 6057,
    6088, 6118, 6148, 6179, 6209, 6240, 6270, 6301, 6331, 6361,
    6392, 6422, 6453, 6483, 6514, 6544, 6574, 6605, 6635, 6666,
    6696, 6727, 6757, 6788, 6818, 6848, 6879, 6909, 6940, 6970,
    731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 742,
    743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754,
    755, 756, 757, 758, 759, 760, 761, 762, 763, 764, 765, 766,
    767, 768, 769, 770, 771, 772, 773, 774, 775, 776, 777, 778,
    779, 780, 781, 782, 783, 784, 785, 786, 787, 788, 789, 790,
    791, 792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802,
    803, 804, 805, 806, 807, 808, 809, 810, 811, 812, 813, 814,
    815, 816, 817, 818, 819, 820, 821, 822, 823, 824, 825, 826,
    827, 828, 829, 830, 831, 832, 833, 834, 835, 836, 837, 838,
    839, 840, 841, 842, 843, 844, 845, 846, 847, 848, 849, 850,
    851, 852, 853, 854, 855, 856, 857, 858, 859, 860, 861, 862,
    863, 864, 865, 866, 867, 868, 869, 870, 871, 872, 873, 874,
    875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 886,
    887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898,
    899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910,
    911, 912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922,
    923, 924, 925, 926, 927, 928, 929, 930, 931, 932, 933, 934,
    935, 936, 937, 938, 939, 940, 941, 942, 943, 944, 945, 946,
    947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 957, 958,
    959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 970,
    971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 981, 982,
    983, 984, 985, 986, 987, 988, 989, 990, 991, 992, 993, 994,
    995, 996, 997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005,
    1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015,
    1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025,
    1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035,
    1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045,
    1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055,
    1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065,
    1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075,
    1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085,
    1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095,
    1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105,
    1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115,
    1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125,
    1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135,
    1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145,
    1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155,
    1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165,
    1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175,
    1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185,
    1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195,
    1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205,
    1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215,
    1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225,
    1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235,
    1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245,
    1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255,
    1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265,
    1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275,
    1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285,
    1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295,
    1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305,
    1306, 1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315,
    1316, 1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325,
    1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335,
    1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345,
    1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355,
    1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365,
    1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375,
    1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385,
    1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395,
    1396, 1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405,
    1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415,
    1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425,
    1426, 1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435,
    1436, 1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445,
    1446, 1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455,
    1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465,
    1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475,
    1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485,
    1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495,
    1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505,
    1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515,
    1516, 1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525,
    1526, 1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535,
    1536, 1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545,
    1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555,
    1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565,
    1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575,
    1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585,
    1586, 1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595,
    1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605,
    1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615,
    1616, 1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625,
    1626, 1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635,
    1636, 1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645,
    1646, 1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655,
    1656, 1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665,
    1666, 1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675,
    1676, 1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685,
    1686, 1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695,
    1696, 1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705,
    1706, 1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715,
    1716, 1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725,
    1726, 1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735,
    1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745,
    1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755,
    1756, 1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765,
    1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775,
    1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785,
    1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795,
    1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805,
    1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815,
    1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825,
    1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835,
    1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845,
    1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855,
    1856, 1857, 1887, 1918, 1948, 1978, 2009, 2039, 2070, 2100,
    2131, 2161, 2192, 2222, 2252, 2283, 2313, 2344, 2374, 2405,
    2435, 2465, 2496, 2526, 2557, 2587, 2618, 2648, 2678, 2709,
    2739, 2770, 2800, 2831, 2861, 2892, 2922, 2952, 2983, 3013,
    3044, 3074, 3105, 3135, 3166, 3196, 3226, 3257, 3287, 3318,
    3348, 3379, 3409, 3439, 3470, 3500, 3531, 3561, 3592, 3622,
    3652, 3683, 3713, 3744, 3774, 3805, 3835, 3866, 3896, 3926,
    3957, 3987, 4018, 4048, 4079, 4109, 4140, 4170, 4200, 4231,
    4261, 4292, 4322, 4353, 4383, 4413, 4444, 4474, 4505, 4535,
    4566, 4596, 4626, 4657, 4687, 4718, 4748, 4779, 4809, 4840,
    4870, 4900, 4931, 4961, 4992, 5022, 5053, 5083, 5114, 5144,
    5174, 5205, 5235, 5266, 5296, 5327, 5357, 5387, 5418, 5448,
    5479, 5509, 5540, 5570, 5600, 5631, 5661, 5692, 5722, 5753,
    5783, 5814, 5844, 5874, 5905, 5935, 5966, 5996, 6027, 6057,
    6088, 6118, 6148, 6179, 6209, 6240, 6270, 6301, 6331, 6361,
    6392, 6422, 6453, 6483, 6514, 6544, 6574, 6605, 6635, 6666,
    6696, 6727, 6757, 6788, 6818, 6848, 6879, 6909, 6940, 6970,
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
    17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
    32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46,
    47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
    62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76,
    77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91,
    92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104,
    105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116,
    117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128,
    129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
    141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
    153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164,
    165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176,
    177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188,
    189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200,
    201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212,
    213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
    225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236,
    237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248,
    249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260,
    261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272,
    273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284,
    285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296,
    297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308,
    309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320,
    321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332,
    333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344,
    345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356,
    357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368,
    369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380,
    381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392,
    393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404,
    405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416,
    417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428,
    429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440,
    441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452,
    453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463, 464,
    465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475, 476,
    477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487, 488,
    489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500,
    501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512,
    513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524,
    525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536,
    537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547, 548,
    549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560,
    561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572,
    573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584,
    585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596,
    597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608,
    609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620,
    621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632,
    633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643, 644,
    645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656,
    657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667, 668,
    669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679, 680,
    681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 692,
    693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704,
    705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716,
    717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728,
    729, 730, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14,
    15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
    30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44,
    45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
    60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74,
    75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89,
    90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103,
    104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115,
    116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127,
    128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139,
    140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151,
    152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163,
    164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175,
    176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187,
    188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199,
    200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211,
    212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223,
    224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235,
    236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247,
    248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259,
    260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271,
    272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283,
    284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295,
    296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307,
    308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319,
    320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331,
    332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343,
    344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355,
    356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367,
    368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379,
    380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391,
    392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403,
    404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415,
    416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427,
    428, 429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439,
    440, 441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451,
    452, 453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463,
    464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475,
    476, 477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487,
    488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499,
    500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511,
    512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523,
    524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535,
    536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547,
    548, 549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559,
    560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571,
    572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583,
    584, 585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595,
    596, 597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607,
    608, 609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619,
    620, 621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631,
    632, 633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643,
    644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655,
    656, 657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667,
    668, 669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679,
    680, 681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691,
    692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703,
    704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715,
    716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727,
    728, 729, 730, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101,
    102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
    114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125,
    126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137,
    138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
    150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161,
    162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173,
    174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185,
    186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197,
    198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209,
    210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221,
    222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233,
    234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245,
    246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257,
    258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269,
    270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281,
    282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293,
    294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305,
    306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317,
    318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329,
    330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341,
    342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353,
    354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365,
    366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377,
    378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389,
    390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401,
    402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412, 413,
    414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424, 425,
    426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436, 437,
    438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448, 449,
    450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 461,
    462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473,
    474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484, 485,
    486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496, 497,
    498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509,
    510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521,
    522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533,
    534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545,
    546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 557,
    558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569,
    570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581,
    582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592, 593,
    594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604, 605,
    606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616, 617,
    618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628, 629,
    630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 641,
    642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653,
    654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664, 665,
    666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676, 677,
    678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688, 689,
    690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700, 701,
    702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713,
    714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725,
    726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736, 737,
    738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749,
    750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760, 761,
    762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772, 773,
    774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785,
    786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797,
    798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 809,
    810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820, 821,
    822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832, 833,
    834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844, 845,
    846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 857,
    858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869,
    870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881,
    882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893,
    894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904, 905,
    906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916, 917,
    918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928, 929,
    930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940, 941,
    942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952, 953,
    954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965,
    966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977,
    978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988, 989,
    990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000, 1001,
    1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011,
    1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021,
    1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031,
    1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041,
    1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051,
    1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061,
    1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071,
    1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081,
    1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091,
    1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101,
    1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111,
    1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121,
    1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131,
    1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141,
    1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151,
    1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161,
    1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171,
    1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181,
    1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191,
    1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201,
    1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211,
    1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221,
    1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231,
    1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241,
    1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251,
    1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261,
    1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271,
    1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281,
    1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291,
    1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301,
    1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311,
    1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321,
    1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331,
    1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341,
    1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351,
    1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361,
    1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371,
    1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381,
    1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391,
    1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401,
    1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411,
    1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421,
    1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431,
    1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441,
    1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451,
    1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461,
    1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471,
    1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481,
    1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491,
    1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501,
    1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511,
    1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521,
    1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531,
    1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541,
    1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551,
    1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561,
    1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571,
    1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581,
    1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591,
    1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601,
    1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611,
    1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621,
    1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631,
    1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641,
    1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651,
    1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661,
    1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671,
    1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681,
    1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691,
    1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701,
    1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711,
    1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721,
    1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731,
    1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741,
    1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751,
    1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761,
    1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771,
    1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781,
    1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791,
    1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801,
    1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811,
    1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821,
    1822, 1823, 1824, 1825, 1825, 1826, 1827, 1828, 1829, 1830,
    1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840,
    1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850,
    1851, 1852, 1853, 1854, 1855, 1855, 1856, 1886, 1916, 1947,
    1977, 2008, 2038, 2068, 2099, 2129, 2160, 2190, 2220, 2251,
    2281, 2312, 2342, 2373, 2403, 2433, 2464, 2494, 2525, 2555,
    2585, 2616, 2646, 2677, 2707, 2738, 2768, 2798, 2829, 2859,
    2890, 2920, 2950, 2981, 3011, 3042, 3072, 3103, 3133, 3163,
    3194, 3224, 3255, 3285, 3315, 3346, 3376, 3407, 3437, 3468,
    3498, 3528, 3559, 3589, 3620, 3650, 3680, 3711, 3741, 3772,
    3802, 3833, 3863, 3893, 3924, 3954, 3985, 4015, 4045, 4076,
    4106, 4137, 4167, 4198, 4228, 4258, 4289, 4319, 4350, 4380,
    4410, 4441, 4471, 4502, 4532, 4563, 4593, 4623, 4654, 4684,
    4715, 4745, 4775, 4806, 4836, 4867, 4897, 4928, 4958, 4988,
    5019, 5049, 5080, 5110, 5140, 5171, 5201, 5232, 5262, 5293,
    5323, 5353, 5384, 5414, 5445, 5475, 5505, 5536, 5566, 5597,
    5627, 5658, 5688, 5718, 5749, 5779, 5810, 5840, 5870, 5901,
    5931, 5962, 5992, 6023, 6053, 6083, 6114, 6144, 6175, 6205,
    6235, 6266, 6296, 6327, 6357, 6388, 6418, 6448, 6479, 6509,
    6540, 6570, 6600, 6631, 6661, 6692, 6722, 6753, 6783, 6813,
    6844, 6874, 6905, 6935, 91, 92, 93, 94, 95, 96, 97, 98, 99,
    100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111,
    112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123,
    124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135,
    136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147,
    148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159,
    160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171,
    172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183,
    184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195,
    196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207,
    208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219,
    220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231,
    232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243,
    244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255,
    256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267,
    268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279,
    280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291,
    292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303,
    304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315,
    316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327,
    328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339,
    340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351,
    352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363,
    364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375,
    376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387,
    388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399,
    400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411,
    412, 413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423,
    424, 425, 426, 427, 428, 429, 430, 431, 432, 433, 434, 435,
    436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447,
    448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459,
    460, 461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471,
    472, 473, 474, 475, 476, 477, 478, 479, 480, 481, 482, 483,
    484, 485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495,
    496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507,
    508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519,
    520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531,
    532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543,
    544, 545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555,
    556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567,
    568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579,
    580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591,
    592, 593, 594, 595, 596, 597, 598, 599, 600, 601, 602, 603,
    604, 605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615,
    616, 617, 618, 619, 620, 621, 622, 623, 624, 625, 626, 627,
    628, 629, 630, 631, 632, 633, 634, 635, 636, 637, 638, 639,
    640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651,
    652, 653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663,
    664, 665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675,
    676, 677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687,
    688, 689, 690, 691, 692, 693, 694, 695, 696, 697, 698, 699,
    700, 701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711,
    712, 713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723,
    724, 725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735,
    736, 737, 738, 739, 740, 741, 742, 743, 744, 745, 746, 747,
    748, 749, 750, 751, 752, 753, 754, 755, 756, 757, 758, 759,
    760, 761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771,
    772, 773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783,
    784, 785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795,
    796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807,
    808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
    820, 821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831,
    832, 833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843,
    844, 845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855,
    856, 857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867,
    868, 869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879,
    880, 881, 882, 883, 884, 885, 886, 887, 888, 889, 890, 891,
    892, 893, 894, 895, 896, 897, 898, 899, 900, 901, 902, 903,
    904, 905, 906, 907, 908, 909, 910, 911, 912, 913, 914, 915,
    916, 917, 918, 919, 920, 921, 922, 923, 924, 925, 926, 927,
    928, 929, 930, 931, 932, 933, 934, 935, 936, 937, 938, 939,
    940, 941, 942, 943, 944, 945, 946, 947, 948, 949, 950, 951,
    952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963,
    964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975,
    976, 977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987,
    988, 989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999,
    1000, 1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009,
    1010, 1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019,
    1020, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029,
    1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039,
    1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049,
    1050, 1051, 1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059,
    1060, 1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069,
    1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079,
    1080, 1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089,
    1090, 1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099,
    1100, 1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109,
    1110, 1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119,
    1120, 1121, 1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129,
    1130, 1131, 1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139,
    1140, 1141, 1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149,
    1150, 1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159,
    1160, 1161, 1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169,
    1170, 1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179,
    1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189,
    1190, 1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199,
    1200, 1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209,
    1210, 1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219,
    1220, 1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229,
    1230, 1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239,
    1240, 1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249,
    1250, 1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259,
    1260, 1261, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269,
    1270, 1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279,
    1280, 1281, 1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289,
    1290, 1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299,
    1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309,
    1310, 1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319,
    1320, 1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329,
    1330, 1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339,
    1340, 1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349,
    1350, 1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359,
    1360, 1361, 1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369,
    1370, 1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379,
    1380, 1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389,
    1390, 1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399,
    1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409,
    1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419,
    1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429,
    1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439,
    1440, 1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449,
    1450, 1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459,
    1460, 1461, 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469,
    1470, 1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479,
    1480, 1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489,
    1490, 1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499,
    1500, 1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509,
    1510, 1511, 1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519,
    1520, 1521, 1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529,
    1530, 1531, 1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539,
    1540, 1541, 1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549,
    1550, 1551, 1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559,
    1560, 1561, 1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569,
    1570, 1571, 1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579,
    1580, 1581, 1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589,
    1590, 1591, 1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599,
    1600, 1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609,
    1610, 1611, 1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619,
    1620, 1621, 1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629,
    1630, 1631, 1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639,
    1640, 1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649,
    1650, 1651, 1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659,
    1660, 1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669,
    1670, 1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679,
    1680, 1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689,
    1690, 1691, 1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699,
    1700, 1701, 1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709,
    1710, 1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719,
    1720, 1721, 1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729,
    1730, 1731, 1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739,
    1740, 1741, 1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749,
    1750, 1751, 1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759,
    1760, 1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769,
    1770, 1771, 1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779,
    1780, 1781, 1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789,
    1790, 1791, 1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799,
    1800, 1801, 1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809,
    1810, 1811, 1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819,
    1820, 1821, 1822, 1823, 1824, 1825, 1825, 1826, 1827, 1828,
    1829, 1830, 1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838,
    1839, 1840, 1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848,
    1849, 1850, 1851, 1852, 1853, 1854, 1855, 1855, 1856, 1886,
    1916, 1947, 1977, 2008, 2038, 2068, 2099, 2129, 2160, 2190,
    2220, 2251, 2281, 2312, 2342, 2373, 2403, 2433, 2464, 2494,
    2525, 2555, 2585, 2616, 2646, 2677, 2707, 2738, 2768, 2798,
    2829, 2859, 2890, 2920, 2950, 2981, 3011, 3042, 3072, 3103,
    3133, 3163, 3194, 3224, 3255, 3285, 3315, 3346, 3376, 3407,
    3437, 3468, 3498, 3528, 3559, 3589, 3620, 3650, 3680, 3711,
    3741, 3772, 3802, 3833, 3863, 3893, 3924, 3954, 3985, 4015,
    4045, 4076, 4106, 4137, 4167, 4198, 4228, 4258, 4289, 4319,
    4350, 4380, 4410, 4441, 4471, 4502, 4532, 4563, 4593, 4623,
    4654, 4684, 4715, 4745, 4775, 4806, 4836, 4867, 4897, 4928,
    4958, 4988, 5019, 5049, 5080, 5110, 5140, 5171, 5201, 5232,
    5262, 5293, 5323, 5353, 5384, 5414, 5445, 5475, 5505, 5536,
    5566, 5597, 5627, 5658, 5688, 5718, 5749, 5779, 5810, 5840,
    5870, 5901, 5931, 5962, 5992, 6023, 6053, 6083, 6114, 6144,
    6175, 6205, 6235, 6266, 6296, 6327, 6357, 6388, 6418, 6448,
    6479, 6509, 6540, 6570, 6600, 6631, 6661, 6692, 6722, 6753,
    6783, 6813, 6844, 6874, 6905, 6935, 91, 92, 93, 94, 95, 96,
    97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108,
    109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
    121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132,
    133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144,
    145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156,
    157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
    169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180,
    181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192,
    193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204,
    205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216,
    217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228,
    229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240,
    241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252,
    253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264,
    265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276,
    277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288,
    289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300,
    301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312,
    313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324,
    325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336,
    337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348,
    349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360,
    361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372,
    373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384,
    385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396,
    397, 398, 399, 400, 401, 402, 403, 404, 405, 406, 407, 408,
    409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420,
    421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432,
    433, 434, 435, 436, 437, 438, 439, 440, 441, 442, 443, 444,
    445, 446, 447, 448, 449, 450, 451, 452, 453, 454, 455, 456,
    457, 458, 459, 460, 461, 462, 463, 464, 465, 466, 467, 468,
    469, 470, 471, 472, 473, 474, 475, 476, 477, 478, 479, 480,
    481, 482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492,
    493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504,
    505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
    517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528,
    529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540,
    541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552,
    553, 554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564,
    565, 566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576,
    577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588,
    589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600,
    601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 612,
    613, 614, 615, 616, 617, 618, 619, 620, 621, 622, 623, 624,
    625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 635, 636,
    637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648,
    649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660,
    661, 662, 663, 664, 665, 666, 667, 668, 669, 670, 671, 672,
    673, 674, 675, 676, 677, 678, 679, 680, 681, 682, 683, 684,
    685, 686, 687, 688, 689, 690, 691, 692, 693, 694, 695, 696,
    697, 698, 699, 700, 701, 702, 703, 704, 705, 706, 707, 708,
    709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 719, 720,
    721, 722, 723, 724, 725, 726, 727, 728, 729, 730, 731, 732,
    733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 744,
    745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756,
    757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 768,
    769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780,
    781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 791, 792,
    793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804,
    805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816,
    817, 818, 819, 820, 821, 822, 823, 824, 825, 826, 827, 828,
    829, 830, 831, 832, 833, 834, 835, 836, 837, 838, 839, 840,
    841, 842, 843, 844, 845, 846, 847, 848, 849, 850, 851, 852,
    853, 854, 855, 856, 857, 858, 859, 860, 861, 862, 863, 864,
    865, 866, 867, 868, 869, 870, 871, 872, 873, 874, 875, 876,
    877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 887, 888,
    889, 890, 891, 892, 893, 894, 895, 896, 897, 898, 899, 900,
    901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 912,
    913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924,
    925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 935, 936,
    937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948,
    949, 950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960,
    961, 962, 963, 964, 965, 966, 967, 968, 969, 970, 971, 972,
    973, 974, 975, 976, 977, 978, 979, 980, 981, 982, 983, 984,
    985, 986, 987, 988, 989, 990, 991, 992, 993, 994, 995, 996,
    997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
    1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016,
    1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026,
    1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036,
    1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046,
    1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056,
    1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066,
    1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076,
    1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086,
    1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096,
    1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106,
    1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116,
    1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125, 1126,
    1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135, 1136,
    1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145, 1146,
    1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156,
    1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166,
    1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176,
    1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186,
    1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196,
    1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206,
    1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215, 1216,
    1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225, 1226,
    1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235, 1236,
    1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245, 1246,
    1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255, 1256,
    1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265, 1266,
    1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 1276,
    1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285, 1286,
    1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295, 1296,
    1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305, 1306,
    1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315, 1316,
    1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325, 1326,
    1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335, 1336,
    1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345, 1346,
    1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355, 1356,
    1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365, 1366,
    1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375, 1376,
    1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385, 1386,
    1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395, 1396,
    1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406,
    1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416,
    1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426,
    1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436,
    1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445, 1446,
    1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455, 1456,
    1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465, 1466,
    1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475, 1476,
    1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485, 1486,
    1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495, 1496,
    1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505, 1506,
    1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515, 1516,
    1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525, 1526,
    1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535, 1536,
    1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545, 1546,
    1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555, 1556,
    1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565, 1566,
    1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575, 1576,
    1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585, 1586,
    1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595, 1596,
    1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 1606,
    1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616,
    1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626,
    1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635, 1636,
    1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645, 1646,
    1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655, 1656,
    1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665, 1666,
    1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676,
    1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685, 1686,
    1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695, 1696,
    1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705, 1706,
    1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715, 1716,
    1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725, 1726,
    1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735, 1736,
    1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745, 1746,
    1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755, 1756,
    1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765, 1766,
    1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775, 1776,
    1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785, 1786,
    1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795, 1796,
    1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 1806,
    1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815, 1816,
    1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825, 1826,
    1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835, 1836,
    1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845, 1846,
    1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855, 1856,
    91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104,
    105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116,
    117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128,
    129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
    141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
    153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164,
    165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176,
    177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188,
    189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200,
    201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212,
    213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
    225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236,
    237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248,
    249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260,
    261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272,
    273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284,
    285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296,
    297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308,
    309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320,
    321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332,
    333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344,
    345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356,
    357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368,
    369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380,
    381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392,
    393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404,
    405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416,
    417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428,
    429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440,
    441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452,
    453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463, 464,
    465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475, 476,
    477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487, 488,
    489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500,
    501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512,
    513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524,
    525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536,
    537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547, 548,
    549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560,
    561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572,
    573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584,
    585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596,
    597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608,
    609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620,
    621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632,
    633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643, 644,
    645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656,
    657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667, 668,
    669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679, 680,
    681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 692,
    693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704,
    705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716,
    717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728,
    729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740,
    741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752,
    753, 754, 755, 756, 757, 758, 759, 760, 761, 762, 763, 764,
    765, 766, 767, 768, 769, 770, 771, 772, 773, 774, 775, 776,
    777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 788,
    789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 800,
    801, 802, 803, 804, 805, 806, 807, 808, 809, 810, 811, 812,
    813, 814, 815, 816, 817, 818, 819, 820, 821, 822, 823, 824,
    825, 826, 827, 828, 829, 830, 831, 832, 833, 834, 835, 836,
    837, 838, 839, 840, 841, 842, 843, 844, 845, 846, 847, 848,
    849, 850, 851, 852, 853, 854, 855, 856, 857, 858, 859, 860,
    861, 862, 863, 864, 865, 866, 867, 868, 869, 870, 871, 872,
    873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884,
    885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896,
    897, 898, 899, 900, 901, 902, 903, 904, 905, 906, 907, 908,
    909, 910, 911, 912, 913, 914, 915, 916, 917, 918, 919, 920,
    921, 922, 923, 924, 925, 926, 927, 928, 929, 930, 931, 932,
    933, 934, 935, 936, 937, 938, 939, 940, 941, 942, 943, 944,
    945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956,
    957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968,
    969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980,
    981, 982, 983, 984, 985, 986, 987, 988, 989, 990, 991, 992,
    993, 994, 995, 996, 997, 998, 999, 1000, 1001, 1002, 1003,
    1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013,
    1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023,
    1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033,
    1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043,
    1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053,
    1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063,
    1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073,
    1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083,
    1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093,
    1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103,
    1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113,
    1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123,
    1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133,
    1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143,
    1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153,
    1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163,
    1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173,
    1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183,
    1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193,
    1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203,
    1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213,
    1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223,
    1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233,
    1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243,
    1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253,
    1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263,
    1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273,
    1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283,
    1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293,
    1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303,
    1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312, 1313,
    1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321, 1322, 1323,
    1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333,
    1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343,
    1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353,
    1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363,
    1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373,
    1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383,
    1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393,
    1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401, 1402, 1403,
    1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413,
    1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423,
    1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431, 1432, 1433,
    1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441, 1442, 1443,
    1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451, 1452, 1453,
    1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463,
    1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473,
    1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483,
    1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493,
    1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503,
    1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513,
    1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521, 1522, 1523,
    1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531, 1532, 1533,
    1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541, 1542, 1543,
    1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553,
    1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563,
    1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573,
    1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583,
    1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591, 1592, 1593,
    1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603,
    1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613,
    1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621, 1622, 1623,
    1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631, 1632, 1633,
    1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641, 1642, 1643,
    1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651, 1652, 1653,
    1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661, 1662, 1663,
    1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671, 1672, 1673,
    1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681, 1682, 1683,
    1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691, 1692, 1693,
    1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701, 1702, 1703,
    1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711, 1712, 1713,
    1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721, 1722, 1723,
    1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732, 1733,
    1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743,
    1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753,
    1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762, 1763,
    1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773,
    1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783,
    1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793,
    1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803,
    1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813,
    1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823,
    1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833,
    1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843,
    1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853,
    1854, 1855, 1856, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
    101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112,
    113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
    125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
    137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148,
    149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160,
    161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172,
    173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184,
    185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196,
    197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208,
    209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220,
    221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232,
    233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244,
    245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256,
    257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268,
    269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280,
    281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292,
    293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304,
    305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316,
    317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328,
    329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340,
    341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352,
    353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364,
    365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376,
    377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388,
    389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400,
    401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412,
    413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424,
    425, 426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436,
    437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448,
    449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460,
    461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472,
    473, 474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484,
    485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496,
    497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508,
    509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520,
    521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532,
    533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544,
    545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556,
    557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568,
    569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580,
    581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592,
    593, 594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604,
    605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616,
    617, 618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628,
    629, 630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640,
    641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652,
    653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664,
    665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676,
    677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688,
    689, 690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700,
    701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712,
    713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724,
    725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736,
    737, 738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748,
    749, 750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760,
    761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772,
    773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784,
    785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796,
    797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808,
    809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820,
    821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832,
    833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844,
    845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856,
    857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868,
    869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880,
    881, 882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892,
    893, 894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904,
    905, 906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916,
    917, 918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928,
    929, 930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940,
    941, 942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952,
    953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964,
    965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976,
    977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988,
    989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000,
    1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010,
    1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020,
    1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030,
    1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040,
    1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050,
    1051, 1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060,
    1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070,
    1071, 1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080,
    1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090,
    1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100,
    1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110,
    1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120,
    1121, 1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130,
    1131, 1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140,
    1141, 1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150,
    1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160,
    1161, 1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170,
    1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180,
    1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190,
    1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200,
    1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210,
    1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220,
    1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230,
    1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240,
    1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250,
    1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260,
    1261, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270,
    1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280,
    1281, 1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290,
    1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300,
    1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310,
    1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320,
    1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330,
    1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340,
    1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350,
    1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360,
    1361, 1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370,
    1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380,
    1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390,
    1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400,
    1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410,
    1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420,
    1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430,
    1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440,
    1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450,
    1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460,
    1461, 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470,
    1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480,
    1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490,
    1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500,
    1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510,
    1511, 1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520,
    1521, 1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530,
    1531, 1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540,
    1541, 1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550,
    1551, 1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560,
    1561, 1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570,
    1571, 1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580,
    1581, 1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590,
    1591, 1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600,
    1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610,
    1611, 1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620,
    1621, 1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630,
    1631, 1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640,
    1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650,
    1651, 1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660,
    1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670,
    1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680,
    1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690,
    1691, 1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700,
    1701, 1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710,
    1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720,
    1721, 1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730,
    1731, 1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740,
    1741, 1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750,
    1751, 1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760,
    1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770,
    1771, 1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780,
    1781, 1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790,
    1791, 1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800,
    1801, 1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810,
    1811, 1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820,
    1821, 1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830,
    1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840,
    1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850,
    1851, 1852, 1853, 1854, 1855, 1856, 91, 92, 93, 94, 95, 96,
    97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108,
    109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
    121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132,
    133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144,
    145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156,
    157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
    169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180,
    181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192,
    193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204,
    205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216,
    217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228,
    229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240,
    241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252,
    253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264,
    265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276,
    277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288,
    289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300,
    301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312,
    313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324,
    325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336,
    337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348,
    349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360,
    361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372,
    373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384,
    385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396,
    397, 398, 399, 400, 401, 402, 403, 404, 405, 406, 407, 408,
    409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420,
    421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432,
    433, 434, 435, 436, 437, 438, 439, 440, 441, 442, 443, 444,
    445, 446, 447, 448, 449, 450, 451, 452, 453, 454, 455, 456,
    457, 458, 459, 460, 461, 462, 463, 464, 465, 466, 467, 468,
    469, 470, 471, 472, 473, 474, 475, 476, 477, 478, 479, 480,
    481, 482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492,
    493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504,
    505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
    517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528,
    529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540,
    541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552,
    553, 554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564,
    565, 566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576,
    577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588,
    589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600,
    601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 612,
    613, 614, 615, 616, 617, 618, 619, 620, 621, 622, 623, 624,
    625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 635, 636,
    637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648,
    649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660,
    661, 662, 663, 664, 665, 666, 667, 668, 669, 670, 671, 672,
    673, 674, 675, 676, 677, 678, 679, 680, 681, 682, 683, 684,
    685, 686, 687, 688, 689, 690, 691, 692, 693, 694, 695, 696,
    697, 698, 699, 700, 701, 702, 703, 704, 705, 706, 707, 708,
    709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 719, 720,
    721, 722, 723, 724, 725, 726, 727, 728, 729, 730, 731, 732,
    733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 744,
    745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756,
    757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 768,
    769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780,
    781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 791, 792,
    793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804,
    805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816,
    817, 818, 819, 820, 821, 822, 823, 824, 825, 826, 827, 828,
    829, 830, 831, 832, 833, 834, 835, 836, 837, 838, 839, 840,
    841, 842, 843, 844, 845, 846, 847, 848, 849, 850, 851, 852,
    853, 854, 855, 856, 857, 858, 859, 860, 861, 862, 863, 864,
    865, 866, 867, 868, 869, 870, 871, 872, 873, 874, 875, 876,
    877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 887, 888,
    889, 890, 891, 892, 893, 894, 895, 896, 897, 898, 899, 900,
    901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 912,
    913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924,
    925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 935, 936,
    937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948,
    949, 950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960,
    961, 962, 963, 964, 965, 966, 967, 968, 969, 970, 971, 972,
    973, 974, 975, 976, 977, 978, 979, 980, 981, 982, 983, 984,
    985, 986, 987, 988, 989, 990, 991, 992, 993, 994, 995, 996,
    997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
    1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016,
    1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026,
    1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036,
    1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046,
    1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056,
    1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066,
    1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076,
    1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086,
    1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096,
    1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106,
    1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116,
    1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125, 1126,
    1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135, 1136,
    1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145, 1146,
    1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156,
    1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166,
    1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176,
    1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186,
    1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196,
    1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206,
    1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215, 1216,
    1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225, 1226,
    1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235, 1236,
    1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245, 1246,
    1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255, 1256,
    1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265, 1266,
    1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 1276,
    1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285, 1286,
    1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295, 1296,
    1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305, 1306,
    1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315, 1316,
    1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325, 1326,
    1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335, 1336,
    1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345, 1346,
    1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355, 1356,
    1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365, 1366,
    1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375, 1376,
    1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385, 1386,
    1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395, 1396,
    1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406,
    1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416,
    1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426,
    1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436,
    1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445, 1446,
    1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455, 1456,
    1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465, 1466,
    1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475, 1476,
    1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485, 1486,
    1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495, 1496,
    1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505, 1506,
    1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515, 1516,
    1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525, 1526,
    1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535, 1536,
    1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545, 1546,
    1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555, 1556,
    1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565, 1566,
    1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575, 1576,
    1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585, 1586,
    1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595, 1596,
    1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 1606,
    1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616,
    1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626,
    1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635, 1636,
    1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645, 1646,
    1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655, 1656,
    1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665, 1666,
    1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676,
    1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685, 1686,
    1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695, 1696,
    1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705, 1706,
    1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715, 1716,
    1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725, 1726,
    1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735, 1736,
    1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745, 1746,
    1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755, 1756,
    1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765, 1766,
    1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775, 1776,
    1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785, 1786,
    1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795, 1796,
    1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 1806,
    1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815, 1816,
    1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825, 1826,
    1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835, 1836,
    1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845, 1846,
    1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855, 1856,
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
    17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
    32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46,
    47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
    62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76,
    77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91,
    92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104,
    105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116,
    117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128,
    129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
    141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
    153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164,
    165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176,
    177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188,
    189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200,
    201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212,
    213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
    225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236,
    237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248,
    249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260,
    261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272,
    273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284,
    285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296,
    297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308,
    309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320,
    321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332,
    333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344,
    345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356,
    357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368,
    369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380,
    381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392,
    393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404,
    405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416,
    417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428,
    429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440,
    441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452,
    453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463, 464,
    465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475, 476,
    477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487, 488,
    489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500,
    501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512,
    513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524,
    525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536,
    537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547, 548,
    549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560,
    561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572,
    573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584,
    585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596,
    597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608,
    609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620,
    621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632,
    633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643, 644,
    645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656,
    657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667, 668,
    669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679, 680,
    681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 692,
    693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704,
    705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716,
    717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728,
    729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740,
    741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752,
    753, 754, 755, 756, 757, 758, 759, 760, 761, 762, 763, 764,
    765, 766, 767, 768, 769, 770, 771, 772, 773, 774, 775, 776,
    777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 788,
    789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 800,
    801, 802, 803, 804, 805, 806, 807, 808, 809, 810, 811, 812,
    813, 814, 815, 816, 817, 818, 819, 820, 821, 822, 823, 824,
    825, 826, 827, 828, 829, 830, 831, 832, 833, 834, 835, 836,
    837, 838, 839, 840, 841, 842, 843, 844, 845, 846, 847, 848,
    849, 850, 851, 852, 853, 854, 855, 856, 857, 858, 859, 860,
    861, 862, 863, 864, 865, 866, 867, 868, 869, 870, 871, 872,
    873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884,
    885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896,
    897, 898, 899, 900, 901, 902, 903, 904, 905, 906, 907, 908,
    909, 910, 911, 912, 913, 914, 915, 916, 917, 918, 919, 920,
    921, 922, 923, 924, 925, 926, 927, 928, 929, 930, 931, 932,
    933, 934, 935, 936, 937, 938, 939, 940, 941, 942, 943, 944,
    945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956,
    957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968,
    969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980,
    981, 982, 983, 984, 985, 986, 987, 988, 989, 990, 991, 992,
    993, 994, 995, 996, 997, 998, 999, 1000, 1001, 1002, 1003,
    1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013,
    1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023,
    1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033,
    1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043,
    1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053,
    1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063,
    1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073,
    1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083,
    1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093,
    1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103,
    1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113,
    1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123,
    1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133,
    1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143,
    1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153,
    1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163,
    1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173,
    1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183,
    1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193,
    1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203,
    1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213,
    1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223,
    1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233,
    1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243,
    1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253,
    1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263,
    1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273,
    1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283,
    1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293,
    1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303,
    1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312, 1313,
    1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321, 1322, 1323,
    1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333,
    1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343,
    1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353,
    1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363,
    1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373,
    1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383,
    1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393,
    1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401, 1402, 1403,
    1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413,
    1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423,
    1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431, 1432, 1433,
    1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441, 1442, 1443,
    1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451, 1452, 1453,
    1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463,
    1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473,
    1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483,
    1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493,
    1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503,
    1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513,
    1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521, 1522, 1523,
    1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531, 1532, 1533,
    1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541, 1542, 1543,
    1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553,
    1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563,
    1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573,
    1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583,
    1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591, 1592, 1593,
    1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603,
    1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613,
    1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621, 1622, 1623,
    1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631, 1632, 1633,
    1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641, 1642, 1643,
    1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651, 1652, 1653,
    1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661, 1662, 1663,
    1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671, 1672, 1673,
    1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681, 1682, 1683,
    1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691, 1692, 1693,
    1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701, 1702, 1703,
    1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711, 1712, 1713,
    1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721, 1722, 1723,
    1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732, 1733,
    1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743,
    1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753,
    1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762, 1763,
    1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773,
    1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783,
    1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793,
    1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803,
    1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813,
    1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823,
    1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833,
    1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843,
    1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853,
    1854, 1855, 1856, 1857, 1887, 1918, 1948, 1978, 2009, 2039,
    2070, 2100, 2131, 2161, 2192, 2222, 2252, 2283, 2313, 2344,
    2374, 2405, 2435, 2465, 2496, 2526, 2557, 2587, 2618, 2648,
    2678, 2709, 2739, 2770, 2800, 2831, 2861, 2892, 2922, 2952,
    2983, 3013, 3044, 3074, 3105, 3135, 3166, 3196, 3226, 3257,
    3287, 3318, 3348, 3379, 3409, 3439, 3470, 3500, 3531, 3561,
    3592, 3622, 3652, 3683, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
    11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25,
    26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
    56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70,
    71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85,
    86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
    101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112,
    113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
    125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
    137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148,
    149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160,
    161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172,
    173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184,
    185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196,
    197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208,
    209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220,
    221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232,
    233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244,
    245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256,
    257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268,
    269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280,
    281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292,
    293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304,
    305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316,
    317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328,
    329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340,
    341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352,
    353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364,
    365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376,
    377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388,
    389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400,
    401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412,
    413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424,
    425, 426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436,
    437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448,
    449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460,
    461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472,
    473, 474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484,
    485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496,
    497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508,
    509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520,
    521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532,
    533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544,
    545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556,
    557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568,
    569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580,
    581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592,
    593, 594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604,
    605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616,
    617, 618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628,
    629, 630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640,
    641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652,
    653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664,
    665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676,
    677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688,
    689, 690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700,
    701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712,
    713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724,
    725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736,
    737, 738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748,
    749, 750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760,
    761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772,
    773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784,
    785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796,
    797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808,
    809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820,
    821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832,
    833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844,
    845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856,
    857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868,
    869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880,
    881, 882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892,
    893, 894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904,
    905, 906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916,
    917, 918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928,
    929, 930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940,
    941, 942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952,
    953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964,
    965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976,
    977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988,
    989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000,
    1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010,
    1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020,
    1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030,
    1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040,
    1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050,
    1051, 1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060,
    1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070,
    1071, 1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080,
    1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090,
    1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100,
    1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110,
    1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120,
    1121, 1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130,
    1131, 1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140,
    1141, 1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150,
    1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160,
    1161, 1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170,
    1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180,
    1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190,
    1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200,
    1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210,
    1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220,
    1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230,
    1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240,
    1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250,
    1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260,
    1261, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270,
    1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280,
    1281, 1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290,
    1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300,
    1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310,
    1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320,
    1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330,
    1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340,
    1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350,
    1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360,
    1361, 1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370,
    1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380,
    1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390,
    1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400,
    1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410,
    1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420,
    1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430,
    1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440,
    1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450,
    1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460,
    1461, 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470,
    1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480,
    1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490,
    1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500,
    1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510,
    1511, 1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520,
    1521, 1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530,
    1531, 1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540,
    1541, 1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550,
    1551, 1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560,
    1561, 1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570,
    1571, 1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580,
    1581, 1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590,
    1591, 1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600,
    1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610,
    1611, 1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620,
    1621, 1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630,
    1631, 1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640,
    1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650,
    1651, 1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660,
    1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670,
    1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680,
    1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690,
    1691, 1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700,
    1701, 1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710,
    1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720,
    1721, 1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730,
    1731, 1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740,
    1741, 1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750,
    1751, 1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760,
    1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770,
    1771, 1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780,
    1781, 1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790,
    1791, 1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800,
    1801, 1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810,
    1811, 1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820,
    1821, 1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830,
    1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840,
    1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850,
    1851, 1852, 1853, 1854, 1855, 1856, 1857, 1887, 1918, 1948,
    1978, 2009, 2039, 2070, 2100, 2131, 2161, 2192, 2222, 2252,
    2283, 2313, 2344, 2374, 2405, 2435, 2465, 2496, 2526, 2557,
    2587, 2618, 2648, 2678, 2709, 2739, 2770, 2800, 2831, 2861,
    2892, 2922, 2952, 2983, 3013, 3044, 3074, 3105, 3135, 3166,
    3196, 3226, 3257, 3287, 3318, 3348, 3379, 3409, 3439, 3470,
    3500, 3531, 3561, 3592, 3622, 3652, 3683, 45, 45.1, 45.2,
    45.3, 45.4, 45.5, 45.6, 45.7, 45.8, 45.9, 46, 46.1, 46.2,
    46.3, 46.4, 46.5, 46.6, 46.7, 46.8, 46.9, 47, 47.1, 47.2,
    47.3, 47.4, 47.5, 47.6, 47.7, 47.8, 47.9, 48, 48.1, 48.2,
    48.3, 48.4, 48.5, 48.6, 48.7, 48.8, 48.9, 49, 49.1, 49.2,
    49.3, 49.4, 49.5, 49.6, 49.7, 49.8, 49.9, 50, 50.1, 50.2,
    50.3, 50.4, 50.5, 50.6, 50.7, 50.8, 50.9, 51, 51.1, 51.2,
    51.3, 51.4, 51.5, 51.6, 51.7, 51.8, 51.9, 52, 52.1, 52.2,
    52.3, 52.4, 52.5, 52.6, 52.7, 52.8, 52.9, 53, 53.1, 53.2,
    53.3, 53.4, 53.5, 53.6, 53.7, 53.8, 53.9, 54, 54.1, 54.2,
    54.3, 54.4, 54.5, 54.6, 54.7, 54.8, 54.9, 55, 55.1, 55.2,
    55.3, 55.4, 55.5, 55.6, 55.7, 55.8, 55.9, 56, 56.1, 56.2,
    56.3, 56.4, 56.5, 56.6, 56.7, 56.8, 56.9, 57, 57.1, 57.2,
    57.3, 57.4, 57.5, 57.6, 57.7, 57.8, 57.9, 58, 58.1, 58.2,
    58.3, 58.4, 58.5, 58.6, 58.7, 58.8, 58.9, 59, 59.1, 59.2,
    59.3, 59.4, 59.5, 59.6, 59.7, 59.8, 59.9, 60, 60.1, 60.2,
    60.3, 60.4, 60.5, 60.6, 60.7, 60.8, 60.9, 61, 61.1, 61.2,
    61.3, 61.4, 61.5, 61.6, 61.7, 61.8, 61.9, 62, 62.1, 62.2,
    62.3, 62.4, 62.5, 62.6, 62.7, 62.8, 62.9, 63, 63.1, 63.2,
    63.3, 63.4, 63.5, 63.6, 63.7, 63.8, 63.9, 64, 64.1, 64.2,
    64.3, 64.4, 64.5, 64.6, 64.7, 64.8, 64.9, 65, 65.1, 65.2,
    65.3, 65.4, 65.5, 65.6, 65.7, 65.8, 65.9, 66, 66.1, 66.2,
    66.3, 66.4, 66.5, 66.6, 66.7, 66.8, 66.9, 67, 67.1, 67.2,
    67.3, 67.4, 67.5, 67.6, 67.7, 67.8, 67.9, 68, 68.1, 68.2,
    68.3, 68.4, 68.5, 68.6, 68.7, 68.8, 68.9, 69, 69.1, 69.2,
    69.3, 69.4, 69.5, 69.6, 69.7, 69.8, 69.9, 70, 70.1, 70.2,
    70.3, 70.4, 70.5, 70.6, 70.7, 70.8, 70.9, 71, 71.1, 71.2,
    71.3, 71.4, 71.5, 71.6, 71.7, 71.8, 71.9, 72, 72.1, 72.2,
    72.3, 72.4, 72.5, 72.6, 72.7, 72.8, 72.9, 73, 73.1, 73.2,
    73.3, 73.4, 73.5, 73.6, 73.7, 73.8, 73.9, 74, 74.1, 74.2,
    74.3, 74.4, 74.5, 74.6, 74.7, 74.8, 74.9, 75, 75.1, 75.2,
    75.3, 75.4, 75.5, 75.6, 75.7, 75.8, 75.9, 76, 76.1, 76.2,
    76.3, 76.4, 76.5, 76.6, 76.7, 76.8, 76.9, 77, 77.1, 77.2,
    77.3, 77.4, 77.5, 77.6, 77.7, 77.8, 77.9, 78, 78.1, 78.2,
    78.3, 78.4, 78.5, 78.6, 78.7, 78.8, 78.9, 79, 79.1, 79.2,
    79.3, 79.4, 79.5, 79.6, 79.7, 79.8, 79.9, 80, 80.1, 80.2,
    80.3, 80.4, 80.5, 80.6, 80.7, 80.8, 80.9, 81, 81.1, 81.2,
    81.3, 81.4, 81.5, 81.6, 81.7, 81.8, 81.9, 82, 82.1, 82.2,
    82.3, 82.4, 82.5, 82.6, 82.7, 82.8, 82.9, 83, 83.1, 83.2,
    83.3, 83.4, 83.5, 83.6, 83.7, 83.8, 83.9, 84, 84.1, 84.2,
    84.3, 84.4, 84.5, 84.6, 84.7, 84.8, 84.9, 85, 85.1, 85.2,
    85.3, 85.4, 85.5, 85.6, 85.7, 85.8, 85.9, 86, 86.1, 86.2,
    86.3, 86.4, 86.5, 86.6, 86.7, 86.8, 86.9, 87, 87.1, 87.2,
    87.3, 87.4, 87.5, 87.6, 87.7, 87.8, 87.9, 88, 88.1, 88.2,
    88.3, 88.4, 88.5, 88.6, 88.7, 88.8, 88.9, 89, 89.1, 89.2,
    89.3, 89.4, 89.5, 89.6, 89.7, 89.8, 89.9, 90, 90.1, 90.2,
    90.3, 90.4, 90.5, 90.6, 90.7, 90.8, 90.9, 91, 91.1, 91.2,
    91.3, 91.4, 91.5, 91.6, 91.7, 91.8, 91.9, 92, 92.1, 92.2,
    92.3, 92.4, 92.5, 92.6, 92.7, 92.8, 92.9, 93, 93.1, 93.2,
    93.3, 93.4, 93.5, 93.6, 93.7, 93.8, 93.9, 94, 94.1, 94.2,
    94.3, 94.4, 94.5, 94.6, 94.7, 94.8, 94.9, 95, 95.1, 95.2,
    95.3, 95.4, 95.5, 95.6, 95.7, 95.8, 95.9, 96, 96.1, 96.2,
    96.3, 96.4, 96.5, 96.6, 96.7, 96.8, 96.9, 97, 97.1, 97.2,
    97.3, 97.4, 97.5, 97.6, 97.7, 97.8, 97.9, 98, 98.1, 98.2,
    98.3, 98.4, 98.5, 98.6, 98.7, 98.8, 98.9, 99, 99.1, 99.2,
    99.3, 99.4, 99.5, 99.6, 99.7, 99.8, 99.9, 100, 100.1, 100.2,
    100.3, 100.4, 100.5, 100.6, 100.7, 100.8, 100.9, 101, 101.1,
    101.2, 101.3, 101.4, 101.5, 101.6, 101.7, 101.8, 101.9, 102,
    102.1, 102.2, 102.3, 102.4, 102.5, 102.6, 102.7, 102.8, 102.9,
    103, 103.1, 103.2, 103.3, 103.4, 103.5, 103.6, 103.7, 103.8,
    103.9, 104, 104.1, 104.2, 104.3, 104.4, 104.5, 104.6, 104.7,
    104.8, 104.9, 105, 105.1, 105.2, 105.3, 105.4, 105.5, 105.6,
    105.7, 105.8, 105.9, 106, 106.1, 106.2, 106.3, 106.4, 106.5,
    106.6, 106.7, 106.8, 106.9, 107, 107.1, 107.2, 107.3, 107.4,
    107.5, 107.6, 107.7, 107.8, 107.9, 108, 108.1, 108.2, 108.3,
    108.4, 108.5, 108.6, 108.7, 108.8, 108.9, 109, 109.1, 109.2,
    109.3, 109.4, 109.5, 109.6, 109.7, 109.8, 109.9, 110, 45,
    45.1, 45.2, 45.3, 45.4, 45.5, 45.6, 45.7, 45.8, 45.9, 46,
    46.1, 46.2, 46.3, 46.4, 46.5, 46.6, 46.7, 46.8, 46.9, 47,
    47.1, 47.2, 47.3, 47.4, 47.5, 47.6, 47.7, 47.8, 47.9, 48,
    48.1, 48.2, 48.3, 48.4, 48.5, 48.6, 48.7, 48.8, 48.9, 49,
    49.1, 49.2, 49.3, 49.4, 49.5, 49.6, 49.7, 49.8, 49.9, 50,
    50.1, 50.2, 50.3, 50.4, 50.5, 50.6, 50.7, 50.8, 50.9, 51,
    51.1, 51.2, 51.3, 51.4, 51.5, 51.6, 51.7, 51.8, 51.9, 52,
    52.1, 52.2, 52.3, 52.4, 52.5, 52.6, 52.7, 52.8, 52.9, 53,
    53.1, 53.2, 53.3, 53.4, 53.5, 53.6, 53.7, 53.8, 53.9, 54,
    54.1, 54.2, 54.3, 54.4, 54.5, 54.6, 54.7, 54.8, 54.9, 55,
    55.1, 55.2, 55.3, 55.4, 55.5, 55.6, 55.7, 55.8, 55.9, 56,
    56.1, 56.2, 56.3, 56.4, 56.5, 56.6, 56.7, 56.8, 56.9, 57,
    57.1, 57.2, 57.3, 57.4, 57.5, 57.6, 57.7, 57.8, 57.9, 58,
    58.1, 58.2, 58.3, 58.4, 58.5, 58.6, 58.7, 58.8, 58.9, 59,
    59.1, 59.2, 59.3, 59.4, 59.5, 59.6, 59.7, 59.8, 59.9, 60,
    60.1, 60.2, 60.3, 60.4, 60.5, 60.6, 60.7, 60.8, 60.9, 61,
    61.1, 61.2, 61.3, 61.4, 61.5, 61.6, 61.7, 61.8, 61.9, 62,
    62.1, 62.2, 62.3, 62.4, 62.5, 62.6, 62.7, 62.8, 62.9, 63,
    63.1, 63.2, 63.3, 63.4, 63.5, 63.6, 63.7, 63.8, 63.9, 64,
    64.1, 64.2, 64.3, 64.4, 64.5, 64.6, 64.7, 64.8, 64.9, 65,
    65.1, 65.2, 65.3, 65.4, 65.5, 65.6, 65.7, 65.8, 65.9, 66,
    66.1, 66.2, 66.3, 66.4, 66.5, 66.6, 66.7, 66.8, 66.9, 67,
    67.1, 67.2, 67.3, 67.4, 67.5, 67.6, 67.7, 67.8, 67.9, 68,
    68.1, 68.2, 68.3, 68.4, 68.5, 68.6, 68.7, 68.8, 68.9, 69,
    69.1, 69.2, 69.3, 69.4, 69.5, 69.6, 69.7, 69.8, 69.9, 70,
    70.1, 70.2, 70.3, 70.4, 70.5, 70.6, 70.7, 70.8, 70.9, 71,
    71.1, 71.2, 71.3, 71.4, 71.5, 71.6, 71.7, 71.8, 71.9, 72,
    72.1, 72.2, 72.3, 72.4, 72.5, 72.6, 72.7, 72.8, 72.9, 73,
    73.1, 73.2, 73.3, 73.4, 73.5, 73.6, 73.7, 73.8, 73.9, 74,
    74.1, 74.2, 74.3, 74.4, 74.5, 74.6, 74.7, 74.8, 74.9, 75,
    75.1, 75.2, 75.3, 75.4, 75.5, 75.6, 75.7, 75.8, 75.9, 76,
    76.1, 76.2, 76.3, 76.4, 76.5, 76.6, 76.7, 76.8, 76.9, 77,
    77.1, 77.2, 77.3, 77.4, 77.5, 77.6, 77.7, 77.8, 77.9, 78,
    78.1, 78.2, 78.3, 78.4, 78.5, 78.6, 78.7, 78.8, 78.9, 79,
    79.1, 79.2, 79.3, 79.4, 79.5, 79.6, 79.7, 79.8, 79.9, 80,
    80.1, 80.2, 80.3, 80.4, 80.5, 80.6, 80.7, 80.8, 80.9, 81,
    81.1, 81.2, 81.3, 81.4, 81.5, 81.6, 81.7, 81.8, 81.9, 82,
    82.1, 82.2, 82.3, 82.4, 82.5, 82.6, 82.7, 82.8, 82.9, 83,
    83.1, 83.2, 83.3, 83.4, 83.5, 83.6, 83.7, 83.8, 83.9, 84,
    84.1, 84.2, 84.3, 84.4, 84.5, 84.6, 84.7, 84.8, 84.9, 85,
    85.1, 85.2, 85.3, 85.4, 85.5, 85.6, 85.7, 85.8, 85.9, 86,
    86.1, 86.2, 86.3, 86.4, 86.5, 86.6, 86.7, 86.8, 86.9, 87,
    87.1, 87.2, 87.3, 87.4, 87.5, 87.6, 87.7, 87.8, 87.9, 88,
    88.1, 88.2, 88.3, 88.4, 88.5, 88.6, 88.7, 88.8, 88.9, 89,
    89.1, 89.2, 89.3, 89.4, 89.5, 89.6, 89.7, 89.8, 89.9, 90,
    90.1, 90.2, 90.3, 90.4, 90.5, 90.6, 90.7, 90.8, 90.9, 91,
    91.1, 91.2, 91.3, 91.4, 91.5, 91.6, 91.7, 91.8, 91.9, 92,
    92.1, 92.2, 92.3, 92.4, 92.5, 92.6, 92.7, 92.8, 92.9, 93,
    93.1, 93.2, 93.3, 93.4, 93.5, 93.6, 93.7, 93.8, 93.9, 94,
    94.1, 94.2, 94.3, 94.4, 94.5, 94.6, 94.7, 94.8, 94.9, 95,
    95.1, 95.2, 95.3, 95.4, 95.5, 95.6, 95.7, 95.8, 95.9, 96,
    96.1, 96.2, 96.3, 96.4, 96.5, 96.6, 96.7, 96.8, 96.9, 97,
    97.1, 97.2, 97.3, 97.4, 97.5, 97.6, 97.7, 97.8, 97.9, 98,
    98.1, 98.2, 98.3, 98.4, 98.5, 98.6, 98.7, 98.8, 98.9, 99,
    99.1, 99.2, 99.3, 99.4, 99.5, 99.6, 99.7, 99.8, 99.9, 100,
    100.1, 100.2, 100.3, 100.4, 100.5, 100.6, 100.7, 100.8, 100.9,
    101, 101.1, 101.2, 101.3, 101.4, 101.5, 101.6, 101.7, 101.8,
    101.9, 102, 102.1, 102.2, 102.3, 102.4, 102.5, 102.6, 102.7,
    102.8, 102.9, 103, 103.1, 103.2, 103.3, 103.4, 103.5, 103.6,
    103.7, 103.8, 103.9, 104, 104.1, 104.2, 104.3, 104.4, 104.5,
    104.6, 104.7, 104.8, 104.9, 105, 105.1, 105.2, 105.3, 105.4,
    105.5, 105.6, 105.7, 105.8, 105.9, 106, 106.1, 106.2, 106.3,
    106.4, 106.5, 106.6, 106.7, 106.8, 106.9, 107, 107.1, 107.2,
    107.3, 107.4, 107.5, 107.6, 107.7, 107.8, 107.9, 108, 108.1,
    108.2, 108.3, 108.4, 108.5, 108.6, 108.7, 108.8, 108.9, 109,
    109.1, 109.2, 109.3, 109.4, 109.5, 109.6, 109.7, 109.8, 109.9,
    110, 65, 65.1, 65.2, 65.3, 65.4, 65.5, 65.6, 65.7, 65.8,
    65.9, 66, 66.1, 66.2, 66.3, 66.4, 66.5, 66.6, 66.7, 66.8,
    66.9, 67, 67.1, 67.2, 67.3, 67.4, 67.5, 67.6, 67.7, 67.8,
    67.9, 68, 68.1, 68.2, 68.3, 68.4, 68.5, 68.6, 68.7, 68.8,
    68.9, 69, 69.1, 69.2, 69.3, 69.4, 69.5, 69.6, 69.7, 69.8,
    69.9, 70, 70.1, 70.2, 70.3, 70.4, 70.5, 70.6, 70.7, 70.8,
    70.9, 71, 71.1, 71.2, 71.3, 71.4, 71.5, 71.6, 71.7, 71.8,
    71.9, 72, 72.1, 72.2, 72.3, 72.4, 72.5, 72.6, 72.7, 72.8,
    72.9, 73, 73.1, 73.2, 73.3, 73.4, 73.5, 73.6, 73.7, 73.8,
    73.9, 74, 74.1, 74.2, 74.3, 74.4, 74.5, 74.6, 74.7, 74.8,
    74.9, 75, 75.1, 75.2, 75.3, 75.4, 75.5, 75.6, 75.7, 75.8,
    75.9, 76, 76.1, 76.2, 76.3, 76.4, 76.5, 76.6, 76.7, 76.8,
    76.9, 77, 77.1, 77.2, 77.3, 77.4, 77.5, 77.6, 77.7, 77.8,
    77.9, 78, 78.1, 78.2, 78.3, 78.4, 78.5, 78.6, 78.7, 78.8,
    78.9, 79, 79.1, 79.2, 79.3, 79.4, 79.5, 79.6, 79.7, 79.8,
    79.9, 80, 80.1, 80.2, 80.3, 80.4, 80.5, 80.6, 80.7, 80.8,
    80.9, 81, 81.1, 81.2, 81.3, 81.4, 81.5, 81.6, 81.7, 81.8,
    81.9, 82, 82.1, 82.2, 82.3, 82.4, 82.5, 82.6, 82.7, 82.8,
    82.9, 83, 83.1, 83.2, 83.3, 83.4, 83.5, 83.6, 83.7, 83.8,
    83.9, 84, 84.1, 84.2, 84.3, 84.4, 84.5, 84.6, 84.7, 84.8,
    84.9, 85, 85.1, 85.2, 85.3, 85.4, 85.5, 85.6, 85.7, 85.8,
    85.9, 86, 86.1, 86.2, 86.3, 86.4, 86.5, 86.6, 86.7, 86.8,
    86.9, 87, 87.1, 87.2, 87.3, 87.4, 87.5, 87.6, 87.7, 87.8,
    87.9, 88, 88.1, 88.2, 88.3, 88.4, 88.5, 88.6, 88.7, 88.8,
    88.9, 89, 89.1, 89.2, 89.3, 89.4, 89.5, 89.6, 89.7, 89.8,
    89.9, 90, 90.1, 90.2, 90.3, 90.4, 90.5, 90.6, 90.7, 90.8,
    90.9, 91, 91.1, 91.2, 91.3, 91.4, 91.5, 91.6, 91.7, 91.8,
    91.9, 92, 92.1, 92.2, 92.3, 92.4, 92.5, 92.6, 92.7, 92.8,
    92.9, 93, 93.1, 93.2, 93.3, 93.4, 93.5, 93.6, 93.7, 93.8,
    93.9, 94, 94.1, 94.2, 94.3, 94.4, 94.5, 94.6, 94.7, 94.8,
    94.9, 95, 95.1, 95.2, 95.3, 95.4, 95.5, 95.6, 95.7, 95.8,
    95.9, 96, 96.1, 96.2, 96.3, 96.4, 96.5, 96.6, 96.7, 96.8,
    96.9, 97, 97.1, 97.2, 97.3, 97.4, 97.5, 97.6, 97.7, 97.8,
    97.9, 98, 98.1, 98.2, 98.3, 98.4, 98.5, 98.6, 98.7, 98.8,
    98.9, 99, 99.1, 99.2, 99.3, 99.4, 99.5, 99.6, 99.7, 99.8,
    99.9, 100, 100.1, 100.2, 100.3, 100.4, 100.5, 100.6, 100.7,
    100.8, 100.9, 101, 101.1, 101.2, 101.3, 101.4, 101.5, 101.6,
    101.7, 101.8, 101.9, 102, 102.1, 102.2, 102.3, 102.4, 102.5,
    102.6, 102.7, 102.8, 102.9, 103, 103.1, 103.2, 103.3, 103.4,
    103.5, 103.6, 103.7, 103.8, 103.9, 104, 104.1, 104.2, 104.3,
    104.4, 104.5, 104.6, 104.7, 104.8, 104.9, 105, 105.1, 105.2,
    105.3, 105.4, 105.5, 105.6, 105.7, 105.8, 105.9, 106, 106.1,
    106.2, 106.3, 106.4, 106.5, 106.6, 106.7, 106.8, 106.9, 107,
    107.1, 107.2, 107.3, 107.4, 107.5, 107.6, 107.7, 107.8, 107.9,
    108, 108.1, 108.2, 108.3, 108.4, 108.5, 108.6, 108.7, 108.8,
    108.9, 109, 109.1, 109.2, 109.3, 109.4, 109.5, 109.6, 109.7,
    109.8, 109.9, 110, 110.1, 110.2, 110.3, 110.4, 110.5, 110.6,
    110.7, 110.8, 110.9, 111, 111.1, 111.2, 111.3, 111.4, 111.5,
    111.6, 111.7, 111.8, 111.9, 112, 112.1, 112.2, 112.3, 112.4,
    112.5, 112.6, 112.7, 112.8, 112.9, 113, 113.1, 113.2, 113.3,
    113.4, 113.5, 113.6, 113.7, 113.8, 113.9, 114, 114.1, 114.2,
    114.3, 114.4, 114.5, 114.6, 114.7, 114.8, 114.9, 115, 115.1,
    115.2, 115.3, 115.4, 115.5, 115.6, 115.7, 115.8, 115.9, 116,
    116.1, 116.2, 116.3, 116.4, 116.5, 116.6, 116.7, 116.8, 116.9,
    117, 117.1, 117.2, 117.3, 117.4, 117.5, 117.6, 117.7, 117.8,
    117.9, 118, 118.1, 118.2, 118.3, 118.4, 118.5, 118.6, 118.7,
    118.8, 118.9, 119, 119.1, 119.2, 119.3, 119.4, 119.5, 119.6,
    119.7, 119.8, 119.9, 120, 65, 65.1, 65.2, 65.3, 65.4, 65.5,
    65.6, 65.7, 65.8, 65.9, 66, 66.1, 66.2, 66.3, 66.4, 66.5,
    66.6, 66.7, 66.8, 66.9, 67, 67.1, 67.2, 67.3, 67.4, 67.5,
    67.6, 67.7, 67.8, 67.9, 68, 68.1, 68.2, 68.3, 68.4, 68.5,
    68.6, 68.7, 68.8, 68.9, 69, 69.1, 69.2, 69.3, 69.4, 69.5,
    69.6, 69.7, 69.8, 69.9, 70, 70.1, 70.2, 70.3, 70.4, 70.5,
    70.6, 70.7, 70.8, 70.9, 71, 71.1, 71.2, 71.3, 71.4, 71.5,
    71.6, 71.7, 71.8, 71.9, 72, 72.1, 72.2, 72.3, 72.4, 72.5,
    72.6, 72.7, 72.8, 72.9, 73, 73.1, 73.2, 73.3, 73.4, 73.5,
    73.6, 73.7, 73.8, 73.9, 74, 74.1, 74.2, 74.3, 74.4, 74.5,
    74.6, 74.7, 74.8, 74.9, 75, 75.1, 75.2, 75.3, 75.4, 75.5,
    75.6, 75.7, 75.8, 75.9, 76, 76.1, 76.2, 76.3, 76.4, 76.5,
    76.6, 76.7, 76.8, 76.9, 77, 77.1, 77.2, 77.3, 77.4, 77.5,
    77.6, 77.7, 77.8, 77.9, 78, 78.1, 78.2, 78.3, 78.4, 78.5,
    78.6, 78.7, 78.8, 78.9, 79, 79.1, 79.2, 79.3, 79.4, 79.5,
    79.6, 79.7, 79.8, 79.9, 80, 80.1, 80.2, 80.3, 80.4, 80.5,
    80.6, 80.7, 80.8, 80.9, 81, 81.1, 81.2, 81.3, 81.4, 81.5,
    81.6, 81.7, 81.8, 81.9, 82, 82.1, 82.2, 82.3, 82.4, 82.5,
    82.6, 82.7, 82.8, 82.9, 83, 83.1, 83.2, 83.3, 83.4, 83.5,
    83.6, 83.7, 83.8, 83.9, 84, 84.1, 84.2, 84.3, 84.4, 84.5,
    84.6, 84.7, 84.8, 84.9, 85, 85.1, 85.2, 85.3, 85.4, 85.5,
    85.6, 85.7, 85.8, 85.9, 86, 86.1, 86.2, 86.3, 86.4, 86.5,
    86.6, 86.7, 86.8, 86.9, 87, 87.1, 87.2, 87.3, 87.4, 87.5,
    87.6, 87.7, 87.8, 87.9, 88, 88.1, 88.2, 88.3, 88.4, 88.5,
    88.6, 88.7, 88.8, 88.9, 89, 89.1, 89.2, 89.3, 89.4, 89.5,
    89.6, 89.7, 89.8, 89.9, 90, 90.1, 90.2, 90.3, 90.4, 90.5,
    90.6, 90.7, 90.8, 90.9, 91, 91.1, 91.2, 91.3, 91.4, 91.5,
    91.6, 91.7, 91.8, 91.9, 92, 92.1, 92.2, 92.3, 92.4, 92.5,
    92.6, 92.7, 92.8, 92.9, 93, 93.1, 93.2, 93.3, 93.4, 93.5,
    93.6, 93.7, 93.8, 93.9, 94, 94.1, 94.2, 94.3, 94.4, 94.5,
    94.6, 94.7, 94.8, 94.9, 95, 95.1, 95.2, 95.3, 95.4, 95.5,
    95.6, 95.7, 95.8, 95.9, 96, 96.1, 96.2, 96.3, 96.4, 96.5,
    96.6, 96.7, 96.8, 96.9, 97, 97.1, 97.2, 97.3, 97.4, 97.5,
    97.6, 97.7, 97.8, 97.9, 98, 98.1, 98.2, 98.3, 98.4, 98.5,
    98.6, 98.7, 98.8, 98.9, 99, 99.1, 99.2, 99.3, 99.4, 99.5,
    99.6, 99.7, 99.8, 99.9, 100, 100.1, 100.2, 100.3, 100.4,
    100.5, 100.6, 100.7, 100.8, 100.9, 101, 101.1, 101.2, 101.3,
    101.4, 101.5, 101.6, 101.7, 101.8, 101.9, 102, 102.1, 102.2,
    102.3, 102.4, 102.5, 102.6, 102.7, 102.8, 102.9, 103, 103.1,
    103.2, 103.3, 103.4, 103.5, 103.6, 103.7, 103.8, 103.9, 104,
    104.1, 104.2, 104.3, 104.4, 104.5, 104.6, 104.7, 104.8, 104.9,
    105, 105.1, 105.2, 105.3, 105.4, 105.5, 105.6, 105.7, 105.8,
    105.9, 106, 106.1, 106.2, 106.3, 106.4, 106.5, 106.6, 106.7,
    106.8, 106.9, 107, 107.1, 107.2, 107.3, 107.4, 107.5, 107.6,
    107.7, 107.8, 107.9, 108, 108.1, 108.2, 108.3, 108.4, 108.5,
    108.6, 108.7, 108.8, 108.9, 109, 109.1, 109.2, 109.3, 109.4,
    109.5, 109.6, 109.7, 109.8, 109.9, 110, 110.1, 110.2, 110.3,
    110.4, 110.5, 110.6, 110.7, 110.8, 110.9, 111, 111.1, 111.2,
    111.3, 111.4, 111.5, 111.6, 111.7, 111.8, 111.9, 112, 112.1,
    112.2, 112.3, 112.4, 112.5, 112.6, 112.7, 112.8, 112.9, 113,
    113.1, 113.2, 113.3, 113.4, 113.5, 113.6, 113.7, 113.8, 113.9,
    114, 114.1, 114.2, 114.3, 114.4, 114.5, 114.6, 114.7, 114.8,
    114.9, 115, 115.1, 115.2, 115.3, 115.4, 115.5, 115.6, 115.7,
    115.8, 115.9, 116, 116.1, 116.2, 116.3, 116.4, 116.5, 116.6,
    116.7, 116.8, 116.9, 117, 117.1, 117.2, 117.3, 117.4, 117.5,
    117.6, 117.7, 117.8, 117.9, 118, 118.1, 118.2, 118.3, 118.4,
    118.5, 118.6, 118.7, 118.8, 118.9, 119, 119.1, 119.2, 119.3,
    119.4, 119.5, 119.6, 119.7, 119.8, 119.9, 120), l = c(-0.3053,
    -0.1867, -0.0681, 0.0505, 0.169, 0.2876, 0.4062, 0.5247,
    0.5094, 0.4941, 0.4789, 0.4636, 0.4483, 0.433, 0.4177, 0.4059,
    0.3946, 0.3839, 0.3735, 0.3636, 0.3541, 0.3449, 0.336, 0.3274,
    0.3191, 0.311, 0.3032, 0.2955, 0.2881, 0.2809, 0.2738, 0.2669,
    0.2602, 0.2536, 0.2472, 0.2409, 0.2348, 0.2287, 0.2228, 0.217,
    0.2113, 0.2058, 0.2003, 0.1949, 0.1896, 0.1844, 0.1793, 0.1743,
    0.1693, 0.1645, 0.1597, 0.155, 0.1503, 0.1457, 0.1412, 0.1368,
    0.1324, 0.128, 0.1238, 0.1196, 0.1154, 0.1113, 0.1072, 0.1032,
    0.0993, 0.0954, 0.0915, 0.0877, 0.084, 0.0803, 0.0766, 0.0729,
    0.0693, 0.0658, 0.0623, 0.0588, 0.0554, 0.052, 0.0486, 0.0452,
    0.0419, 0.0387, 0.0354, 0.0322, 0.0291, 0.0259, 0.0228, 0.0197,
    0.0167, 0.0137, 0.0107, 0.0077, 0.0048, 0.0018, -0.0011,
    -0.0039, -0.0068, -0.0096, -0.0124, -0.0151, -0.0179, -0.0206,
    -0.0233, -0.026, -0.0287, -0.0313, -0.0339, -0.0365, -0.0391,
    -0.0416, -0.0442, -0.0467, -0.0492, -0.0517, -0.0541, -0.0566,
    -0.059, -0.0614, -0.0638, -0.0662, -0.0686, -0.0709, -0.0732,
    -0.0756, -0.0779, -0.0801, -0.0824, -0.0847, -0.0869, -0.0891,
    -0.0913, -0.0935, -0.0957, -0.0979, -0.1, -0.1022, -0.1043,
    -0.1064, -0.1085, -0.1106, -0.1127, -0.1147, -0.1168, -0.1188,
    -0.1208, -0.1229, -0.1249, -0.1269, -0.1288, -0.1308, -0.1328,
    -0.1347, -0.1366, -0.1386, -0.1405, -0.1424, -0.1443, -0.1462,
    -0.148, -0.1499, -0.1518, -0.1536, -0.1554, -0.1573, -0.1591,
    -0.1609, -0.1627, -0.1645, -0.1663, -0.168, -0.1698, -0.1715,
    -0.1733, -0.175, -0.1768, -0.1785, -0.1802, -0.1819, -0.1836,
    -0.1853, -0.187, -0.1886, -0.1903, -0.1919, -0.1936, -0.1952,
    -0.1969, -0.1985, -0.2001, -0.2017, -0.2033, -0.2049, -0.2065,
    -0.2081, -0.2097, -0.2112, -0.2128, -0.2144, -0.2159, -0.2174,
    -0.219, -0.2205, -0.222, -0.2235, -0.2251, -0.2266, -0.2281,
    -0.2295, -0.231, -0.2325, -0.234, -0.2354, -0.2369, -0.2384,
    -0.2398, -0.2413, -0.2427, -0.2441, -0.2456, -0.247, -0.2484,
    -0.2498, -0.2512, -0.2526, -0.254, -0.2554, -0.2568, -0.2581,
    -0.2595, -0.2609, -0.2622, -0.2636, -0.265, -0.2663, -0.2676,
    -0.269, -0.2703, -0.2716, -0.273, -0.2743, -0.2756, -0.2769,
    -0.2782, -0.2795, -0.2808, -0.2821, -0.2834, -0.2847, -0.2859,
    -0.2872, -0.2885, -0.2898, -0.291, -0.2923, -0.2935, -0.2948,
    -0.296, -0.2972, -0.2985, -0.2997, -0.3009, -0.3022, -0.3034,
    -0.3046, -0.3058, -0.307, -0.3082, -0.3094, -0.3106, -0.3118,
    -0.313, -0.3142, -0.3153, -0.3165, -0.3177, -0.3189, -0.32,
    -0.3212, -0.3223, -0.3235, -0.3246, -0.3258, -0.3269, -0.3281,
    -0.3292, -0.3303, -0.3315, -0.3326, -0.3337, -0.3348, -0.3359,
    -0.3371, -0.3382, -0.3393, -0.3404, -0.3415, -0.3426, -0.3437,
    -0.3448, -0.3458, -0.3469, -0.348, -0.3491, -0.3502, -0.3512,
    -0.3523, -0.3534, -0.3544, -0.3555, -0.3565, -0.3576, -0.3586,
    -0.3597, -0.3607, -0.3618, -0.3628, -0.3638, -0.3649, -0.3659,
    -0.3669, -0.3679, -0.369, -0.37, -0.371, -0.372, -0.373,
    -0.374, -0.375, -0.376, -0.377, -0.378, -0.379, -0.38, -0.381,
    -0.382, -0.383, -0.3839, -0.3849, -0.3859, -0.3869, -0.3878,
    -0.3888, -0.3898, -0.3907, -0.3917, -0.3926, -0.3936, -0.3945,
    -0.3955, -0.3964, -0.3974, -0.3983, -0.3993, -0.4002, -0.4011,
    -0.4021, -0.403, -0.4039, -0.4049, -0.4058, -0.4067, -0.4076,
    -0.4085, -0.4095, -0.4104, -0.4113, -0.4122, -0.4131, -0.414,
    -0.4149, -0.4158, -0.4167, -0.4176, -0.4185, -0.4194, -0.4203,
    -0.4211, -0.422, -0.4229, -0.4238, -0.4247, -0.4255, -0.4264,
    -0.4273, -0.4282, -0.429, -0.4299, -0.4308, -0.4316, -0.4325,
    -0.4333, -0.4342, -0.435, -0.4359, -0.4367, -0.4376, -0.4384,
    -0.4393, -0.4401, -0.441, -0.4418, -0.4426, -0.4435, -0.4443,
    -0.4451, -0.446, -0.4468, -0.4476, -0.4484, -0.4493, -0.4501,
    -0.4509, -0.4517, -0.4525, -0.4533, -0.4541, -0.455, -0.4558,
    -0.4566, -0.4574, -0.4582, -0.459, -0.4598, -0.4606, -0.4614,
    -0.4621, -0.4629, -0.4637, -0.4645, -0.4653, -0.4661, -0.4669,
    -0.4677, -0.4684, -0.4692, -0.47, -0.4708, -0.4715, -0.4723,
    -0.4731, -0.4738, -0.4746, -0.4754, -0.4761, -0.4769, -0.4777,
    -0.4784, -0.4792, -0.4799, -0.4807, -0.4814, -0.4822, -0.4829,
    -0.4837, -0.4844, -0.4852, -0.4859, -0.4867, -0.4874, -0.4881,
    -0.4889, -0.4896, -0.4903, -0.4911, -0.4918, -0.4925, -0.4933,
    -0.494, -0.4947, -0.4954, -0.4962, -0.4969, -0.4976, -0.4983,
    -0.499, -0.4997, -0.5005, -0.5012, -0.5019, -0.5026, -0.5033,
    -0.504, -0.5047, -0.5054, -0.5061, -0.5068, -0.5075, -0.5082,
    -0.5089, -0.5096, -0.5103, -0.511, -0.5117, -0.5124, -0.5131,
    -0.5138, -0.5144, -0.5151, -0.5158, -0.5165, -0.5172, -0.5179,
    -0.5185, -0.5192, -0.5199, -0.5206, -0.5212, -0.5219, -0.5226,
    -0.5233, -0.5239, -0.5246, -0.5253, -0.5259, -0.5266, -0.5273,
    -0.5279, -0.5286, -0.5292, -0.5299, -0.5306, -0.5312, -0.5319,
    -0.5325, -0.5332, -0.5338, -0.5345, -0.5351, -0.5358, -0.5364,
    -0.5371, -0.5377, -0.5383, -0.539, -0.5396, -0.5403, -0.5409,
    -0.5415, -0.5422, -0.5428, -0.5434, -0.5441, -0.5447, -0.5453,
    -0.546, -0.5466, -0.5472, -0.5479, -0.5485, -0.5491, -0.5497,
    -0.5503, -0.551, -0.5516, -0.5522, -0.5528, -0.5534, -0.5541,
    -0.5547, -0.5553, -0.5559, -0.5565, -0.5571, -0.5577, -0.5583,
    -0.5589, -0.5595, -0.5602, -0.5608, -0.5614, -0.562, -0.5626,
    -0.5632, -0.5638, -0.5644, -0.565, -0.5656, -0.5662, -0.5667,
    -0.5673, -0.5679, -0.5685, -0.5691, -0.5697, -0.5703, -0.5709,
    -0.5715, -0.5721, -0.5726, -0.5732, -0.5738, -0.5744, -0.575,
    -0.5755, -0.5761, -0.5767, -0.5773, -0.5779, -0.5784, -0.579,
    -0.5796, -0.5802, -0.5807, -0.5813, -0.5819, -0.5824, -0.583,
    -0.5836, -0.5841, -0.5847, -0.5853, -0.5858, -0.5864, -0.587,
    -0.5875, -0.5881, -0.5886, -0.5892, -0.5898, -0.5903, -0.5909,
    -0.5914, -0.592, -0.5925, -0.5931, -0.5936, -0.5942, -0.5947,
    -0.5953, -0.5958, -0.5964, -0.5969, -0.5975, -0.598, -0.5986,
    -0.5991, -0.5996, -0.6002, -0.6007, -0.6013, -0.6018, -0.6023,
    -0.6029, -0.6034, -0.604, -0.6045, -0.605, -0.6056, -0.6061,
    -0.6066, -0.6072, -0.6077, -0.6082, -0.6087, -0.6093, -0.6098,
    -0.6103, -0.6109, -0.6114, -0.6119, -0.6124, -0.613, -0.6135,
    -0.614, -0.6145, -0.615, -0.6156, -0.6161, -0.6166, -0.6171,
    -0.6176, -0.6181, -0.6187, -0.6192, -0.6197, -0.6202, -0.6207,
    -0.6212, -0.6217, -0.6222, -0.6227, -0.6233, -0.6238, -0.6243,
    -0.6248, -0.6253, -0.6258, -0.6263, -0.6268, -0.6273, -0.6278,
    -0.6283, -0.6288, -0.6293, -0.6298, -0.6303, -0.6308, -0.6313,
    -0.6318, -0.6323, -0.6328, -0.6333, -0.6338, -0.6343, -0.6348,
    -0.6352, -0.6357, -0.6362, -0.6367, -0.6372, -0.6377, -0.6382,
    -0.6387, -0.6392, -0.6396, -0.6401, -0.6406, -0.6411, -0.6416,
    -0.6421, -0.6425, -0.643, -0.6435, -0.644, -0.6445, -0.6449,
    -0.6454, -0.6459, -0.6464, -0.6469, -0.6473, -0.6187, -0.6175,
    -0.6164, -0.6152, -0.614, -0.6129, -0.6117, -0.6105, -0.6094,
    -0.6082, -0.607, -0.6059, -0.6047, -0.6036, -0.6024, -0.6012,
    -0.6001, -0.5989, -0.5978, -0.5966, -0.5955, -0.5943, -0.5932,
    -0.592, -0.5909, -0.5897, -0.5886, -0.5874, -0.5863, -0.5851,
    -0.584, -0.5828, -0.5817, -0.5805, -0.5794, -0.5783, -0.5771,
    -0.576, -0.5748, -0.5737, -0.5726, -0.5714, -0.5703, -0.5692,
    -0.568, -0.5669, -0.5658, -0.5647, -0.5635, -0.5624, -0.5613,
    -0.5602, -0.559, -0.5579, -0.5568, -0.5557, -0.5546, -0.5535,
    -0.5523, -0.5512, -0.5501, -0.549, -0.5479, -0.5468, -0.5457,
    -0.5446, -0.5435, -0.5424, -0.5413, -0.5402, -0.5391, -0.538,
    -0.5369, -0.5358, -0.5347, -0.5336, -0.5325, -0.5315, -0.5304,
    -0.5293, -0.5282, -0.5271, -0.526, -0.525, -0.5239, -0.5228,
    -0.5217, -0.5207, -0.5196, -0.5185, -0.5175, -0.5164, -0.5153,
    -0.5143, -0.5132, -0.5122, -0.5111, -0.5101, -0.509, -0.508,
    -0.5069, -0.5059, -0.5048, -0.5038, -0.5027, -0.5017, -0.5006,
    -0.4996, -0.4986, -0.4975, -0.4965, -0.4955, -0.4944, -0.4934,
    -0.4924, -0.4914, -0.4904, -0.4893, -0.4883, -0.4873, -0.4863,
    -0.4853, -0.4843, -0.4833, -0.4823, -0.4813, -0.4803, -0.4793,
    -0.4783, -0.4773, -0.4763, -0.4753, -0.4743, -0.4733, -0.4723,
    -0.4713, -0.4704, -0.4694, -0.4684, -0.4674, -0.4665, -0.4655,
    -0.4645, -0.4636, -0.4626, -0.4616, -0.4607, -0.4597, -0.4587,
    -0.4578, -0.4568, -0.4559, -0.4549, -0.454, -0.4531, -0.4521,
    -0.4512, -0.4502, -0.4493, -0.4484, -0.4474, -0.4465, -0.4456,
    -0.4446, -0.4437, -0.4428, -0.4419, -0.441, -0.4401, -0.4391,
    -0.4382, -0.4373, -0.4364, -0.4355, -0.4346, -0.4337, -0.4328,
    -0.4319, -0.431, -0.4301, -0.4293, -0.4284, -0.4275, -0.4266,
    -0.4257, -0.4249, -0.424, -0.4231, -0.4222, -0.4214, -0.4205,
    -0.4196, -0.4188, -0.4179, -0.4171, -0.4162, -0.4154, -0.4145,
    -0.4137, -0.4128, -0.412, -0.4111, -0.4103, -0.4095, -0.4086,
    -0.4078, -0.407, -0.4062, -0.4053, -0.4045, -0.4037, -0.4029,
    -0.4021, -0.4013, -0.4005, -0.3997, -0.3988, -0.398, -0.3973,
    -0.3965, -0.3957, -0.3949, -0.3941, -0.3933, -0.3925, -0.3917,
    -0.391, -0.3902, -0.3894, -0.3886, -0.3879, -0.3871, -0.3864,
    -0.3856, -0.3848, -0.3841, -0.3833, -0.3826, -0.3818, -0.3811,
    -0.3804, -0.3796, -0.3789, -0.3782, -0.3774, -0.3767, -0.376,
    -0.3753, -0.3745, -0.3738, -0.3731, -0.3724, -0.3717, -0.371,
    -0.3703, -0.3696, -0.3689, -0.3682, -0.3675, -0.3668, -0.3661,
    -0.3655, -0.3648, -0.3641, -0.3634, -0.3628, -0.3621, -0.3614,
    -0.3608, -0.3601, -0.3594, -0.3588, -0.3581, -0.3575, -0.3568,
    -0.3562, -0.3556, -0.3549, -0.3543, -0.3536, -0.353, -0.3524,
    -0.3518, -0.3511, -0.3505, -0.3499, -0.3493, -0.3487, -0.3481,
    -0.3475, -0.3469, -0.3463, -0.3457, -0.3451, -0.3445, -0.3439,
    -0.3433, -0.3427, -0.3422, -0.3416, -0.341, -0.3404, -0.3399,
    -0.3393, -0.3388, -0.3382, -0.3376, -0.3371, -0.3365, -0.336,
    -0.3354, -0.3349, -0.3344, -0.3338, -0.3333, -0.3328, -0.3322,
    -0.3317, -0.3312, -0.3307, -0.3302, -0.3296, -0.3291, -0.3286,
    -0.3281, -0.3276, -0.3271, -0.3266, -0.3261, -0.3257, -0.3252,
    -0.3247, -0.3242, -0.3237, -0.3233, -0.3228, -0.3223, -0.3218,
    -0.3214, -0.3209, -0.3205, -0.32, -0.3196, -0.3191, -0.3187,
    -0.3182, -0.3178, -0.3174, -0.3169, -0.3165, -0.3161, -0.3156,
    -0.3152, -0.3148, -0.3144, -0.314, -0.3136, -0.3132, -0.3128,
    -0.3124, -0.312, -0.3116, -0.3112, -0.3108, -0.3104, -0.31,
    -0.3097, -0.3093, -0.3089, -0.3085, -0.3082, -0.3078, -0.3074,
    -0.3071, -0.3067, -0.3064, -0.306, -0.3057, -0.3054, -0.305,
    -0.3047, -0.3043, -0.304, -0.3037, -0.3034, -0.3031, -0.3027,
    -0.3024, -0.3021, -0.3018, -0.3015, -0.3012, -0.3009, -0.3006,
    -0.3003, -0.3, -0.2997, -0.2995, -0.2992, -0.2989, -0.2986,
    -0.2984, -0.2981, -0.2978, -0.2976, -0.2973, -0.2971, -0.2968,
    -0.2966, -0.2963, -0.2961, -0.2959, -0.2956, -0.2954, -0.2952,
    -0.2949, -0.2947, -0.2945, -0.2943, -0.2941, -0.2939, -0.2937,
    -0.2934, -0.2932, -0.2931, -0.2929, -0.2927, -0.2925, -0.2923,
    -0.2921, -0.2919, -0.2918, -0.2916, -0.2914, -0.2913, -0.2911,
    -0.2909, -0.2908, -0.2906, -0.2905, -0.2903, -0.2902, -0.2901,
    -0.2899, -0.2898, -0.2897, -0.2895, -0.2894, -0.2893, -0.2892,
    -0.289, -0.2889, -0.2888, -0.2887, -0.2886, -0.2885, -0.2884,
    -0.2883, -0.2882, -0.2881, -0.2881, -0.288, -0.2879, -0.2878,
    -0.2877, -0.2877, -0.2876, -0.2875, -0.2875, -0.2874, -0.2874,
    -0.2873, -0.2873, -0.2872, -0.2872, -0.2871, -0.2871, -0.2871,
    -0.287, -0.287, -0.287, -0.287, -0.2869, -0.2869, -0.2869,
    -0.2869, -0.2869, -0.2869, -0.2869, -0.2869, -0.2869, -0.2869,
    -0.2869, -0.2869, -0.2869, -0.287, -0.287, -0.287, -0.287,
    -0.2871, -0.2871, -0.2871, -0.2872, -0.2872, -0.2873, -0.2873,
    -0.2874, -0.2874, -0.2875, -0.2875, -0.2876, -0.2877, -0.2877,
    -0.2878, -0.2879, -0.288, -0.288, -0.2881, -0.2882, -0.2883,
    -0.2884, -0.2885, -0.2886, -0.2887, -0.2888, -0.2889, -0.289,
    -0.2891, -0.2892, -0.2893, -0.2894, -0.2896, -0.2897, -0.2898,
    -0.2899, -0.2901, -0.2902, -0.2903, -0.2905, -0.2906, -0.2908,
    -0.2909, -0.2911, -0.2912, -0.2914, -0.2915, -0.2917, -0.2918,
    -0.292, -0.2922, -0.2924, -0.2925, -0.2927, -0.2929, -0.2931,
    -0.2933, -0.2934, -0.2936, -0.2938, -0.294, -0.2942, -0.2944,
    -0.2946, -0.2948, -0.295, -0.2952, -0.2954, -0.2957, -0.2959,
    -0.2961, -0.2963, -0.2965, -0.2968, -0.297, -0.2972, -0.2975,
    -0.2977, -0.2979, -0.2982, -0.2984, -0.2987, -0.2989, -0.2992,
    -0.2994, -0.2997, -0.3, -0.3002, -0.3005, -0.3008, -0.301,
    -0.3013, -0.3016, -0.3018, -0.3021, -0.3024, -0.3027, -0.303,
    -0.3033, -0.3036, -0.3038, -0.3041, -0.3044, -0.3047, -0.305,
    -0.3054, -0.3057, -0.306, -0.3063, -0.3066, -0.3069, -0.3072,
    -0.3076, -0.3079, -0.3082, -0.3085, -0.3089, -0.3092, -0.3095,
    -0.3099, -0.3102, -0.3106, -0.3109, -0.3113, -0.3116, -0.312,
    -0.3123, -0.3127, -0.313, -0.3134, -0.3138, -0.3141, -0.3145,
    -0.3149, -0.3152, -0.3156, -0.316, -0.3164, -0.3168, -0.3171,
    -0.3175, -0.3179, -0.3183, -0.3187, -0.3191, -0.3195, -0.3199,
    -0.3203, -0.3207, -0.3211, -0.3215, -0.322, -0.3224, -0.3228,
    -0.3232, -0.3236, -0.3241, -0.3245, -0.3249, -0.3253, -0.3258,
    -0.3262, -0.3266, -0.3271, -0.3275, -0.328, -0.3284, -0.3289,
    -0.3293, -0.3298, -0.3302, -0.3307, -0.3312, -0.3316, -0.3321,
    -0.3325, -0.333, -0.3335, -0.334, -0.3344, -0.3349, -0.3354,
    -0.3359, -0.3364, -0.3369, -0.3373, -0.3378, -0.3383, -0.3388,
    -0.3393, -0.3398, -0.3403, -0.3408, -0.3413, -0.3418, -0.3424,
    -0.3429, -0.3434, -0.3439, -0.3444, -0.3449, -0.3455, -0.346,
    -0.3465, -0.3471, -0.3476, -0.3481, -0.3487, -0.3492, -0.3497,
    -0.3503, -0.3508, -0.3514, -0.3519, -0.3525, -0.353, -0.3536,
    -0.3541, -0.3547, -0.3553, -0.3558, -0.3564, -0.357, -0.3575,
    -0.3581, -0.3587, -0.3593, -0.3598, -0.3604, -0.361, -0.3616,
    -0.3622, -0.3628, -0.3634, -0.364, -0.3646, -0.3652, -0.3658,
    -0.3664, -0.367, -0.3676, -0.3682, -0.3688, -0.3694, -0.37,
    -0.3706, -0.3713, -0.3719, -0.3725, -0.3731, -0.3738, -0.3744,
    -0.375, -0.3756, -0.3763, -0.3769, -0.3776, -0.3782, -0.3789,
    -0.3795, -0.3801, -0.3808, -0.3815, -0.3821, -0.3828, -0.3834,
    -0.3841, -0.3847, -0.3854, -0.3861, -0.3867, -0.3874, -0.3881,
    -0.3888, -0.3894, -0.3901, -0.3908, -0.3915, -0.3922, -0.3929,
    -0.3936, -0.3942, -0.3949, -0.3956, -0.3963, -0.397, -0.3977,
    -0.3984, -0.3991, -0.3998, -0.4006, -0.4013, -0.402, -0.4027,
    -0.4034, -0.4041, -0.4049, -0.4056, -0.4063, -0.407, -0.4078,
    -0.4085, -0.4092, -0.41, -0.4107, -0.4114, -0.4122, -0.4129,
    -0.4137, -0.4144, -0.4151, -0.4159, -0.4166, -0.4174, -0.4182,
    -0.4189, -0.4197, -0.4204, -0.4212, -0.422, -0.4227, -0.4235,
    -0.4243, -0.425, -0.4258, -0.4266, -0.4274, -0.4281, -0.4289,
    -0.4297, -0.4305, -0.4313, -0.4321, -0.4328, -0.4336, -0.4344,
    -0.4352, -0.436, -0.4368, -0.4376, -0.4384, -0.4392, -0.44,
    -0.4408, -0.4417, -0.4425, -0.4433, -0.4441, -0.4449, -0.4457,
    -0.4465, -0.4474, -0.4482, -0.449, -0.4498, -0.4507, -0.4515,
    -0.4523, -0.4532, -0.454, -0.4548, -0.4557, -0.4565, -0.4574,
    -0.4582, -0.459, -0.4599, -0.4607, -0.4616, -0.4624, -0.4633,
    -0.4641, -0.465, -0.4659, -0.4667, -0.4676, -0.4684, -0.4693,
    -0.4702, -0.471, -0.4719, -0.4728, -0.4736, -0.4745, -0.4754,
    -0.4762, -0.4771, -0.478, -0.4789, -0.4798, -0.4806, -0.4815,
    -0.4824, -0.4833, -0.4842, -0.4851, -0.486, -0.4869, -0.4877,
    -0.4886, -0.4895, -0.4904, -0.4913, -0.4922, -0.4931, -0.494,
    -0.4949, -0.4958, -0.4968, -0.4977, -0.4986, -0.4995, -0.5004,
    -0.5013, -0.5022, -0.5031, -0.504, -0.505, -0.5059, -0.5068,
    -0.5077, -0.5087, -0.5096, -0.5105, -0.5114, -0.5124, -0.5133,
    -0.5142, -0.5151, -0.5161, -0.517, -0.518, -0.5189, -0.5198,
    -0.5208, -0.5217, -0.5227, -0.5236, -0.5245, -0.5255, -0.5264,
    -0.5274, -0.5283, -0.5293, -0.5302, -0.5312, -0.5321, -0.5331,
    -0.5341, -0.535, -0.536, -0.5369, -0.5379, -0.5389, -0.5398,
    -0.5408, -0.5418, -0.5427, -0.5437, -0.5447, -0.5456, -0.5466,
    -0.5476, -0.5486, -0.5495, -0.5505, -0.5515, -0.5525, -0.5535,
    -0.5544, -0.5554, -0.5564, -0.5574, -0.5584, -0.5594, -0.5604,
    -0.5614, -0.5623, -0.5633, -0.5643, -0.5653, -0.5663, -0.5673,
    -0.5683, -0.5693, -0.5703, -0.5713, -0.5723, -0.5733, -0.5743,
    -0.5754, -0.5764, -0.5774, -0.5784, -0.5794, -0.5804, -0.5814,
    -0.5824, -0.5835, -0.5845, -0.5855, -0.5865, -0.5875, -0.5886,
    -0.5896, -0.5906, -0.5916, -0.5927, -0.5937, -0.5947, -0.5958,
    -0.5968, -0.5978, -0.5989, -0.5999, -0.6009, -0.602, -0.603,
    -0.604, -0.6051, -0.6061, -0.6072, -0.6082, -0.6093, -0.6103,
    -0.6114, -0.6124, -0.6135, -0.6145, -0.6156, -0.6166, -0.6177,
    -0.6187, -0.6198, -0.6209, -0.6219, -0.623, -0.6241, -0.6251,
    -0.6262, -0.6273, -0.6283, -0.6294, -0.6305, -0.6315, -0.6326,
    -0.6337, -0.6348, -0.6358, -0.6369, -0.638, -0.6391, -0.6402,
    -0.6412, -0.6423, -0.6434, -0.6445, -0.6456, -0.6467, -0.6478,
    -0.6488, -0.6499, -0.651, -0.6521, -0.6532, -0.6543, -0.6554,
    -0.6565, -0.6576, -0.6587, -0.6598, -0.6609, -0.662, -0.6631,
    -0.6642, -0.6653, -0.6665, -0.6676, -0.6687, -0.6698, -0.6709,
    -0.672, -0.6731, -0.6743, -0.6754, -0.6765, -0.6776, -0.6787,
    -0.6799, -0.681, -0.6821, -0.6833, -0.6844, -0.6855, -0.6866,
    -0.6878, -0.6889, -0.69, -0.6912, -0.6923, -0.6935, -0.6946,
    -0.6957, -0.6969, -0.698, -0.6992, -0.7003, -0.7015, -0.7026,
    -0.7038, -0.7049, -0.7061, -0.7072, -0.7084, -0.7095, -0.7107,
    -0.7118, -0.713, -0.7141, -0.7153, -0.7165, -0.7176, -0.7188,
    -0.72, -0.7211, -0.7223, -0.7235, -0.7387, -0.7621, -0.7856,
    -0.8089, -0.8322, -0.8554, -0.8785, -0.9015, -0.9243, -0.9471,
    -0.9697, -0.9921, -1.0144, -1.0365, -1.0584, -1.0801, -1.1017,
    -1.123, -1.1441, -1.1649, -1.1856, -1.206, -1.2261, -1.246,
    -1.2656, -1.2849, -1.304, -1.3228, -1.3414, -1.3596, -1.3776,
    -1.3953, -1.4126, -1.4297, -1.4464, -1.4629, -1.479, -1.4947,
    -1.5101, -1.5252, -1.5399, -1.5542, -1.5681, -1.5817, -1.5948,
    -1.6076, -1.6199, -1.6318, -1.6433, -1.6544, -1.6651, -1.6753,
    -1.6851, -1.6944, -1.7032, -1.7116, -1.7196, -1.7271, -1.7341,
    -1.7407, -1.7468, -1.7525, -1.7578, -1.7626, -1.767, -1.771,
    -1.7745, -1.7777, -1.7804, -1.7828, -1.7847, -1.7862, -1.7873,
    -1.7881, -1.7884, -1.7884, -1.788, -1.7873, -1.7861, -1.7846,
    -1.7828, -1.7806, -1.778, -1.7751, -1.7719, -1.7684, -1.7645,
    -1.7604, -1.7559, -1.7511, -1.7461, -1.7408, -1.7352, -1.7293,
    -1.7232, -1.7168, -1.7102, -1.7033, -1.6962, -1.6888, -1.6811,
    -1.6732, -1.6651, -1.6568, -1.6482, -1.6394, -1.6304, -1.6211,
    -1.6116, -1.602, -1.5921, -1.5821, -1.5719, -1.5615, -1.551,
    -1.5403, -1.5294, -1.5185, -1.5074, -1.4961, -1.4848, -1.4733,
    -1.4617, -1.45, -1.4382, -1.4263, -1.4143, -1.4022, -1.39,
    -1.3777, -1.3653, -1.3529, -1.3403, -1.3277, -1.3149, -1.3021,
    -1.2892, -1.2762, -1.2631, -1.2499, -1.2366, -1.2233, -1.2098,
    -1.1962, -1.1826, -1.1688, -1.155, -1.141, -1.127, -1.1129,
    -1.0986, -1.0843, -1.0699, -1.0553, -1.0407, -1.026, -1.0112,
    -0.9962, -0.9812, -0.9661, -0.9509, -0.9356, -0.9202, -0.9048,
    -0.8892, -0.8735, -0.8578, -0.8419, -0.8419, -0.0631, 0.0362,
    0.1355, 0.2347, 0.334, 0.4333, 0.5326, 0.6319, 0.6142, 0.5965,
    0.5789, 0.5612, 0.5435, 0.5258, 0.5082, 0.4947, 0.482, 0.4699,
    0.4583, 0.4472, 0.4365, 0.4263, 0.4164, 0.4069, 0.3977, 0.3888,
    0.3802, 0.3718, 0.3637, 0.3558, 0.3481, 0.3406, 0.3333, 0.3262,
    0.3192, 0.3124, 0.3058, 0.2993, 0.2929, 0.2867, 0.2806, 0.2747,
    0.2688, 0.263, 0.2574, 0.2519, 0.2464, 0.2411, 0.2358, 0.2306,
    0.2255, 0.2205, 0.2156, 0.2107, 0.2059, 0.2012, 0.1966, 0.192,
    0.1875, 0.183, 0.1787, 0.1743, 0.17, 0.1658, 0.1617, 0.1575,
    0.1535, 0.1495, 0.1455, 0.1416, 0.1377, 0.1339, 0.1301, 0.1263,
    0.1226, 0.119, 0.1154, 0.1118, 0.1082, 0.1047, 0.1013, 0.0978,
    0.0944, 0.0911, 0.0877, 0.0844, 0.0811, 0.0779, 0.0747, 0.0715,
    0.0684, 0.0652, 0.0621, 0.0591, 0.056, 0.053, 0.05, 0.0471,
    0.0442, 0.0412, 0.0384, 0.0355, 0.0327, 0.0298, 0.027, 0.0243,
    0.0215, 0.0188, 0.0161, 0.0134, 0.0107, 0.0081, 0.0055, 0.0029,
    3e-04, -0.0023, -0.0048, -0.0074, -0.0099, -0.0124, -0.0148,
    -0.0173, -0.0197, -0.0222, -0.0246, -0.027, -0.0293, -0.0317,
    -0.034, -0.0364, -0.0387, -0.041, -0.0433, -0.0455, -0.0478,
    -0.05, -0.0522, -0.0545, -0.0566, -0.0588, -0.061, -0.0632,
    -0.0653, -0.0674, -0.0696, -0.0717, -0.0737, -0.0758, -0.0779,
    -0.08, -0.082, -0.084, -0.086, -0.0881, -0.0901, -0.092,
    -0.094, -0.096, -0.0979, -0.0999, -0.1018, -0.1037, -0.1056,
    -0.1075, -0.1094, -0.1113, -0.1132, -0.115, -0.1169, -0.1187,
    -0.1206, -0.1224, -0.1242, -0.126, -0.1278, -0.1296, -0.1314,
    -0.1331, -0.1349, -0.1366, -0.1384, -0.1401, -0.1418, -0.1436,
    -0.1453, -0.147, -0.1487, -0.1503, -0.152, -0.1537, -0.1554,
    -0.157, -0.1587, -0.1603, -0.1619, -0.1635, -0.1652, -0.1668,
    -0.1684, -0.17, -0.1715, -0.1731, -0.1747, -0.1763, -0.1778,
    -0.1794, -0.1809, -0.1824, -0.184, -0.1855, -0.187, -0.1885,
    -0.19, -0.1915, -0.193, -0.1945, -0.196, -0.1975, -0.1989,
    -0.2004, -0.2018, -0.2033, -0.2047, -0.2062, -0.2076, -0.209,
    -0.2104, -0.2119, -0.2133, -0.2147, -0.2161, -0.2175, -0.2188,
    -0.2202, -0.2216, -0.223, -0.2243, -0.2257, -0.227, -0.2284,
    -0.2297, -0.2311, -0.2324, -0.2337, -0.2351, -0.2364, -0.2377,
    -0.239, -0.2403, -0.2416, -0.2429, -0.2442, -0.2455, -0.2467,
    -0.248, -0.2493, -0.2505, -0.2518, -0.2531, -0.2543, -0.2556,
    -0.2568, -0.258, -0.2593, -0.2605, -0.2617, -0.263, -0.2642,
    -0.2654, -0.2666, -0.2678, -0.269, -0.2702, -0.2714, -0.2726,
    -0.2737, -0.2749, -0.2761, -0.2773, -0.2784, -0.2796, -0.2808,
    -0.2819, -0.2831, -0.2842, -0.2854, -0.2865, -0.2876, -0.2888,
    -0.2899, -0.291, -0.2922, -0.2933, -0.2944, -0.2955, -0.2966,
    -0.2977, -0.2988, -0.2999, -0.301, -0.3021, -0.3032, -0.3043,
    -0.3053, -0.3064, -0.3075, -0.3086, -0.3096, -0.3107, -0.3118,
    -0.3128, -0.3139, -0.3149, -0.316, -0.317, -0.3181, -0.3191,
    -0.3201, -0.3212, -0.3222, -0.3232, -0.3242, -0.3253, -0.3263,
    -0.3273, -0.3283, -0.3293, -0.3303, -0.3313, -0.3323, -0.3333,
    -0.3343, -0.3353, -0.3363, -0.3373, -0.3382, -0.3392, -0.3402,
    -0.3412, -0.3421, -0.3431, -0.3441, -0.345, -0.346, -0.347,
    -0.3479, -0.3489, -0.3498, -0.3508, -0.3517, -0.3526, -0.3536,
    -0.3545, -0.3555, -0.3564, -0.3573, -0.3582, -0.3592, -0.3601,
    -0.361, -0.3619, -0.3628, -0.3638, -0.3647, -0.3656, -0.3665,
    -0.3674, -0.3683, -0.3692, -0.3701, -0.371, -0.3719, -0.3727,
    -0.3736, -0.3745, -0.3754, -0.3763, -0.3772, -0.378, -0.3789,
    -0.3798, -0.3806, -0.3815, -0.3824, -0.3832, -0.3841, -0.385,
    -0.3858, -0.3867, -0.3875, -0.3884, -0.3892, -0.3901, -0.3909,
    -0.3917, -0.3926, -0.3934, -0.3943, -0.3951, -0.3959, -0.3968,
    -0.3976, -0.3984, -0.3992, -0.4001, -0.4009, -0.4017, -0.4025,
    -0.4033, -0.4041, -0.4049, -0.4057, -0.4066, -0.4074, -0.4082,
    -0.409, -0.4098, -0.4106, -0.4114, -0.4121, -0.4129, -0.4137,
    -0.4145, -0.4153, -0.4161, -0.4169, -0.4176, -0.4184, -0.4192,
    -0.42, -0.4208, -0.4215, -0.4223, -0.4231, -0.4238, -0.4246,
    -0.4254, -0.4261, -0.4269, -0.4276, -0.4284, -0.4292, -0.4299,
    -0.4307, -0.4314, -0.4322, -0.4329, -0.4337, -0.4344, -0.4351,
    -0.4359, -0.4366, -0.4374, -0.4381, -0.4388, -0.4396, -0.4403,
    -0.441, -0.4418, -0.4425, -0.4432, -0.4439, -0.4447, -0.4454,
    -0.4461, -0.4468, -0.4475, -0.4482, -0.449, -0.4497, -0.4504,
    -0.4511, -0.4518, -0.4525, -0.4532, -0.4539, -0.4546, -0.4553,
    -0.456, -0.4567, -0.4574, -0.4581, -0.4588, -0.4595, -0.4602,
    -0.4609, -0.4616, -0.4623, -0.4629, -0.4636, -0.4643, -0.465,
    -0.4657, -0.4663, -0.467, -0.4677, -0.4684, -0.469, -0.4697,
    -0.4704, -0.4711, -0.4717, -0.4724, -0.4731, -0.4737, -0.4744,
    -0.4751, -0.4757, -0.4764, -0.477, -0.4777, -0.4783, -0.479,
    -0.4797, -0.4803, -0.481, -0.4816, -0.4823, -0.4829, -0.4836,
    -0.4842, -0.4848, -0.4855, -0.4861, -0.4868, -0.4874, -0.488,
    -0.4887, -0.4893, -0.49, -0.4906, -0.4912, -0.4919, -0.4925,
    -0.4931, -0.4937, -0.4944, -0.495, -0.4956, -0.4962, -0.4969,
    -0.4975, -0.4981, -0.4987, -0.4993, -0.5, -0.5006, -0.5012,
    -0.5018, -0.5024, -0.503, -0.5036, -0.5043, -0.5049, -0.5055,
    -0.5061, -0.5067, -0.5073, -0.5079, -0.5085, -0.5091, -0.5097,
    -0.5103, -0.5109, -0.5115, -0.5121, -0.5127, -0.5133, -0.5139,
    -0.5145, -0.5151, -0.5156, -0.5162, -0.5168, -0.5174, -0.518,
    -0.5186, -0.5192, -0.5197, -0.5203, -0.5209, -0.5215, -0.5221,
    -0.5226, -0.5232, -0.5238, -0.5244, -0.525, -0.5255, -0.5261,
    -0.5267, -0.5272, -0.5278, -0.5284, -0.529, -0.5295, -0.5301,
    -0.5307, -0.5312, -0.5318, -0.5323, -0.5329, -0.5335, -0.534,
    -0.5346, -0.5351, -0.5357, -0.5363, -0.5368, -0.5374, -0.5379,
    -0.5385, -0.539, -0.5396, -0.5401, -0.5407, -0.5412, -0.5418,
    -0.5423, -0.5429, -0.5434, -0.544, -0.5445, -0.5451, -0.5456,
    -0.5461, -0.5467, -0.5472, -0.5478, -0.5483, -0.5488, -0.5494,
    -0.5499, -0.5504, -0.551, -0.5515, -0.552, -0.5526, -0.5531,
    -0.5536, -0.5542, -0.5547, -0.5552, -0.5557, -0.5563, -0.5568,
    -0.5573, -0.5578, -0.5584, -0.5589, -0.5594, -0.5599, -0.5605,
    -0.561, -0.5615, -0.562, -0.5625, -0.563, -0.5636, -0.5641,
    -0.5646, -0.5651, -0.5656, -0.5661, -0.5666, -0.5672, -0.5677,
    -0.5682, -0.5687, -0.5692, -0.5697, -0.5702, -0.5707, -0.5712,
    -0.5717, -0.5722, -0.5727, -0.5732, -0.5737, -0.5742, -0.5747,
    -0.5752, -0.5757, -0.5762, -0.5767, -0.5772, -0.5777, -0.5782,
    -0.5787, -0.5792, -0.5797, -0.5802, -0.5807, -0.5812, -0.5817,
    -0.5821, -0.5826, -0.5831, -0.5836, -0.5841, -0.5846, -0.5851,
    -0.5855, -0.586, -0.5865, -0.587, -0.5875, -0.588, -0.5884,
    -0.5889, -0.5894, -0.5899, -0.5904, -0.5908, -0.5913, -0.5918,
    -0.5923, -0.5927, -0.5932, -0.5937, -0.5942, -0.5946, -0.5951,
    -0.5956, -0.5961, -0.5965, -0.597, -0.5975, -0.5979, -0.5984,
    -0.5989, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684, -0.5684,
    -0.8886, -0.9068, -0.9248, -0.9427, -0.9605, -0.978, -0.9954,
    -1.0126, -1.0296, -1.0464, -1.063, -1.0794, -1.0956, -1.1115,
    -1.1272, -1.1427, -1.1579, -1.1728, -1.1875, -1.2019, -1.216,
    -1.2298, -1.2433, -1.2565, -1.2693, -1.2819, -1.2941, -1.306,
    -1.3175, -1.3287, -1.3395, -1.3499, -1.36, -1.3697, -1.379,
    -1.388, -1.3966, -1.4047, -1.4125, -1.4199, -1.427, -1.4336,
    -1.4398, -1.4456, -1.4511, -1.4561, -1.4607, -1.465, -1.4688,
    -1.4723, -1.4753, -1.478, -1.4803, -1.4823, -1.4838, -1.485,
    -1.4859, -1.4864, -1.4866, -1.4864, -1.4859, -1.4851, -1.4839,
    -1.4825, -1.4807, -1.4787, -1.4763, -1.4737, -1.4708, -1.4677,
    -1.4642, -1.4606, -1.4567, -1.4526, -1.4482, -1.4436, -1.4389,
    -1.4339, -1.4288, -1.4235, -1.418, -1.4123, -1.4065, -1.4006,
    -1.3945, -1.3883, -1.3819, -1.3755, -1.3689, -1.3621, -1.3553,
    -1.3483, -1.3413, -1.3341, -1.3269, -1.3195, -1.3121, -1.3046,
    -1.297, -1.2894, -1.2816, -1.2739, -1.2661, -1.2583, -1.2504,
    -1.2425, -1.2345, -1.2266, -1.2186, -1.2107, -1.2027, -1.1947,
    -1.1867, -1.1788, -1.1708, -1.1629, -1.1549, -1.147, -1.139,
    -1.1311, -1.1232, -1.1153, -1.1074, -1.0996, -1.0917, -1.0838,
    -1.076, -1.0681, -1.0603, -1.0525, -1.0447, -1.0368, -1.029,
    -1.0212, -1.0134, -1.0055, -0.9977, -0.9898, -0.9819, -0.974,
    -0.9661, -0.9582, -0.9503, -0.9423, -0.9344, -0.9264, -0.9184,
    -0.9104, -0.9024, -0.8944, -0.8863, -0.8783, -0.8703, -0.8623,
    -0.8542, -0.8462, -0.8382, -0.8301, -0.8221, -0.814, -0.806,
    -0.798, -0.7899, -0.7819, -0.7738, -0.7658, -0.7577, -0.7496,
    -0.7496, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0.3933,
    0.3916, 0.39, 0.3884, 0.3868, 0.3852, 0.3836, 0.3821, 0.3805,
    0.379, 0.3774, 0.3759, 0.3744, 0.3729, 0.3714, 0.3699, 0.3684,
    0.3669, 0.3655, 0.364, 0.3626, 0.3611, 0.3597, 0.3583, 0.3569,
    0.3555, 0.3541, 0.3527, 0.3513, 0.3499, 0.3485, 0.3472, 0.3458,
    0.3445, 0.3432, 0.3418, 0.3405, 0.3392, 0.3379, 0.3366, 0.3353,
    0.334, 0.3327, 0.3314, 0.3301, 0.3289, 0.3276, 0.3264, 0.3251,
    0.3239, 0.3226, 0.3214, 0.3202, 0.319, 0.3177, 0.3165, 0.3153,
    0.3141, 0.3129, 0.3117, 0.3106, 0.3094, 0.3082, 0.307, 0.3059,
    0.3047, 0.3036, 0.3024, 0.3013, 0.3001, 0.299, 0.2979, 0.2967,
    0.2956, 0.2945, 0.2934, 0.2923, 0.2912, 0.2901, 0.289, 0.2879,
    0.2868, 0.2857, 0.2847, 0.2836, 0.2825, 0.2814, 0.2804, 0.2793,
    0.2783, 0.2772, 0.2762, 0.2751, 0.2741, 0.273, 0.272, 0.271,
    0.27, 0.2689, 0.2679, 0.2669, 0.2659, 0.2649, 0.2639, 0.2629,
    0.2619, 0.2609, 0.2599, 0.2589, 0.2579, 0.2569, 0.256, 0.255,
    0.254, 0.253, 0.2521, 0.2511, 0.2502, 0.2492, 0.2482, 0.2473,
    0.2463, 0.2454, 0.2445, 0.2435, 0.2426, 0.2417, 0.2407, 0.2398,
    0.2389, 0.2379, 0.237, 0.2361, 0.2352, 0.2343, 0.2334, 0.2325,
    0.2316, 0.2307, 0.2298, 0.2289, 0.228, 0.2271, 0.2262, 0.2253,
    0.2244, 0.2235, 0.2227, 0.2218, 0.2209, 0.22, 0.2192, 0.2183,
    0.2174, 0.2166, 0.2157, 0.2148, 0.214, 0.2131, 0.2123, 0.2114,
    0.2106, 0.2097, 0.2089, 0.2081, 0.2072, 0.2064, 0.2056, 0.2047,
    0.2039, 0.2031, 0.2022, 0.2014, 0.2006, 0.1998, 0.199, 0.1981,
    0.1973, 0.1965, 0.1957, 0.1949, 0.1941, 0.1933, 0.1925, 0.1917,
    0.1909, 0.1901, 0.1893, 0.1885, 0.1877, 0.1869, 0.1861, 0.1853,
    0.1846, 0.1838, 0.183, 0.1822, 0.1814, 0.1807, 0.1799, 0.1791,
    0.1784, 0.1776, 0.1768, 0.1761, 0.1753, 0.1745, 0.1738, 0.173,
    0.1723, 0.1715, 0.1707, 0.17, 0.1692, 0.1685, 0.1678, 0.167,
    0.1663, 0.1655, 0.1648, 0.164, 0.1633, 0.1626, 0.1618, 0.1611,
    0.1604, 0.1596, 0.1589, 0.1582, 0.1575, 0.1567, 0.156, 0.1553,
    0.1546, 0.1539, 0.1531, 0.1524, 0.1517, 0.151, 0.1503, 0.1496,
    0.1489, 0.1482, 0.1475, 0.1468, 0.1461, 0.1454, 0.1447, 0.144,
    0.1433, 0.1426, 0.1419, 0.1412, 0.1405, 0.1398, 0.1391, 0.1384,
    0.1377, 0.137, 0.1364, 0.1357, 0.135, 0.1343, 0.1336, 0.133,
    0.1323, 0.1316, 0.1309, 0.1303, 0.1296, 0.1289, 0.1283, 0.1276,
    0.1269, 0.1263, 0.1256, 0.1249, 0.1243, 0.1236, 0.1229, 0.1223,
    0.1216, 0.121, 0.1203, 0.1197, 0.119, 0.1184, 0.1177, 0.1171,
    0.1164, 0.1158, 0.1151, 0.1145, 0.1138, 0.1132, 0.1125, 0.1119,
    0.1113, 0.1106, 0.11, 0.1093, 0.1087, 0.1081, 0.1074, 0.1068,
    0.1062, 0.1056, 0.1049, 0.1043, 0.1037, 0.103, 0.1024, 0.1018,
    0.1012, 0.1005, 0.0999, 0.0993, 0.0987, 0.0981, 0.0975, 0.0968,
    0.0962, 0.0956, 0.095, 0.0944, 0.0938, 0.0932, 0.0926, 0.0919,
    0.0913, 0.0907, 0.0901, 0.0895, 0.0889, 0.0883, 0.0877, 0.0871,
    0.0865, 0.0859, 0.0853, 0.0847, 0.0841, 0.0835, 0.0829, 0.0823,
    0.0817, 0.0812, 0.0806, 0.08, 0.0794, 0.0788, 0.0782, 0.0776,
    0.077, 0.0764, 0.0759, 0.0753, 0.0747, 0.0741, 0.0735, 0.073,
    0.0724, 0.0718, 0.0712, 0.0706, 0.0701, 0.0695, 0.0689, 0.0683,
    0.0678, 0.0672, 0.0666, 0.0661, 0.0655, 0.0649, 0.0644, 0.0638,
    0.0632, 0.0627, 0.0621, 0.0615, 0.061, 0.0604, 0.0598, 0.0593,
    0.0587, 0.0582, 0.0576, 0.0571, 0.0565, 0.0559, 0.0554, 0.0548,
    0.0543, 0.0537, 0.0532, 0.0526, 0.0521, 0.0515, 0.051, 0.0504,
    0.0499, 0.0493, 0.0488, 0.0482, 0.0477, 0.0471, 0.0466, 0.0461,
    0.0455, 0.045, 0.0444, 0.0439, 0.0434, 0.0428, 0.0423, 0.0417,
    0.0412, 0.0407, 0.0401, 0.0396, 0.0391, 0.0385, 0.038, 0.0375,
    0.0369, 0.0364, 0.0359, 0.0353, 0.0348, 0.0343, 0.0338, 0.0332,
    0.0327, 0.0322, 0.0317, 0.0311, 0.0306, 0.0301, 0.0296, 0.0291,
    0.0285, 0.028, 0.0275, 0.027, 0.0265, 0.0259, 0.0254, 0.0249,
    0.0244, 0.0239, 0.0234, 0.0228, 0.0223, 0.0218, 0.0213, 0.0208,
    0.0203, 0.0198, 0.0193, 0.0188, 0.0183, 0.0177, 0.0172, 0.0167,
    0.0162, 0.0157, 0.0152, 0.0147, 0.0142, 0.0137, 0.0132, 0.0127,
    0.0122, 0.0117, 0.0112, 0.0107, 0.0102, 0.0097, 0.0092, 0.0087,
    0.0082, 0.0077, 0.0072, 0.0067, 0.0062, 0.0057, 0.0052, 0.0047,
    0.0043, 0.0038, 0.0033, 0.0028, 0.0023, 0.0018, 0.0013, 8e-04,
    3e-04, -1e-04, -6e-04, -0.0011, -0.0016, -0.0021, -0.0026,
    -0.0031, -0.0035, -0.004, -0.0045, -0.005, -0.0055, -0.006,
    -0.0064, -0.0069, -0.0074, -0.0079, -0.0083, -0.0088, -0.0093,
    -0.0098, -0.0103, -0.0107, -0.0112, -0.0117, -0.0122, -0.0126,
    -0.0131, -0.0136, -0.014, -0.0145, -0.015, -0.0155, -0.0159,
    -0.0164, -0.0169, -0.0173, -0.0178, -0.0183, -0.0187, -0.0192,
    -0.0197, -0.0201, -0.0206, -0.0211, -0.0215, -0.022, -0.0225,
    -0.0229, -0.0234, -0.0238, -0.0243, -0.0248, -0.0252, -0.0257,
    -0.0261, -0.0266, -0.0271, -0.0275, -0.028, -0.0284, -0.0289,
    -0.0294, -0.0298, -0.0303, -0.0307, -0.0312, -0.0316, -0.0321,
    -0.0325, -0.033, -0.0334, -0.0339, -0.0343, -0.0348, -0.0352,
    -0.0357, -0.0361, -0.0366, -0.037, -0.0375, -0.0379, -0.0384,
    -0.0388, -0.0393, -0.0397, -0.0402, -0.0406, -0.0411, -0.0415,
    -0.042, -0.0424, -0.0428, -0.0433, -0.0437, -0.0442, -0.0446,
    -0.045, -0.0455, -0.0459, -0.0464, -0.0468, -0.0472, -0.0477,
    -0.0481, -0.0486, -0.049, -0.0494, -0.0499, -0.0503, -0.0507,
    -0.0512, -0.0516, -0.0521, -0.0525, -0.0529, -0.0534, -0.0538,
    -0.0542, -0.0546, -0.0551, -0.0555, -0.0559, -0.0564, -0.0568,
    -0.0572, -0.0577, -0.0581, -0.0585, -0.0589, -0.0594, -0.0598,
    -0.0602, -0.0607, -0.0611, -0.0615, -0.0619, -0.0624, -0.0628,
    -0.0632, -0.0636, -0.0641, -0.0645, -0.0649, -0.0653, -0.0657,
    -0.0662, -0.0666, -0.067, -0.0674, -0.0679, -0.0683, -0.0687,
    -0.0691, -0.0695, -0.0699, -0.0704, -0.0708, -0.0712, -0.0716,
    -0.072, -0.0725, -0.0729, -0.0733, -0.0737, -0.0741, -0.0745,
    -0.0749, -0.0754, -0.0758, -0.0762, -0.0766, -0.077, -0.0774,
    -0.0778, -0.0782, -0.0787, -0.0791, -0.0795, -0.0799, -0.0803,
    -0.0807, -0.0811, -0.0815, -0.0819, -0.0823, -0.0827, -0.0831,
    -0.0836, -0.084, -0.0844, -0.0848, -0.0852, -0.0856, -0.086,
    -0.0864, -0.0868, -0.0872, -0.0876, -0.088, -0.0884, -0.0888,
    -0.0892, -0.0896, -0.09, -0.0904, -0.0908, -0.0912, -0.0916,
    -0.092, -0.0924, -0.0928, -0.0932, -0.0936, -0.094, -0.0944,
    -0.0948, -0.0952, -0.0956, -0.096, -0.0964, -0.0968, -0.0972,
    -0.0976, -0.098, -0.0984, -0.0988, -0.0992, -0.0996, -0.0999,
    -0.1003, -0.1007, -0.1011, -0.1015, -0.1019, -0.1023, -0.1027,
    -0.1031, -0.1035, -0.1039, -0.1043, -0.1046, -0.105, -0.1054,
    -0.1058, -0.1062, -0.1066, -0.107, -0.1074, -0.1077, -0.1081,
    -0.1085, -0.1089, -0.1093, -0.1097, -0.1101, -0.1105, -0.1108,
    -0.1112, -0.1116, -0.112, -0.1124, -0.1128, -0.1131, -0.1135,
    -0.1139, -0.1143, -0.1147, -0.115, -0.1154, -0.1158, -0.1162,
    -0.1166, -0.117, -0.1173, -0.1177, -0.1181, -0.1185, -0.1188,
    -0.1192, -0.1196, -0.12, -0.1204, -0.1207, -0.1211, -0.1215,
    -0.1219, -0.1222, -0.1226, -0.123, -0.1234, -0.1237, -0.1241,
    -0.1245, -0.1249, -0.1252, -0.1256, -0.126, -0.1264, -0.1267,
    -0.1271, -0.1275, -0.1279, -0.1282, -0.1286, -0.129, -0.1293,
    -0.1297, -0.1301, -0.1305, -0.1308, -0.1312, -0.1316, -0.1319,
    -0.1323, -0.1327, -0.133, -0.1334, -0.1338, -0.1341, -0.1345,
    -0.1349, -0.1352, -0.1356, -0.136, -0.1363, -0.1367, -0.1371,
    -0.1374, -0.1378, -0.1382, -0.1385, -0.1389, -0.1393, -0.1396,
    -0.14, -0.1403, -0.1407, -0.1411, -0.1414, -0.1418, -0.1422,
    -0.1425, -0.1429, -0.1432, -0.1436, -0.144, -0.1443, -0.1447,
    -0.145, -0.1454, -0.1458, -0.1461, -0.1465, -0.1468, -0.1472,
    -0.1476, -0.1479, -0.1483, -0.1486, -0.149, -0.1493, -0.1497,
    -0.1501, -0.1504, -0.1508, -0.1511, -0.1515, -0.1518, -0.1522,
    -0.1525, -0.1529, -0.1533, -0.1536, -0.154, -0.1543, -0.1547,
    -0.155, -0.1554, -0.1557, -0.1561, -0.1564, -0.1568, -0.1571,
    -0.1575, -0.1578, -0.1582, -0.1585, -0.1589, -0.1592, -0.1596,
    -0.1599, -0.1603, -0.1606, -0.161, -0.1613, -0.1617, -0.162,
    -0.1624, -0.1627, -0.1631, -0.1634, -0.1638, -0.1641, -0.1645,
    -0.1648, -0.1652, -0.1655, -0.1658, -0.1662, -0.1665, -0.1669,
    -0.1672, -0.1676, -0.1679, -0.1683, -0.1686, -0.1689, -0.1693,
    -0.1696, -0.17, -0.1703, -0.1707, -0.171, -0.1713, -0.1717,
    -0.172, -0.1724, -0.1727, -0.1731, -0.1734, -0.1737, -0.1741,
    -0.1744, -0.1748, -0.1751, -0.1754, -0.1758, -0.1761, -0.1765,
    -0.1768, -0.1771, -0.1775, -0.1778, -0.1781, -0.1785, -0.1788,
    -0.1792, -0.1795, -0.1798, -0.1802, -0.1805, -0.1808, -0.1812,
    -0.1815, -0.1818, -0.1822, -0.1825, -0.1829, -0.1832, -0.1835,
    -0.1839, -0.1842, -0.1845, -0.1849, -0.1852, -0.1855, -0.1859,
    -0.1862, -0.1865, -0.1869, -0.1872, -0.1875, -0.1879, -0.1882,
    -0.1885, -0.1888, -0.1892, -0.1895, -0.1898, -0.1902, -0.1905,
    -0.1908, -0.1912, -0.1915, -0.1918, -0.1921, -0.1925, -0.1928,
    -0.1931, -0.1935, -0.1938, -0.1941, -0.1944, -0.1948, -0.1951,
    -0.1954, -0.1958, -0.1961, -0.1964, -0.1967, -0.1971, -0.1974,
    -0.1977, -0.198, -0.1984, -0.1987, -0.199, -0.1993, -0.1997,
    -0.2, -0.2003, -0.2006, -0.201, -0.2013, -0.2016, -0.2019,
    -0.2023, -0.2026, -0.2029, -0.2032, -0.2035, -0.2039, -0.2042,
    -0.2045, -0.2048, -0.2052, -0.2055, -0.2058, -0.2061, -0.2064,
    -0.2068, -0.2071, -0.2074, -0.2077, -0.208, -0.2084, -0.2087,
    -0.209, -0.2093, -0.2096, -0.21, -0.2103, -0.2106, -0.2109,
    -0.2112, -0.2116, -0.2119, -0.2122, -0.2125, -0.2128, -0.2131,
    -0.2135, -0.2138, -0.2141, -0.2144, -0.2147, -0.215, -0.2153,
    -0.2157, -0.216, -0.2163, -0.2166, -0.2169, -0.2172, -0.2176,
    -0.2179, -0.2182, -0.2185, -0.2188, -0.2191, -0.2194, -0.2197,
    -0.2201, -0.2204, -0.2207, -0.221, -0.2213, -0.2216, -0.2219,
    -0.2222, -0.2226, -0.2229, -0.2232, -0.2235, -0.2238, -0.2241,
    -0.2244, -0.2247, -0.225, -0.2254, -0.2257, -0.226, -0.2263,
    -0.2266, -0.2269, -0.2272, -0.2275, -0.2278, -0.2281, -0.2284,
    -0.2288, -0.2291, -0.2294, -0.2297, -0.23, -0.2303, -0.2306,
    -0.2309, -0.2312, -0.2315, -0.2318, -0.2321, -0.2324, -0.2327,
    -0.2331, -0.2334, -0.2337, -0.234, -0.2343, -0.2346, -0.2349,
    -0.2352, -0.2355, -0.2358, -0.2361, -0.2364, -0.2367, -0.237,
    -0.2373, -0.2376, -0.2379, -0.2382, -0.2385, -0.2388, -0.2391,
    -0.2394, -0.2397, -0.24, -0.2403, -0.2406, -0.2409, -0.2412,
    -0.2415, -0.2418, -0.2422, -0.2425, -0.2428, -0.2431, -0.2434,
    -0.2437, -0.244, -0.2443, -0.2446, -0.2449, -0.2452, -0.2455,
    -0.2457, -0.246, -0.2463, -0.2466, -0.2469, -0.2472, -0.2475,
    -0.2478, -0.2481, -0.2484, -0.2487, -0.249, -0.2493, -0.2496,
    -0.2499, -0.2502, -0.2505, -0.2508, -0.2511, -0.2514, -0.2517,
    -0.252, -0.2523, -0.2526, -0.2529, -0.2532, -0.2535, -0.2538,
    -0.2541, -0.2544, -0.2546, -0.2549, -0.2552, -0.2555, -0.2558,
    -0.2561, -0.2564, -0.2567, -0.257, -0.2573, -0.2576, -0.2579,
    -0.2582, -0.2585, -0.2588, -0.259, -0.2593, -0.2596, -0.2599,
    -0.2602, -0.2605, -0.2608, -0.2611, -0.2614, -0.2617, -0.262,
    -0.2623, -0.2625, -0.2628, -0.2631, -0.2634, -0.2637, -0.264,
    -0.2643, -0.2646, -0.2649, -0.2652, -0.2654, -0.2657, -0.266,
    -0.2663, -0.2666, -0.2669, -0.2672, -0.2675, -0.2677, -0.268,
    -0.2683, -0.2686, -0.2689, -0.2692, -0.2695, -0.2698, -0.27,
    -0.2703, -0.2706, -0.2709, -0.2712, -0.2715, -0.2718, -0.272,
    -0.2723, -0.2726, -0.2729, -0.2732, -0.2735, -0.2738, -0.274,
    -0.2743, -0.2746, -0.2749, -0.2752, -0.2755, -0.2758, -0.276,
    -0.2763, -0.2766, -0.2769, -0.2772, -0.2775, -0.2777, -0.278,
    -0.2783, -0.2786, -0.2789, -0.2791, -0.2794, -0.2797, -0.28,
    -0.2803, -0.2806, -0.2808, -0.2811, -0.2814, -0.2817, -0.282,
    -0.2822, -0.2825, -0.2828, -0.2831, -0.2834, -0.2836, -0.2839,
    -0.2842, -0.2845, -0.2848, -0.285, -0.2853, -0.2856, -0.2859,
    -0.2862, -0.2864, -0.2867, -0.287, -0.2873, -0.2876, -0.2878,
    -0.2881, -0.2884, -0.2887, -0.2889, -0.2892, -0.2895, -0.2898,
    -0.2901, -0.2903, -0.2906, -0.2909, -0.2912, -0.2914, -0.2917,
    -0.292, -0.2923, -0.2925, -0.2928, -0.2931, -0.2934, -0.2936,
    -0.2939, -0.2942, -0.2945, -0.2947, -0.295, -0.2953, -0.2956,
    -0.2958, -0.2961, -0.2964, -0.2967, -0.2969, -0.2972, -0.2975,
    -0.2978, -0.298, -0.2983, -0.2986, -0.2989, -0.2991, -0.2994,
    -0.2997, -0.3, -0.3002, -0.3005, -0.3008, -0.301, -0.3013,
    -0.3016, -0.3019, -0.3021, -0.3024, -0.3027, -0.3029, -0.3032,
    -0.3035, -0.3038, -0.304, -0.3043, -0.3046, -0.3048, -0.3051,
    -0.3054, -0.3056, -0.3059, -0.3062, -0.3065, -0.3067, -0.307,
    -0.3073, -0.3075, -0.3078, -0.3081, -0.3083, -0.3086, -0.3089,
    -0.3091, -0.3094, -0.3097, -0.31, -0.3102, -0.3105, -0.3108,
    -0.311, -0.3113, -0.3116, -0.3118, -0.3121, -0.3124, -0.3126,
    -0.3129, -0.3132, -0.3134, -0.3137, -0.314, -0.3142, -0.3145,
    -0.3148, -0.315, -0.3153, -0.3156, -0.3158, -0.3161, -0.3164,
    -0.3166, -0.3169, -0.3172, -0.3174, -0.3177, -0.3179, -0.3182,
    -0.3185, -0.3187, -0.319, -0.3193, -0.3195, -0.3198, -0.3201,
    -0.3203, -0.3206, -0.3208, -0.3211, -0.3214, -0.3216, -0.3219,
    -0.3222, -0.3224, -0.3227, -0.323, -0.3232, -0.3235, -0.3237,
    -0.324, -0.3243, -0.3245, -0.3248, -0.325, -0.3253, -0.3256,
    -0.3258, -0.3261, -0.3264, -0.3266, -0.3269, -0.3271, -0.3274,
    -0.3277, -0.3279, -0.3282, -0.3284, -0.3287, -0.329, -0.3292,
    -0.3295, -0.3297, -0.33, -0.3303, -0.3305, -0.3308, -0.331,
    -0.3313, -0.3316, -0.3318, -0.3321, -0.3323, -0.3326, -0.3328,
    -0.3331, -0.3334, -0.3336, -0.3339, -0.3341, -0.3344, -0.3347,
    -0.3349, -0.3352, -0.3354, -0.3357, -0.3359, -0.3362, -0.3365,
    -0.3367, -0.337, -0.3372, -0.3375, -0.3377, -0.338, -0.3382,
    -0.3385, -0.3388, -0.339, -0.3393, -0.3395, -0.3398, -0.34,
    -0.3403, -0.3405, -0.3408, -0.3411, -0.3413, -0.3416, -0.3418,
    -0.3421, -0.3423, -0.3426, -0.3428, -0.3431, -0.3433, -0.3436,
    -0.3439, -0.3441, -0.3444, -0.3446, -0.3449, -0.3451, -0.3454,
    -0.3456, -0.3459, -0.3461, -0.3464, -0.3466, -0.3469, -0.3471,
    -0.3474, -0.3476, -0.3479, -0.3482, -0.3484, -0.3487, -0.3489,
    -0.3492, -0.3494, -0.3497, -0.3499, -0.3502, -0.3504, -0.3507,
    -0.3509, -0.3512, -0.3514, -0.3517, -0.3519, -0.3522, -0.3524,
    -0.3527, -0.3529, -0.3532, -0.3534, -0.3537, -0.3539, -0.3542,
    -0.3544, -0.3547, -0.3549, -0.3552, -0.3554, -0.3557, -0.3559,
    -0.3562, -0.3564, -0.3567, -0.3569, -0.3572, -0.3574, -0.3577,
    -0.3579, -0.3582, -0.3584, -0.3586, -0.3589, -0.3591, -0.3594,
    -0.3596, -0.3599, -0.3601, -0.3604, -0.3606, -0.3609, -0.3611,
    -0.3614, -0.3616, -0.3619, -0.3621, -0.3624, -0.3626, -0.3628,
    -0.3631, -0.3633, -0.3636, -0.3638, -0.3641, -0.3643, -0.3646,
    -0.3648, -0.3651, -0.3653, -0.3656, -0.3658, -0.366, -0.3663,
    -0.3665, -0.3668, -0.367, -0.3673, -0.3675, -0.3678, -0.368,
    -0.3682, -0.3685, -0.3687, -0.369, -0.3692, -0.3695, -0.3697,
    -0.3699, -0.3702, -0.3704, -0.3707, -0.3709, -0.3712, -0.3714,
    -0.3717, -0.3719, -0.3721, -0.3724, -0.3726, -0.3729, -0.3731,
    -0.3733, -0.3736, -0.3738, -0.3741, -0.3743, -0.3746, -0.3748,
    -0.375, -0.3753, -0.3755, -0.3758, -0.376, -0.3762, -0.3765,
    -0.3767, -0.377, -0.3772, -0.3775, -0.3777, -0.3779, -0.3782,
    -0.3784, -0.3787, -0.3789, -0.3791, -0.3794, -0.3796, -0.3799,
    -0.3801, -0.3803, -0.3806, -0.3808, -0.3811, -0.3813, -0.3815,
    -0.3818, -0.382, -0.3822, -0.3825, -0.3827, -0.383, -0.3832,
    -0.3834, -0.3837, -0.3839, -0.3842, -0.3844, -0.3846, -0.3849,
    -0.3851, -0.3853, -0.3856, -0.3858, -0.3861, -0.3863, -0.3865,
    -0.3868, -0.387, -0.3872, -0.3875, -0.3877, -0.388, -0.3882,
    -0.3884, -0.3887, -0.3889, -0.3891, -0.3894, -0.3896, -0.3898,
    -0.3901, -0.3903, -0.3906, -0.3908, -0.391, -0.3913, -0.3915,
    -0.3917, -0.392, -0.3922, -0.3924, -0.3927, -0.3929, -0.3931,
    -0.3934, -0.3936, -0.3938, -0.3941, -0.3943, -0.3946, -0.3948,
    -0.395, -0.3953, -0.3955, -0.3957, -0.396, -0.3962, -0.3964,
    -0.3967, -0.3969, -0.3971, -0.3974, -0.3976, -0.3978, -0.72895,
    -0.3981, -0.3983, -0.3985, -0.3988, -0.399, -0.3992, -0.3995,
    -0.3997, -0.3999, -0.4002, -0.4004, -0.4006, -0.4009, -0.4011,
    -0.4013, -0.4015, -0.4018, -0.402, -0.4022, -0.4025, -0.4027,
    -0.4029, -0.4032, -0.4034, -0.4036, -0.4039, -0.4041, -0.4043,
    -0.4046, -0.4048, -0.75845, -0.405, -0.78927, -0.82138, -0.85473,
    -0.88928, -0.92496, -0.96164, -0.99919, -1.03745, -1.07629,
    -1.11556, -1.15511, -1.1948, -1.23449, -1.27403, -1.31328,
    -1.3521, -1.39034, -1.42785, -1.4645, -1.50018, -1.53485,
    -1.5685, -1.60108, -1.63258, -1.66297, -1.69222, -1.7203,
    -1.74719, -1.77285, -1.79727, -1.8204, -1.84224, -1.86274,
    -1.88189, -1.89968, -1.91614, -1.93128, -1.94514, -1.95773,
    -1.96908, -1.9792, -1.98813, -1.99588, -2.00248, -2.00795,
    -2.01231, -2.01558, -2.0178, -2.01897, -2.01912, -2.01828,
    -2.01647, -2.01371, -2.01004, -2.00546, -2, -1.9937, -1.98657,
    -1.97863, -1.96991, -1.96043, -1.95022, -1.9393, -1.9277,
    -1.91544, -1.90255, -1.88906, -1.87501, -1.86041, -1.8453,
    -1.82971, -1.81367, -1.7972, -1.78034, -1.76312, -1.74555,
    -1.72768, -1.70954, -1.69114, -1.67254, -1.65377, -1.63486,
    -1.61586, -1.5968, -1.57771, -1.55864, -1.53962, -1.5207,
    -1.5019, -1.48326, -1.46482, -1.44663, -1.4287, -1.41108,
    -1.39378, -1.37683, -1.36024, -1.34404, -1.32825, -1.31289,
    -1.29798, -1.28355, -1.26961, -1.25619, -1.24331, -1.23099,
    -1.21926, -1.20812, -1.19761, -1.18774, -1.17852, -1.16998,
    -1.16213, -1.15499, -1.14858, -1.14291, -1.138, -1.13388,
    -1.13055, -1.12804, -1.12636, -1.12553, -1.12555, -1.12638,
    -1.128, -1.13037, -1.13345, -1.13722, -1.14163, -1.14666,
    -1.15227, -1.15843, -1.16511, -1.17226, -1.17986, -1.18788,
    -1.19627, -1.20499, -1.21395, -1.2231, -1.23235, -1.24164,
    -1.2509, -1.26004, -1.26901, -1.27772, -1.28612, -1.29412,
    -1.30165, -1.30865, -1.31504, -1.32075, -1.32576, -1.33005,
    -1.33359, -1.33637, -1.33836, -1.33955, -1.33992, -1.33944,
    -1.3381, -1.33587, -1.33274, -1.32869, -1.32369, -1.31773,
    -1.3108, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.49271, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733, -0.1733,
    -0.1733, -0.1733, -0.1733, -0.50464, -0.1733, -0.51656, -0.52844,
    -0.5403, -0.55212, -0.56392, -0.57568, -0.5874, -0.59908,
    -0.61073, -0.62233, -0.63388, -0.64539, -0.65684, -0.66825,
    -0.67959, -0.69089, -0.70212, -0.71329, -0.72439, -0.73543,
    -0.74641, -0.75731, -0.76814, -0.77891, -0.7896, -0.80022,
    -0.81076, -0.82123, -0.83162, -0.84193, -0.85217, -0.86233,
    -0.8724, -0.88239, -0.8923, -0.90213, -0.91187, -0.92153,
    -0.93111, -0.94061, -0.95002, -0.95935, -0.9686, -0.97776,
    -0.98685, -0.99585, -1.00477, -1.0136, -1.02236, -1.03103,
    -1.03963, -1.04814, -1.05657, -1.06493, -1.07321, -1.08141,
    -1.08954, -1.09759, -1.10557, -1.11347, -1.12131, -1.12907,
    -1.13676, -1.14439, -1.15194, -1.15943, -1.16685, -1.1742,
    -1.18149, -1.18871, -1.19587, -1.20297, -1.21, -1.21697,
    -1.22389, -1.23074, -1.23753, -1.24427, -1.25095, -1.25757,
    -1.26414, -1.27064, -1.27709, -1.28349, -1.28983, -1.29611,
    -1.30233, -1.3085, -1.31461, -1.32067, -1.32667, -1.33261,
    -1.3385, -1.34434, -1.35012, -1.35584, -1.3615, -1.36711,
    -1.37265, -1.37814, -1.38357, -1.38894, -1.39425, -1.3995,
    -1.40469, -1.40982, -1.41489, -1.41989, -1.42484, -1.42971,
    -1.43453, -1.43928, -1.44397, -1.44859, -1.45315, -1.45764,
    -1.46207, -1.46642, -1.47072, -1.47494, -1.4791, -1.48319,
    -1.48721, -1.49116, -1.49504, -1.49886, -1.5026, -1.50628,
    -1.50989, -1.51343, -1.51691, -1.52031, -1.52364, -1.52691,
    -1.53011, -1.53324, -1.5363, -1.5393, -1.54222, -1.54508,
    -1.54788, -1.55061, -1.55328, -1.55588, -1.55843, -1.56091,
    -1.56333, -1.56569, -1.56799, -1.57024, -1.57243, -1.57456,
    -1.57664, -1.57867, -1.58064, -1.58256, -1.58443, -1.58625,
    -1.58803, -1.58975, -1.59143, -1.59307, -1.59466, -1.59621,
    -1.59771, -1.59918, -1.60061, -0.303, -0.3039, -0.3047, -0.3056,
    -0.3064, -0.3072, -0.3081, -0.3089, -0.3097, -0.3106, -0.3114,
    -0.3122, -0.313, -0.3138, -0.3146, -0.3154, -0.3162, -0.317,
    -0.3178, -0.3186, -0.3194, -0.3202, -0.321, -0.3218, -0.3226,
    -0.3234, -0.3242, -0.3249, -0.3257, -0.3265, -0.3272, -0.328,
    -0.3288, -0.3295, -0.3303, -0.3311, -0.3318, -0.3326, -0.3333,
    -0.3341, -0.3348, -0.3356, -0.3363, -0.3371, -0.3378, -0.3386,
    -0.3393, -0.34, -0.3408, -0.3415, -0.3422, -0.343, -0.3437,
    -0.3444, -0.3451, -0.3458, -0.3466, -0.3473, -0.348, -0.3487,
    -0.3494, -0.3501, -0.3509, -0.3516, -0.3523, -0.353, -0.3537,
    -0.3544, -0.3551, -0.3558, -0.3565, -0.3572, -0.3579, -0.3586,
    -0.3592, -0.3599, -0.3606, -0.3613, -0.362, -0.3627, -0.3634,
    -0.364, -0.3647, -0.3654, -0.3661, -0.3668, -0.3674, -0.3681,
    -0.3688, -0.3694, -0.3701, -0.3708, -0.3714, -0.3721, -0.3728,
    -0.3734, -0.3741, -0.3748, -0.3754, -0.3761, -0.3767, -0.3774,
    -0.378, -0.3787, -0.3793, -0.38, -0.3806, -0.3813, -0.3819,
    -0.3826, -0.3832, -0.3839, -0.3845, -0.3852, -0.3858, -0.3864,
    -0.3871, -0.3877, -0.3884, -0.389, -0.3896, -0.3903, -0.3909,
    -0.3915, -0.3921, -0.3928, -0.3934, -0.394, -0.3947, -0.3953,
    -0.3959, -0.3965, -0.3971, -0.3978, -0.3984, -0.399, -0.3996,
    -0.4002, -0.4009, -0.4015, -0.4021, -0.4027, -0.4033, -0.4039,
    -0.4045, -0.4051, -0.4058, -0.4064, -0.407, -0.4076, -0.4082,
    -0.4088, -0.4094, -0.41, -0.4106, -0.4112, -0.4118, -0.4124,
    -0.413, -0.4136, -0.4142, -0.4148, -0.4154, -0.416, -0.4166,
    -0.4172, -0.4177, -0.4183, -0.4189, -0.4195, -0.4201, -0.4207,
    -0.4213, -0.4219, -0.4224, -0.423, -0.4236, -0.4242, -0.4248,
    -0.4254, -0.4259, -0.4265, -0.4271, -0.4277, -0.4283, -0.4288,
    -0.4294, -0.43, -0.4306, -0.4311, -0.4317, -0.4323, -0.4329,
    -0.4334, -0.434, -0.4346, -0.4351, -0.4357, -0.4363, -0.4368,
    -0.4374, -0.438, -0.4385, -0.4391, -0.4397, -0.4402, -0.4408,
    -0.4414, -0.4419, -0.4425, -0.443, -0.4436, -0.4441, -0.4447,
    -0.4453, -0.4458, -0.4464, -0.4469, -0.4475, -0.448, -0.4486,
    -0.4491, -0.4497, -0.4502, -0.4508, -0.4514, -0.4519, -0.4524,
    -0.453, -0.4535, -0.4541, -0.4546, -0.4552, -0.4557, -0.4563,
    -0.4568, -0.4574, -0.4579, -0.4584, -0.459, -0.4595, -0.4601,
    -0.4606, -0.4612, -0.4617, -0.4622, -0.4628, -0.4633, -0.4638,
    -0.4644, -0.4649, -0.4655, -0.466, -0.4665, -0.4671, -0.4676,
    -0.4681, -0.4687, -0.4692, -0.4697, -0.4702, -0.4708, -0.4713,
    -0.4718, -0.4724, -0.4729, -0.4734, -0.4739, -0.4745, -0.475,
    -0.4755, -0.476, -0.4766, -0.4771, -0.4776, -0.4781, -0.4787,
    -0.4792, -0.4797, -0.4802, -0.4807, -0.4813, -0.4818, -0.4823,
    -0.4828, -0.4833, -0.4839, -0.4844, -0.4849, -0.4854, -0.4859,
    -0.4864, -0.4869, -0.4875, -0.488, -0.4885, -0.489, -0.4895,
    -0.49, -0.4905, -0.491, -0.4916, -0.4921, -0.4926, -0.4931,
    -0.4936, -0.4941, -0.4946, -0.4951, -0.4956, -0.4961, -0.4966,
    -0.4971, -0.4976, -0.4981, -0.4986, -0.4992, -0.4997, -0.5002,
    -0.5007, -0.5012, -0.5017, -0.5022, -0.5027, -0.5032, -0.5037,
    -0.5042, -0.5047, -0.5052, -0.5057, -0.5062, -0.5067, -0.5072,
    -0.5076, -0.5081, -0.5086, -0.5091, -0.5096, -0.5101, -0.5106,
    -0.5111, -0.5116, -0.5121, -0.5126, -0.5131, -0.5136, -0.5141,
    -0.5146, -0.515, -0.5155, -0.516, -0.5165, -0.517, -0.5175,
    -0.518, -0.5185, -0.519, -0.5194, -0.5199, -0.5204, -0.5209,
    -0.5214, -0.5219, -0.5224, -0.5228, -0.5233, -0.5238, -0.5243,
    -0.5248, -0.5253, -0.5257, -0.5262, -0.5267, -0.5272, -0.5277,
    -0.5281, -0.5286, -0.5291, -0.5296, -0.5301, -0.5305, -0.531,
    -0.5315, -0.532, -0.5324, -0.5329, -0.5334, -0.5339, -0.5344,
    -0.5348, -0.5353, -0.5358, -0.5362, -0.5367, -0.5372, -0.5377,
    -0.5381, -0.5386, -0.5391, -0.5396, -0.54, -0.5405, -0.541,
    -0.5414, -0.5419, -0.5424, -0.5429, -0.5433, -0.5438, -0.5443,
    -0.5447, -0.5452, -0.5457, -0.5461, -0.5466, -0.5471, -0.5475,
    -0.548, -0.5485, -0.5489, -0.5494, -0.5499, -0.5503, -0.5508,
    -0.5512, -0.5517, -0.5522, -0.5526, -0.5531, -0.5536, -0.554,
    -0.5545, -0.5549, -0.5554, -0.5559, -0.5563, -0.5568, -0.5572,
    -0.5577, -0.5582, -0.5586, -0.5591, -0.5595, -0.56, -0.5605,
    -0.5609, -0.5614, -0.5618, -0.5623, -0.5627, -0.5632, -0.5636,
    -0.5641, -0.5646, -0.565, -0.5655, -0.5659, -0.5664, -0.5668,
    -0.5673, -0.5677, -0.5682, -0.5686, -0.5691, -0.5695, -0.57,
    -0.5704, -0.5709, -0.5713, -0.5718, -0.5722, -0.5727, -0.5731,
    -0.5736, -0.574, -0.5745, -0.5749, -0.5754, -0.5758, -0.5763,
    -0.5767, -0.5772, -0.5776, -0.5781, -0.5785, -0.579, -0.5794,
    -0.5799, -0.5803, -0.5807, -0.5812, -0.5816, -0.5821, -0.5825,
    -0.583, -0.5834, -0.5839, -0.5843, -0.5847, -0.5852, -0.5856,
    -0.5861, -0.5865, -0.5869, -0.5874, -0.5878, -0.5883, -0.5887,
    -0.5891, -0.5896, -0.59, -0.5905, -0.5909, -0.5913, -0.5918,
    -0.5922, -0.5927, -0.5931, -0.5935, -0.594, -0.5944, -0.5948,
    -0.5953, -0.5957, -0.5961, -0.5966, -0.597, -0.5975, -0.5979,
    -0.5983, -0.5988, -0.5992, -0.5996, -0.6001, -0.6005, -0.6009,
    -0.6014, -0.6018, -0.6022, -0.6027, -0.6031, -0.6035, -0.6039,
    -0.6044, -0.6048, -0.6052, -0.6057, -0.6061, -0.6065, -0.607,
    -0.6074, -0.6078, -0.6082, -0.6087, -0.6091, -0.6095, -0.61,
    -0.6104, -0.6108, -0.6112, -0.6117, -0.6121, -0.6125, -0.613,
    -0.6134, -0.6138, -0.6142, -0.6147, -0.6151, -0.6155, -0.6159,
    -0.6164, -0.6168, -0.6172, -0.6176, -0.6181, -0.6185, -0.6189,
    -0.6193, -0.6197, -0.6202, -0.6206, -0.621, -0.6214, -0.6219,
    -0.6223, -0.6227, -0.6231, -0.6235, -0.624, -0.6244, -0.6248,
    -0.6252, -0.6256, -0.6261, -0.6265, -0.6269, -0.6273, -0.6277,
    -0.6282, -0.6286, -0.629, -0.6294, -0.6298, -0.6302, -0.6307,
    -0.6311, -0.6315, -0.6319, -0.6323, -0.6327, -0.6332, -0.6336,
    -0.634, -0.6344, -0.6348, -0.6352, -0.6357, -0.6361, -0.6365,
    -0.6369, -0.6373, -0.6377, -0.6381, -0.6385, -0.639, -0.6394,
    -0.6398, -0.6402, -0.6406, -0.641, -0.6414, -0.6418, -0.6423,
    -0.6427, -0.6431, -0.6435, -0.6439, -0.6443, -0.6447, -0.6451,
    -0.6455, -0.646, -0.6464, -0.6468, -0.6472, -0.6476, -0.648,
    -0.6484, -0.6488, -0.6492, -0.6496, -0.65, -0.6504, -0.6509,
    -0.6513, -0.6517, -0.6521, -0.6525, -0.6529, -0.6533, -0.6537,
    -0.6541, -0.6545, -0.6549, -0.6553, -0.6557, -0.6561, -0.6565,
    -0.6569, -0.6573, -0.6578, -0.6582, -0.6586, -0.659, -0.6594,
    -0.6598, -0.6602, -0.6606, -0.661, -0.6614, -0.6618, -0.6622,
    -0.6626, -0.663, -0.6634, -0.6638, -0.6642, -0.6646, -0.665,
    -0.6654, -0.6658, -0.6662, -0.6666, -0.667, -0.6674, -0.6678,
    -0.6682, -0.6686, -0.669, -0.6694, -0.6698, -0.6702, -0.6706,
    -0.671, -0.6714, -0.6718, -0.6722, -0.6726, -0.673, -0.6734,
    -0.6738, -0.6742, -0.6746, -0.675, -0.6754, -0.6758, -0.6761,
    -0.6765, -0.6769, -0.6773, -0.6777, -0.6781, -0.6785, -0.6789,
    -0.6793, -0.6797, -0.6801, -0.6805, -0.6809, -0.6813, -0.6817,
    -0.6821, -0.6825, -0.6829, -0.6832, -0.6836, -0.684, -0.6844,
    -0.6848, -0.6852, -0.6856, -0.686, -0.6864, -0.6868, -0.6872,
    -0.6876, -0.6879, -0.6883, -0.6887, -0.6891, -0.6895, -0.6899,
    -0.6903, -0.6907, -0.6911, -0.6915, -0.6918, -0.6922, -0.6926,
    -0.693, -0.6934, -0.6938, -0.6942, -0.6946, -0.695, -0.6953,
    -0.6957, -0.6961, -0.6965, -0.6969, -0.6973, -0.6977, -0.6981,
    -0.6984, -0.6988, -0.6992, -0.6996, -0.7, -0.7004, -0.7008,
    -0.7011, -0.7015, -0.7019, -0.7023, -0.7027, -0.7031, -0.7035,
    -0.7038, -0.7042, -0.7046, -0.705, -0.7054, -0.7058, -0.7061,
    -0.7065, -0.7069, -0.7073, -0.7077, -0.7081, -0.7084, -0.7088,
    -0.7092, -0.7096, -0.71, -0.7104, -0.7107, -0.7111, -0.7115,
    -0.7119, -0.7123, -0.7126, -0.713, -0.7134, -0.7138, -0.7142,
    -0.7145, -0.7149, -0.7153, -0.7157, -0.7161, -0.7164, -0.7168,
    -0.7172, -0.7176, -0.718, -0.7183, -0.7187, -0.7191, -0.7195,
    -0.7199, -0.7202, -0.7206, -0.721, -0.7214, -0.7217, -0.7221,
    -0.7225, -0.7229, -0.7232, -0.7236, -0.724, -0.7244, -0.7248,
    -0.7251, -0.7255, -0.7259, -0.7263, -0.7266, -0.727, -0.7274,
    -0.7278, -0.7281, -0.7285, -0.7289, -0.7293, -0.7296, -0.73,
    -0.7304, -0.7308, -0.7311, -0.7315, -0.7319, -0.7323, -0.7326,
    -0.733, -0.7334, -0.7337, -0.7341, -0.7345, -0.7349, -0.7352,
    -0.7356, -0.736, -0.7364, -0.7367, -0.7371, -0.7375, -0.7378,
    -0.7382, -0.7386, -0.739, -0.7393, -0.7397, -0.7401, -0.7404,
    -0.7408, -0.7412, -0.7415, -0.7419, -0.7423, -0.7427, -0.743,
    -0.7434, -0.7438, -0.7441, -0.7445, -0.7449, -0.7452, -0.7456,
    -0.746, -0.7463, -0.7467, -0.7471, -0.7475, -0.7478, -0.7482,
    -0.7486, -0.7489, -0.7493, -0.7497, -0.75, -0.7504, -0.7508,
    -0.7511, -0.7515, -0.7519, -0.7522, -0.7526, -0.753, -0.7533,
    -0.7537, -0.7541, -0.7544, -0.7548, -0.7552, -0.7555, -0.7559,
    -0.7562, -0.7566, -0.757, -0.7573, -0.7577, -0.7581, -0.7584,
    -0.7588, -0.7592, -0.7595, -0.7599, -0.7603, -0.7606, -0.761,
    -0.7613, -0.7617, -0.7621, -0.7624, -0.7628, -0.7632, -0.7635,
    -0.7639, -0.7642, -0.7646, -0.765, -0.7653, -0.7657, -0.7661,
    -0.7664, -0.7668, -0.7671, -0.7675, -0.7679, -0.7682, -0.7686,
    -0.7689, -0.7693, -0.7697, -0.77, -0.7704, -0.7708, -0.7711,
    -0.7715, -0.7718, -0.7722, -0.7726, -0.7729, -0.7733, -0.7736,
    -0.774, -0.7743, -0.7747, -0.7751, -0.7754, -0.7758, -0.7761,
    -0.7765, -0.7769, -0.7772, -0.7776, -0.7779, -0.7783, -0.7786,
    -0.779, -0.7794, -0.7797, -0.7801, -0.7804, -0.7808, -0.7811,
    -0.7815, -0.7819, -0.7822, -0.7826, -0.7829, -0.7833, -0.7836,
    -0.784, -0.7844, -0.7847, -0.7851, -0.7854, -0.7858, -0.7861,
    -0.7865, -0.7868, -0.7872, -0.7875, -0.7879, -0.7883, -0.7886,
    -0.789, -0.7893, -0.7897, -0.79, -0.7904, -0.7907, -0.7911,
    -0.7914, -0.7918, -0.7921, -0.7925, -0.7929, -0.7932, -0.7936,
    -0.7939, -0.7943, -0.7946, -0.795, -0.7953, -0.7957, -0.796,
    -0.7964, -0.7967, -0.7971, -0.7974, -0.7978, -0.7981, -0.7985,
    -0.7988, -0.7992, -0.7995, -0.7999, -0.8002, -0.8006, -0.8009,
    -0.8013, -0.8016, -0.802, -0.8023, -0.8027, -0.803, -0.8034,
    -0.8037, -0.8041, -0.8044, -0.8048, -0.8051, -0.8055, -0.8058,
    -0.8062, -0.8065, -0.8069, -0.8072, -0.8076, -0.8079, -0.8083,
    -0.8086, -0.809, -0.8093, -0.8097, -0.81, -0.8104, -0.8107,
    -0.8111, -0.8114, -0.8118, -0.8121, -0.8125, -0.8128, -0.8132,
    -0.8135, -0.8138, -0.8142, -0.8145, -0.8149, -0.8152, -0.8156,
    -0.8159, -0.8163, -0.8166, -0.817, -0.8173, -0.8177, -0.818,
    -0.8183, -0.8187, -0.819, -0.8194, -0.8197, -0.8201, -0.8204,
    -0.8208, -0.8211, -0.8214, -0.8218, -0.8221, -0.8225, -0.8228,
    -0.8232, -0.8235, -0.8239, -0.8242, -0.8245, -0.8249, -0.8252,
    -0.8256, -0.8259, -0.8263, -0.8266, -0.8269, -0.8273, -0.8276,
    -0.828, -0.8283, -0.8287, -0.829, -0.8293, -0.8297, -0.83,
    -0.8304, -0.8307, -0.8311, -0.8314, -0.8317, -0.8321, -0.8324,
    -0.8328, -0.8331, -0.8334, -0.8338, -0.8341, -0.8345, -0.8348,
    -0.8351, -0.8355, -0.8358, -0.8362, -0.8365, -0.8368, -0.8372,
    -0.8375, -0.8379, -0.8382, -0.8385, -0.8389, -0.8392, -0.8396,
    -0.8399, -0.8402, -0.8406, -0.8409, -0.8413, -0.8416, -0.8419,
    -0.8423, -0.8426, -0.8429, -0.8433, -0.8436, -0.844, -0.8443,
    -0.8446, -0.845, -0.8453, -0.8457, -0.846, -0.8463, -0.8467,
    -0.847, -0.8473, -0.8477, -0.848, -0.8484, -0.8487, -0.849,
    -0.8494, -0.8497, -0.85, -0.8504, -0.8507, -0.851, -0.8514,
    -0.8517, -0.8521, -0.8524, -0.8527, -0.8531, -0.8534, -0.8537,
    -0.8541, -0.8544, -0.8547, -0.8551, -0.8554, -0.8557, -0.8561,
    -0.8564, -0.8567, -0.8571, -0.8574, -0.8577, -0.8581, -0.8584,
    -0.8588, -0.8591, -0.8594, -0.8598, -0.8601, -0.8604, -0.8608,
    -0.8611, -0.8614, -0.8618, -0.8621, -0.8624, -0.8628, -0.8631,
    -0.8634, -0.8638, -0.8641, -0.8644, -0.8647, -0.8651, -0.8654,
    -0.8657, -0.8661, -0.8664, -0.8667, -0.8671, -0.8674, -0.8677,
    -0.8681, -0.8684, -0.8687, -0.8691, -0.8694, -0.8697, -0.8701,
    -0.8704, -0.8707, -0.8711, -0.8714, -0.8717, -0.872, -0.8724,
    -0.8727, -0.873, -0.8734, -0.8737, -0.874, -0.8744, -0.8747,
    -0.875, -0.8753, -0.8757, -0.876, -0.8763, -0.8767, -0.877,
    -0.8773, -0.8776, -0.878, -0.8783, -0.8786, -0.879, -0.8793,
    -0.8796, -0.88, -0.8803, -0.8806, -0.8809, -0.8813, -0.8816,
    -0.8819, -0.8822, -0.8826, -0.8829, -0.8832, -0.8836, -0.8839,
    -0.8842, -0.8845, -0.8849, -0.8852, -0.8855, -0.8859, -0.8862,
    -0.8865, -0.8868, -0.8872, -0.8875, -0.8878, -0.8881, -0.8885,
    -0.8888, -0.8891, -0.8894, -0.8898, -0.8901, -0.8904, -0.8907,
    -0.8911, -0.8914, -0.8917, -0.8921, -0.8924, -0.8927, -0.893,
    -0.8934, -0.8937, -0.894, -0.8943, -0.8947, -0.895, -0.8953,
    -0.8956, -0.896, -0.8963, -0.8966, -0.8969, -0.8972, -0.8976,
    -0.8979, -0.8982, -0.8985, -0.8989, -0.8992, -0.8995, -0.8998,
    -0.9002, -0.9005, -0.9008, -0.9011, -0.9015, -0.9018, -0.9021,
    -0.9024, -0.9028, -0.9031, -0.9034, -0.9037, -0.904, -0.9044,
    -0.9047, -0.905, -0.9053, -0.9057, -0.906, -0.9063, -0.9066,
    -0.9069, -0.9073, -0.9076, -0.9079, -0.9082, -0.9085, -0.9089,
    -0.9092, -0.9095, -0.9098, -0.9102, -0.9105, -0.9108, -0.9111,
    -0.9114, -0.9118, -0.9121, -0.9124, -0.9127, -0.913, -0.9134,
    -0.9137, -0.914, -0.9143, -0.9146, -0.915, -0.9153, -0.9156,
    -0.9159, -0.9162, -0.9166, -0.9169, -0.9172, -0.9175, -0.9178,
    -0.9182, -0.9185, -0.9188, -0.9191, -0.9194, -0.9198, -0.9201,
    -0.9204, -0.9207, -0.921, -0.9213, -0.9217, -0.922, -0.9223,
    -0.9226, -0.9229, -0.9233, -0.9236, -0.9239, -0.9242, -0.9245,
    -0.9248, -0.9252, -0.9255, -0.9258, -0.9261, -0.9264, -0.9268,
    -0.9271, -0.9274, -0.9277, -0.928, -0.9283, -0.9287, -0.929,
    -0.9293, -0.9296, -0.9299, -0.9302, -0.9306, -0.9309, -0.9312,
    -0.9315, -0.9318, -0.9321, -0.9325, -0.9328, -0.9331, -0.9334,
    -0.9337, -0.934, -0.9343, -0.9347, -0.935, -0.9353, -0.9356,
    -0.9359, -0.9362, -0.9366, -0.9369, -0.9372, -0.9375, -0.9378,
    -0.9381, -0.9384, -0.9388, -0.9391, -0.9394, -0.9397, -0.94,
    -0.9403, -0.9406, -0.941, -0.9413, -0.9416, -0.9419, -0.9422,
    -0.9425, -0.9428, -0.9432, -0.9435, -0.9438, -0.9441, -0.9444,
    -0.9447, -0.945, -0.9453, -0.9457, -0.946, -0.9463, -0.9466,
    -0.9469, -0.9472, -0.9475, -0.9479, -0.9482, -0.9485, -0.9488,
    -0.9491, -0.9494, -0.9497, -0.95, -0.9503, -0.9507, -0.951,
    -0.9513, -0.9516, -0.9519, -0.9522, -0.9525, -0.9528, -0.9532,
    -0.9535, -0.9538, -0.9541, -0.9544, -0.9547, -0.955, -0.9553,
    -0.9556, -0.956, -0.9563, -0.9566, -0.9569, -0.9572, -0.9575,
    -0.9578, -0.9581, -0.9584, -0.9587, -0.9591, -0.9594, -0.9597,
    -0.96, -0.9603, -0.9606, -0.9609, -0.9612, -0.9615, -0.9618,
    -0.9622, -0.9625, -0.9628, -0.9631, -0.9634, -0.9637, -0.964,
    -0.9643, -0.9646, -0.9649, -0.9652, -0.9656, -0.9659, -0.9662,
    -0.9665, -0.9668, -0.9671, -0.9674, -0.9677, -0.968, -0.9683,
    -0.9686, -0.9689, -0.9693, -0.9696, -0.9699, -0.9702, -0.9705,
    -0.9708, -0.9711, -0.9714, -0.9717, -0.972, -0.9723, -0.9726,
    -0.9729, -0.9733, -0.9736, -0.9739, -0.9742, -0.9745, -0.9748,
    -0.9751, -0.9754, -0.9757, -0.976, -0.9763, -0.9766, -0.9769,
    -0.9772, -0.9775, -0.9779, -0.9782, -0.9785, -0.9788, -0.9791,
    -0.9794, -0.9797, -0.98, -0.9803, -0.9806, -0.9809, -0.9812,
    -0.9815, -0.9818, -0.9821, -0.9824, -0.9827, -0.983, -0.9834,
    -0.9837, -0.984, -0.9843, -0.9846, -0.9849, -0.9852, -0.9855,
    -0.9858, -0.9861, -0.9864, -0.9867, -0.987, -0.9873, -0.9876,
    -0.9879, -0.9882, -0.9885, -0.9888, -0.9891, -0.9894, -0.9897,
    -0.99, -0.9903, -0.9907, -0.991, -0.9913, -0.9916, -0.9919,
    -0.9922, -0.9925, -0.9928, -0.9931, -0.9934, -0.9937, -0.994,
    -0.9943, -0.9946, -0.9949, -0.9952, -0.9955, -0.9958, -0.9961,
    -0.9964, -0.9967, -0.997, -0.9973, -0.9976, -0.9979, -0.9982,
    -0.9985, -0.9988, -0.9991, -0.9994, -0.9997, -1, -1.0003,
    -1.0006, -1.0009, -1.0012, -1.0015, -1.0018, -1.0021, -1.0024,
    -1.0027, -1.003, -1.0033, -1.0036, -1.0039, -1.0042, -1.0045,
    -1.0049, -1.0052, -1.0055, -1.0058, -1.0061, -1.0064, -1.0067,
    -1.007, -1.0073, -1.0076, -1.0079, -1.0082, -1.0085, -1.0088,
    -1.0091, -1.0094, -1.0097, -1.01, -1.0103, -1.0106, -1.0109,
    -1.0112, -1.0115, -1.0118, -1.012, -1.0123, -1.0126, -1.0129,
    -1.0132, -1.0135, -1.0138, -1.0141, -1.0144, -1.0147, -1.015,
    -1.0153, -1.0156, -1.0159, -1.0162, -1.0165, -1.0168, -1.0171,
    -1.0174, -1.0177, -1.018, -1.0183, -1.0186, -1.0189, -1.0192,
    -1.0195, -1.0198, -1.0201, -1.0204, -1.0207, -1.021, -1.0213,
    -1.0216, -1.0219, -1.0222, -1.0225, -1.0228, -1.0231, -1.0234,
    -1.0237, -1.024, -1.0243, -1.0246, -1.0249, -1.0252, -1.0255,
    -1.0258, -1.0261, -1.0263, -1.0266, -1.0269, -1.0272, -1.0275,
    -1.0278, -1.0281, -1.0284, -1.0287, -1.029, -0.2019, -0.204,
    -0.206, -0.208, -0.21, -0.212, -0.2139, -0.2159, -0.2178,
    -0.2197, -0.2216, -0.2235, -0.2253, -0.2272, -0.229, -0.2308,
    -0.2326, -0.2344, -0.2362, -0.238, -0.2397, -0.2414, -0.2431,
    -0.2449, -0.2465, -0.2482, -0.2499, -0.2516, -0.2532, -0.2548,
    -0.2564, -0.2581, -0.2597, -0.2612, -0.2628, -0.2644, -0.2659,
    -0.2675, -0.269, -0.2705, -0.2721, -0.2736, -0.2751, -0.2765,
    -0.278, -0.2795, -0.2809, -0.2824, -0.2838, -0.2853, -0.2867,
    -0.2881, -0.2895, -0.2909, -0.2923, -0.2937, -0.2951, -0.2964,
    -0.2978, -0.2991, -0.3005, -0.3018, -0.3031, -0.3044, -0.3058,
    -0.3071, -0.3084, -0.3097, -0.3109, -0.3122, -0.3135, -0.3147,
    -0.316, -0.3173, -0.3185, -0.3197, -0.321, -0.3222, -0.3234,
    -0.3246, -0.3258, -0.327, -0.3282, -0.3294, -0.3306, -0.3318,
    -0.3329, -0.3341, -0.3353, -0.3364, -0.3376, -0.3387, -0.3399,
    -0.341, -0.3421, -0.3432, -0.3444, -0.3455, -0.3466, -0.3477,
    -0.3488, -0.3499, -0.351, -0.3521, -0.3531, -0.3542, -0.3553,
    -0.3563, -0.3574, -0.3585, -0.3595, -0.3606, -0.3616, -0.3626,
    -0.3637, -0.3647, -0.3657, -0.3667, -0.3678, -0.3688, -0.3698,
    -0.3708, -0.3718, -0.3728, -0.3738, -0.3748, -0.3757, -0.3767,
    -0.3777, -0.3787, -0.3796, -0.3806, -0.3816, -0.3825, -0.3835,
    -0.3844, -0.3854, -0.3863, -0.3873, -0.3882, -0.3891, -0.3901,
    -0.391, -0.3919, -0.3928, -0.3938, -0.3947, -0.3956, -0.3965,
    -0.3974, -0.3983, -0.3992, -0.4001, -0.401, -0.4019, -0.4028,
    -0.4036, -0.4045, -0.4054, -0.4063, -0.4071, -0.408, -0.4089,
    -0.4097, -0.4106, -0.4114, -0.4123, -0.4131, -0.414, -0.4148,
    -0.4157, -0.4165, -0.4173, -0.4182, -0.419, -0.4198, -0.4207,
    -0.4215, -0.4223, -0.4231, -0.4239, -0.4248, -0.4256, -0.4264,
    -0.4272, -0.428, -0.4288, -0.4296, -0.4304, -0.4312, -0.432,
    -0.4327, -0.4335, -0.4343, -0.4351, -0.4359, -0.4366, -0.4374,
    -0.4382, -0.439, -0.4397, -0.4405, -0.4413, -0.442, -0.4428,
    -0.4435, -0.4443, -0.445, -0.4458, -0.4465, -0.4473, -0.448,
    -0.4488, -0.4495, -0.4502, -0.451, -0.4517, -0.4524, -0.4532,
    -0.4539, -0.4546, -0.4553, -0.4561, -0.4568, -0.4575, -0.4582,
    -0.4589, -0.4596, -0.4603, -0.461, -0.4617, -0.4625, -0.4632,
    -0.4639, -0.4645, -0.4652, -0.4659, -0.4666, -0.4673, -0.468,
    -0.4687, -0.4694, -0.4701, -0.4708, -0.4714, -0.4721, -0.4728,
    -0.4735, -0.4741, -0.4748, -0.4755, -0.4761, -0.4768, -0.4775,
    -0.4781, -0.4788, -0.4795, -0.4801, -0.4808, -0.4814, -0.4821,
    -0.4827, -0.4834, -0.484, -0.4847, -0.4853, -0.486, -0.4866,
    -0.4873, -0.4879, -0.4885, -0.4892, -0.4898, -0.4904, -0.4911,
    -0.4917, -0.4923, -0.493, -0.4936, -0.4942, -0.4948, -0.4955,
    -0.4961, -0.4967, -0.4973, -0.4979, -0.4985, -0.4992, -0.4998,
    -0.5004, -0.501, -0.5016, -0.5022, -0.5028, -0.5034, -0.504,
    -0.5046, -0.5052, -0.5058, -0.5064, -0.507, -0.5076, -0.5082,
    -0.5088, -0.5094, -0.51, -0.5106, -0.5111, -0.5117, -0.5123,
    -0.5129, -0.5135, -0.5141, -0.5146, -0.5152, -0.5158, -0.5164,
    -0.517, -0.5175, -0.5181, -0.5187, -0.5192, -0.5198, -0.5204,
    -0.5209, -0.5215, -0.5221, -0.5226, -0.5232, -0.5238, -0.5243,
    -0.5249, -0.5254, -0.526, -0.5265, -0.5271, -0.5277, -0.5282,
    -0.5288, -0.5293, -0.5299, -0.5304, -0.531, -0.5315, -0.532,
    -0.5326, -0.5331, -0.5337, -0.5342, -0.5347, -0.5353, -0.5358,
    -0.5364, -0.5369, -0.5374, -0.538, -0.5385, -0.539, -0.5396,
    -0.5401, -0.5406, -0.5411, -0.5417, -0.5422, -0.5427, -0.5432,
    -0.5438, -0.5443, -0.5448, -0.5453, -0.5458, -0.5464, -0.5469,
    -0.5474, -0.5479, -0.5484, -0.5489, -0.5494, -0.5499, -0.5505,
    -0.551, -0.5515, -0.552, -0.5525, -0.553, -0.5535, -0.554,
    -0.5545, -0.555, -0.5555, -0.556, -0.5565, -0.557, -0.5575,
    -0.558, -0.5585, -0.559, -0.5595, -0.56, -0.5605, -0.5609,
    -0.5614, -0.5619, -0.5624, -0.5629, -0.5634, -0.5639, -0.5644,
    -0.5648, -0.5653, -0.5658, -0.5663, -0.5668, -0.5673, -0.5677,
    -0.5682, -0.5687, -0.5692, -0.5696, -0.5701, -0.5706, -0.5711,
    -0.5715, -0.572, -0.5725, -0.573, -0.5734, -0.5739, -0.5744,
    -0.5748, -0.5753, -0.5758, -0.5762, -0.5767, -0.5772, -0.5776,
    -0.5781, -0.5785, -0.579, -0.5795, -0.5799, -0.5804, -0.5808,
    -0.5813, -0.5818, -0.5822, -0.5827, -0.5831, -0.5836, -0.584,
    -0.5845, -0.5849, -0.5854, -0.5858, -0.5863, -0.5867, -0.5872,
    -0.5876, -0.5881, -0.5885, -0.589, -0.5894, -0.5898, -0.5903,
    -0.5907, -0.5912, -0.5916, -0.5921, -0.5925, -0.5929, -0.5934,
    -0.5938, -0.5942, -0.5947, -0.5951, -0.5956, -0.596, -0.5964,
    -0.5969, -0.5973, -0.5977, -0.5981, -0.5986, -0.599, -0.5994,
    -0.5999, -0.6003, -0.6007, -0.6011, -0.6016, -0.602, -0.6024,
    -0.6028, -0.6033, -0.6037, -0.6041, -0.6045, -0.605, -0.6054,
    -0.6058, -0.6062, -0.6066, -0.6071, -0.6075, -0.6079, -0.6083,
    -0.6087, -0.6091, -0.6096, -0.61, -0.6104, -0.6108, -0.6112,
    -0.6116, -0.612, -0.6124, -0.6128, -0.6133, -0.6137, -0.6141,
    -0.6145, -0.6149, -0.6153, -0.6157, -0.6161, -0.6165, -0.6169,
    -0.6173, -0.6177, -0.6181, -0.6185, -0.6189, -0.6193, -0.6197,
    -0.6201, -0.6205, -0.6209, -0.6213, -0.6217, -0.6221, -0.6225,
    -0.6229, -0.6233, -0.6237, -0.6241, -0.6245, -0.6249, -0.6253,
    -0.6257, -0.6261, -0.6265, -0.6268, -0.6272, -0.6276, -0.628,
    -0.6284, -0.6288, -0.6292, -0.6296, -0.6299, -0.6303, -0.6307,
    -0.6311, -0.6315, -0.6319, -0.6323, -0.6326, -0.633, -0.6334,
    -0.6338, -0.6342, -0.6346, -0.6349, -0.6353, -0.6357, -0.6361,
    -0.6364, -0.6368, -0.6372, -0.6376, -0.638, -0.6383, -0.6387,
    -0.6391, -0.6395, -0.6398, -0.6402, -0.6406, -0.6409, -0.6413,
    -0.6417, -0.6421, -0.6424, -0.6428, -0.6432, -0.6435, -0.6439,
    -0.6443, -0.6446, -0.645, -0.6454, -0.6457, -0.6461, -0.6465,
    -0.6468, -0.6472, -0.6476, -0.6479, -0.6483, -0.6487, -0.649,
    -0.6494, -0.6498, -0.6501, -0.6505, -0.6508, -0.6512, -0.6516,
    -0.6519, -0.6523, -0.6526, -0.653, -0.6533, -0.6537, -0.6541,
    -0.6544, -0.6548, -0.6551, -0.6555, -0.6558, -0.6562, -0.6565,
    -0.6569, -0.6572, -0.6576, -0.658, -0.6583, -0.6587, -0.659,
    -0.6594, -0.6597, -0.6601, -0.6604, -0.6608, -0.6611, -0.6614,
    -0.6618, -0.6621, -0.6625, -0.6628, -0.6632, -0.6635, -0.6639,
    -0.6642, -0.6646, -0.6649, -0.6652, -0.6656, -0.6659, -0.6663,
    -0.6666, -0.667, -0.6673, -0.6676, -0.668, -0.6683, -0.6687,
    -0.669, -0.6693, -0.6697, -0.67, -0.6704, -0.6707, -0.671,
    -0.6714, -0.6717, -0.672, -0.6724, -0.6727, -0.673, -0.6734,
    -0.6737, -0.674, -0.6744, -0.6747, -0.675, -0.6754, -0.6757,
    -0.676, -0.6764, -0.6767, -0.677, -0.6774, -0.6777, -0.678,
    -0.6783, -0.6787, -0.679, -0.6793, -0.6797, -0.68, -0.6803,
    -0.6806, -0.681, -0.6813, -0.6816, -0.6819, -0.6823, -0.6826,
    -0.6829, -0.6832, -0.6836, -0.6839, -0.6842, -0.6845, -0.6849,
    -0.6852, -0.6855, -0.6858, -0.6861, -0.6865, -0.6868, -0.6871,
    -0.6874, -0.6877, -0.6881, -0.6884, -0.6887, -0.689, -0.6893,
    -0.6896, -0.69, -0.6903, -0.6906, -0.6909, -0.6912, -0.6915,
    -0.6918, -0.6922, -0.6925, -0.6928, -0.6931, -0.6934, -0.6937,
    -0.694, -0.6944, -0.6947, -0.695, -0.6953, -0.6956, -0.6959,
    -0.6962, -0.6965, -0.6968, -0.6971, -0.6975, -0.6978, -0.6981,
    -0.6984, -0.6987, -0.699, -0.6993, -0.6996, -0.6999, -0.7002,
    -0.7005, -0.7008, -0.7011, -0.7014, -0.7018, -0.7021, -0.7024,
    -0.7027, -0.703, -0.7033, -0.7036, -0.7039, -0.7042, -0.7045,
    -0.7048, -0.7051, -0.7054, -0.7057, -0.706, -0.7063, -0.7066,
    -0.7069, -0.7072, -0.7075, -0.7078, -0.7081, -0.7084, -0.7087,
    -0.709, -0.7093, -0.7096, -0.7099, -0.7102, -0.7105, -0.7108,
    -0.711, -0.7113, -0.7116, -0.7119, -0.7122, -0.7125, -0.7128,
    -0.7131, -0.7134, -0.7137, -0.714, -0.7143, -0.7146, -0.7149,
    -0.7152, -0.7154, -0.7157, -0.716, -0.7163, -0.7166, -0.7169,
    -0.7172, -0.7175, -0.7178, -0.7181, -0.7183, -0.7186, -0.7189,
    -0.7192, -0.7195, -0.7198, -0.7201, -0.7204, -0.7206, -0.7209,
    -0.7212, -0.7215, -0.7218, -0.7221, -0.7224, -0.7226, -0.7229,
    -0.7232, -0.7235, -0.7238, -0.7241, -0.7243, -0.7246, -0.7249,
    -0.7252, -0.7255, -0.7258, -0.726, -0.7263, -0.7266, -0.7269,
    -0.7272, -0.7274, -0.7277, -0.728, -0.7283, -0.7286, -0.7288,
    -0.7291, -0.7294, -0.7297, -0.73, -0.7302, -0.7305, -0.7308,
    -0.7311, -0.7313, -0.7316, -0.7319, -0.7322, -0.7325, -0.7327,
    -0.733, -0.7333, -0.7336, -0.7338, -0.7341, -0.7344, -0.7347,
    -0.7349, -0.7352, -0.7355, -0.7357, -0.736, -0.7363, -0.7366,
    -0.7368, -0.7371, -0.7374, -0.7376, -0.7379, -0.7382, -0.7385,
    -0.7387, -0.739, -0.7393, -0.7395, -0.7398, -0.7401, -0.7404,
    -0.7406, -0.7409, -0.7412, -0.7414, -0.7417, -0.742, -0.7422,
    -0.7425, -0.7428, -0.743, -0.7433, -0.7436, -0.7438, -0.7441,
    -0.7444, -0.7446, -0.7449, -0.7452, -0.7454, -0.7457, -0.7459,
    -0.7462, -0.7465, -0.7467, -0.747, -0.7473, -0.7475, -0.7478,
    -0.7481, -0.7483, -0.7486, -0.7488, -0.7491, -0.7494, -0.7496,
    -0.7499, -0.7501, -0.7504, -0.7507, -0.7509, -0.7512, -0.7514,
    -0.7517, -0.752, -0.7522, -0.7525, -0.7527, -0.753, -0.7533,
    -0.7535, -0.7538, -0.754, -0.7543, -0.7546, -0.7548, -0.7551,
    -0.7553, -0.7556, -0.7558, -0.7561, -0.7563, -0.7566, -0.7569,
    -0.7571, -0.7574, -0.7576, -0.7579, -0.7581, -0.7584, -0.7586,
    -0.7589, -0.7591, -0.7594, -0.7597, -0.7599, -0.7602, -0.7604,
    -0.7607, -0.7609, -0.7612, -0.7614, -0.7617, -0.7619, -0.7622,
    -0.7624, -0.7627, -0.7629, -0.7632, -0.7634, -0.7637, -0.7639,
    -0.7642, -0.7644, -0.7647, -0.7649, -0.7652, -0.7654, -0.7657,
    -0.7659, -0.7662, -0.7664, -0.7667, -0.7669, -0.7672, -0.7674,
    -0.7676, -0.7679, -0.7681, -0.7684, -0.7686, -0.7689, -0.7691,
    -0.7694, -0.7696, -0.7699, -0.7701, -0.7704, -0.7706, -0.7708,
    -0.7711, -0.7713, -0.7716, -0.7718, -0.7721, -0.7723, -0.7725,
    -0.7728, -0.773, -0.7733, -0.7735, -0.7738, -0.774, -0.7742,
    -0.7745, -0.7747, -0.775, -0.7752, -0.7754, -0.7757, -0.7759,
    -0.7762, -0.7764, -0.7767, -0.7769, -0.7771, -0.7774, -0.7776,
    -0.7778, -0.7781, -0.7783, -0.7786, -0.7788, -0.779, -0.7793,
    -0.7795, -0.7798, -0.78, -0.7802, -0.7805, -0.7807, -0.7809,
    -0.7812, -0.7814, -0.7817, -0.7819, -0.7821, -0.7824, -0.7826,
    -0.7828, -0.7831, -0.7833, -0.7835, -0.7838, -0.784, -0.7842,
    -0.7845, -0.7847, -0.7849, -0.7852, -0.7854, -0.7856, -0.7859,
    -0.7861, -0.7863, -0.7866, -0.7868, -0.787, -0.7873, -0.7875,
    -0.7877, -0.788, -0.7882, -0.7884, -0.7887, -0.7889, -0.7891,
    -0.7894, -0.7896, -0.7898, -0.79, -0.7903, -0.7905, -0.7907,
    -0.791, -0.7912, -0.7914, -0.7917, -0.7919, -0.7921, -0.7923,
    -0.7926, -0.7928, -0.793, -0.7933, -0.7935, -0.7937, -0.7939,
    -0.7942, -0.7944, -0.7946, -0.7948, -0.7951, -0.7953, -0.7955,
    -0.7957, -0.796, -0.7962, -0.7964, -0.7967, -0.7969, -0.7971,
    -0.7973, -0.7976, -0.7978, -0.798, -0.7982, -0.7985, -0.7987,
    -0.7989, -0.7991, -0.7993, -0.7996, -0.7998, -0.8, -0.8002,
    -0.8005, -0.8007, -0.8009, -0.8011, -0.8014, -0.8016, -0.8018,
    -0.802, -0.8022, -0.8025, -0.8027, -0.8029, -0.8031, -0.8033,
    -0.8036, -0.8038, -0.804, -0.8042, -0.8045, -0.8047, -0.8049,
    -0.8051, -0.8053, -0.8056, -0.8058, -0.806, -0.8062, -0.8064,
    -0.8066, -0.8069, -0.8071, -0.8073, -0.8075, -0.8077, -0.808,
    -0.8082, -0.8084, -0.8086, -0.8088, -0.809, -0.8093, -0.8095,
    -0.8097, -0.8099, -0.8101, -0.8103, -0.8106, -0.8108, -0.811,
    -0.8112, -0.8114, -0.8116, -0.8119, -0.8121, -0.8123, -0.8125,
    -0.8127, -0.8129, -0.8131, -0.8134, -0.8136, -0.8138, -0.814,
    -0.8142, -0.8144, -0.8146, -0.8149, -0.8151, -0.8153, -0.8155,
    -0.8157, -0.8159, -0.8161, -0.8163, -0.8166, -0.8168, -0.817,
    -0.8172, -0.8174, -0.8176, -0.8178, -0.818, -0.8182, -0.8185,
    -0.8187, -0.8189, -0.8191, -0.8193, -0.8195, -0.8197, -0.8199,
    -0.8201, -0.8204, -0.8206, -0.8208, -0.821, -0.8212, -0.8214,
    -0.8216, -0.8218, -0.822, -0.8222, -0.8224, -0.8227, -0.8229,
    -0.8231, -0.8233, -0.8235, -0.8237, -0.8239, -0.8241, -0.8243,
    -0.8245, -0.8247, -0.8249, -0.8251, -0.8253, -0.8256, -0.8258,
    -0.826, -0.8262, -0.8264, -0.8266, -0.8268, -0.827, -0.8272,
    -0.8274, -0.8276, -0.8278, -0.828, -0.8282, -0.8284, -0.8286,
    -0.8288, -0.829, -0.8293, -0.8295, -0.8297, -0.8299, -0.8301,
    -0.8303, -0.8305, -0.8307, -0.8309, -0.8311, -0.8313, -0.8315,
    -0.8317, -0.8319, -0.8321, -0.8323, -0.8325, -0.8327, -0.8329,
    -0.8331, -0.8333, -0.8335, -0.8337, -0.8339, -0.8341, -0.8343,
    -0.8345, -0.8347, -0.8349, -0.8351, -0.8353, -0.8355, -0.8357,
    -0.8359, -0.8361, -0.8363, -0.8365, -0.8367, -0.8369, -0.8371,
    -0.8373, -0.8375, -0.8377, -0.8379, -0.8381, -0.8383, -0.8385,
    -0.8387, -0.8389, -0.8391, -0.8393, -0.8395, -0.8397, -0.8399,
    -0.8401, -0.8403, -0.8405, -0.8407, -0.8409, -0.8411, -0.8413,
    -0.8415, -0.8417, -0.8419, -0.8421, -0.8423, -0.8425, -0.8427,
    -0.8429, -0.843, -0.8432, -0.8434, -0.8436, -0.8438, -0.844,
    -0.8442, -0.8444, -0.8446, -0.8448, -0.845, -0.8452, -0.8454,
    -0.8456, -0.8458, -0.846, -0.8462, -0.8464, -0.8466, -0.8467,
    -0.8469, -0.8471, -0.8473, -0.8475, -0.8477, -0.8479, -0.8481,
    -0.8483, -0.8485, -0.8487, -0.8489, -0.8491, -0.8493, -0.8494,
    -0.8496, -0.8498, -0.85, -0.8502, -0.8504, -0.8506, -0.8508,
    -0.851, -0.8512, -0.8514, -0.8516, -0.8517, -0.8519, -0.8521,
    -0.8523, -0.8525, -0.8527, -0.8529, -0.8531, -0.8533, -0.8535,
    -0.8536, -0.8538, -0.854, -0.8542, -0.8544, -0.8546, -0.8548,
    -0.855, -0.8552, -0.8554, -0.8555, -0.8557, -0.8559, -0.8561,
    -0.8563, -0.8565, -0.8567, -0.8569, -0.857, -0.8572, -0.8574,
    -0.8576, -0.8578, -0.858, -0.8582, -0.8584, -0.8585, -0.8587,
    -0.8589, -0.8591, -0.8593, -0.8595, -0.8597, -0.8599, -0.86,
    -0.8602, -0.8604, -0.8606, -0.8608, -0.861, -0.8612, -0.8613,
    -0.8615, -0.8617, -0.8619, -0.8621, -0.8623, -0.8624, -0.8626,
    -0.8628, -0.863, -0.8632, -0.8634, -0.8636, -0.8637, -0.8639,
    -0.8641, -0.8643, -0.8645, -0.8647, -0.8648, -0.865, -0.8652,
    -0.8654, -0.8656, -0.8658, -0.8659, -0.8661, -0.8663, -0.8665,
    -0.8667, -0.8669, -0.867, -0.8672, -0.8674, -0.8676, -0.8678,
    -0.8679, -0.8681, -0.8683, -0.8685, -0.8687, -0.8689, -0.869,
    -0.8692, -0.8694, -0.8696, -0.8698, -0.8699, -0.8701, -0.8703,
    -0.8705, -0.8707, -0.8708, -0.871, -0.8712, -0.8714, -0.8716,
    -0.8717, -0.8719, -0.8721, -0.8723, -0.8725, -0.8726, -0.8728,
    -0.873, -0.8732, -0.8734, -0.8735, -0.8737, -0.8739, -0.8741,
    -0.8743, -0.8744, -0.8746, -0.8748, -0.875, -0.8751, -0.8753,
    -0.8755, -0.8757, -0.8759, -0.876, -0.8762, -0.8764, -0.8766,
    -0.8767, -0.8769, -0.8771, -0.8773, -0.8775, -0.8776, -0.8778,
    -0.878, -0.8782, -0.8783, -0.8785, -0.8787, -0.8789, -0.879,
    -0.8792, -0.8794, -0.8796, -0.8797, -0.8799, -0.8801, -0.8803,
    -0.8804, -0.8806, -0.8808, -0.881, -0.8811, -0.8813, -0.8815,
    -0.8817, -0.8818, -0.882, -0.8822, -0.8824, -0.8825, -0.8827,
    -0.8829, -0.8831, -0.8832, -0.8834, -0.8836, -0.8838, -0.8839,
    -0.8841, -0.8843, -0.8844, -0.8846, -0.8848, -0.885, -0.8851,
    -0.8853, -0.8855, -0.8857, -0.8858, -0.886, -0.8862, -0.8863,
    -0.8865, -0.8867, -0.8869, -0.887, -0.8872, -0.8874, -0.8876,
    -0.8877, -0.8879, -0.8881, -0.8882, -0.8884, -0.8886, -0.8888,
    -0.8889, -0.8891, -0.8893, -0.8894, -0.8896, -0.8898, -0.8899,
    -0.8901, -0.8903, -0.8905, -0.8906, -0.8908, -0.891, -0.8911,
    -0.8913, -0.8915, -0.8916, -0.8918, -0.892, -0.8922, -0.8923,
    -0.8925, -0.8927, -0.8928, -0.893, -0.8932, -0.8933, -0.8935,
    -0.8937, -0.8938, -0.894, -0.8942, -0.8943, -0.8945, -0.8947,
    -0.8949, -0.895, -0.8952, -0.8954, -0.8955, -0.8957, -0.8959,
    -0.896, -0.8962, -0.8964, -0.8965, -0.8967, -0.8969, -0.897,
    -0.8972, -0.8974, -0.8975, -0.8977, -0.8979, -0.898, -0.8982,
    -0.8984, -0.8985, -0.8987, -0.8989, -0.899, -0.8992, -0.8994,
    -0.8995, -0.8997, -0.8999, -0.9, -0.9002, -0.9004, -0.9005,
    -0.9007, -0.9008, -0.901, -0.9012, -0.9013, -0.9015, -0.9017,
    -0.9018, -0.902, -0.9022, -0.9023, -0.9025, -0.9027, -0.9028,
    -0.903, -0.9032, -0.9033, -0.9035, -0.9036, -0.9038, -0.904,
    -0.9041, -0.9043, -0.9045, -0.9046, -0.9048, -0.9049, -0.9051,
    -0.9053, -0.9054, -0.9056, -0.9058, -0.9059, -0.9061, -0.9063,
    -0.9064, -0.9066, -0.9067, -0.9069, -0.9071, -0.9072, -0.9074,
    -0.9075, -0.9077, -0.9079, -0.908, -0.9082, -0.9084, -0.9085,
    -0.9087, -0.9088, -0.909, -0.9092, -0.9093, -0.9095, -0.9096,
    -0.9098, -0.91, -0.9101, -0.9103, -0.9105, -0.9106, -0.9108,
    -0.9109, -0.9111, -0.9113, -0.9114, -0.9116, -0.9117, -0.9119,
    -0.9121, -0.9122, -0.9124, -0.9125, -0.9127, -0.9129, -0.913,
    -0.9132, -0.9133, -0.9135, -0.9136, -0.9138, -0.914, -0.9141,
    -0.9143, -0.9144, -0.9146, -0.9148, -0.9149, -0.9151, -0.9152,
    0.003, 0.0023, 0.0016, 9e-04, 2e-04, -5e-04, -0.0012, -0.0018,
    -0.0025, -0.0032, -0.0038, -0.0045, -0.0051, -0.0057, -0.0064,
    -0.007, -0.0077, -0.0083, -0.0089, -0.0095, -0.0101, -0.0107,
    -0.0113, -0.0119, -0.0125, -0.0131, -0.0137, -0.0143, -0.0149,
    -0.0155, -0.0161, -0.0166, -0.0172, -0.0178, -0.0183, -0.0189,
    -0.0195, -0.02, -0.0206, -0.0211, -0.0217, -0.0222, -0.0227,
    -0.0233, -0.0238, -0.0244, -0.0249, -0.0254, -0.0259, -0.0265,
    -0.027, -0.0275, -0.028, -0.0285, -0.029, -0.0295, -0.03,
    -0.0305, -0.031, -0.0315, -0.032, -0.0325, -0.033, -0.0335,
    -0.034, -0.0345, -0.0349, -0.0354, -0.0359, -0.0364, -0.0368,
    -0.0373, -0.0378, -0.0383, -0.0387, -0.0392, -0.0396, -0.0401,
    -0.0406, -0.041, -0.0415, -0.0419, -0.0424, -0.0428, -0.0433,
    -0.0437, -0.0441, -0.0446, -0.045, -0.0455, -0.0459, -0.0463,
    -0.0468, -0.0472, -0.0476, -0.048, -0.0485, -0.0489, -0.0493,
    -0.0497, -0.0502, -0.0506, -0.051, -0.0514, -0.0518, -0.0522,
    -0.0526, -0.0531, -0.0535, -0.0539, -0.0543, -0.0547, -0.0551,
    -0.0555, -0.0559, -0.0563, -0.0567, -0.0571, -0.0575, -0.0578,
    -0.0582, -0.0586, -0.059, -0.0594, -0.0598, -0.0602, -0.0606,
    -0.0609, -0.0613, -0.0617, -0.0621, -0.0625, -0.0628, -0.0632,
    -0.0636, -0.0639, -0.0643, -0.0647, -0.0651, -0.0654, -0.0658,
    -0.0662, -0.0665, -0.0669, -0.0673, -0.0676, -0.068, -0.0683,
    -0.0687, -0.069, -0.0694, -0.0698, -0.0701, -0.0705, -0.0708,
    -0.0712, -0.0715, -0.0719, -0.0722, -0.0726, -0.0729, -0.0733,
    -0.0736, -0.0739, -0.0743, -0.0746, -0.075, -0.0753, -0.0756,
    -0.076, -0.0763, -0.0767, -0.077, -0.0773, -0.0777, -0.078,
    -0.0783, -0.0786, -0.079, -0.0793, -0.0796, -0.08, -0.0803,
    -0.0806, -0.0809, -0.0813, -0.0816, -0.0819, -0.0822, -0.0825,
    -0.0829, -0.0832, -0.0835, -0.0838, -0.0841, -0.0845, -0.0848,
    -0.0851, -0.0854, -0.0857, -0.086, -0.0863, -0.0866, -0.087,
    -0.0873, -0.0876, -0.0879, -0.0882, -0.0885, -0.0888, -0.0891,
    -0.0894, -0.0897, -0.09, -0.0903, -0.0906, -0.0909, -0.0912,
    -0.0915, -0.0918, -0.0921, -0.0924, -0.0927, -0.093, -0.0933,
    -0.0936, -0.0939, -0.0942, -0.0945, -0.0948, -0.0951, -0.0953,
    -0.0956, -0.0959, -0.0962, -0.0965, -0.0968, -0.0971, -0.0974,
    -0.0976, -0.0979, -0.0982, -0.0985, -0.0988, -0.0991, -0.0993,
    -0.0996, -0.0999, -0.1002, -0.1005, -0.1007, -0.101, -0.1013,
    -0.1016, -0.1019, -0.1021, -0.1024, -0.1027, -0.103, -0.1032,
    -0.1035, -0.1038, -0.1041, -0.1043, -0.1046, -0.1049, -0.1051,
    -0.1054, -0.1057, -0.1059, -0.1062, -0.1065, -0.1067, -0.107,
    -0.1073, -0.1075, -0.1078, -0.1081, -0.1083, -0.1086, -0.1089,
    -0.1091, -0.1094, -0.1097, -0.1099, -0.1102, -0.1104, -0.1107,
    -0.111, -0.1112, -0.1115, -0.1117, -0.112, -0.1122, -0.1125,
    -0.1128, -0.113, -0.1133, -0.1135, -0.1138, -0.114, -0.1143,
    -0.1145, -0.1148, -0.115, -0.1153, -0.1155, -0.1158, -0.116,
    -0.1163, -0.1165, -0.1168, -0.117, -0.1173, -0.1175, -0.1178,
    -0.118, -0.1183, -0.1185, -0.1188, -0.119, -0.1193, -0.1195,
    -0.1197, -0.12, -0.1202, -0.1205, -0.1207, -0.121, -0.1212,
    -0.1214, -0.1217, -0.1219, -0.1222, -0.1224, -0.1226, -0.1229,
    -0.1231, -0.1233, -0.1236, -0.1238, -0.1241, -0.1243, -0.1245,
    -0.1248, -0.125, -0.1252, -0.1255, -0.1257, -0.1259, -0.1262,
    -0.1264, -0.1266, -0.1269, -0.1271, -0.1273, -0.1276, -0.1278,
    -0.128, -0.1282, -0.1285, -0.1287, -0.1289, -0.1292, -0.1294,
    -0.1296, -0.1298, -0.1301, -0.1303, -0.1305, -0.1308, -0.131,
    -0.1312, -0.1314, -0.1317, -0.1319, -0.1321, -0.1323, -0.1325,
    -0.1328, -0.133, -0.1332, -0.1334, -0.1337, -0.1339, -0.1341,
    -0.1343, -0.1345, -0.1348, -0.135, -0.1352, -0.1354, -0.1356,
    -0.1359, -0.1361, -0.1363, -0.1365, -0.1367, -0.1369, -0.1372,
    -0.1374, -0.1376, -0.1378, -0.138, -0.1382, -0.1385, -0.1387,
    -0.1389, -0.1391, -0.1393, -0.1395, -0.1397, -0.1399, -0.1402,
    -0.1404, -0.1406, -0.1408, -0.141, -0.1412, -0.1414, -0.1416,
    -0.1418, -0.1421, -0.1423, -0.1425, -0.1427, -0.1429, -0.1431,
    -0.1433, -0.1435, -0.1437, -0.1439, -0.1441, -0.1443, -0.1446,
    -0.1448, -0.145, -0.1452, -0.1454, -0.1456, -0.1458, -0.146,
    -0.1462, -0.1464, -0.1466, -0.1468, -0.147, -0.1472, -0.1474,
    -0.1476, -0.1478, -0.148, -0.1482, -0.1484, -0.1486, -0.1488,
    -0.149, -0.1492, -0.1494, -0.1496, -0.1498, -0.15, -0.1502,
    -0.1504, -0.1506, -0.1508, -0.151, -0.1512, -0.1514, -0.1516,
    -0.1518, -0.152, -0.1522, -0.1524, -0.1526, -0.1528, -0.153,
    -0.1532, -0.1534, -0.1536, -0.1538, -0.154, -0.1541, -0.1543,
    -0.1545, -0.1547, -0.1549, -0.1551, -0.1553, -0.1555, -0.1557,
    -0.1559, -0.1561, -0.1563, -0.1565, -0.1566, -0.1568, -0.157,
    -0.1572, -0.1574, -0.1576, -0.1578, -0.158, -0.1582, -0.1584,
    -0.1585, -0.1587, -0.1589, -0.1591, -0.1593, -0.1595, -0.1597,
    -0.1599, -0.16, -0.1602, -0.1604, -0.1606, -0.1608, -0.161,
    -0.1612, -0.1613, -0.1615, -0.1617, -0.1619, -0.1621, -0.1623,
    -0.1625, -0.1626, -0.1628, -0.163, -0.1632, -0.1634, -0.1636,
    -0.1637, -0.1639, -0.1641, -0.1643, -0.1645, -0.1647, -0.1648,
    -0.165, -0.1652, -0.1654, -0.1656, -0.1657, -0.1659, -0.1661,
    -0.1663, -0.1665, -0.1666, -0.1668, -0.167, -0.1672, -0.1674,
    -0.1675, -0.1677, -0.1679, -0.1681, -0.1682, -0.1684, -0.1686,
    -0.1688, -0.169, -0.1691, -0.1693, -0.1695, -0.1697, -0.1698,
    -0.17, -0.1702, -0.1704, -0.1705, -0.1707, -0.1709, -0.1711,
    -0.1712, -0.1714, -0.1716, -0.1718, -0.1719, -0.1721, -0.1723,
    -0.1725, -0.1726, -0.1728, -0.173, -0.1731, -0.1733, -0.1735,
    -0.1737, -0.1738, -0.174, -0.1742, -0.1743, -0.1745, -0.1747,
    -0.1749, -0.175, -0.1752, -0.1754, -0.1755, -0.1757, -0.1759,
    -0.1761, -0.1762, -0.1764, -0.1766, -0.1767, -0.1769, -0.1771,
    -0.1772, -0.1774, -0.1776, -0.1777, -0.1779, -0.1781, -0.1782,
    -0.1784, -0.1786, -0.1787, -0.1789, -0.1791, -0.1792, -0.1794,
    -0.1796, -0.1797, -0.1799, -0.1801, -0.1802, -0.1804, -0.1806,
    -0.1807, -0.1809, -0.1811, -0.1812, -0.1814, -0.1816, -0.1817,
    -0.1819, -0.182, -0.1822, -0.1824, -0.1825, -0.1827, -0.1829,
    -0.183, -0.1832, -0.1834, -0.1835, -0.1837, -0.1838, -0.184,
    -0.1842, -0.1843, -0.1845, -0.1846, -0.1848, -0.185, -0.1851,
    -0.1853, -0.1855, -0.1856, -0.1858, -0.1859, -0.1861, -0.1863,
    -0.1864, -0.1866, -0.1867, -0.1869, -0.187, -0.1872, -0.1874,
    -0.1875, -0.1877, -0.1878, -0.188, -0.1882, -0.1883, -0.1885,
    -0.1886, -0.1888, -0.1889, -0.1891, -0.1893, -0.1894, -0.1896,
    -0.1897, -0.1899, -0.19, -0.1902, -0.1904, -0.1905, -0.1907,
    -0.1908, -0.191, -0.1911, -0.1913, -0.1914, -0.1916, -0.1918,
    -0.1919, -0.1921, -0.1922, -0.1924, -0.1925, -0.1927, -0.1928,
    -0.193, -0.1931, -0.1933, -0.1934, -0.1936, -0.1938, -0.1939,
    -0.1941, -0.1942, -0.1944, -0.1945, -0.1947, -0.1948, -0.195,
    -0.1951, -0.1953, -0.1954, -0.1956, -0.1957, -0.1959, -0.196,
    -0.1962, -0.1963, -0.1965, -0.1966, -0.1968, -0.1969, -0.1971,
    -0.1972, -0.1974, -0.1975, -0.1977, -0.1978, -0.198, -0.1981,
    -0.1983, -0.1984, -0.1986, -0.1987, -0.1989, -0.199, -0.1992,
    -0.1993, -0.1995, -0.1996, -0.1998, -0.1999, -0.2001, -0.2002,
    -0.2004, -0.2005, -0.2007, -0.2008, -0.2009, -0.2011, -0.2012,
    -0.2014, -0.2015, -0.2017, -0.2018, -0.202, -0.2021, -0.2023,
    -0.2024, -0.2026, -0.2027, -0.2028, -0.203, -0.2031, -0.2033,
    -0.2034, -0.2036, -0.2037, -0.2039, -0.204, -0.2041, -0.2043,
    -0.2044, -0.2046, -0.2047, -0.2049, -0.205, -0.2052, -0.2053,
    -0.2054, -0.2056, -0.2057, -0.2059, -0.206, -0.2062, -0.2063,
    -0.2064, -0.2066, -0.2067, -0.2069, -0.207, -0.2072, -0.2073,
    -0.2074, -0.2076, -0.2077, -0.2079, -0.208, -0.2081, -0.2083,
    -0.2084, -0.2086, -0.2087, -0.2088, -0.209, -0.2091, -0.2093,
    -0.2094, -0.2095, -0.2097, -0.2098, -0.21, -0.2101, -0.2102,
    -0.2104, -0.2105, -0.2107, -0.2108, -0.2109, -0.2111, -0.2112,
    -0.2114, -0.2115, -0.2116, -0.2118, -0.2119, -0.2121, -0.2122,
    -0.2123, -0.2125, -0.2126, -0.2127, -0.2129, -0.213, -0.2132,
    -0.2133, -0.2134, -0.2136, -0.2137, -0.2138, -0.214, -0.2141,
    -0.2142, -0.2144, -0.2145, -0.2147, -0.2148, -0.2149, -0.2151,
    -0.2152, -0.2153, -0.2155, -0.2156, -0.2157, -0.2159, -0.216,
    -0.2161, -0.2163, -0.2164, -0.2166, -0.2167, -0.2168, -0.217,
    -0.2171, -0.2172, -0.2174, -0.2175, -0.2176, -0.2178, -0.2179,
    -0.218, -0.2182, -0.2183, -0.2184, -0.2186, -0.2187, -0.2188,
    -0.219, -0.2191, -0.2192, -0.2194, -0.2195, -0.2196, -0.2198,
    -0.2199, -0.22, -0.2202, -0.2203, -0.2204, -0.2206, -0.2207,
    -0.2208, -0.2209, -0.2211, -0.2212, -0.2213, -0.2215, -0.2216,
    -0.2217, -0.2219, -0.222, -0.2221, -0.2223, -0.2224, -0.2225,
    -0.2227, -0.2228, -0.2229, -0.223, -0.2232, -0.2233, -0.2234,
    -0.2236, -0.2237, -0.2238, -0.224, -0.2241, -0.2242, -0.2243,
    -0.2245, -0.2246, -0.2247, -0.2249, -0.225, -0.2251, -0.2252,
    -0.2254, -0.2255, -0.2256, -0.2258, -0.2259, -0.226, -0.2261,
    -0.2263, -0.2264, -0.2265, -0.2267, -0.2268, -0.2269, -0.227,
    -0.2272, -0.2273, -0.2274, -0.2275, -0.2277, -0.2278, -0.2279,
    -0.2281, -0.2282, -0.2283, -0.2284, -0.2286, -0.2287, -0.2288,
    -0.2289, -0.2291, -0.2292, -0.2293, -0.2294, -0.2296, -0.2297,
    -0.2298, -0.2299, -0.2301, -0.2302, -0.2303, -0.2304, -0.2306,
    -0.2307, -0.2308, -0.2309, -0.2311, -0.2312, -0.2313, -0.2314,
    -0.2316, -0.2317, -0.2318, -0.2319, -0.2321, -0.2322, -0.2323,
    -0.2324, -0.2326, -0.2327, -0.2328, -0.2329, -0.2331, -0.2332,
    -0.2333, -0.2334, -0.2336, -0.2337, -0.2338, -0.2339, -0.234,
    -0.2342, -0.2343, -0.2344, -0.2345, -0.2347, -0.2348, -0.2349,
    -0.235, -0.2351, -0.2353, -0.2354, -0.2355, -0.2356, -0.2358,
    -0.2359, -0.236, -0.2361, -0.2362, -0.2364, -0.2365, -0.2366,
    -0.2367, -0.2369, -0.237, -0.2371, -0.2372, -0.2373, -0.2375,
    -0.2376, -0.2377, -0.2378, -0.2379, -0.2381, -0.2382, -0.2383,
    -0.2384, -0.2385, -0.2387, -0.2388, -0.2389, -0.239, -0.2391,
    -0.2393, -0.2394, -0.2395, -0.2396, -0.2397, -0.2399, -0.24,
    -0.2401, -0.2402, -0.2403, -0.2405, -0.2406, -0.2407, -0.2408,
    -0.2409, -0.241, -0.2412, -0.2413, -0.2414, -0.2415, -0.2416,
    -0.2418, -0.2419, -0.242, -0.2421, -0.2422, -0.2423, -0.2425,
    -0.2426, -0.2427, -0.2428, -0.2429, -0.2431, -0.2432, -0.2433,
    -0.2434, -0.2435, -0.2436, -0.2438, -0.2439, -0.244, -0.2441,
    -0.2442, -0.2443, -0.2445, -0.2446, -0.2447, -0.2448, -0.2449,
    -0.245, -0.2452, -0.2453, -0.2454, -0.2455, -0.2456, -0.2457,
    -0.2458, -0.246, -0.2461, -0.2462, -0.2463, -0.2464, -0.2465,
    -0.2467, -0.2468, -0.2469, -0.247, -0.2471, -0.2472, -0.2473,
    -0.2475, -0.2476, -0.2477, -0.2478, -0.2479, -0.248, -0.2481,
    -0.2483, -0.2484, -0.2485, -0.2486, -0.2487, -0.2488, -0.2489,
    -0.2491, -0.2492, -0.2493, -0.2494, -0.2495, -0.2496, -0.2497,
    -0.2499, -0.25, -0.2501, -0.2502, -0.2503, -0.2504, -0.2505,
    -0.2506, -0.2508, -0.2509, -0.251, -0.2511, -0.2512, -0.2513,
    -0.2514, -0.2516, -0.2517, -0.2518, -0.2519, -0.252, -0.2521,
    -0.2522, -0.2523, -0.2524, -0.2526, -0.2527, -0.2528, -0.2529,
    -0.253, -0.2531, -0.2532, -0.2533, -0.2535, -0.2536, -0.2537,
    -0.2538, -0.2539, -0.254, -0.2541, -0.2542, -0.2543, -0.2545,
    -0.2546, -0.2547, -0.2548, -0.2549, -0.255, -0.2551, -0.2552,
    -0.2553, -0.2554, -0.2556, -0.2557, -0.2558, -0.2559, -0.256,
    -0.2561, -0.2562, -0.2563, -0.2564, -0.2565, -0.2567, -0.2568,
    -0.2569, -0.257, -0.2571, -0.2572, -0.2573, -0.2574, -0.2575,
    -0.2576, -0.2578, -0.2579, -0.258, -0.2581, -0.2582, -0.2583,
    -0.2584, -0.2585, -0.2586, -0.2587, -0.2588, -0.2589, -0.2591,
    -0.2592, -0.2593, -0.2594, -0.2595, -0.2596, -0.2597, -0.2598,
    -0.2599, -0.26, -0.2601, -0.2602, -0.2604, -0.2605, -0.2606,
    -0.2607, -0.2608, -0.2609, -0.261, -0.2611, -0.2612, -0.2613,
    -0.2614, -0.2615, -0.2616, -0.2617, -0.2619, -0.262, -0.2621,
    -0.2622, -0.2623, -0.2624, -0.2625, -0.2626, -0.2627, -0.2628,
    -0.2629, -0.263, -0.2631, -0.2632, -0.2633, -0.2634, -0.2636,
    -0.2637, -0.2638, -0.2639, -0.264, -0.2641, -0.2642, -0.2643,
    -0.2644, -0.2645, -0.2646, -0.2647, -0.2648, -0.2649, -0.265,
    -0.2651, -0.2652, -0.2653, -0.2655, -0.2656, -0.2657, -0.2658,
    -0.2659, -0.266, -0.2661, -0.2662, -0.2663, -0.2664, -0.2665,
    -0.2666, -0.2667, -0.2668, -0.2669, -0.267, -0.2671, -0.2672,
    -0.2673, -0.2674, -0.2675, -0.2676, -0.2678, -0.2679, -0.268,
    -0.2681, -0.2682, -0.2683, -0.2684, -0.2685, -0.2686, -0.2687,
    -0.2688, -0.2689, -0.269, -0.2691, -0.2692, -0.2693, -0.2694,
    -0.2695, -0.2696, -0.2697, -0.2698, -0.2699, -0.27, -0.2701,
    -0.2702, -0.2703, -0.2704, -0.2705, -0.2706, -0.2707, -0.2708,
    -0.2709, -0.271, -0.2711, -0.2713, -0.2714, -0.2715, -0.2716,
    -0.2717, -0.2718, -0.2719, -0.272, -0.2721, -0.2722, -0.2723,
    -0.2724, -0.2725, -0.2726, -0.2727, -0.2728, -0.2729, -0.273,
    -0.2731, -0.2732, -0.2733, -0.2734, -0.2735, -0.2736, -0.2737,
    -0.2738, -0.2739, -0.274, -0.2741, -0.2742, -0.2743, -0.2744,
    -0.2745, -0.2746, -0.2747, -0.2748, -0.2749, -0.275, -0.2751,
    -0.2752, -0.2753, -0.2754, -0.2755, -0.2756, -0.2757, -0.2758,
    -0.2759, -0.276, -0.2761, -0.2762, -0.2763, -0.2764, -0.2765,
    -0.2766, -0.2767, -0.2768, -0.2769, -0.277, -0.2771, -0.2772,
    -0.2773, -0.2774, -0.2775, -0.2776, -0.2777, -0.2778, -0.2779,
    -0.278, -0.2781, -0.2782, -0.2783, -0.2784, -0.2785, -0.2786,
    -0.2787, -0.2788, -0.2789, -0.279, -0.2791, -0.2792, -0.2793,
    -0.2794, -0.2795, -0.2796, -0.2797, -0.2798, -0.2799, -0.28,
    -0.2801, -0.2801, -0.2802, -0.2803, -0.2804, -0.2805, -0.2806,
    -0.2807, -0.2808, -0.2809, -0.281, -0.2811, -0.2812, -0.2813,
    -0.2814, -0.2815, -0.2816, -0.2817, -0.2818, -0.2819, -0.282,
    -0.2821, -0.2822, -0.2823, -0.2824, -0.2825, -0.2826, -0.2827,
    -0.2828, -0.2829, -0.283, -0.2831, -0.2832, -0.2833, -0.2834,
    -0.2835, -0.2835, -0.2836, -0.2837, -0.2838, -0.2839, -0.284,
    -0.2841, -0.2842, -0.2843, -0.2844, -0.2845, -0.2846, -0.2847,
    -0.2848, -0.2849, -0.285, -0.2851, -0.2852, -0.2853, -0.2854,
    -0.2855, -0.2856, -0.2857, -0.2858, -0.2858, -0.2859, -0.286,
    -0.2861, -0.2862, -0.2863, -0.2864, -0.2865, -0.2866, -0.2867,
    -0.2868, -0.2869, -0.287, -0.2871, -0.2872, -0.2873, -0.2874,
    -0.2875, -0.2876, -0.2877, -0.2877, -0.2878, -0.2879, -0.288,
    -0.2881, -0.2882, -0.2883, -0.2884, -0.2885, -0.2886, -0.2887,
    -0.2888, -0.2889, -0.289, -0.2891, -0.2892, -0.2893, -0.2893,
    -0.2894, -0.2895, -0.2896, -0.2897, -0.2898, -0.2899, -0.29,
    -0.2901, -0.2902, -0.2903, -0.2904, -0.2905, -0.2906, -0.2907,
    -0.2907, -0.2908, -0.2909, -0.291, -0.2911, -0.2912, -0.2913,
    -0.2914, -0.2915, -0.2916, -0.2917, -0.2918, -0.2919, -0.292,
    -0.2921, -0.2921, -0.2922, -0.2923, -0.2924, -0.2925, -0.2926,
    -0.2927, -0.2928, -0.2929, -0.293, -0.2931, -0.2932, -0.2933,
    -0.2933, -0.2934, -0.2935, -0.2936, -0.2937, -0.2938, -0.2939,
    -0.294, -0.2941, -0.2942, -0.2943, -0.2944, -0.2944, -0.2945,
    -0.2946, -0.2947, -0.2948, -0.2949, -0.295, -0.2951, -0.2952,
    -0.2953, -0.2954, -0.2955, -0.2955, -0.2956, -0.2957, -0.2958,
    -0.2959, -0.296, -0.2961, -0.2962, -0.2963, -0.2964, -0.2965,
    -0.2965, -0.2966, -0.2967, -0.2968, -0.2969, -0.297, -0.2971,
    -0.2972, -0.2973, -0.2974, -0.2974, -0.2975, -0.2976, -0.2977,
    -0.2978, -0.2979, -0.298, -0.2981, -0.2982, -0.2983, -0.2984,
    -0.2984, -0.2985, -0.2986, -0.2987, -0.2988, -0.2989, -0.299,
    -0.2991, -0.2992, -0.2992, -0.2993, -0.2994, -0.2995, -0.2996,
    -0.2997, -0.2998, -0.2999, -0.3, -0.3001, -0.3001, -0.3002,
    -0.3003, -0.3004, -0.3005, -0.3006, -0.3007, -0.3008, -0.3009,
    -0.3009, -0.301, -0.3011, -0.3012, -0.3013, -0.3014, -0.3015,
    -0.3016, -0.3017, -0.3017, -0.3018, -0.3019, -0.302, -0.3021,
    -0.3022, -0.3023, -0.3024, -0.3025, -0.3025, -0.3026, -0.3027,
    -0.3028, -0.3029, -0.303, -0.3031, -0.3032, -0.3032, -0.3033,
    -0.3034, -0.3035, -0.3036, -0.3037, -0.3038, -0.3039, -0.304,
    -0.304, -0.3041, -0.3042, -0.3043, -0.3044, -0.3045, -0.3046,
    -0.3047, -0.3047, -0.3048, -0.3049, -0.305, -0.3051, -0.3052,
    -0.3053, -0.3053, -0.3054, -0.3055, -0.3056, -0.3057, -0.3058,
    -0.3059, -0.306, -0.306, -0.3061, -0.3062, -0.3063, -0.3064,
    -0.3065, -0.3066, -0.3067, -0.3067, -0.3068, -0.3069, -0.307,
    -0.3071, -0.3072, -0.3073, -0.3073, -0.3074, -0.3075, -0.3076,
    -0.3077, -0.3078, -0.3079, -0.308, -0.308, -0.3081, -0.3082,
    -0.3083, -0.3084, -0.3085, -0.3086, -0.3086, -0.3087, -0.3088,
    -0.3089, -0.309, -0.3091, -0.3092, -0.3092, -0.3093, -0.3094,
    -0.3095, -0.3096, -0.3097, -0.3098, -0.3098, -0.3099, -0.31,
    -0.3101, -0.3102, -0.3103, -0.3104, -0.3104, -0.3105, -0.3106,
    -0.3107, 0.1882, 0.1859, 0.1836, 0.1813, 0.1791, 0.1769,
    0.1747, 0.1725, 0.1703, 0.1682, 0.1661, 0.164, 0.1619, 0.1598,
    0.1578, 0.1557, 0.1537, 0.1517, 0.1497, 0.1477, 0.1458, 0.1438,
    0.1419, 0.14, 0.1381, 0.1362, 0.1343, 0.1325, 0.1306, 0.1288,
    0.127, 0.1252, 0.1234, 0.1216, 0.1198, 0.1181, 0.1164, 0.1146,
    0.1129, 0.1112, 0.1095, 0.1078, 0.1062, 0.1045, 0.1028, 0.1012,
    0.0996, 0.098, 0.0964, 0.0948, 0.0932, 0.0916, 0.09, 0.0885,
    0.0869, 0.0854, 0.0839, 0.0824, 0.0808, 0.0794, 0.0779, 0.0764,
    0.0749, 0.0734, 0.072, 0.0706, 0.0691, 0.0677, 0.0663, 0.0649,
    0.0635, 0.0621, 0.0607, 0.0593, 0.0579, 0.0566, 0.0552, 0.0539,
    0.0525, 0.0512, 0.0498, 0.0485, 0.0472, 0.0459, 0.0446, 0.0433,
    0.042, 0.0408, 0.0395, 0.0382, 0.037, 0.0357, 0.0345, 0.0332,
    0.032, 0.0308, 0.0295, 0.0283, 0.0271, 0.0259, 0.0247, 0.0235,
    0.0223, 0.0211, 0.02, 0.0188, 0.0176, 0.0165, 0.0153, 0.0142,
    0.013, 0.0119, 0.0108, 0.0097, 0.0085, 0.0074, 0.0063, 0.0052,
    0.0041, 0.003, 0.0019, 9e-04, -2e-04, -0.0013, -0.0024, -0.0034,
    -0.0045, -0.0055, -0.0066, -0.0076, -0.0087, -0.0097, -0.0107,
    -0.0117, -0.0128, -0.0138, -0.0148, -0.0158, -0.0168, -0.0178,
    -0.0188, -0.0197, -0.0207, -0.0217, -0.0227, -0.0236, -0.0246,
    -0.0256, -0.0265, -0.0275, -0.0284, -0.0293, -0.0303, -0.0312,
    -0.0321, -0.0331, -0.034, -0.0349, -0.0358, -0.0367, -0.0376,
    -0.0385, -0.0394, -0.0403, -0.0412, -0.0421, -0.0429, -0.0438,
    -0.0447, -0.0455, -0.0464, -0.0473, -0.0481, -0.049, -0.0498,
    -0.0506, -0.0515, -0.0523, -0.0531, -0.054, -0.0548, -0.0556,
    -0.0564, -0.0572, -0.058, -0.0588, -0.0596, -0.0604, -0.0612,
    -0.062, -0.0628, -0.0635, -0.0643, -0.0651, -0.0658, -0.0666,
    -0.0674, -0.0681, -0.0689, -0.0696, -0.0704, -0.0711, -0.0718,
    -0.0726, -0.0733, -0.074, -0.0747, -0.0754, -0.0762, -0.0769,
    -0.0776, -0.0783, -0.079, -0.0797, -0.0804, -0.0811, -0.0817,
    -0.0824, -0.0831, -0.0838, -0.0844, -0.0851, -0.0858, -0.0864,
    -0.0871, -0.0878, -0.0884, -0.089, -0.0897, -0.0903, -0.091,
    -0.0916, -0.0922, -0.0929, -0.0935, -0.0941, -0.0947, -0.0953,
    -0.096, -0.0966, -0.0972, -0.0978, -0.0984, -0.099, -0.0996,
    -0.1002, -0.1007, -0.1013, -0.1019, -0.1025, -0.1031, -0.1036,
    -0.1042, -0.1048, -0.1053, -0.1059, -0.1065, -0.107, -0.1076,
    -0.1081, -0.1087, -0.1092, -0.1097, -0.1103, -0.1108, -0.1113,
    -0.1119, -0.1124, -0.1129, -0.1134, -0.114, -0.1145, -0.115,
    -0.1155, -0.116, -0.1165, -0.117, -0.1175, -0.118, -0.1185,
    -0.119, -0.1195, -0.12, -0.1205, -0.1209, -0.1214, -0.1219,
    -0.1224, -0.1228, -0.1233, -0.1238, -0.1242, -0.1247, -0.1251,
    -0.1256, -0.1261, -0.1265, -0.127, -0.1274, -0.1278, -0.1283,
    -0.1287, -0.1292, -0.1296, -0.13, -0.1305, -0.1309, -0.1313,
    -0.1317, -0.1322, -0.1326, -0.133, -0.1334, -0.1338, -0.1342,
    -0.1346, -0.135, -0.1355, -0.1359, -0.1363, -0.1367, -0.137,
    -0.1374, -0.1378, -0.1382, -0.1386, -0.139, -0.1394, -0.1398,
    -0.1401, -0.1405, -0.1409, -0.1413, -0.1416, -0.142, -0.1424,
    -0.1427, -0.1431, -0.1435, -0.1438, -0.1442, -0.1445, -0.1449,
    -0.1452, -0.1456, -0.1459, -0.1463, -0.1466, -0.147, -0.1473,
    -0.1477, -0.148, -0.1483, -0.1487, -0.149, -0.1493, -0.1497,
    -0.15, -0.1503, -0.1506, -0.151, -0.1513, -0.1516, -0.1519,
    -0.1522, -0.1525, -0.1529, -0.1532, -0.1535, -0.1538, -0.1541,
    -0.1544, -0.1547, -0.155, -0.1553, -0.1556, -0.1559, -0.1562,
    -0.1565, -0.1568, -0.1571, -0.1574, -0.1576, -0.1579, -0.1582,
    -0.1585, -0.1588, -0.1591, -0.1593, -0.1596, -0.1599, -0.1602,
    -0.1604, -0.1607, -0.161, -0.1613, -0.1615, -0.1618, -0.1621,
    -0.1623, -0.1626, -0.1628, -0.1631, -0.1634, -0.1636, -0.1639,
    -0.1641, -0.1644, -0.1646, -0.1649, -0.1651, -0.1654, -0.1656,
    -0.1659, -0.1661, -0.1664, -0.1666, -0.1668, -0.1671, -0.1673,
    -0.1676, -0.1678, -0.168, -0.1683, -0.1685, -0.1687, -0.1689,
    -0.1692, -0.1694, -0.1696, -0.1699, -0.1701, -0.1703, -0.1705,
    -0.1707, -0.171, -0.1712, -0.1714, -0.1716, -0.1718, -0.172,
    -0.1723, -0.1725, -0.1727, -0.1729, -0.1731, -0.1733, -0.1735,
    -0.1737, -0.1739, -0.1741, -0.1743, -0.1745, -0.1747, -0.1749,
    -0.1751, -0.1753, -0.1755, -0.1757, -0.1759, -0.1761, -0.1763,
    -0.1765, -0.1767, -0.1769, -0.1771, -0.1773, -0.1774, -0.1776,
    -0.1778, -0.178, -0.1782, -0.1784, -0.1785, -0.1787, -0.1789,
    -0.1791, -0.1793, -0.1794, -0.1796, -0.1798, -0.18, -0.1801,
    -0.1803, -0.1805, -0.1807, -0.1808, -0.181, -0.1812, -0.1813,
    -0.1815, -0.1817, -0.1818, -0.182, -0.1822, -0.1823, -0.1825,
    -0.1827, -0.1828, -0.183, -0.1832, -0.1833, -0.1835, -0.1836,
    -0.1838, -0.1839, -0.1841, -0.1843, -0.1844, -0.1846, -0.1847,
    -0.1849, -0.185, -0.1852, -0.1853, -0.1855, -0.1856, -0.1858,
    -0.1859, -0.1861, -0.1862, -0.1864, -0.1865, -0.1867, -0.1868,
    -0.187, -0.1871, -0.1872, -0.1874, -0.1875, -0.1877, -0.1878,
    -0.1879, -0.1881, -0.1882, -0.1884, -0.1885, -0.1886, -0.1888,
    -0.1889, -0.189, -0.1892, -0.1893, -0.1894, -0.1896, -0.1897,
    -0.1898, -0.19, -0.1901, -0.1902, -0.1904, -0.1905, -0.1906,
    -0.1908, -0.1909, -0.191, -0.1911, -0.1913, -0.1914, -0.1915,
    -0.1917, -0.1918, -0.1919, -0.192, -0.1921, -0.1923, -0.1924,
    -0.1925, -0.1926, -0.1928, -0.1929, -0.193, -0.1931, -0.1932,
    -0.1934, -0.1935, -0.1936, -0.1937, -0.1938, -0.194, -0.1941,
    -0.1942, -0.1943, -0.1944, -0.1945, -0.1947, -0.1948, -0.1949,
    -0.195, -0.1951, -0.1952, -0.1953, -0.1954, -0.1956, -0.1957,
    -0.1958, -0.1959, -0.196, -0.1961, -0.1962, -0.1963, -0.1964,
    -0.1965, -0.1967, -0.1968, -0.1969, -0.197, -0.1971, -0.1972,
    -0.1973, -0.1974, -0.1975, -0.1976, -0.1977, -0.1978, -0.1979,
    -0.198, -0.1981, -0.1982, -0.1983, -0.1984, -0.1985, -0.1986,
    -0.1987, -0.1989, -0.199, -0.1991, -0.1992, -0.1993, -0.1994,
    -0.1995, -0.1996, -0.1997, -0.1998, -0.1998, -0.1999, -0.2,
    -0.2001, -0.2002, -0.2003, -0.2004, -0.2005, -0.2006, -0.2007,
    -0.2008, -0.2009, -0.201, -0.2011, -0.2012, -0.2013, -0.2014,
    -0.2015, -0.2016, -0.2017, -0.2018, -0.2018, -0.2019, -0.202,
    -0.2021, -0.2022, -0.2023, -0.2024, -0.2025, -0.2026, -0.2027,
    -0.2028, -0.2028, -0.2029, -0.203, -0.2031, -0.2032, -0.2033,
    -0.2034, -0.2035, -0.2036, -0.2036, -0.2037, -0.2038, -0.2039,
    -0.204, -0.2041, -0.2042, -0.2042, -0.2043, -0.2044, -0.2045,
    -0.2046, -0.2047, -0.2048, -0.2048, -0.2049, -0.205, -0.2051,
    -0.2052, -0.2053, -0.2053, -0.2054, -0.2055, -0.2056, -0.2057,
    -0.2057, -0.2058, -0.2059, -0.206, -0.2061, -0.2061, -0.2062,
    -0.2063, -0.2064, -0.2065, -0.2065, -0.2066, -0.2067, -0.2068,
    -0.2069, -0.2069, -0.207, -0.2071, -0.2072, -0.2072, -0.2073,
    -0.2074, -0.2075, -0.2075, -0.2076, -0.2077, -0.2078, -0.2078,
    -0.2079, -0.208, -0.2081, -0.2081, -0.2082, -0.2083, -0.2084,
    -0.2084, -0.2085, -0.2086, -0.2086, -0.2087, -0.2088, -0.2089,
    -0.2089, -0.209, -0.2091, -0.2091, -0.2092, -0.2093, -0.2094,
    -0.2094, -0.2095, -0.2096, -0.2096, -0.2097, -0.2098, -0.2098,
    -0.2099, -0.21, -0.21, -0.2101, -0.2102, -0.2102, -0.2103,
    -0.2104, -0.2104, -0.2105, -0.2106, -0.2106, -0.2107, -0.2108,
    -0.2108, -0.2109, -0.211, -0.211, -0.2111, -0.2112, -0.2112,
    -0.2113, -0.2113, -0.2114, -0.2115, -0.2115, -0.2116, -0.2117,
    -0.2117, -0.2118, -0.2118, -0.2119, -0.212, -0.212, -0.2121,
    -0.2122, -0.2122, -0.2123, -0.2123, -0.2124, -0.2125, -0.2125,
    -0.2126, -0.2126, -0.2127, -0.2128, -0.2128, -0.2129, -0.2129,
    -0.213, -0.213, -0.2131, -0.2132, -0.2132, -0.2133, -0.2133,
    -0.2134, -0.2134, -0.2135, -0.2136, -0.2136, -0.2137, -0.2137,
    -0.2138, -0.2138, -0.2139, -0.2139, -0.214, -0.2141, -0.2141,
    -0.2142, -0.2142, -0.2143, -0.2143, -0.2144, -0.2144, -0.2145,
    -0.2145, -0.2146, -0.2146, -0.2147, -0.2148, -0.2148, -0.2149,
    -0.2149, -0.215, -0.215, -0.2151, -0.2151, -0.2152, -0.2152,
    -0.2153, -0.2153, -0.2154, -0.2154, -0.2155, -0.2155, -0.2156,
    -0.2156, -0.2157, -0.2157, -0.2158, -0.2158, -0.2159, -0.2159,
    -0.216, -0.216, -0.2161, -0.2161, -0.2162, -0.2162, -0.2163,
    -0.2163, -0.2163, -0.2164, -0.2164, -0.2165, -0.2165, -0.2166,
    -0.2166, -0.2167, -0.2167, -0.2168, -0.2168, -0.2169, -0.2169,
    -0.217, -0.217, -0.217, -0.2171, -0.2171, -0.2172, -0.2172,
    -0.2173, -0.2173, -0.2174, -0.2174, -0.2174, -0.2175, -0.2175,
    -0.2176, -0.2176, -0.2177, -0.2177, -0.2178, -0.2178, -0.2178,
    -0.2179, -0.2179, -0.218, -0.218, -0.2181, -0.2181, -0.2181,
    -0.2182, -0.2182, -0.2183, -0.2183, -0.2183, -0.2184, -0.2184,
    -0.2185, -0.2185, -0.2186, -0.2186, -0.2186, -0.2187, -0.2187,
    -0.2188, -0.2188, -0.2188, -0.2189, -0.2189, -0.219, -0.219,
    -0.219, -0.2191, -0.2191, -0.2192, -0.2192, -0.2192, -0.2193,
    -0.2193, -0.2194, -0.2194, -0.2194, -0.2195, -0.2195, -0.2195,
    -0.2196, -0.2196, -0.2197, -0.2197, -0.2197, -0.2198, -0.2198,
    -0.2199, -0.2199, -0.2199, -0.22, -0.22, -0.22, -0.2201,
    -0.2201, -0.2202, -0.2202, -0.2202, -0.2203, -0.2203, -0.2203,
    -0.2204, -0.2204, -0.2204, -0.2205, -0.2205, -0.2206, -0.2206,
    -0.2206, -0.2207, -0.2207, -0.2207, -0.2208, -0.2208, -0.2208,
    -0.2209, -0.2209, -0.221, -0.221, -0.221, -0.2211, -0.2211,
    -0.2211, -0.2212, -0.2212, -0.2212, -0.2213, -0.2213, -0.2213,
    -0.2214, -0.2214, -0.2214, -0.2215, -0.2215, -0.2215, -0.2216,
    -0.2216, -0.2216, -0.2217, -0.2217, -0.2217, -0.2218, -0.2218,
    -0.2218, -0.2219, -0.2219, -0.2219, -0.222, -0.222, -0.222,
    -0.2221, -0.2221, -0.2221, -0.2222, -0.2222, -0.2222, -0.2223,
    -0.2223, -0.2223, -0.2224, -0.2224, -0.2224, -0.2225, -0.2225,
    -0.2225, -0.2226, -0.2226, -0.2226, -0.2227, -0.2227, -0.2227,
    -0.2228, -0.2228, -0.2228, -0.2229, -0.2229, -0.2229, -0.223,
    -0.223, -0.223, -0.223, -0.2231, -0.2231, -0.2231, -0.2232,
    -0.2232, -0.2232, -0.2233, -0.2233, -0.2233, -0.2234, -0.2234,
    -0.2234, -0.2234, -0.2235, -0.2235, -0.2235, -0.2236, -0.2236,
    -0.2236, -0.2237, -0.2237, -0.2237, -0.2238, -0.2238, -0.2238,
    -0.2238, -0.2239, -0.2239, -0.2239, -0.224, -0.224, -0.224,
    -0.2241, -0.2241, -0.2241, -0.2241, -0.2242, -0.2242, -0.2242,
    -0.2243, -0.2243, -0.2243, -0.2243, -0.2244, -0.2244, -0.2244,
    -0.2245, -0.2245, -0.2245, -0.2245, -0.2246, -0.2246, -0.2246,
    -0.2247, -0.2247, -0.2247, -0.2247, -0.2248, -0.2248, -0.2248,
    -0.2249, -0.2249, -0.2249, -0.2249, -0.225, -0.225, -0.225,
    -0.2251, -0.2251, -0.2251, -0.2251, -0.2252, -0.2252, -0.2252,
    -0.2253, -0.2253, -0.2253, -0.2253, -0.2254, -0.2254, -0.2254,
    -0.2254, -0.2255, -0.2255, -0.2255, -0.2256, -0.2256, -0.2256,
    -0.2256, -0.2257, -0.2257, -0.2257, -0.2257, -0.2258, -0.2258,
    -0.2258, -0.2259, -0.2259, -0.2259, -0.2259, -0.226, -0.226,
    -0.226, -0.226, -0.2261, -0.2261, -0.2261, -0.2261, -0.2262,
    -0.2262, -0.2262, -0.2262, -0.2263, -0.2263, -0.2263, -0.2264,
    -0.2264, -0.2264, -0.2264, -0.2265, -0.2265, -0.2265, -0.2265,
    -0.2266, -0.2266, -0.2266, -0.2266, -0.2267, -0.2267, -0.2267,
    -0.2267, -0.2268, -0.2268, -0.2268, -0.2268, -0.2269, -0.2269,
    -0.2269, -0.2269, -0.227, -0.227, -0.227, -0.227, -0.2271,
    -0.2271, -0.2271, -0.2271, -0.2272, -0.2272, -0.2272, -0.2272,
    -0.2273, -0.2273, -0.2273, -0.2273, -0.2274, -0.2274, -0.2274,
    -0.2274, -0.2275, -0.2275, -0.2275, -0.2275, -0.2276, -0.2276,
    -0.2276, -0.2276, -0.2277, -0.2277, -0.2277, -0.2277, -0.2277,
    -0.2278, -0.2278, -0.2278, -0.2278, -0.2279, -0.2279, -0.2279,
    -0.2279, -0.228, -0.228, -0.228, -0.228, -0.2281, -0.2281,
    -0.2281, -0.2281, -0.2282, -0.2282, -0.2282, -0.2282, -0.2282,
    -0.2283, -0.2283, -0.2283, -0.2283, -0.2284, -0.2284, -0.2284,
    -0.2284, -0.2285, -0.2285, -0.2285, -0.2285, -0.2285, -0.2286,
    -0.2286, -0.2286, -0.2286, -0.2287, -0.2287, -0.2287, -0.2287,
    -0.2287, -0.2288, -0.2288, -0.2288, -0.2288, -0.2289, -0.2289,
    -0.2289, -0.2289, -0.2289, -0.229, -0.229, -0.229, -0.229,
    -0.2291, -0.2291, -0.2291, -0.2291, -0.2291, -0.2292, -0.2292,
    -0.2292, -0.2292, -0.2292, -0.2293, -0.2293, -0.2293, -0.2293,
    -0.2294, -0.2294, -0.2294, -0.2294, -0.2294, -0.2295, -0.2295,
    -0.2295, -0.2295, -0.2295, -0.2296, -0.2296, -0.2296, -0.2296,
    -0.2297, -0.2297, -0.2297, -0.2297, -0.2297, -0.2298, -0.2298,
    -0.2298, -0.2298, -0.2298, -0.2299, -0.2299, -0.2299, -0.2299,
    -0.2299, -0.23, -0.23, -0.23, -0.23, -0.23, -0.2301, -0.2301,
    -0.2301, -0.2301, -0.2301, -0.2302, -0.2302, -0.2302, -0.2302,
    -0.2302, -0.2303, -0.2303, -0.2303, -0.2303, -0.2303, -0.2304,
    -0.2304, -0.2304, -0.2304, -0.2304, -0.2305, -0.2305, -0.2305,
    -0.2305, -0.2305, -0.2306, -0.2306, -0.2306, -0.2306, -0.2306,
    -0.2307, -0.2307, -0.2307, -0.2307, -0.2307, -0.2308, -0.2308,
    -0.2308, -0.2308, -0.2308, -0.2308, -0.2309, -0.2309, -0.2309,
    -0.2309, -0.2309, -0.231, -0.231, -0.231, -0.231, -0.231,
    -0.2311, -0.2311, -0.2311, -0.2311, -0.2311, -0.2311, -0.2312,
    -0.2312, -0.2312, -0.2312, -0.2312, -0.2313, -0.2313, -0.2313,
    -0.2313, -0.2313, -0.2314, -0.2314, -0.2314, -0.2314, -0.2314,
    -0.2314, -0.2315, -0.2315, -0.2315, -0.2315, -0.2315, -0.2316,
    -0.2316, -0.2316, -0.2316, -0.2316, -0.2316, -0.2317, -0.2317,
    -0.2317, -0.2317, -0.2317, -0.2318, -0.2318, -0.2318, -0.2318,
    -0.2318, -0.2318, -0.2319, -0.2319, -0.2319, -0.2319, -0.2319,
    -0.2319, -0.232, -0.232, -0.232, -0.232, -0.232, -0.2321,
    -0.2321, -0.2321, -0.2321, -0.2321, -0.2321, -0.2322, -0.2322,
    -0.2322, -0.2322, -0.2322, -0.2322, -0.2323, -0.2323, -0.2323,
    -0.2323, -0.2323, -0.2324, -0.2324, -0.2324, -0.2324, -0.2324,
    -0.2324, -0.2325, -0.2325, -0.2325, -0.2325, -0.2325, -0.2325,
    -0.2326, -0.2326, -0.2326, -0.2326, -0.2326, -0.2326, -0.2327,
    -0.2327, -0.2327, -0.2327, -0.2327, -0.2327, -0.2328, -0.2328,
    -0.2328, -0.2328, -0.2328, -0.2328, -0.2329, -0.2329, -0.2329,
    -0.2329, -0.2329, -0.2329, -0.233, -0.233, -0.233, -0.233,
    -0.233, -0.233, -0.2331, -0.2331, -0.2331, -0.2331, -0.2331,
    -0.2331, -0.2332, -0.2332, -0.2332, -0.2332, -0.2332, -0.2332,
    -0.2333, -0.2333, -0.2333, -0.2333, -0.2333, -0.2333, -0.2334,
    -0.2334, -0.2334, -0.2334, -0.2334, -0.2334, -0.2335, -0.2335,
    -0.2335, -0.2335, -0.2335, -0.2335, -0.2336, -0.2336, -0.2336,
    -0.2336, -0.2336, -0.2336, -0.2337, -0.2337, -0.2337, -0.2337,
    -0.2337, -0.2337, -0.2337, -0.2338, -0.2338, -0.2338, -0.2338,
    -0.2338, -0.2338, -0.2339, -0.2339, -0.2339, -0.2339, -0.2339,
    -0.2339, -0.234, -0.234, -0.234, -0.234, -0.234, -0.234,
    -0.234, -0.2341, -0.2341, -0.2341, -0.2341, -0.2341, -0.2341,
    -0.2342, -0.2342, -0.2342, -0.2342, -0.2342, -0.2342, -0.2342,
    -0.2343, -0.2343, -0.2343, -0.2343, -0.2343, -0.2343, -0.2344,
    -0.2344, -0.2344, -0.2344, -0.2344, -0.2344, -0.2344, -0.2345,
    -0.2345, -0.2345, -0.2345, -0.2345, -0.2345, -0.2346, -0.2346,
    -0.2346, -0.2346, -0.2346, -0.2346, -0.2346, -0.2347, -0.2347,
    -0.2347, -0.2347, -0.2347, -0.2347, -0.2348, -0.2348, -0.2348,
    -0.2348, -0.2348, -0.2348, -0.2348, -0.2349, -0.2349, -0.2349,
    -0.2349, -0.2349, -0.2349, -0.2349, -0.235, -0.235, -0.235,
    -0.235, -0.235, -0.235, -0.2351, -0.2351, -0.2351, -0.2351,
    -0.2351, -0.2351, -0.2351, -0.2352, -0.2352, -0.2352, -0.2352,
    -0.2352, -0.2352, -0.2352, -0.2353, -0.2353, -0.2353, -0.2353,
    -0.2353, -0.2353, -0.2353, -0.2354, -0.2354, -0.2354, -0.2354,
    -0.2354, -0.2354, -0.2354, -0.2355, -0.2355, -0.2355, -0.2355,
    -0.2355, -0.2355, -0.2355, -0.2356, -0.2356, -0.2356, -0.2356,
    -0.2356, -0.2356, -0.2356, -0.2357, -0.2357, -0.2357, -0.2357,
    -0.2357, -0.2357, -0.2357, -0.2358, -0.2358, -0.2358, -0.2358,
    -0.2358, -0.2358, -0.2358, -0.2359, -0.2359, -0.2359, -0.2359,
    -0.2359, -0.2359, -0.2359, -0.236, -0.236, -0.236, -0.236,
    -0.236, -0.236, -0.236, -0.2361, -0.2361, -0.2361, -0.2361,
    -0.2361, -0.2361, -0.2361, -0.2362, -0.2362, -0.2362, -0.2362,
    -0.2362, -0.2362, -0.2362, -0.2363, -0.2363, -0.2363, -0.2363,
    -0.2363, -0.2363, -0.2363, -0.2363, -0.2364, -0.2364, -0.2364,
    -0.2364, -0.2364, -0.2364, -0.2364, -0.2365, -0.2365, -0.2365,
    -0.2365, -0.2365, -0.2365, -0.2365, -0.2366, -0.2366, -0.2366,
    -0.2366, -0.2366, -0.2366, -0.2366, -0.2366, -0.2367, -0.2367,
    -0.2367, -0.2367, -0.2367, -0.2367, -0.2367, -0.2368, -0.2368,
    -0.2368, -0.2368, -0.2368, -0.2368, -0.2368, -0.2369, -0.2369,
    -0.2369, -0.2369, -0.2369, -0.2369, -0.2369, -0.2369, -0.237,
    -0.237, -0.237, -0.237, -0.237, -0.237, -0.237, -0.2371,
    -0.2371, -0.2371, -0.2371, -0.2371, -0.2371, -0.2371, -0.2371,
    -0.2372, 0.3487, 0.3127, 0.3029, 0.2959, 0.2903, 0.2855,
    0.2813, 0.2776, 0.2742, 0.2711, 0.2681, 0.2654, 0.2628, 0.2604,
    0.2581, 0.2558, 0.2537, 0.2517, 0.2497, 0.2478, 0.246, 0.2442,
    0.2425, 0.2408, 0.2392, 0.2376, 0.2361, 0.2346, 0.2331, 0.2317,
    0.2303, 0.229, 0.2276, 0.2263, 0.225, 0.2237, 0.2225, 0.2213,
    0.2201, 0.2189, 0.2178, 0.2166, 0.2155, 0.2144, 0.2133, 0.2122,
    0.2112, 0.2101, 0.2091, 0.2081, 0.2071, 0.2061, 0.2052, 0.2042,
    0.2032, 0.2023, 0.2014, 0.2005, 0.1996, 0.1987, 0.1978, 0.1969,
    0.196, 0.1952, 0.1943, 0.1935, 0.1926, 0.1918, 0.191, 0.1902,
    0.1894, 0.1886, 0.1878, 0.187, 0.1863, 0.1855, 0.1847, 0.184,
    0.1832, 0.1825, 0.1818, 0.181, 0.1803, 0.1796, 0.1789, 0.1782,
    0.1775, 0.1768, 0.1761, 0.1754, 0.1747, 0.174, 0.1734, 0.1727,
    0.172, 0.1714, 0.1707, 0.1701, 0.1694, 0.1688, 0.1682, 0.1675,
    0.1669, 0.1663, 0.1657, 0.1651, 0.1644, 0.1638, 0.1632, 0.1626,
    0.162, 0.1614, 0.1609, 0.1603, 0.1597, 0.1591, 0.1585, 0.158,
    0.1574, 0.1568, 0.1563, 0.1557, 0.1551, 0.1546, 0.154, 0.1535,
    0.1529, 0.1524, 0.1519, 0.1513, 0.1508, 0.1502, 0.1497, 0.1492,
    0.1487, 0.1481, 0.1476, 0.1471, 0.1466, 0.1461, 0.1456, 0.1451,
    0.1446, 0.1441, 0.1436, 0.1431, 0.1426, 0.1421, 0.1416, 0.1411,
    0.1406, 0.1401, 0.1396, 0.1391, 0.1387, 0.1382, 0.1377, 0.1372,
    0.1368, 0.1363, 0.1358, 0.1354, 0.1349, 0.1344, 0.134, 0.1335,
    0.1331, 0.1326, 0.1322, 0.1317, 0.1313, 0.1308, 0.1304, 0.1299,
    0.1295, 0.129, 0.1286, 0.1282, 0.1277, 0.1273, 0.1269, 0.1264,
    0.126, 0.1256, 0.1251, 0.1247, 0.1243, 0.1239, 0.1235, 0.123,
    0.1226, 0.1222, 0.1218, 0.1214, 0.121, 0.1206, 0.1201, 0.1197,
    0.1193, 0.1189, 0.1185, 0.1181, 0.1177, 0.1173, 0.1169, 0.1165,
    0.1161, 0.1157, 0.1153, 0.1149, 0.1145, 0.1142, 0.1138, 0.1134,
    0.113, 0.1126, 0.1122, 0.1118, 0.1115, 0.1111, 0.1107, 0.1103,
    0.1099, 0.1096, 0.1092, 0.1088, 0.1084, 0.1081, 0.1077, 0.1073,
    0.107, 0.1066, 0.1062, 0.1059, 0.1055, 0.1051, 0.1048, 0.1044,
    0.104, 0.1037, 0.1033, 0.103, 0.1026, 0.1023, 0.1019, 0.1015,
    0.1012, 0.1008, 0.1005, 0.1001, 0.0998, 0.0994, 0.0991, 0.0987,
    0.0984, 0.0981, 0.0977, 0.0974, 0.097, 0.0967, 0.0963, 0.096,
    0.0957, 0.0953, 0.095, 0.0947, 0.0943, 0.094, 0.0937, 0.0933,
    0.093, 0.0927, 0.0923, 0.092, 0.0917, 0.0913, 0.091, 0.0907,
    0.0904, 0.09, 0.0897, 0.0894, 0.0891, 0.0887, 0.0884, 0.0881,
    0.0878, 0.0875, 0.0871, 0.0868, 0.0865, 0.0862, 0.0859, 0.0856,
    0.0852, 0.0849, 0.0846, 0.0843, 0.084, 0.0837, 0.0834, 0.0831,
    0.0827, 0.0824, 0.0821, 0.0818, 0.0815, 0.0812, 0.0809, 0.0806,
    0.0803, 0.08, 0.0797, 0.0794, 0.0791, 0.0788, 0.0785, 0.0782,
    0.0779, 0.0776, 0.0773, 0.077, 0.0767, 0.0764, 0.0761, 0.0758,
    0.0755, 0.0752, 0.0749, 0.0746, 0.0744, 0.0741, 0.0738, 0.0735,
    0.0732, 0.0729, 0.0726, 0.0723, 0.072, 0.0718, 0.0715, 0.0712,
    0.0709, 0.0706, 0.0703, 0.0701, 0.0698, 0.0695, 0.0692, 0.0689,
    0.0686, 0.0684, 0.0681, 0.0678, 0.0675, 0.0672, 0.067, 0.0667,
    0.0664, 0.0661, 0.0659, 0.0656, 0.0653, 0.065, 0.0648, 0.0645,
    0.0642, 0.064, 0.0637, 0.0634, 0.0631, 0.0629, 0.0626, 0.0623,
    0.0621, 0.0618, 0.0615, 0.0613, 0.061, 0.0607, 0.0605, 0.0602,
    0.0599, 0.0597, 0.0594, 0.0591, 0.0589, 0.0586, 0.0583, 0.0581,
    0.0578, 0.0576, 0.0573, 0.057, 0.0568, 0.0565, 0.0563, 0.056,
    0.0557, 0.0555, 0.0552, 0.055, 0.0547, 0.0545, 0.0542, 0.054,
    0.0537, 0.0534, 0.0532, 0.0529, 0.0527, 0.0524, 0.0522, 0.0519,
    0.0517, 0.0514, 0.0512, 0.0509, 0.0507, 0.0504, 0.0502, 0.0499,
    0.0497, 0.0494, 0.0492, 0.0489, 0.0487, 0.0484, 0.0482, 0.0479,
    0.0477, 0.0475, 0.0472, 0.047, 0.0467, 0.0465, 0.0462, 0.046,
    0.0458, 0.0455, 0.0453, 0.045, 0.0448, 0.0445, 0.0443, 0.0441,
    0.0438, 0.0436, 0.0433, 0.0431, 0.0429, 0.0426, 0.0424, 0.0422,
    0.0419, 0.0417, 0.0414, 0.0412, 0.041, 0.0407, 0.0405, 0.0403,
    0.04, 0.0398, 0.0396, 0.0393, 0.0391, 0.0389, 0.0386, 0.0384,
    0.0382, 0.0379, 0.0377, 0.0375, 0.0373, 0.037, 0.0368, 0.0366,
    0.0363, 0.0361, 0.0359, 0.0357, 0.0354, 0.0352, 0.035, 0.0347,
    0.0345, 0.0343, 0.0341, 0.0338, 0.0336, 0.0334, 0.0332, 0.0329,
    0.0327, 0.0325, 0.0323, 0.032, 0.0318, 0.0316, 0.0314, 0.0312,
    0.0309, 0.0307, 0.0305, 0.0303, 0.03, 0.0298, 0.0296, 0.0294,
    0.0292, 0.0289, 0.0287, 0.0285, 0.0283, 0.0281, 0.0279, 0.0276,
    0.0274, 0.0272, 0.027, 0.0268, 0.0266, 0.0263, 0.0261, 0.0259,
    0.0257, 0.0255, 0.0253, 0.025, 0.0248, 0.0246, 0.0244, 0.0242,
    0.024, 0.0238, 0.0236, 0.0233, 0.0231, 0.0229, 0.0227, 0.0225,
    0.0223, 0.0221, 0.0219, 0.0217, 0.0214, 0.0212, 0.021, 0.0208,
    0.0206, 0.0204, 0.0202, 0.02, 0.0198, 0.0196, 0.0194, 0.0192,
    0.0189, 0.0187, 0.0185, 0.0183, 0.0181, 0.0179, 0.0177, 0.0175,
    0.0173, 0.0171, 0.0169, 0.0167, 0.0165, 0.0163, 0.0161, 0.0159,
    0.0157, 0.0155, 0.0153, 0.0151, 0.0149, 0.0147, 0.0144, 0.0142,
    0.014, 0.0138, 0.0136, 0.0134, 0.0132, 0.013, 0.0128, 0.0126,
    0.0124, 0.0122, 0.012, 0.0118, 0.0116, 0.0114, 0.0112, 0.0111,
    0.0109, 0.0107, 0.0105, 0.0103, 0.0101, 0.0099, 0.0097, 0.0095,
    0.0093, 0.0091, 0.0089, 0.0087, 0.0085, 0.0083, 0.0081, 0.0079,
    0.0077, 0.0075, 0.0073, 0.0071, 0.0069, 0.0067, 0.0066, 0.0064,
    0.0062, 0.006, 0.0058, 0.0056, 0.0054, 0.0052, 0.005, 0.0048,
    0.0046, 0.0044, 0.0043, 0.0041, 0.0039, 0.0037, 0.0035, 0.0033,
    0.0031, 0.0029, 0.0027, 0.0025, 0.0024, 0.0022, 0.002, 0.0018,
    0.0016, 0.0014, 0.0012, 0.001, 8e-04, 7e-04, 5e-04, 3e-04,
    1e-04, -1e-04, -3e-04, -5e-04, -6e-04, -8e-04, -0.001, -0.0012,
    -0.0014, -0.0016, -0.0018, -0.0019, -0.0021, -0.0023, -0.0025,
    -0.0027, -0.0029, -0.003, -0.0032, -0.0034, -0.0036, -0.0038,
    -0.004, -0.0041, -0.0043, -0.0045, -0.0047, -0.0049, -0.0051,
    -0.0052, -0.0054, -0.0056, -0.0058, -0.006, -0.0061, -0.0063,
    -0.0065, -0.0067, -0.0069, -0.007, -0.0072, -0.0074, -0.0076,
    -0.0078, -0.0079, -0.0081, -0.0083, -0.0085, -0.0087, -0.0088,
    -0.009, -0.0092, -0.0094, -0.0095, -0.0097, -0.0099, -0.0101,
    -0.0102, -0.0104, -0.0106, -0.0108, -0.011, -0.0111, -0.0113,
    -0.0115, -0.0117, -0.0118, -0.012, -0.0122, -0.0124, -0.0125,
    -0.0127, -0.0129, -0.0131, -0.0132, -0.0134, -0.0136, -0.0137,
    -0.0139, -0.0141, -0.0143, -0.0144, -0.0146, -0.0148, -0.015,
    -0.0151, -0.0153, -0.0155, -0.0156, -0.0158, -0.016, -0.0162,
    -0.0163, -0.0165, -0.0167, -0.0168, -0.017, -0.0172, -0.0174,
    -0.0175, -0.0177, -0.0179, -0.018, -0.0182, -0.0184, -0.0185,
    -0.0187, -0.0189, -0.0191, -0.0192, -0.0194, -0.0196, -0.0197,
    -0.0199, -0.0201, -0.0202, -0.0204, -0.0206, -0.0207, -0.0209,
    -0.0211, -0.0212, -0.0214, -0.0216, -0.0217, -0.0219, -0.0221,
    -0.0222, -0.0224, -0.0226, -0.0227, -0.0229, -0.0231, -0.0232,
    -0.0234, -0.0236, -0.0237, -0.0239, -0.0241, -0.0242, -0.0244,
    -0.0246, -0.0247, -0.0249, -0.025, -0.0252, -0.0254, -0.0255,
    -0.0257, -0.0259, -0.026, -0.0262, -0.0264, -0.0265, -0.0267,
    -0.0268, -0.027, -0.0272, -0.0273, -0.0275, -0.0277, -0.0278,
    -0.028, -0.0281, -0.0283, -0.0285, -0.0286, -0.0288, -0.0289,
    -0.0291, -0.0293, -0.0294, -0.0296, -0.0297, -0.0299, -0.0301,
    -0.0302, -0.0304, -0.0305, -0.0307, -0.0309, -0.031, -0.0312,
    -0.0313, -0.0315, -0.0317, -0.0318, -0.032, -0.0321, -0.0323,
    -0.0324, -0.0326, -0.0328, -0.0329, -0.0331, -0.0332, -0.0334,
    -0.0336, -0.0337, -0.0339, -0.034, -0.0342, -0.0343, -0.0345,
    -0.0346, -0.0348, -0.035, -0.0351, -0.0353, -0.0354, -0.0356,
    -0.0357, -0.0359, -0.0361, -0.0362, -0.0364, -0.0365, -0.0367,
    -0.0368, -0.037, -0.0371, -0.0373, -0.0374, -0.0376, -0.0378,
    -0.0379, -0.0381, -0.0382, -0.0384, -0.0385, -0.0387, -0.0388,
    -0.039, -0.0391, -0.0393, -0.0394, -0.0396, -0.0397, -0.0399,
    -0.0401, -0.0402, -0.0404, -0.0405, -0.0407, -0.0408, -0.041,
    -0.0411, -0.0413, -0.0414, -0.0416, -0.0417, -0.0419, -0.042,
    -0.0422, -0.0423, -0.0425, -0.0426, -0.0428, -0.0429, -0.0431,
    -0.0432, -0.0434, -0.0435, -0.0437, -0.0438, -0.044, -0.0441,
    -0.0443, -0.0444, -0.0446, -0.0447, -0.0449, -0.045, -0.0452,
    -0.0453, -0.0455, -0.0456, -0.0458, -0.0459, -0.0461, -0.0462,
    -0.0464, -0.0465, -0.0466, -0.0468, -0.0469, -0.0471, -0.0472,
    -0.0474, -0.0475, -0.0477, -0.0478, -0.048, -0.0481, -0.0483,
    -0.0484, -0.0486, -0.0487, -0.0489, -0.049, -0.0491, -0.0493,
    -0.0494, -0.0496, -0.0497, -0.0499, -0.05, -0.0502, -0.0503,
    -0.0505, -0.0506, -0.0507, -0.0509, -0.051, -0.0512, -0.0513,
    -0.0515, -0.0516, -0.0518, -0.0519, -0.052, -0.0522, -0.0523,
    -0.0525, -0.0526, -0.0528, -0.0529, -0.053, -0.0532, -0.0533,
    -0.0535, -0.0536, -0.0538, -0.0539, -0.054, -0.0542, -0.0543,
    -0.0545, -0.0546, -0.0548, -0.0549, -0.055, -0.0552, -0.0553,
    -0.0555, -0.0556, -0.0558, -0.0559, -0.056, -0.0562, -0.0563,
    -0.0565, -0.0566, -0.0567, -0.0569, -0.057, -0.0572, -0.0573,
    -0.0574, -0.0576, -0.0577, -0.0579, -0.058, -0.0581, -0.0583,
    -0.0584, -0.0586, -0.0587, -0.0588, -0.059, -0.0591, -0.0593,
    -0.0594, -0.0595, -0.0597, -0.0598, -0.06, -0.0601, -0.0602,
    -0.0604, -0.0605, -0.0607, -0.0608, -0.0609, -0.0611, -0.0612,
    -0.0613, -0.0615, -0.0616, -0.0618, -0.0619, -0.062, -0.0622,
    -0.0623, -0.0624, -0.0626, -0.0627, -0.0629, -0.063, -0.0631,
    -0.0633, -0.0634, -0.0635, -0.0637, -0.0638, -0.0639, -0.0641,
    -0.0642, -0.0644, -0.0645, -0.0646, -0.0648, -0.0649, -0.065,
    -0.0652, -0.0653, -0.0654, -0.0656, -0.0657, -0.0658, -0.066,
    -0.0661, -0.0663, -0.0664, -0.0665, -0.0667, -0.0668, -0.0669,
    -0.0671, -0.0672, -0.0673, -0.0675, -0.0676, -0.0677, -0.0679,
    -0.068, -0.0681, -0.0683, -0.0684, -0.0685, -0.0687, -0.0688,
    -0.0689, -0.0691, -0.0692, -0.0693, -0.0695, -0.0696, -0.0697,
    -0.0699, -0.07, -0.0701, -0.0703, -0.0704, -0.0705, -0.0707,
    -0.0708, -0.0709, -0.0711, -0.0712, -0.0713, -0.0715, -0.0716,
    -0.0717, -0.0718, -0.072, -0.0721, -0.0722, -0.0724, -0.0725,
    -0.0726, -0.0728, -0.0729, -0.073, -0.0732, -0.0733, -0.0734,
    -0.0736, -0.0737, -0.0738, -0.0739, -0.0741, -0.0742, -0.0743,
    -0.0745, -0.0746, -0.0747, -0.0749, -0.075, -0.0751, -0.0752,
    -0.0754, -0.0755, -0.0756, -0.0758, -0.0759, -0.076, -0.0762,
    -0.0763, -0.0764, -0.0765, -0.0767, -0.0768, -0.0769, -0.0771,
    -0.0772, -0.0773, -0.0774, -0.0776, -0.0777, -0.0778, -0.078,
    -0.0781, -0.0782, -0.0783, -0.0785, -0.0786, -0.0787, -0.0788,
    -0.079, -0.0791, -0.0792, -0.0794, -0.0795, -0.0796, -0.0797,
    -0.0799, -0.08, -0.0801, -0.0802, -0.0804, -0.0805, -0.0806,
    -0.0808, -0.0809, -0.081, -0.0811, -0.0813, -0.0814, -0.0815,
    -0.0816, -0.0818, -0.0819, -0.082, -0.0821, -0.0823, -0.0824,
    -0.0825, -0.0826, -0.0828, -0.0829, -0.083, -0.0831, -0.0833,
    -0.0834, -0.0835, -0.0836, -0.0838, -0.0839, -0.084, -0.0841,
    -0.0843, -0.0844, -0.0845, -0.0846, -0.0848, -0.0849, -0.085,
    -0.0851, -0.0853, -0.0854, -0.0855, -0.0856, -0.0858, -0.0859,
    -0.086, -0.0861, -0.0863, -0.0864, -0.0865, -0.0866, -0.0868,
    -0.0869, -0.087, -0.0871, -0.0872, -0.0874, -0.0875, -0.0876,
    -0.0877, -0.0879, -0.088, -0.0881, -0.0882, -0.0883, -0.0885,
    -0.0886, -0.0887, -0.0888, -0.089, -0.0891, -0.0892, -0.0893,
    -0.0894, -0.0896, -0.0897, -0.0898, -0.0899, -0.0901, -0.0902,
    -0.0903, -0.0904, -0.0905, -0.0907, -0.0908, -0.0909, -0.091,
    -0.0912, -0.0913, -0.0914, -0.0915, -0.0916, -0.0918, -0.0919,
    -0.092, -0.0921, -0.0922, -0.0924, -0.0925, -0.0926, -0.0927,
    -0.0928, -0.093, -0.0931, -0.0932, -0.0933, -0.0934, -0.0936,
    -0.0937, -0.0938, -0.0939, -0.094, -0.0942, -0.0943, -0.0944,
    -0.0945, -0.0946, -0.0948, -0.0949, -0.095, -0.0951, -0.0952,
    -0.0954, -0.0955, -0.0956, -0.0957, -0.0958, -0.0959, -0.0961,
    -0.0962, -0.0963, -0.0964, -0.0965, -0.0967, -0.0968, -0.0969,
    -0.097, -0.0971, -0.0972, -0.0974, -0.0975, -0.0976, -0.0977,
    -0.0978, -0.098, -0.0981, -0.0982, -0.0983, -0.0984, -0.0985,
    -0.0987, -0.0988, -0.0989, -0.099, -0.0991, -0.0992, -0.0994,
    -0.0995, -0.0996, -0.0997, -0.0998, -0.0999, -0.1001, -0.1002,
    -0.1003, -0.1004, -0.1005, -0.1006, -0.1008, -0.1009, -0.101,
    -0.1011, -0.1012, -0.1013, -0.1015, -0.1016, -0.1017, -0.1018,
    -0.1019, -0.102, -0.1022, -0.1023, -0.1024, -0.1025, -0.1026,
    -0.1027, -0.1028, -0.103, -0.1031, -0.1032, -0.1033, -0.1034,
    -0.1035, -0.1037, -0.1038, -0.1039, -0.104, -0.1041, -0.1042,
    -0.1043, -0.1045, -0.1046, -0.1047, -0.1048, -0.1049, -0.105,
    -0.1051, -0.1053, -0.1054, -0.1055, -0.1056, -0.1057, -0.1058,
    -0.1059, -0.1061, -0.1062, -0.1063, -0.1064, -0.1065, -0.1066,
    -0.1067, -0.1068, -0.107, -0.1071, -0.1072, -0.1073, -0.1074,
    -0.1075, -0.1076, -0.1078, -0.1079, -0.108, -0.1081, -0.1082,
    -0.1083, -0.1084, -0.1085, -0.1087, -0.1088, -0.1089, -0.109,
    -0.1091, -0.1092, -0.1093, -0.1094, -0.1096, -0.1097, -0.1098,
    -0.1099, -0.11, -0.1101, -0.1102, -0.1103, -0.1105, -0.1106,
    -0.1107, -0.1108, -0.1109, -0.111, -0.1111, -0.1112, -0.1113,
    -0.1115, -0.1116, -0.1117, -0.1118, -0.1119, -0.112, -0.1121,
    -0.1122, -0.1123, -0.1125, -0.1126, -0.1127, -0.1128, -0.1129,
    -0.113, -0.1131, -0.1132, -0.1133, -0.1134, -0.1136, -0.1137,
    -0.1138, -0.1139, -0.114, -0.1141, -0.1142, -0.1143, -0.1144,
    -0.1146, -0.1147, -0.1148, -0.1149, -0.115, -0.1151, -0.1152,
    -0.1153, -0.1154, -0.1155, -0.1156, -0.1158, -0.1159, -0.116,
    -0.1161, -0.1162, -0.1163, -0.1164, -0.1165, -0.1166, -0.1167,
    -0.1168, -0.117, -0.1171, -0.1172, -0.1173, -0.1174, -0.1175,
    -0.1176, -0.1177, -0.1178, -0.1179, -0.118, -0.1182, -0.1183,
    -0.1184, -0.1185, -0.1186, -0.1187, -0.1188, -0.1189, -0.119,
    -0.1191, -0.1192, -0.1193, -0.1195, -0.1196, -0.1197, -0.1198,
    -0.1199, -0.12, -0.1201, -0.1202, -0.1203, -0.1204, -0.1205,
    -0.1206, -0.1207, -0.1208, -0.121, -0.1211, -0.1212, -0.1213,
    -0.1214, -0.1215, -0.1216, -0.1217, -0.1218, -0.1219, -0.122,
    -0.1221, -0.1222, -0.1223, -0.1225, -0.1226, -0.1227, -0.1228,
    -0.1229, -0.123, -0.1231, -0.1232, -0.1233, -0.1234, -0.1235,
    -0.1236, -0.1237, -0.1238, -0.1239, -0.124, -0.1242, -0.1243,
    -0.1244, -0.1245, -0.1246, -0.1247, -0.1248, -0.1249, -0.125,
    -0.1251, -0.1252, -0.1253, -0.1254, -0.1255, -0.1256, -0.1257,
    -0.1258, -0.1259, -0.126, -0.1262, -0.1263, -0.1264, -0.1265,
    -0.1266, -0.1267, -0.1268, -0.1269, -0.127, -0.1271, -0.1272,
    -0.1273, -0.1274, -0.1275, -0.1276, -0.1277, -0.1278, -0.1279,
    -0.128, -0.1281, -0.1282, -0.1283, -0.1285, -0.1286, -0.1287,
    -0.1288, -0.1289, -0.129, -0.1291, -0.1292, -0.1293, -0.1294,
    -0.1295, -0.1296, -0.1297, -0.1298, -0.1299, -0.13, -0.1301,
    -0.1302, -0.1303, -0.1304, -0.1305, -0.1306, -0.1307, -0.1308,
    -0.1309, -0.131, -0.1311, -0.1312, -0.1314, -0.1315, -0.1316,
    -0.1317, -0.1318, -0.1319, -0.132, -0.1321, -0.1322, -0.1323,
    -0.1324, -0.1325, -0.1326, -0.1327, -0.1328, -0.1329, -0.133,
    -0.1331, -0.1332, -0.1333, -0.1334, -0.1335, -0.1336, -0.1337,
    -0.1338, -0.1339, -0.134, -0.1341, -0.1342, -0.1343, -0.1344,
    -0.1345, -0.1346, -0.1347, -0.1348, -0.1349, -0.135, -0.1351,
    -0.1352, -0.1353, -0.1354, -0.1355, -0.1356, -0.1357, -0.1358,
    -0.1359, -0.136, -0.1361, -0.1362, -0.1363, -0.1364, -0.1365,
    -0.1366, -0.1367, -0.1368, -0.1369, -0.137, -0.1371, -0.1373,
    -0.1374, -0.1375, -0.1376, -0.1377, -0.1378, -0.1379, -0.138,
    -0.1381, -0.1382, -0.1383, -0.1384, -0.1385, -0.1386, -0.1387,
    -0.1388, -0.1389, -0.139, -0.1391, -0.1392, -0.1393, -0.1394,
    -0.1395, -0.1396, -0.1397, -0.1398, -0.1399, -0.14, -0.1401,
    -0.1402, -0.1403, -0.1404, -0.1404, -0.1405, -0.1406, -0.1407,
    -0.1408, -0.1409, -0.141, -0.1411, -0.1412, -0.1413, -0.1414,
    -0.1415, -0.1416, -0.1417, -0.1418, -0.1419, -0.142, -0.1421,
    -0.1422, -0.1423, -0.1424, -0.1425, -0.1426, -0.1427, -0.1428,
    -0.1429, -0.143, -0.1431, -0.1432, -0.1433, -0.1434, -0.1435,
    -0.1436, -0.1437, -0.1438, -0.1439, -0.144, -0.1441, -0.1442,
    -0.1443, -0.1444, -0.1445, -0.1446, -0.1447, -0.1448, -0.1449,
    -0.145, -0.1451, -0.1452, -0.1453, -0.1454, -0.1455, -0.1456,
    -0.1457, -0.1458, -0.1459, -0.146, -0.1461, -0.1462, -0.1462,
    -0.1463, -0.1464, -0.1465, -0.1466, -0.1467, -0.1468, -0.1469,
    -0.147, -0.1471, -0.1472, -0.1473, -0.1474, -0.1475, -0.1476,
    -0.1477, -0.1478, -0.1479, -0.148, -0.1481, -0.1482, -0.1483,
    -0.1484, -0.1485, -0.1486, -0.1487, -0.1488, -0.1489, -0.149,
    -0.1491, -0.1491, -0.1492, -0.1493, -0.1494, -0.1495, -0.1496,
    -0.1497, -0.1498, -0.1499, -0.15, -0.1501, -0.1502, -0.1503,
    -0.1504, -0.1505, -0.1506, -0.1507, -0.1508, -0.1509, -0.151,
    -0.1511, -0.1512, -0.1513, -0.1514, -0.1514, -0.1515, -0.1516,
    -0.1517, -0.1518, -0.1519, -0.152, -0.1521, -0.1522, -0.1523,
    -0.1524, -0.1525, -0.1526, -0.1527, -0.1528, -0.1529, -0.153,
    -0.1531, -0.1532, -0.1533, -0.1533, -0.1534, -0.2026, -0.213,
    -0.2234, -0.2338, -0.2443, -0.2548, -0.2653, -0.2758, -0.2864,
    -0.2969, -0.3075, -0.318, -0.3285, -0.339, -0.3494, -0.3598,
    -0.3701, -0.3804, -0.3906, -0.4007, -0.4107, -0.4207, -0.4305,
    -0.4402, -0.4499, -0.4594, -0.4688, -0.4781, -0.4873, -0.4964,
    -0.5053, -0.5142, -0.5229, -0.5315, -0.5399, -0.5482, -0.5564,
    -0.5644, -0.5722, -0.5799, -0.5873, -0.5946, -0.6017, -0.6085,
    -0.6152, -0.6216, -0.6278, -0.6337, -0.6393, -0.6446, -0.6496,
    -0.6543, -0.6585, -0.6624, -0.6659, -0.6689, -0.6714, -0.6735,
    -0.6752, -0.6764, -0.6764, 0.3809, 0.3259, 0.3101, 0.2986,
    0.2891, 0.281, 0.2737, 0.2671, 0.2609, 0.2551, 0.2497, 0.2446,
    0.2397, 0.2349, 0.2304, 0.226, 0.2218, 0.2177, 0.2137, 0.2099,
    0.2061, 0.2024, 0.1989, 0.1954, 0.1919, 0.1886, 0.1853, 0.1821,
    0.1789, 0.1758, 0.1727, 0.1697, 0.1668, 0.1638, 0.161, 0.1582,
    0.1554, 0.1526, 0.1499, 0.1473, 0.1446, 0.142, 0.1395, 0.1369,
    0.1344, 0.132, 0.1295, 0.1271, 0.1247, 0.1224, 0.12, 0.1177,
    0.1154, 0.1132, 0.1109, 0.1087, 0.1065, 0.1044, 0.1022, 0.1001,
    0.098, 0.0959, 0.0938, 0.0918, 0.0897, 0.0877, 0.0857, 0.0838,
    0.0818, 0.0798, 0.0779, 0.076, 0.0741, 0.0722, 0.0704, 0.0685,
    0.0667, 0.0648, 0.063, 0.0612, 0.0595, 0.0577, 0.0559, 0.0542,
    0.0525, 0.0508, 0.049, 0.0474, 0.0457, 0.044, 0.0424, 0.0407,
    0.0391, 0.0375, 0.0358, 0.0342, 0.0327, 0.0311, 0.0295, 0.0279,
    0.0264, 0.0249, 0.0233, 0.0218, 0.0203, 0.0188, 0.0173, 0.0158,
    0.0144, 0.0129, 0.0114, 0.01, 0.0086, 0.0071, 0.0057, 0.0043,
    0.0029, 0.0015, 1e-04, -0.0013, -0.0026, -0.004, -0.0053,
    -0.0067, -0.008, -0.0094, -0.0107, -0.012, -0.0133, -0.0146,
    -0.0159, -0.0172, -0.0185, -0.0198, -0.021, -0.0223, -0.0235,
    -0.0248, -0.026, -0.0273, -0.0285, -0.0297, -0.0309, -0.0321,
    -0.0333, -0.0345, -0.0357, -0.0369, -0.0381, -0.0393, -0.0404,
    -0.0416, -0.0428, -0.0439, -0.045, -0.0462, -0.0473, -0.0484,
    -0.0496, -0.0507, -0.0518, -0.0529, -0.054, -0.0551, -0.0562,
    -0.0573, -0.0583, -0.0594, -0.0605, -0.0615, -0.0626, -0.0637,
    -0.0647, -0.0658, -0.0668, -0.0678, -0.0689, -0.0699, -0.0709,
    -0.0719, -0.0729, -0.0739, -0.0749, -0.0759, -0.0769, -0.0779,
    -0.0789, -0.0799, -0.0808, -0.0818, -0.0828, -0.0837, -0.0847,
    -0.0857, -0.0866, -0.0875, -0.0885, -0.0894, -0.0904, -0.0913,
    -0.0922, -0.0931, -0.094, -0.095, -0.0959, -0.0968, -0.0977,
    -0.0986, -0.0995, -0.1003, -0.1012, -0.1021, -0.103, -0.1039,
    -0.1047, -0.1056, -0.1065, -0.1073, -0.1082, -0.109, -0.1099,
    -0.1107, -0.1116, -0.1124, -0.1132, -0.1141, -0.1149, -0.1157,
    -0.1165, -0.1173, -0.1181, -0.119, -0.1198, -0.1206, -0.1214,
    -0.1222, -0.1229, -0.1237, -0.1245, -0.1253, -0.1261, -0.1269,
    -0.1276, -0.1284, -0.1292, -0.1299, -0.1307, -0.1314, -0.1322,
    -0.1329, -0.1337, -0.1344, -0.1352, -0.1359, -0.1367, -0.1374,
    -0.1381, -0.1388, -0.1396, -0.1403, -0.141, -0.1417, -0.1424,
    -0.1431, -0.1438, -0.1445, -0.1452, -0.1459, -0.1466, -0.1473,
    -0.148, -0.1487, -0.1494, -0.1501, -0.1507, -0.1514, -0.1521,
    -0.1528, -0.1534, -0.1541, -0.1547, -0.1554, -0.1561, -0.1567,
    -0.1574, -0.158, -0.1587, -0.1593, -0.1599, -0.1606, -0.1612,
    -0.1618, -0.1625, -0.1631, -0.1637, -0.1643, -0.165, -0.1656,
    -0.1662, -0.1668, -0.1674, -0.168, -0.1686, -0.1692, -0.1698,
    -0.1704, -0.171, -0.1716, -0.1722, -0.1728, -0.1734, -0.174,
    -0.1745, -0.1751, -0.1757, -0.1763, -0.1768, -0.1774, -0.178,
    -0.1785, -0.1791, -0.1797, -0.1802, -0.1808, -0.1813, -0.1819,
    -0.1824, -0.183, -0.1835, -0.1841, -0.1846, -0.1851, -0.1857,
    -0.1862, -0.1867, -0.1873, -0.1878, -0.1883, -0.1889, -0.1894,
    -0.1899, -0.1904, -0.1909, -0.1914, -0.192, -0.1925, -0.193,
    -0.1935, -0.194, -0.1945, -0.195, -0.1955, -0.196, -0.1965,
    -0.197, -0.1974, -0.1979, -0.1984, -0.1989, -0.1994, -0.1999,
    -0.2003, -0.2008, -0.2013, -0.2018, -0.2022, -0.2027, -0.2032,
    -0.2036, -0.2041, -0.2046, -0.205, -0.2055, -0.2059, -0.2064,
    -0.2068, -0.2073, -0.2077, -0.2082, -0.2086, -0.2091, -0.2095,
    -0.21, -0.2104, -0.2108, -0.2113, -0.2117, -0.2121, -0.2126,
    -0.213, -0.2134, -0.2139, -0.2143, -0.2147, -0.2151, -0.2155,
    -0.216, -0.2164, -0.2168, -0.2172, -0.2176, -0.218, -0.2184,
    -0.2188, -0.2192, -0.2196, -0.22, -0.2204, -0.2208, -0.2212,
    -0.2216, -0.222, -0.2224, -0.2228, -0.2232, -0.2236, -0.224,
    -0.2243, -0.2247, -0.2251, -0.2255, -0.2259, -0.2262, -0.2266,
    -0.227, -0.2274, -0.2277, -0.2281, -0.2285, -0.2288, -0.2292,
    -0.2296, -0.2299, -0.2303, -0.2307, -0.231, -0.2314, -0.2317,
    -0.2321, -0.2324, -0.2328, -0.2331, -0.2335, -0.2338, -0.2342,
    -0.2345, -0.2349, -0.2352, -0.2355, -0.2359, -0.2362, -0.2366,
    -0.2369, -0.2372, -0.2376, -0.2379, -0.2382, -0.2385, -0.2389,
    -0.2392, -0.2395, -0.2398, -0.2402, -0.2405, -0.2408, -0.2411,
    -0.2414, -0.2418, -0.2421, -0.2424, -0.2427, -0.243, -0.2433,
    -0.2436, -0.2439, -0.2442, -0.2446, -0.2449, -0.2452, -0.2455,
    -0.2458, -0.2461, -0.2464, -0.2467, -0.247, -0.2472, -0.2475,
    -0.2478, -0.2481, -0.2484, -0.2487, -0.249, -0.2493, -0.2496,
    -0.2499, -0.2501, -0.2504, -0.2507, -0.251, -0.2513, -0.2515,
    -0.2518, -0.2521, -0.2524, -0.2526, -0.2529, -0.2532, -0.2535,
    -0.2537, -0.254, -0.2543, -0.2545, -0.2548, -0.2551, -0.2553,
    -0.2556, -0.2558, -0.2561, -0.2564, -0.2566, -0.2569, -0.2571,
    -0.2574, -0.2577, -0.2579, -0.2582, -0.2584, -0.2587, -0.2589,
    -0.2592, -0.2594, -0.2597, -0.2599, -0.2601, -0.2604, -0.2606,
    -0.2609, -0.2611, -0.2614, -0.2616, -0.2618, -0.2621, -0.2623,
    -0.2625, -0.2628, -0.263, -0.2632, -0.2635, -0.2637, -0.2639,
    -0.2642, -0.2644, -0.2646, -0.2649, -0.2651, -0.2653, -0.2655,
    -0.2658, -0.266, -0.2662, -0.2664, -0.2666, -0.2669, -0.2671,
    -0.2673, -0.2675, -0.2677, -0.2679, -0.2682, -0.2684, -0.2686,
    -0.2688, -0.269, -0.2692, -0.2694, -0.2696, -0.2698, -0.27,
    -0.2702, -0.2705, -0.2707, -0.2709, -0.2711, -0.2713, -0.2715,
    -0.2717, -0.2719, -0.2721, -0.2723, -0.2725, -0.2727, -0.2729,
    -0.273, -0.2732, -0.2734, -0.2736, -0.2738, -0.274, -0.2742,
    -0.2744, -0.2746, -0.2748, -0.275, -0.2751, -0.2753, -0.2755,
    -0.2757, -0.2759, -0.2761, -0.2763, -0.2764, -0.2766, -0.2768,
    -0.277, -0.2772, -0.2773, -0.2775, -0.2777, -0.2779, -0.278,
    -0.2782, -0.2784, -0.2786, -0.2787, -0.2789, -0.2791, -0.2793,
    -0.2794, -0.2796, -0.2798, -0.2799, -0.2801, -0.2803, -0.2804,
    -0.2806, -0.2808, -0.2809, -0.2811, -0.2813, -0.2814, -0.2816,
    -0.2818, -0.2819, -0.2821, -0.2822, -0.2824, -0.2826, -0.2827,
    -0.2829, -0.283, -0.2832, -0.2834, -0.2835, -0.2837, -0.2838,
    -0.284, -0.2841, -0.2843, -0.2844, -0.2846, -0.2847, -0.2849,
    -0.285, -0.2852, -0.2853, -0.2855, -0.2856, -0.2858, -0.2859,
    -0.2861, -0.2862, -0.2864, -0.2865, -0.2866, -0.2868, -0.2869,
    -0.2871, -0.2872, -0.2874, -0.2875, -0.2876, -0.2878, -0.2879,
    -0.2881, -0.2882, -0.2883, -0.2885, -0.2886, -0.2887, -0.2889,
    -0.289, -0.2891, -0.2893, -0.2894, -0.2895, -0.2897, -0.2898,
    -0.2899, -0.2901, -0.2902, -0.2903, -0.2905, -0.2906, -0.2907,
    -0.2909, -0.291, -0.2911, -0.2912, -0.2914, -0.2915, -0.2916,
    -0.2917, -0.2919, -0.292, -0.2921, -0.2922, -0.2924, -0.2925,
    -0.2926, -0.2927, -0.2928, -0.293, -0.2931, -0.2932, -0.2933,
    -0.2934, -0.2936, -0.2937, -0.2938, -0.2939, -0.294, -0.2942,
    -0.2943, -0.2944, -0.2945, -0.2946, -0.2947, -0.2948, -0.295,
    -0.2951, -0.2952, -0.2953, -0.2954, -0.2955, -0.2956, -0.2957,
    -0.2959, -0.296, -0.2961, -0.2962, -0.2963, -0.2964, -0.2965,
    -0.2966, -0.2967, -0.2968, -0.2969, -0.297, -0.2972, -0.2973,
    -0.2974, -0.2975, -0.2976, -0.2977, -0.2978, -0.2979, -0.298,
    -0.2981, -0.2982, -0.2983, -0.2984, -0.2985, -0.2986, -0.2987,
    -0.2988, -0.2989, -0.299, -0.2991, -0.2992, -0.2993, -0.2994,
    -0.2995, -0.2996, -0.2997, -0.2998, -0.2999, -0.3, -0.3001,
    -0.3002, -0.3003, -0.3004, -0.3005, -0.3006, -0.3007, -0.3007,
    -0.3008, -0.3009, -0.301, -0.3011, -0.3012, -0.3013, -0.3014,
    -0.3015, -0.3016, -0.3017, -0.3018, -0.3019, -0.3019, -0.302,
    -0.3021, -0.3022, -0.3023, -0.3024, -0.3025, -0.3026, -0.3027,
    -0.3027, -0.3028, -0.3029, -0.303, -0.3031, -0.3032, -0.3033,
    -0.3033, -0.3034, -0.3035, -0.3036, -0.3037, -0.3038, -0.3039,
    -0.3039, -0.304, -0.3041, -0.3042, -0.3043, -0.3044, -0.3044,
    -0.3045, -0.3046, -0.3047, -0.3048, -0.3048, -0.3049, -0.305,
    -0.3051, -0.3052, -0.3052, -0.3053, -0.3054, -0.3055, -0.3056,
    -0.3056, -0.3057, -0.3058, -0.3059, -0.3059, -0.306, -0.3061,
    -0.3062, -0.3063, -0.3063, -0.3064, -0.3065, -0.3066, -0.3066,
    -0.3067, -0.3068, -0.3069, -0.3069, -0.307, -0.3071, -0.3072,
    -0.3072, -0.3073, -0.3074, -0.3074, -0.3075, -0.3076, -0.3077,
    -0.3077, -0.3078, -0.3079, -0.308, -0.308, -0.3081, -0.3082,
    -0.3082, -0.3083, -0.3084, -0.3085, -0.3085, -0.3086, -0.3087,
    -0.3087, -0.3088, -0.3089, -0.3089, -0.309, -0.3091, -0.3091,
    -0.3092, -0.3093, -0.3093, -0.3094, -0.3095, -0.3095, -0.3096,
    -0.3097, -0.3097, -0.3098, -0.3099, -0.3099, -0.31, -0.3101,
    -0.3101, -0.3102, -0.3103, -0.3103, -0.3104, -0.3105, -0.3105,
    -0.3106, -0.3107, -0.3107, -0.3108, -0.3109, -0.3109, -0.311,
    -0.311, -0.3111, -0.3112, -0.3112, -0.3113, -0.3114, -0.3114,
    -0.3115, -0.3116, -0.3116, -0.3117, -0.3117, -0.3118, -0.3119,
    -0.3119, -0.312, -0.312, -0.3121, -0.3122, -0.3122, -0.3123,
    -0.3123, -0.3124, -0.3125, -0.3125, -0.3126, -0.3126, -0.3127,
    -0.3128, -0.3128, -0.3129, -0.3129, -0.313, -0.3131, -0.3131,
    -0.3132, -0.3132, -0.3133, -0.3134, -0.3134, -0.3135, -0.3135,
    -0.3136, -0.3136, -0.3137, -0.3138, -0.3138, -0.3139, -0.3139,
    -0.314, -0.314, -0.3141, -0.3142, -0.3142, -0.3143, -0.3143,
    -0.3144, -0.3144, -0.3145, -0.3145, -0.3146, -0.3147, -0.3147,
    -0.3148, -0.3148, -0.3149, -0.3149, -0.315, -0.315, -0.3151,
    -0.3152, -0.3152, -0.3153, -0.3153, -0.3154, -0.3154, -0.3155,
    -0.3155, -0.3156, -0.3156, -0.3157, -0.3158, -0.3158, -0.3159,
    -0.3159, -0.316, -0.316, -0.3161, -0.3161, -0.3162, -0.3162,
    -0.3163, -0.3163, -0.3164, -0.3164, -0.3165, -0.3165, -0.3166,
    -0.3167, -0.3167, -0.3168, -0.3168, -0.3169, -0.3169, -0.317,
    -0.317, -0.3171, -0.3171, -0.3172, -0.3172, -0.3173, -0.3173,
    -0.3174, -0.3174, -0.3175, -0.3175, -0.3176, -0.3176, -0.3177,
    -0.3177, -0.3178, -0.3178, -0.3179, -0.3179, -0.318, -0.318,
    -0.3181, -0.3181, -0.3182, -0.3182, -0.3183, -0.3183, -0.3184,
    -0.3184, -0.3185, -0.3185, -0.3186, -0.3186, -0.3187, -0.3187,
    -0.3188, -0.3188, -0.3189, -0.3189, -0.319, -0.319, -0.3191,
    -0.3191, -0.3192, -0.3192, -0.3193, -0.3193, -0.3194, -0.3194,
    -0.3195, -0.3195, -0.3196, -0.3196, -0.3197, -0.3197, -0.3198,
    -0.3198, -0.3198, -0.3199, -0.3199, -0.32, -0.32, -0.3201,
    -0.3201, -0.3202, -0.3202, -0.3203, -0.3203, -0.3204, -0.3204,
    -0.3205, -0.3205, -0.3206, -0.3206, -0.3207, -0.3207, -0.3208,
    -0.3208, -0.3208, -0.3209, -0.3209, -0.321, -0.321, -0.3211,
    -0.3211, -0.3212, -0.3212, -0.3213, -0.3213, -0.3214, -0.3214,
    -0.3215, -0.3215, -0.3216, -0.3216, -0.3216, -0.3217, -0.3217,
    -0.3218, -0.3218, -0.3219, -0.3219, -0.322, -0.322, -0.3221,
    -0.3221, -0.3222, -0.3222, -0.3222, -0.3223, -0.3223, -0.3224,
    -0.3224, -0.3225, -0.3225, -0.3226, -0.3226, -0.3227, -0.3227,
    -0.3227, -0.3228, -0.3228, -0.3229, -0.3229, -0.323, -0.323,
    -0.3231, -0.3231, -0.3232, -0.3232, -0.3232, -0.3233, -0.3233,
    -0.3234, -0.3234, -0.3235, -0.3235, -0.3236, -0.3236, -0.3237,
    -0.3237, -0.3237, -0.3238, -0.3238, -0.3239, -0.3239, -0.324,
    -0.324, -0.3241, -0.3241, -0.3241, -0.3242, -0.3242, -0.3243,
    -0.3243, -0.3244, -0.3244, -0.3245, -0.3245, -0.3245, -0.3246,
    -0.3246, -0.3247, -0.3247, -0.3248, -0.3248, -0.3249, -0.3249,
    -0.3249, -0.325, -0.325, -0.3251, -0.3251, -0.3252, -0.3252,
    -0.3253, -0.3253, -0.3253, -0.3254, -0.3254, -0.3255, -0.3255,
    -0.3256, -0.3256, -0.3257, -0.3257, -0.3257, -0.3258, -0.3258,
    -0.3259, -0.3259, -0.326, -0.326, -0.3261, -0.3261, -0.3261,
    -0.3262, -0.3262, -0.3263, -0.3263, -0.3264, -0.3264, -0.3264,
    -0.3265, -0.3265, -0.3266, -0.3266, -0.3267, -0.3267, -0.3268,
    -0.3268, -0.3268, -0.3269, -0.3269, -0.327, -0.327, -0.3271,
    -0.3271, -0.3271, -0.3272, -0.3272, -0.3273, -0.3273, -0.3274,
    -0.3274, -0.3274, -0.3275, -0.3275, -0.3276, -0.3276, -0.3277,
    -0.3277, -0.3278, -0.3278, -0.3278, -0.3279, -0.3279, -0.328,
    -0.328, -0.3281, -0.3281, -0.3281, -0.3282, -0.3282, -0.3283,
    -0.3283, -0.3284, -0.3284, -0.3284, -0.3285, -0.3285, -0.3286,
    -0.3286, -0.3287, -0.3287, -0.3287, -0.3288, -0.3288, -0.3289,
    -0.3289, -0.329, -0.329, -0.329, -0.3291, -0.3291, -0.3292,
    -0.3292, -0.3293, -0.3293, -0.3293, -0.3294, -0.3294, -0.3295,
    -0.3295, -0.3296, -0.3296, -0.3296, -0.3297, -0.3297, -0.3298,
    -0.3298, -0.3299, -0.3299, -0.3299, -0.33, -0.33, -0.3301,
    -0.3301, -0.3302, -0.3302, -0.3302, -0.3303, -0.3303, -0.3304,
    -0.3304, -0.3305, -0.3305, -0.3305, -0.3306, -0.3306, -0.3307,
    -0.3307, -0.3308, -0.3308, -0.3308, -0.3309, -0.3309, -0.331,
    -0.331, -0.3311, -0.3311, -0.3311, -0.3312, -0.3312, -0.3313,
    -0.3313, -0.3314, -0.3314, -0.3314, -0.3315, -0.3315, -0.3316,
    -0.3316, -0.3317, -0.3317, -0.3317, -0.3318, -0.3318, -0.3319,
    -0.3319, -0.332, -0.332, -0.332, -0.3321, -0.3321, -0.3322,
    -0.3322, -0.3322, -0.3323, -0.3323, -0.3324, -0.3324, -0.3325,
    -0.3325, -0.3325, -0.3326, -0.3326, -0.3327, -0.3327, -0.3328,
    -0.3328, -0.3328, -0.3329, -0.3329, -0.333, -0.333, -0.3331,
    -0.3331, -0.3331, -0.3332, -0.3332, -0.3333, -0.3333, -0.3334,
    -0.3334, -0.3334, -0.3335, -0.3335, -0.3336, -0.3336, -0.3337,
    -0.3337, -0.3337, -0.3338, -0.3338, -0.3339, -0.3339, -0.3339,
    -0.334, -0.334, -0.3341, -0.3341, -0.3342, -0.3342, -0.3342,
    -0.3343, -0.3343, -0.3344, -0.3344, -0.3345, -0.3345, -0.3345,
    -0.3346, -0.3346, -0.3347, -0.3347, -0.3348, -0.3348, -0.3348,
    -0.3349, -0.3349, -0.335, -0.335, -0.3351, -0.3351, -0.3351,
    -0.3352, -0.3352, -0.3353, -0.3353, -0.3354, -0.3354, -0.3354,
    -0.3355, -0.3355, -0.3356, -0.3356, -0.3357, -0.3357, -0.3357,
    -0.3358, -0.3358, -0.3359, -0.3359, -0.3359, -0.336, -0.336,
    -0.3361, -0.3361, -0.3362, -0.3362, -0.3362, -0.3363, -0.3363,
    -0.3364, -0.3364, -0.3365, -0.3365, -0.3365, -0.3366, -0.3366,
    -0.3367, -0.3367, -0.3368, -0.3368, -0.3368, -0.3369, -0.3369,
    -0.337, -0.337, -0.3371, -0.3371, -0.3371, -0.3372, -0.3372,
    -0.3373, -0.3373, -0.3374, -0.3374, -0.3374, -0.3375, -0.3375,
    -0.3376, -0.3376, -0.3377, -0.3377, -0.3377, -0.3378, -0.3378,
    -0.3379, -0.3379, -0.338, -0.338, -0.338, -0.3381, -0.3381,
    -0.3382, -0.3382, -0.3383, -0.3383, -0.3383, -0.3384, -0.3384,
    -0.3385, -0.3385, -0.3386, -0.3386, -0.3386, -0.3387, -0.3387,
    -0.3388, -0.3388, -0.3389, -0.3389, -0.3389, -0.339, -0.339,
    -0.3391, -0.3391, -0.3392, -0.3392, -0.3392, -0.3393, -0.3393,
    -0.3394, -0.3394, -0.3395, -0.3395, -0.3396, -0.3396, -0.3396,
    -0.3397, -0.3397, -0.3398, -0.3398, -0.3399, -0.3399, -0.3399,
    -0.34, -0.34, -0.3401, -0.3401, -0.3402, -0.3402, -0.3402,
    -0.3403, -0.3403, -0.3404, -0.3404, -0.3405, -0.3405, -0.3405,
    -0.3406, -0.3406, -0.3407, -0.3407, -0.3408, -0.3408, -0.3408,
    -0.3409, -0.3409, -0.341, -0.341, -0.3411, -0.3411, -0.3412,
    -0.3412, -0.3412, -0.3413, -0.3413, -0.3414, -0.3414, -0.3415,
    -0.3415, -0.3415, -0.3416, -0.3416, -0.3417, -0.3417, -0.3418,
    -0.3418, -0.3418, -0.3419, -0.3419, -0.342, -0.342, -0.3421,
    -0.3421, -0.3421, -0.3422, -0.3422, -0.3423, -0.3423, -0.3424,
    -0.3424, -0.3425, -0.3425, -0.3425, -0.3426, -0.3426, -0.3427,
    -0.3427, -0.3428, -0.3428, -0.3428, -0.3429, -0.3429, -0.343,
    -0.343, -0.3431, -0.3431, -0.3431, -0.3432, -0.3432, -0.3433,
    -0.3433, -0.3434, -0.3434, -0.3434, -0.3435, -0.3435, -0.3436,
    -0.3436, -0.3437, -0.3437, -0.3438, -0.3438, -0.3438, -0.3439,
    -0.3439, -0.344, -0.344, -0.3441, -0.3441, -0.3441, -0.3442,
    -0.3442, -0.3443, -0.3443, -0.3444, -0.3444, -0.3444, -0.3445,
    -0.3445, -0.3446, -0.3446, -0.3447, -0.3447, -0.3448, -0.3448,
    -0.3448, -0.3449, -0.3449, -0.345, -0.345, -0.3451, -0.3451,
    -0.3451, -0.3452, -0.3452, -0.3453, -0.3453, -0.3454, -0.3454,
    -0.3454, -0.3455, -0.3455, -0.3456, -0.3456, -0.3457, -0.3457,
    -0.3457, -0.3458, -0.3458, -0.3459, -0.3459, -0.346, -0.346,
    -0.346, -0.3461, -0.3461, -0.3462, -0.3462, -0.3463, -0.3463,
    -0.3463, -0.3464, -0.3464, -0.3465, -0.3465, -0.3466, -0.3466,
    -0.3467, -0.3467, -0.3467, -0.3468, -0.3468, -0.3469, -0.3469,
    -0.347, -0.347, -0.347, -0.3471, -0.3471, -0.3472, -0.3472,
    -0.3473, -0.3473, -0.3473, -0.3474, -0.3474, -0.3475, -0.3475,
    -0.3476, -0.3476, -0.3476, -0.3477, -0.3477, -0.3478, -0.3478,
    -0.3479, -0.3479, -0.3479, -0.348, -0.348, -0.3481, -0.3481,
    -0.3482, -0.3482, -0.3482, -0.3483, -0.3483, -0.3484, -0.3484,
    -0.3485, -0.3485, -0.3485, -0.3486, -0.3486, -0.3487, -0.3487,
    -0.3488, -0.3488, -0.3488, -0.3489, -0.3489, -0.349, -0.349,
    -0.3491, -0.3491, -0.3491, -0.3492, -0.3492, -0.3493, -0.3493,
    -0.3493, -0.3494, -0.3494, -0.3495, -0.3495, -0.3496, -0.3496,
    -0.3496, -0.3497, -0.3497, -0.3498, -0.3498, -0.3499, -0.3499,
    -0.3499, -0.35, -0.35, -0.3501, -0.3501, -0.3502, -0.3502,
    -0.3502, -0.3503, -0.3503, -0.3504, -0.3504, -0.3505, -0.3505,
    -0.3505, -0.3506, -0.3506, -0.3507, -0.3507, -0.3507, -0.3508,
    -0.3508, -0.3509, -0.3509, -0.351, -0.351, -0.351, -0.3511,
    -0.3511, -0.3512, -0.3512, -0.3513, -0.3513, -0.3513, -0.3514,
    -0.3514, -0.3515, -0.3515, -0.3515, -0.3516, -0.3516, -0.3517,
    -0.3517, -0.3518, -0.3518, -0.3518, -0.3519, -0.3519, -0.352,
    -0.352, -0.352, -0.3521, -0.3521, -0.3522, -0.3522, -0.3523,
    -0.3523, -0.3523, -0.3524, -0.3524, -0.3525, -0.3525, -0.3526,
    -0.3526, -0.3526, -0.3527, -0.3527, -0.3528, -0.3528, -0.3528,
    -0.3529, -0.3529, -0.353, -0.353, -0.3531, -0.4681, -0.4711,
    -0.4742, -0.4773, -0.4803, -0.4834, -0.4864, -0.4894, -0.4924,
    -0.4954, -0.4984, -0.5013, -0.5043, -0.5072, -0.51, -0.5129,
    -0.5157, -0.5185, -0.5213, -0.524, -0.5268, -0.5294, -0.5321,
    -0.5347, -0.5372, -0.5398, -0.5423, -0.5447, -0.5471, -0.5495,
    -0.5518, -0.5541, -0.5563, -0.5585, -0.5606, -0.5627, -0.5647,
    -0.5667, -0.5686, -0.5704, -0.5722, -0.574, -0.5757, -0.5773,
    -0.5789, -0.5804, -0.5819, -0.5833, -0.5847, -0.5859, -0.5872,
    -0.5883, -0.5895, -0.5905, -0.5915, -0.5925, -0.5934, -0.5942,
    -0.595, -0.5958, -0.5958, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521, -0.3521,
    -0.3521, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833,
    -0.3833, -0.3833, -0.3833, -0.3833, -0.3833, -0.3833), m = c(13.4069,
    13.3976, 13.3883, 13.3791, 13.3698, 13.3606, 13.3513, 13.3421,
    13.3843, 13.4265, 13.4687, 13.511, 13.5532, 13.5954, 13.6377,
    13.7174, 13.8006, 13.8854, 13.9707, 14.0558, 14.1404, 14.2241,
    14.3065, 14.3877, 14.4675, 14.5457, 14.6225, 14.6977, 14.7714,
    14.8436, 14.914, 14.9822, 15.0485, 15.1127, 15.175, 15.2355,
    15.2942, 15.3511, 15.4062, 15.4597, 15.5115, 15.5618, 15.6107,
    15.6582, 15.7043, 15.7492, 15.7929, 15.8353, 15.8767, 15.9169,
    15.956, 15.9941, 16.0311, 16.0672, 16.1023, 16.1365, 16.1698,
    16.2021, 16.2336, 16.2642, 16.2941, 16.3231, 16.3513, 16.3787,
    16.4053, 16.4312, 16.4562, 16.4806, 16.5042, 16.5271, 16.5494,
    16.571, 16.592, 16.6124, 16.6321, 16.6514, 16.67, 16.6882,
    16.7058, 16.7229, 16.7396, 16.7557, 16.7715, 16.7867, 16.8016,
    16.8161, 16.8301, 16.8438, 16.8571, 16.8701, 16.8827, 16.895,
    16.9069, 16.9186, 16.9299, 16.941, 16.9518, 16.9623, 16.9725,
    16.9825, 16.9923, 17.0018, 17.0111, 17.0201, 17.029, 17.0376,
    17.0461, 17.0544, 17.0624, 17.0704, 17.0781, 17.0857, 17.0931,
    17.1003, 17.1074, 17.1144, 17.1212, 17.1279, 17.1344, 17.1409,
    17.1472, 17.1533, 17.1594, 17.1653, 17.1712, 17.1769, 17.1825,
    17.188, 17.1934, 17.1987, 17.2038, 17.2089, 17.2138, 17.2187,
    17.2234, 17.2281, 17.2326, 17.237, 17.2414, 17.2456, 17.2497,
    17.2537, 17.2576, 17.2615, 17.2652, 17.2688, 17.2723, 17.2757,
    17.2791, 17.2823, 17.2854, 17.2885, 17.2914, 17.2943, 17.297,
    17.2997, 17.3023, 17.3048, 17.3072, 17.3095, 17.3117, 17.3139,
    17.316, 17.318, 17.3199, 17.3218, 17.3235, 17.3252, 17.3268,
    17.3284, 17.3299, 17.3313, 17.3326, 17.3338, 17.335, 17.3361,
    17.3371, 17.3381, 17.339, 17.3398, 17.3406, 17.3412, 17.3419,
    17.3424, 17.3429, 17.3433, 17.3437, 17.3439, 17.3441, 17.3443,
    17.3444, 17.3444, 17.3443, 17.3442, 17.344, 17.3438, 17.3434,
    17.3431, 17.3426, 17.3421, 17.3416, 17.3409, 17.3402, 17.3395,
    17.3387, 17.3378, 17.3369, 17.3359, 17.3349, 17.3338, 17.3326,
    17.3314, 17.3302, 17.3289, 17.3275, 17.3261, 17.3246, 17.323,
    17.3215, 17.3198, 17.3181, 17.3164, 17.3146, 17.3127, 17.3108,
    17.3089, 17.3069, 17.3048, 17.3027, 17.3006, 17.2984, 17.2962,
    17.2939, 17.2916, 17.2892, 17.2868, 17.2844, 17.2819, 17.2794,
    17.2768, 17.2742, 17.2715, 17.2688, 17.2661, 17.2633, 17.2605,
    17.2577, 17.2548, 17.2519, 17.249, 17.246, 17.243, 17.2399,
    17.2368, 17.2337, 17.2306, 17.2274, 17.2242, 17.221, 17.2177,
    17.2144, 17.2111, 17.2078, 17.2044, 17.2011, 17.1976, 17.1942,
    17.1908, 17.1873, 17.1838, 17.1803, 17.1767, 17.1731, 17.1696,
    17.1659, 17.1623, 17.1587, 17.155, 17.1513, 17.1476, 17.1439,
    17.1402, 17.1364, 17.1326, 17.1288, 17.125, 17.1212, 17.1174,
    17.1135, 17.1097, 17.1058, 17.1019, 17.098, 17.0941, 17.0901,
    17.0862, 17.0823, 17.0783, 17.0743, 17.0703, 17.0663, 17.0623,
    17.0583, 17.0543, 17.0503, 17.0463, 17.0422, 17.0382, 17.0341,
    17.0301, 17.026, 17.0219, 17.0178, 17.0138, 17.0097, 17.0056,
    17.0015, 16.9974, 16.9933, 16.9892, 16.985, 16.9809, 16.9768,
    16.9727, 16.9686, 16.9644, 16.9603, 16.9562, 16.9521, 16.9479,
    16.9438, 16.9397, 16.9355, 16.9314, 16.9273, 16.9231, 16.919,
    16.9148, 16.9107, 16.9066, 16.9024, 16.8983, 16.8942, 16.89,
    16.8859, 16.8817, 16.8776, 16.8735, 16.8693, 16.8652, 16.861,
    16.8569, 16.8528, 16.8486, 16.8445, 16.8404, 16.8363, 16.8321,
    16.828, 16.8239, 16.8198, 16.8156, 16.8115, 16.8074, 16.8033,
    16.7992, 16.7951, 16.7909, 16.7868, 16.7827, 16.7786, 16.7745,
    16.7704, 16.7663, 16.7622, 16.7582, 16.7541, 16.75, 16.7459,
    16.7418, 16.7377, 16.7337, 16.7296, 16.7255, 16.7215, 16.7174,
    16.7134, 16.7093, 16.7053, 16.7012, 16.6972, 16.6932, 16.6891,
    16.6851, 16.6811, 16.6771, 16.6731, 16.6691, 16.6651, 16.6611,
    16.6571, 16.6531, 16.6491, 16.6451, 16.6412, 16.6372, 16.6332,
    16.6293, 16.6253, 16.6214, 16.6175, 16.6135, 16.6096, 16.6057,
    16.6018, 16.5979, 16.594, 16.5901, 16.5862, 16.5823, 16.5784,
    16.5745, 16.5707, 16.5668, 16.5629, 16.5591, 16.5553, 16.5514,
    16.5476, 16.5438, 16.5399, 16.5361, 16.5323, 16.5285, 16.5247,
    16.5209, 16.5172, 16.5134, 16.5096, 16.5059, 16.5021, 16.4984,
    16.4946, 16.4909, 16.4871, 16.4834, 16.4797, 16.476, 16.4723,
    16.4686, 16.4649, 16.4612, 16.4576, 16.4539, 16.4502, 16.4466,
    16.4429, 16.4393, 16.4357, 16.432, 16.4284, 16.4248, 16.4212,
    16.4176, 16.414, 16.4104, 16.4069, 16.4033, 16.3997, 16.3962,
    16.3926, 16.3891, 16.3856, 16.3821, 16.3785, 16.375, 16.3715,
    16.368, 16.3646, 16.3611, 16.3576, 16.3541, 16.3507, 16.3472,
    16.3438, 16.3404, 16.3369, 16.3335, 16.3301, 16.3267, 16.3233,
    16.3199, 16.3165, 16.3131, 16.3098, 16.3064, 16.3031, 16.2997,
    16.2964, 16.293, 16.2897, 16.2864, 16.2831, 16.2798, 16.2765,
    16.2732, 16.2699, 16.2666, 16.2634, 16.2601, 16.2568, 16.2536,
    16.2504, 16.2471, 16.2439, 16.2407, 16.2375, 16.2343, 16.2311,
    16.2279, 16.2247, 16.2215, 16.2184, 16.2152, 16.2121, 16.2089,
    16.2058, 16.2027, 16.1996, 16.1964, 16.1933, 16.1902, 16.1872,
    16.1841, 16.181, 16.1779, 16.1749, 16.1718, 16.1688, 16.1658,
    16.1627, 16.1597, 16.1567, 16.1537, 16.1507, 16.1477, 16.1447,
    16.1418, 16.1388, 16.1359, 16.1329, 16.13, 16.127, 16.1241,
    16.1212, 16.1183, 16.1154, 16.1125, 16.1096, 16.1067, 16.1039,
    16.101, 16.0981, 16.0953, 16.0925, 16.0896, 16.0868, 16.084,
    16.0812, 16.0784, 16.0756, 16.0728, 16.0701, 16.0673, 16.0646,
    16.0618, 16.0591, 16.0564, 16.0536, 16.0509, 16.0482, 16.0455,
    16.0429, 16.0402, 16.0375, 16.0349, 16.0322, 16.0296, 16.0269,
    16.0243, 16.0217, 16.0191, 16.0165, 16.0139, 16.0113, 16.0088,
    16.0062, 16.0036, 16.0011, 15.9986, 15.996, 15.9935, 15.991,
    15.9885, 15.986, 15.9835, 15.9811, 15.9786, 15.9761, 15.9737,
    15.9713, 15.9688, 15.9664, 15.964, 15.9616, 15.9592, 15.9568,
    15.9544, 15.9521, 15.9497, 15.9473, 15.945, 15.9427, 15.9403,
    15.938, 15.9357, 15.9334, 15.9311, 15.9288, 15.9266, 15.9243,
    15.922, 15.9198, 15.9176, 15.9153, 15.9131, 15.9109, 15.9087,
    15.9065, 15.9043, 15.9021, 15.9, 15.8978, 15.8956, 15.8935,
    15.8913, 15.8892, 15.8871, 15.885, 15.8829, 15.8808, 15.8787,
    15.8766, 15.8745, 15.8725, 15.8704, 15.8684, 15.8663, 15.8643,
    15.8623, 15.8602, 15.8582, 15.8562, 15.8542, 15.8522, 15.8503,
    15.8483, 15.8463, 15.8444, 15.8424, 15.8405, 15.8385, 15.8366,
    15.8347, 15.8328, 15.8309, 15.829, 15.8271, 15.8252, 15.8233,
    15.8214, 15.8196, 15.8177, 15.8158, 15.814, 15.8122, 15.8103,
    15.8085, 15.8067, 15.8049, 15.8031, 15.8013, 15.7995, 15.7977,
    15.7959, 15.7941, 15.7924, 15.7906, 15.7888, 15.7871, 15.7853,
    15.7836, 15.7819, 15.7802, 15.7784, 15.7767, 15.775, 15.7733,
    15.7716, 15.7699, 15.7682, 15.7665, 15.7649, 15.7632, 15.7615,
    15.7599, 15.7582, 15.7566, 15.7549, 15.7533, 15.7517, 15.75,
    15.7484, 15.7468, 15.7452, 15.7436, 15.742, 15.7404, 15.7388,
    15.7372, 15.7356, 16.0189, 16.0176, 16.0163, 16.015, 16.0136,
    16.0123, 16.011, 16.0097, 16.0084, 16.0071, 16.0058, 16.0045,
    16.0032, 16.0019, 16.0006, 15.9993, 15.998, 15.9967, 15.9954,
    15.9941, 15.9928, 15.9915, 15.9902, 15.9889, 15.9876, 15.9863,
    15.985, 15.9838, 15.9825, 15.9812, 15.9799, 15.9786, 15.9773,
    15.976, 15.9748, 15.9735, 15.9722, 15.9709, 15.9697, 15.9684,
    15.9671, 15.9658, 15.9646, 15.9633, 15.962, 15.9607, 15.9595,
    15.9582, 15.9569, 15.9557, 15.9544, 15.9532, 15.9519, 15.9506,
    15.9494, 15.9481, 15.9468, 15.9456, 15.9443, 15.9431, 15.9418,
    15.9406, 15.9393, 15.9381, 15.9368, 15.9356, 15.9343, 15.9331,
    15.9318, 15.9306, 15.9293, 15.9281, 15.9268, 15.9256, 15.9244,
    15.9231, 15.9219, 15.9206, 15.9194, 15.9182, 15.9169, 15.9157,
    15.9145, 15.9132, 15.912, 15.9108, 15.9095, 15.9083, 15.9071,
    15.9058, 15.9046, 15.9034, 15.9022, 15.9009, 15.8997, 15.8985,
    15.8973, 15.8961, 15.8948, 15.8936, 15.8924, 15.8912, 15.89,
    15.8888, 15.8875, 15.8863, 15.8851, 15.8839, 15.8827, 15.8815,
    15.8803, 15.8791, 15.8779, 15.8767, 15.8755, 15.8742, 15.873,
    15.8718, 15.8706, 15.8694, 15.8682, 15.867, 15.8658, 15.8646,
    15.8634, 15.8622, 15.8611, 15.8599, 15.8587, 15.8575, 15.8563,
    15.8551, 15.8539, 15.8527, 15.8515, 15.8503, 15.8491, 15.848,
    15.8468, 15.8456, 15.8444, 15.8432, 15.842, 15.8409, 15.8397,
    15.8385, 15.8373, 15.8361, 15.835, 15.8338, 15.8326, 15.8314,
    15.8303, 15.8291, 15.8279, 15.8267, 15.8256, 15.8244, 15.8232,
    15.8221, 15.8209, 15.8197, 15.8186, 15.8174, 15.8162, 15.8151,
    15.8139, 15.8127, 15.8116, 15.8104, 15.8093, 15.8081, 15.8069,
    15.8058, 15.8046, 15.8035, 15.8023, 15.8012, 15.8, 15.7989,
    15.7977, 15.7966, 15.7954, 15.7943, 15.7931, 15.792, 15.7908,
    15.7897, 15.7885, 15.7874, 15.7862, 15.7851, 15.7839, 15.7828,
    15.7817, 15.7805, 15.7794, 15.7782, 15.7771, 15.776, 15.7748,
    15.7737, 15.7726, 15.7714, 15.7703, 15.7692, 15.768, 15.7669,
    15.7658, 15.7646, 15.7635, 15.7624, 15.7612, 15.7601, 15.759,
    15.7579, 15.7567, 15.7556, 15.7545, 15.7534, 15.7522, 15.7511,
    15.75, 15.7489, 15.7478, 15.7466, 15.7455, 15.7444, 15.7433,
    15.7422, 15.7411, 15.74, 15.7388, 15.7377, 15.7366, 15.7355,
    15.7344, 15.7333, 15.7322, 15.7311, 15.73, 15.7289, 15.7278,
    15.7267, 15.7256, 15.7245, 15.7234, 15.7222, 15.7211, 15.72,
    15.719, 15.7179, 15.7168, 15.7157, 15.7146, 15.7135, 15.7124,
    15.7113, 15.7102, 15.7091, 15.708, 15.7069, 15.7058, 15.7047,
    15.7037, 15.7026, 15.7015, 15.7004, 15.6993, 15.6982, 15.6971,
    15.6961, 15.695, 15.6939, 15.6928, 15.6917, 15.6907, 15.6896,
    15.6885, 15.6874, 15.6864, 15.6853, 15.6842, 15.6832, 15.6821,
    15.681, 15.6799, 15.6789, 15.6778, 15.6767, 15.6757, 15.6746,
    15.6735, 15.6725, 15.6714, 15.6704, 15.6693, 15.6682, 15.6672,
    15.6661, 15.6651, 15.664, 15.663, 15.6619, 15.6609, 15.6598,
    15.6588, 15.6577, 15.6567, 15.6556, 15.6546, 15.6535, 15.6525,
    15.6514, 15.6504, 15.6493, 15.6483, 15.6473, 15.6462, 15.6452,
    15.6441, 15.6431, 15.6421, 15.641, 15.64, 15.639, 15.6379,
    15.6369, 15.6359, 15.6349, 15.6338, 15.6328, 15.6318, 15.6308,
    15.6297, 15.6287, 15.6277, 15.6267, 15.6256, 15.6246, 15.6236,
    15.6226, 15.6216, 15.6206, 15.6196, 15.6185, 15.6175, 15.6165,
    15.6155, 15.6145, 15.6135, 15.6125, 15.6115, 15.6105, 15.6095,
    15.6085, 15.6075, 15.6065, 15.6055, 15.6045, 15.6035, 15.6025,
    15.6015, 15.6005, 15.5995, 15.5986, 15.5976, 15.5966, 15.5956,
    15.5946, 15.5936, 15.5926, 15.5917, 15.5907, 15.5897, 15.5887,
    15.5878, 15.5868, 15.5858, 15.5848, 15.5839, 15.5829, 15.5819,
    15.581, 15.58, 15.579, 15.5781, 15.5771, 15.5761, 15.5752,
    15.5742, 15.5733, 15.5723, 15.5714, 15.5704, 15.5695, 15.5685,
    15.5676, 15.5666, 15.5657, 15.5647, 15.5638, 15.5628, 15.5619,
    15.5609, 15.56, 15.5591, 15.5581, 15.5572, 15.5563, 15.5553,
    15.5544, 15.5535, 15.5525, 15.5516, 15.5507, 15.5498, 15.5489,
    15.5479, 15.547, 15.5461, 15.5452, 15.5443, 15.5434, 15.5424,
    15.5415, 15.5406, 15.5397, 15.5388, 15.5379, 15.537, 15.5361,
    15.5352, 15.5343, 15.5334, 15.5325, 15.5316, 15.5307, 15.5298,
    15.5289, 15.5281, 15.5272, 15.5263, 15.5254, 15.5245, 15.5236,
    15.5228, 15.5219, 15.521, 15.5201, 15.5193, 15.5184, 15.5175,
    15.5167, 15.5158, 15.5149, 15.5141, 15.5132, 15.5123, 15.5115,
    15.5106, 15.5098, 15.5089, 15.5081, 15.5072, 15.5064, 15.5055,
    15.5047, 15.5038, 15.503, 15.5021, 15.5013, 15.5005, 15.4996,
    15.4988, 15.498, 15.4971, 15.4963, 15.4955, 15.4946, 15.4938,
    15.493, 15.4922, 15.4914, 15.4905, 15.4897, 15.4889, 15.4881,
    15.4873, 15.4865, 15.4857, 15.4848, 15.484, 15.4832, 15.4824,
    15.4816, 15.4808, 15.48, 15.4792, 15.4785, 15.4777, 15.4769,
    15.4761, 15.4753, 15.4745, 15.4737, 15.4729, 15.4722, 15.4714,
    15.4706, 15.4698, 15.4691, 15.4683, 15.4675, 15.4667, 15.466,
    15.4652, 15.4645, 15.4637, 15.4629, 15.4622, 15.4614, 15.4607,
    15.4599, 15.4592, 15.4584, 15.4577, 15.4569, 15.4562, 15.4554,
    15.4547, 15.4539, 15.4532, 15.4525, 15.4517, 15.451, 15.4503,
    15.4495, 15.4488, 15.4481, 15.4473, 15.4466, 15.4459, 15.4452,
    15.4445, 15.4437, 15.443, 15.4423, 15.4416, 15.4409, 15.4402,
    15.4395, 15.4388, 15.438, 15.4373, 15.4366, 15.4359, 15.4352,
    15.4345, 15.4338, 15.4332, 15.4325, 15.4318, 15.4311, 15.4304,
    15.4297, 15.429, 15.4283, 15.4276, 15.427, 15.4263, 15.4256,
    15.4249, 15.4243, 15.4236, 15.4229, 15.4222, 15.4216, 15.4209,
    15.4202, 15.4196, 15.4189, 15.4182, 15.4176, 15.4169, 15.4162,
    15.4156, 15.4149, 15.4143, 15.4136, 15.413, 15.4123, 15.4117,
    15.411, 15.4104, 15.4097, 15.4091, 15.4084, 15.4078, 15.4072,
    15.4065, 15.4059, 15.4052, 15.4046, 15.404, 15.4033, 15.4027,
    15.4021, 15.4015, 15.4008, 15.4002, 15.3996, 15.399, 15.3983,
    15.3977, 15.3971, 15.3965, 15.3958, 15.3952, 15.3946, 15.394,
    15.3934, 15.3928, 15.3922, 15.3916, 15.3909, 15.3903, 15.3897,
    15.3891, 15.3885, 15.3879, 15.3873, 15.3867, 15.3861, 15.3855,
    15.3849, 15.3843, 15.3837, 15.3831, 15.3825, 15.382, 15.3814,
    15.3808, 15.3802, 15.3796, 15.379, 15.3784, 15.3778, 15.3773,
    15.3767, 15.3761, 15.3755, 15.3749, 15.3744, 15.3738, 15.3732,
    15.3726, 15.3721, 15.3715, 15.3709, 15.3703, 15.3698, 15.3692,
    15.3686, 15.3681, 15.3675, 15.3669, 15.3664, 15.3658, 15.3652,
    15.3647, 15.3641, 15.3636, 15.363, 15.3624, 15.3619, 15.3613,
    15.3608, 15.3602, 15.3597, 15.3591, 15.3586, 15.358, 15.3575,
    15.3569, 15.3564, 15.3558, 15.3553, 15.3547, 15.3542, 15.3537,
    15.3531, 15.3526, 15.352, 15.3515, 15.351, 15.3504, 15.3499,
    15.3493, 15.3488, 15.3483, 15.3477, 15.3472, 15.3467, 15.3461,
    15.3456, 15.3451, 15.3445, 15.344, 15.3435, 15.343, 15.3424,
    15.3419, 15.3414, 15.3409, 15.3403, 15.3398, 15.3393, 15.3388,
    15.3383, 15.3377, 15.3372, 15.3367, 15.3362, 15.3357, 15.3352,
    15.3346, 15.3341, 15.3336, 15.3331, 15.3326, 15.3321, 15.3316,
    15.3311, 15.3306, 15.3301, 15.3295, 15.329, 15.3285, 15.328,
    15.3275, 15.327, 15.3265, 15.326, 15.3255, 15.325, 15.3245,
    15.324, 15.3235, 15.323, 15.3225, 15.322, 15.3215, 15.3211,
    15.3206, 15.3201, 15.3196, 15.3191, 15.3186, 15.3181, 15.3176,
    15.3171, 15.3166, 15.3162, 15.3157, 15.3152, 15.3147, 15.3142,
    15.3137, 15.3133, 15.3128, 15.3123, 15.3118, 15.3113, 15.3109,
    15.3104, 15.3099, 15.3094, 15.309, 15.3085, 15.308, 15.3075,
    15.3071, 15.3066, 15.3061, 15.3057, 15.3052, 15.3047, 15.3043,
    15.3038, 15.3033, 15.3029, 15.3024, 15.3019, 15.3015, 15.301,
    15.3005, 15.3001, 15.2996, 15.2992, 15.2987, 15.2982, 15.2978,
    15.2973, 15.2969, 15.2964, 15.2959, 15.2955, 15.295, 15.2946,
    15.2941, 15.2937, 15.2932, 15.2928, 15.2923, 15.2919, 15.2914,
    15.291, 15.2905, 15.2901, 15.2896, 15.2892, 15.2888, 15.2883,
    15.2879, 15.2874, 15.287, 15.2865, 15.2861, 15.2857, 15.2852,
    15.2848, 15.2844, 15.2839, 15.2835, 15.283, 15.2826, 15.2822,
    15.2817, 15.2813, 15.2809, 15.2805, 15.28, 15.2796, 15.2792,
    15.2787, 15.2783, 15.2779, 15.2775, 15.277, 15.2766, 15.2762,
    15.2758, 15.2753, 15.2749, 15.2745, 15.2741, 15.2737, 15.2732,
    15.2728, 15.2724, 15.272, 15.2716, 15.2712, 15.2708, 15.2703,
    15.2699, 15.2695, 15.2691, 15.2687, 15.2683, 15.2679, 15.2675,
    15.2671, 15.2667, 15.2662, 15.2658, 15.2654, 15.265, 15.2646,
    15.2642, 15.2638, 15.2634, 15.263, 15.2626, 15.2622, 15.2618,
    15.2614, 15.261, 15.2606, 15.2602, 15.2598, 15.2594, 15.259,
    15.2586, 15.2582, 15.2579, 15.2575, 15.2571, 15.2567, 15.2563,
    15.2559, 15.2555, 15.2551, 15.2547, 15.2543, 15.254, 15.2536,
    15.2532, 15.2528, 15.2524, 15.252, 15.2516, 15.2513, 15.2509,
    15.2505, 15.2501, 15.2497, 15.2494, 15.249, 15.2486, 15.2482,
    15.2478, 15.2475, 15.2471, 15.2467, 15.2463, 15.246, 15.2456,
    15.2452, 15.2448, 15.2445, 15.2441, 15.2437, 15.2433, 15.243,
    15.2426, 15.2422, 15.2419, 15.2415, 15.2411, 15.2408, 15.2404,
    15.24, 15.2397, 15.2393, 15.2389, 15.2386, 15.2382, 15.2378,
    15.2375, 15.2371, 15.2368, 15.2364, 15.236, 15.2357, 15.2353,
    15.235, 15.2346, 15.2342, 15.2339, 15.2335, 15.2332, 15.2328,
    15.2325, 15.2321, 15.2318, 15.2314, 15.2311, 15.2307, 15.2304,
    15.23, 15.2297, 15.2293, 15.229, 15.2286, 15.2283, 15.2279,
    15.2276, 15.2272, 15.2269, 15.2265, 15.2262, 15.2258, 15.2255,
    15.2252, 15.2248, 15.2245, 15.2241, 15.2238, 15.2235, 15.2231,
    15.2228, 15.2224, 15.2221, 15.2218, 15.2214, 15.2211, 15.2208,
    15.2204, 15.2201, 15.2198, 15.2194, 15.2191, 15.2188, 15.2184,
    15.2181, 15.2178, 15.2175, 15.2171, 15.2168, 15.2165, 15.2162,
    15.2158, 15.2155, 15.2152, 15.2149, 15.2145, 15.2142, 15.2139,
    15.2136, 15.2133, 15.213, 15.2126, 15.2123, 15.212, 15.2117,
    15.2114, 15.2111, 15.2108, 15.2104, 15.2101, 15.2098, 15.2095,
    15.2092, 15.2089, 15.2086, 15.2083, 15.208, 15.2077, 15.2074,
    15.2071, 15.2068, 15.2065, 15.2061, 15.2058, 15.2055, 15.2052,
    15.2049, 15.2047, 15.2044, 15.2041, 15.2038, 15.2035, 15.2032,
    15.2029, 15.2026, 15.2023, 15.202, 15.2017, 15.2014, 15.2011,
    15.2008, 15.2005, 15.2003, 15.2, 15.1997, 15.1994, 15.1991,
    15.1988, 15.1985, 15.1983, 15.198, 15.1977, 15.1974, 15.1971,
    15.1969, 15.1966, 15.1963, 15.196, 15.1958, 15.1955, 15.1952,
    15.1949, 15.1947, 15.1944, 15.1941, 15.1938, 15.1936, 15.1933,
    15.193, 15.1928, 15.1925, 15.1922, 15.192, 15.1917, 15.1914,
    15.1912, 15.1909, 15.1906, 15.1904, 15.1901, 15.1899, 15.1896,
    15.1893, 15.1891, 15.1888, 15.1886, 15.1883, 15.188, 15.1878,
    15.1875, 15.1873, 15.187, 15.1868, 15.1865, 15.1863, 15.186,
    15.1858, 15.1855, 15.1853, 15.185, 15.1848, 15.1845, 15.1843,
    15.184, 15.2641, 15.2616, 15.2604, 15.2605, 15.2619, 15.2645,
    15.2684, 15.2737, 15.2801, 15.2877, 15.2965, 15.3062, 15.3169,
    15.3285, 15.3408, 15.354, 15.3679, 15.3825, 15.3978, 15.4137,
    15.4302, 15.4473, 15.465, 15.4832, 15.5019, 15.521, 15.5407,
    15.5608, 15.5814, 15.6023, 15.6237, 15.6455, 15.6677, 15.6903,
    15.7133, 15.7368, 15.7606, 15.7848, 15.8094, 15.8344, 15.8597,
    15.8855, 15.9116, 15.9381, 15.9651, 15.9925, 16.0205, 16.049,
    16.0781, 16.1078, 16.1381, 16.1692, 16.2009, 16.2333, 16.2665,
    16.3004, 16.3351, 16.3704, 16.4065, 16.4433, 16.4807, 16.5189,
    16.5578, 16.5974, 16.6376, 16.6786, 16.7203, 16.7628, 16.8059,
    16.8497, 16.8941, 16.9392, 16.985, 17.0314, 17.0784, 17.1262,
    17.1746, 17.2236, 17.2734, 17.324, 17.3752, 17.4272, 17.4799,
    17.5334, 17.5877, 17.6427, 17.6985, 17.7551, 17.8124, 17.8704,
    17.9292, 17.9887, 18.0488, 18.1096, 18.171, 18.233, 18.2955,
    18.3586, 18.4221, 18.486, 18.5502, 18.6148, 18.6795, 18.7445,
    18.8095, 18.8746, 18.9398, 19.005, 19.0701, 19.1351, 19.2,
    19.2648, 19.3294, 19.3937, 19.4578, 19.5217, 19.5853, 19.6486,
    19.7117, 19.7744, 19.8367, 19.8987, 19.9603, 20.0215, 20.0823,
    20.1427, 20.2026, 20.2621, 20.3211, 20.3796, 20.4376, 20.4951,
    20.5521, 20.6085, 20.6644, 20.7197, 20.7745, 20.8287, 20.8824,
    20.9355, 20.9881, 21.04, 21.0914, 21.1423, 21.1925, 21.2423,
    21.2914, 21.34, 21.388, 21.4354, 21.4822, 21.5285, 21.5742,
    21.6193, 21.6638, 21.7077, 21.751, 21.7937, 21.8358, 21.8773,
    21.9182, 21.9585, 21.9982, 22.0374, 22.076, 22.114, 22.1514,
    22.1883, 22.1883, 13.3363, 13.3185, 13.3006, 13.2828, 13.2649,
    13.247, 13.2292, 13.2113, 13.2455, 13.2796, 13.3137, 13.3478,
    13.3819, 13.416, 13.4501, 13.5169, 13.5873, 13.6595, 13.7325,
    13.8056, 13.8784, 13.9505, 14.0216, 14.0916, 14.1603, 14.2276,
    14.2935, 14.3579, 14.4208, 14.4824, 14.5422, 14.6003, 14.6566,
    14.7112, 14.7642, 14.8157, 14.8657, 14.9142, 14.9614, 15.0073,
    15.052, 15.0955, 15.138, 15.1794, 15.2198, 15.2591, 15.2974,
    15.3347, 15.3709, 15.4063, 15.4408, 15.4744, 15.5072, 15.5393,
    15.5706, 15.6012, 15.6311, 15.6604, 15.689, 15.717, 15.7444,
    15.7713, 15.7975, 15.8232, 15.8483, 15.8729, 15.8968, 15.9202,
    15.9431, 15.9655, 15.9874, 16.0087, 16.0297, 16.0501, 16.0702,
    16.0897, 16.1089, 16.1277, 16.1461, 16.164, 16.1817, 16.1989,
    16.2158, 16.2323, 16.2485, 16.2644, 16.28, 16.2952, 16.3101,
    16.3247, 16.339, 16.3531, 16.3668, 16.3803, 16.3935, 16.4065,
    16.4192, 16.4316, 16.4438, 16.4557, 16.4673, 16.4788, 16.49,
    16.5009, 16.5117, 16.5222, 16.5325, 16.5426, 16.5525, 16.5622,
    16.5717, 16.581, 16.5901, 16.5991, 16.6078, 16.6164, 16.6249,
    16.6331, 16.6412, 16.6492, 16.657, 16.6647, 16.6722, 16.6795,
    16.6868, 16.6939, 16.7009, 16.7077, 16.7144, 16.721, 16.7274,
    16.7337, 16.7399, 16.746, 16.7519, 16.7577, 16.7634, 16.7689,
    16.7743, 16.7797, 16.7848, 16.7899, 16.7948, 16.7997, 16.8044,
    16.809, 16.8134, 16.8178, 16.822, 16.8262, 16.8302, 16.8341,
    16.8379, 16.8416, 16.8452, 16.8487, 16.8521, 16.8554, 16.8586,
    16.8617, 16.8648, 16.8677, 16.8705, 16.8732, 16.8759, 16.8784,
    16.8808, 16.8832, 16.8854, 16.8876, 16.8897, 16.8917, 16.8936,
    16.8954, 16.8971, 16.8987, 16.9002, 16.9017, 16.9031, 16.9043,
    16.9055, 16.9066, 16.9077, 16.9086, 16.9095, 16.9102, 16.9109,
    16.9116, 16.9121, 16.9125, 16.9129, 16.9132, 16.9135, 16.9136,
    16.9137, 16.9137, 16.9136, 16.9135, 16.9133, 16.913, 16.9127,
    16.9122, 16.9118, 16.9112, 16.9106, 16.9099, 16.9091, 16.9083,
    16.9074, 16.9065, 16.9055, 16.9044, 16.9033, 16.9021, 16.9008,
    16.8995, 16.8981, 16.8967, 16.8952, 16.8937, 16.8921, 16.8905,
    16.8888, 16.887, 16.8852, 16.8834, 16.8814, 16.8795, 16.8775,
    16.8754, 16.8733, 16.8712, 16.869, 16.8667, 16.8644, 16.8621,
    16.8597, 16.8572, 16.8548, 16.8522, 16.8497, 16.8471, 16.8444,
    16.8417, 16.839, 16.8362, 16.8334, 16.8305, 16.8276, 16.8247,
    16.8217, 16.8187, 16.8157, 16.8126, 16.8095, 16.8063, 16.8031,
    16.7999, 16.7967, 16.7934, 16.79, 16.7867, 16.7833, 16.7799,
    16.7764, 16.773, 16.7695, 16.7659, 16.7624, 16.7588, 16.7551,
    16.7515, 16.7478, 16.7441, 16.7404, 16.7367, 16.7329, 16.7291,
    16.7253, 16.7214, 16.7176, 16.7137, 16.7098, 16.7059, 16.7019,
    16.698, 16.694, 16.69, 16.686, 16.682, 16.6779, 16.6739,
    16.6698, 16.6657, 16.6616, 16.6575, 16.6534, 16.6492, 16.6451,
    16.6409, 16.6367, 16.6326, 16.6284, 16.6242, 16.62, 16.6157,
    16.6115, 16.6073, 16.603, 16.5988, 16.5945, 16.5903, 16.586,
    16.5817, 16.5774, 16.5731, 16.5688, 16.5645, 16.5602, 16.5559,
    16.5516, 16.5473, 16.543, 16.5387, 16.5343, 16.53, 16.5257,
    16.5213, 16.517, 16.5127, 16.5083, 16.504, 16.4997, 16.4953,
    16.491, 16.4867, 16.4823, 16.478, 16.4737, 16.4693, 16.465,
    16.4607, 16.4563, 16.452, 16.4477, 16.4434, 16.4391, 16.4347,
    16.4304, 16.4261, 16.4218, 16.4175, 16.4132, 16.4089, 16.4046,
    16.4004, 16.3961, 16.3918, 16.3875, 16.3833, 16.379, 16.3748,
    16.3705, 16.3663, 16.3621, 16.3578, 16.3536, 16.3494, 16.3452,
    16.341, 16.3368, 16.3326, 16.3284, 16.3242, 16.32, 16.3158,
    16.3117, 16.3075, 16.3034, 16.2992, 16.2951, 16.291, 16.2868,
    16.2827, 16.2786, 16.2745, 16.2704, 16.2663, 16.2622, 16.2582,
    16.2541, 16.25, 16.246, 16.2419, 16.2379, 16.2339, 16.2298,
    16.2258, 16.2218, 16.2178, 16.2138, 16.2099, 16.2059, 16.2019,
    16.198, 16.194, 16.1901, 16.1862, 16.1822, 16.1783, 16.1744,
    16.1705, 16.1667, 16.1628, 16.1589, 16.1551, 16.1512, 16.1474,
    16.1435, 16.1397, 16.1359, 16.1321, 16.1283, 16.1245, 16.1207,
    16.117, 16.1132, 16.1095, 16.1057, 16.102, 16.0983, 16.0946,
    16.0909, 16.0872, 16.0835, 16.0798, 16.0762, 16.0725, 16.0689,
    16.0652, 16.0616, 16.058, 16.0544, 16.0508, 16.0472, 16.0436,
    16.04, 16.0365, 16.0329, 16.0294, 16.0258, 16.0223, 16.0188,
    16.0153, 16.0118, 16.0083, 16.0048, 16.0013, 15.9979, 15.9944,
    15.991, 15.9875, 15.9841, 15.9807, 15.9773, 15.9739, 15.9705,
    15.9671, 15.9638, 15.9604, 15.9571, 15.9537, 15.9504, 15.9471,
    15.9438, 15.9405, 15.9372, 15.9339, 15.9307, 15.9274, 15.9241,
    15.9209, 15.9177, 15.9145, 15.9112, 15.908, 15.9049, 15.9017,
    15.8985, 15.8953, 15.8922, 15.8891, 15.8859, 15.8828, 15.8797,
    15.8766, 15.8735, 15.8704, 15.8673, 15.8643, 15.8612, 15.8582,
    15.8552, 15.8521, 15.8491, 15.8461, 15.8431, 15.8401, 15.8372,
    15.8342, 15.8313, 15.8283, 15.8254, 15.8224, 15.8195, 15.8166,
    15.8137, 15.8108, 15.808, 15.8051, 15.8022, 15.7994, 15.7965,
    15.7937, 15.7909, 15.7881, 15.7853, 15.7825, 15.7797, 15.7769,
    15.7742, 15.7714, 15.7687, 15.7659, 15.7632, 15.7605, 15.7578,
    15.7551, 15.7524, 15.7497, 15.747, 15.7444, 15.7417, 15.7391,
    15.7364, 15.7338, 15.7312, 15.7286, 15.726, 15.7234, 15.7208,
    15.7183, 15.7157, 15.7132, 15.7106, 15.7081, 15.7056, 15.703,
    15.7005, 15.698, 15.6956, 15.6931, 15.6906, 15.6882, 15.6857,
    15.6833, 15.6808, 15.6784, 15.676, 15.6736, 15.6712, 15.6688,
    15.6665, 15.6641, 15.6617, 15.6594, 15.6571, 15.6547, 15.6524,
    15.6501, 15.6478, 15.6455, 15.6432, 15.6409, 15.6387, 15.6364,
    15.6342, 15.6319, 15.6297, 15.6275, 15.6253, 15.6231, 15.6209,
    15.6187, 15.6165, 15.6144, 15.6122, 15.61, 15.6079, 15.6058,
    15.6037, 15.6015, 15.5994, 15.5973, 15.5953, 15.5932, 15.5911,
    15.589, 15.587, 15.585, 15.5829, 15.5809, 15.5789, 15.5769,
    15.5749, 15.5729, 15.5709, 15.569, 15.567, 15.5651, 15.5631,
    15.5612, 15.5593, 15.5574, 15.5555, 15.5536, 15.5517, 15.5498,
    15.548, 15.5461, 15.5443, 15.5424, 15.5406, 15.5388, 15.537,
    15.5352, 15.5334, 15.5316, 15.5299, 15.5281, 15.5263, 15.5246,
    15.5229, 15.5212, 15.5194, 15.5177, 15.5161, 15.5144, 15.5127,
    15.511, 15.5094, 15.5077, 15.5061, 15.5045, 15.5028, 15.5012,
    15.4996, 15.498, 15.4965, 15.4949, 15.4933, 15.4918, 15.4902,
    15.4887, 15.4872, 15.4856, 15.4841, 15.4826, 15.4811, 15.4797,
    15.4782, 15.4767, 15.4753, 15.4738, 15.4724, 15.471, 15.4695,
    15.4681, 15.4667, 15.4653, 15.4639, 15.4626, 15.4612, 15.4598,
    15.4585, 15.4572, 15.4558, 15.4545, 15.4532, 15.4519, 15.4506,
    15.4493, 15.448, 15.4467, 15.4455, 15.4442, 15.443, 15.4417,
    15.4405, 15.4393, 15.4381, 15.4368, 15.4356, 15.4345, 15.4333,
    15.4321, 15.4309, 15.4298, 15.4286, 15.4275, 15.4263, 15.4252,
    15.4241, 15.423, 15.4219, 15.4208, 15.4197, 15.4186, 15.4175,
    15.4164, 15.4154, 15.4143, 15.4133, 15.4122, 15.4112, 15.4102,
    15.4092, 15.4082, 15.4072, 15.4062, 15.4052, 15.6881, 15.6871,
    15.6861, 15.6851, 15.6841, 15.6831, 15.6822, 15.6812, 15.6802,
    15.6792, 15.6782, 15.6772, 15.6763, 15.6753, 15.6743, 15.6733,
    15.6724, 15.6714, 15.6704, 15.6695, 15.6685, 15.6675, 15.6666,
    15.6656, 15.6646, 15.6637, 15.6627, 15.6618, 15.6608, 15.6599,
    15.6589, 15.658, 15.657, 15.6561, 15.6551, 15.6542, 15.6532,
    15.6523, 15.6514, 15.6504, 15.6495, 15.6486, 15.6476, 15.6467,
    15.6458, 15.6448, 15.6439, 15.643, 15.6421, 15.6411, 15.6402,
    15.6393, 15.6384, 15.6375, 15.6366, 15.6356, 15.6347, 15.6338,
    15.6329, 15.632, 15.6311, 15.6302, 15.6293, 15.6284, 15.6275,
    15.6266, 15.6257, 15.6248, 15.6239, 15.623, 15.6221, 15.6212,
    15.6203, 15.6194, 15.6185, 15.6176, 15.6168, 15.6159, 15.615,
    15.6141, 15.6132, 15.6123, 15.6115, 15.6106, 15.6097, 15.6088,
    15.6079, 15.6071, 15.6062, 15.6053, 15.6044, 15.6036, 15.6027,
    15.6018, 15.601, 15.6001, 15.5992, 15.5984, 15.5975, 15.5966,
    15.5958, 15.5949, 15.5941, 15.5932, 15.5923, 15.5915, 15.5906,
    15.5898, 15.5889, 15.5881, 15.5872, 15.5863, 15.5855, 15.5846,
    15.5838, 15.5829, 15.5821, 15.5812, 15.5804, 15.5796, 15.5787,
    15.5779, 15.577, 15.5762, 15.5753, 15.5745, 15.5737, 15.5728,
    15.572, 15.5711, 15.5703, 15.5695, 15.5686, 15.5678, 15.567,
    15.5661, 15.5653, 15.5645, 15.5636, 15.5628, 15.562, 15.5611,
    15.5603, 15.5595, 15.5587, 15.5578, 15.557, 15.5562, 15.5554,
    15.5545, 15.5537, 15.5529, 15.5521, 15.5513, 15.5504, 15.5496,
    15.5488, 15.548, 15.5472, 15.5463, 15.5455, 15.5447, 15.5439,
    15.5431, 15.5423, 15.5414, 15.5406, 15.5398, 15.539, 15.5382,
    15.5374, 15.5366, 15.5358, 15.535, 15.5341, 15.5333, 15.5325,
    15.5317, 15.5309, 15.5301, 15.5293, 15.5285, 15.5277, 15.5269,
    15.5261, 15.5253, 15.5245, 15.5237, 15.5229, 15.5221, 15.5213,
    15.5205, 15.5197, 15.5189, 15.5181, 15.5173, 15.5165, 15.5157,
    15.5149, 15.5141, 15.5133, 15.5125, 15.5117, 15.5109, 15.5101,
    15.5093, 15.5086, 15.5078, 15.507, 15.5062, 15.5054, 15.5046,
    15.5038, 15.503, 15.5023, 15.5015, 15.5007, 15.4999, 15.4991,
    15.4983, 15.4976, 15.4968, 15.496, 15.4952, 15.4944, 15.4937,
    15.4929, 15.4921, 15.4913, 15.4906, 15.4898, 15.489, 15.4883,
    15.4875, 15.4867, 15.4859, 15.4852, 15.4844, 15.4836, 15.4829,
    15.4821, 15.4814, 15.4806, 15.4798, 15.4791, 15.4783, 15.4776,
    15.4768, 15.476, 15.4753, 15.4745, 15.4738, 15.473, 15.4723,
    15.4715, 15.4708, 15.47, 15.4693, 15.4685, 15.4678, 15.467,
    15.4663, 15.4656, 15.4648, 15.4641, 15.4633, 15.4626, 15.4619,
    15.4611, 15.4604, 15.4597, 15.4589, 15.4582, 15.4575, 15.4568,
    15.456, 15.4553, 15.4546, 15.4539, 15.4531, 15.4524, 15.4517,
    15.451, 15.4503, 15.4495, 15.4488, 15.4481, 15.4474, 15.4467,
    15.446, 15.4453, 15.4446, 15.4439, 15.4432, 15.4425, 15.4418,
    15.4411, 15.4404, 15.4397, 15.439, 15.4383, 15.4376, 15.4369,
    15.4362, 15.4355, 15.4349, 15.4342, 15.4335, 15.4328, 15.4321,
    15.4315, 15.4308, 15.4301, 15.4294, 15.4288, 15.4281, 15.4274,
    15.4268, 15.4261, 15.4254, 15.4248, 15.4241, 15.4234, 15.4228,
    15.4221, 15.4215, 15.4208, 15.4202, 15.4195, 15.4189, 15.4182,
    15.4176, 15.4169, 15.4163, 15.4157, 15.415, 15.4144, 15.4137,
    15.4131, 15.4125, 15.4119, 15.4112, 15.4106, 15.41, 15.4093,
    15.4087, 15.4081, 15.4075, 15.4069, 15.4063, 15.4056, 15.405,
    15.4044, 15.4038, 15.4032, 15.4026, 15.402, 15.4014, 15.4008,
    15.4002, 15.3996, 15.399, 15.3984, 15.3978, 15.3972, 15.3966,
    15.396, 15.3954, 15.3949, 15.3943, 15.3937, 15.3931, 15.3925,
    15.392, 15.3914, 15.3908, 15.3902, 15.3897, 15.3891, 15.3885,
    15.388, 15.3874, 15.3868, 15.3863, 15.3857, 15.3852, 15.3846,
    15.384, 15.3835, 15.3829, 15.3824, 15.3818, 15.3813, 15.3808,
    15.3802, 15.3797, 15.3791, 15.3786, 15.378, 15.3775, 15.377,
    15.3764, 15.3759, 15.3754, 15.3748, 15.3743, 15.3738, 15.3733,
    15.3727, 15.3722, 15.3717, 15.3712, 15.3707, 15.3702, 15.3696,
    15.3691, 15.3686, 15.3681, 15.3676, 15.3671, 15.3666, 15.3661,
    15.3656, 15.3651, 15.3646, 15.3641, 15.3636, 15.3631, 15.3626,
    15.3621, 15.3616, 15.3611, 15.3606, 15.3601, 15.3597, 15.3592,
    15.3587, 15.3582, 15.3577, 15.3572, 15.3568, 15.3563, 15.3558,
    15.3553, 15.3549, 15.3544, 15.3539, 15.3535, 15.353, 15.3525,
    15.3521, 15.3516, 15.3511, 15.3507, 15.3502, 15.3497, 15.3493,
    15.3488, 15.3484, 15.3479, 15.3475, 15.347, 15.3465, 15.3461,
    15.3456, 15.3452, 15.3448, 15.3443, 15.3439, 15.3434, 15.343,
    15.3425, 15.3421, 15.3416, 15.3412, 15.3408, 15.3403, 15.3399,
    15.3395, 15.339, 15.3386, 15.3382, 15.3377, 15.3373, 15.3369,
    15.3364, 15.336, 15.3356, 15.3352, 15.3347, 15.3343, 15.3339,
    15.3335, 15.3331, 15.3326, 15.3322, 15.3318, 15.3314, 15.331,
    15.3306, 15.3301, 15.3297, 15.3293, 15.3289, 15.3285, 15.3281,
    15.3277, 15.3273, 15.3269, 15.3265, 15.3261, 15.3257, 15.3252,
    15.3248, 15.3244, 15.324, 15.3236, 15.3233, 15.3229, 15.3225,
    15.3221, 15.3217, 15.3213, 15.3209, 15.3205, 15.3201, 15.3197,
    15.3193, 15.3189, 15.3185, 15.3182, 15.3178, 15.3174, 15.317,
    15.3166, 15.3162, 15.3159, 15.3155, 15.3151, 15.3147, 15.3143,
    15.314, 15.3136, 15.3132, 15.3128, 15.3125, 15.3121, 15.3117,
    15.3114, 15.311, 15.3106, 15.3102, 15.3099, 15.3095, 15.3091,
    15.3088, 15.3084, 15.308, 15.3077, 15.3073, 15.307, 15.3066,
    15.3062, 15.3059, 15.3055, 15.3052, 15.3048, 15.3044, 15.3041,
    15.3037, 15.3034, 15.303, 15.3027, 15.3023, 15.302, 15.3016,
    15.3013, 15.3009, 15.3006, 15.3002, 15.2999, 15.2996, 15.2992,
    15.2989, 15.2985, 15.2982, 15.2978, 15.2975, 15.2972, 15.2968,
    15.2965, 15.2962, 15.2958, 15.2955, 15.2952, 15.2948, 15.2945,
    15.2942, 15.2938, 15.2935, 15.2932, 15.2929, 15.2925, 15.2922,
    15.2919, 15.2916, 15.2913, 15.2909, 15.2906, 15.2903, 15.29,
    15.2897, 15.2894, 15.289, 15.2887, 15.2884, 15.2881, 15.2878,
    15.2875, 15.2872, 15.2869, 15.2866, 15.2863, 15.286, 15.2857,
    15.2854, 15.2851, 15.2848, 15.2845, 15.2842, 15.2839, 15.2836,
    15.2833, 15.283, 15.2827, 15.2824, 15.2821, 15.2818, 15.2816,
    15.2813, 15.281, 15.2807, 15.2804, 15.2801, 15.2799, 15.2796,
    15.2793, 15.279, 15.2788, 15.2785, 15.2782, 15.2779, 15.2777,
    15.2774, 15.2771, 15.2769, 15.2766, 15.2763, 15.2761, 15.2758,
    15.2755, 15.2753, 15.275, 15.2748, 15.2745, 15.2742, 15.274,
    15.2737, 15.2735, 15.2732, 15.273, 15.2727, 15.2725, 15.2722,
    15.272, 15.2717, 15.2715, 15.2713, 15.271, 15.2708, 15.2705,
    15.2703, 15.2701, 15.2698, 15.2696, 15.2694, 15.2691, 15.2689,
    15.2687, 15.2685, 15.2682, 15.268, 15.2678, 15.2676, 15.2673,
    15.2671, 15.2669, 15.2667, 15.2665, 15.2662, 15.266, 15.2658,
    15.2656, 15.2654, 15.2652, 15.265, 15.2648, 15.2646, 15.2644,
    15.2642, 15.264, 15.2638, 15.2636, 15.2634, 15.2632, 15.263,
    15.2628, 15.2626, 15.2624, 15.2622, 15.262, 15.2619, 15.2617,
    15.2615, 15.2613, 15.2611, 15.2609, 15.2608, 15.2606, 15.2604,
    15.2602, 15.2601, 15.2599, 15.2597, 15.2596, 15.2594, 15.2592,
    15.2591, 15.2589, 15.2587, 15.2586, 15.2584, 15.2583, 15.2581,
    15.2579, 15.2578, 15.2576, 15.2575, 15.2573, 15.2572, 15.257,
    15.2569, 15.2568, 15.2566, 15.2565, 15.2563, 15.2562, 15.2561,
    15.2559, 15.2558, 15.2557, 15.2555, 15.2554, 15.2553, 15.2551,
    15.255, 15.2549, 15.2548, 15.2547, 15.2545, 15.2544, 15.2543,
    15.2542, 15.2541, 15.254, 15.2538, 15.2537, 15.2536, 15.2535,
    15.2534, 15.2533, 15.2532, 15.2531, 15.253, 15.2529, 15.2528,
    15.2527, 15.2526, 15.2525, 15.2525, 15.2524, 15.2523, 15.2522,
    15.2521, 15.252, 15.2519, 15.2519, 15.2518, 15.2517, 15.2516,
    15.2515, 15.2515, 15.2514, 15.2513, 15.2513, 15.2512, 15.2511,
    15.2511, 15.251, 15.2509, 15.2509, 15.2508, 15.2508, 15.2507,
    15.2507, 15.2506, 15.2506, 15.2505, 15.2505, 15.2504, 15.2504,
    15.2503, 15.2503, 15.2502, 15.2502, 15.2502, 15.2501, 15.2501,
    15.25, 15.25, 15.25, 15.25, 15.2499, 15.2499, 15.2499, 15.2498,
    15.2498, 15.2498, 15.2498, 15.2498, 15.2497, 15.2497, 15.2497,
    15.2497, 15.2497, 15.2497, 15.2497, 15.2497, 15.2497, 15.2497,
    15.2496, 15.2496, 15.2496, 15.2496, 15.2496, 15.2497, 15.2497,
    15.2497, 15.2497, 15.2497, 15.2497, 15.2497, 15.2497, 15.2497,
    15.2497, 15.2498, 15.2498, 15.2498, 15.2498, 15.2498, 15.2499,
    15.2499, 15.2499, 15.2499, 15.25, 15.25, 15.25, 15.25, 15.2501,
    15.2501, 15.2501, 15.2502, 15.2502, 15.2502, 15.2503, 15.2503,
    15.2504, 15.2504, 15.2505, 15.2505, 15.2505, 15.2506, 15.2506,
    15.2507, 15.2507, 15.2508, 15.2508, 15.2509, 15.2509, 15.251,
    15.2511, 15.2511, 15.2512, 15.2512, 15.2513, 15.2514, 15.2514,
    15.2515, 15.2515, 15.2516, 15.2517, 15.2517, 15.2518, 15.2519,
    15.2519, 15.252, 15.2521, 15.2522, 15.2522, 15.2523, 15.2524,
    15.2525, 15.2525, 15.2526, 15.2527, 15.2528, 15.2529, 15.2529,
    15.253, 15.2531, 15.2532, 15.2533, 15.2534, 15.2534, 15.2535,
    15.2536, 15.2537, 15.2538, 15.2539, 15.254, 15.2541, 15.2542,
    15.2543, 15.2543, 15.2544, 15.2545, 15.2546, 15.2547, 15.2548,
    15.2549, 15.255, 15.2551, 15.2552, 15.2553, 15.2554, 15.2555,
    15.2556, 15.2557, 15.2558, 15.2559, 15.256, 15.2561, 15.2563,
    15.2564, 15.2565, 15.2566, 15.2567, 15.2568, 15.2569, 15.257,
    15.2571, 15.2572, 15.2574, 15.2575, 15.2576, 15.2577, 15.2578,
    15.2579, 15.258, 15.2582, 15.2583, 15.2584, 15.2585, 15.2586,
    15.2587, 15.2589, 15.259, 15.2591, 15.2592, 15.2593, 15.2595,
    15.2596, 15.2597, 15.2598, 15.2599, 15.2601, 15.2602, 15.2603,
    15.2604, 15.2606, 15.2607, 15.2608, 15.261, 15.2611, 15.2612,
    15.2613, 15.2615, 15.2616, 15.2617, 15.2619, 15.262, 15.2621,
    15.2622, 15.2624, 15.2625, 15.2626, 15.2628, 15.2629, 15.263,
    15.2632, 15.2633, 15.2635, 15.2636, 15.2637, 15.2639, 15.264,
    15.2641, 15.2643, 15.2644, 15.2646, 15.2647, 15.2648, 15.265,
    15.2651, 15.2653, 15.2654, 15.2655, 15.2657, 15.2658, 15.266,
    15.2661, 15.2663, 15.2664, 15.2665, 15.2667, 15.2668, 15.267,
    15.2671, 15.2673, 15.2674, 15.2676, 15.2677, 15.2679, 15.268,
    15.2682, 15.2683, 15.2685, 15.2686, 15.2688, 15.2689, 15.2691,
    15.2692, 15.2694, 15.2695, 15.2697, 15.2698, 15.27, 15.2702,
    15.2703, 15.2705, 15.2706, 15.2708, 15.2709, 15.2711, 15.2713,
    15.2714, 15.2716, 15.2717, 15.2719, 15.272, 15.2722, 15.2724,
    15.2725, 15.2727, 15.2729, 15.273, 15.2732, 15.2733, 15.2735,
    15.2737, 15.2738, 15.274, 15.2742, 15.2743, 15.2745, 15.2747,
    15.2748, 15.275, 15.2752, 15.2753, 15.2755, 15.2757, 15.2758,
    15.276, 15.2762, 15.2763, 15.2765, 15.2767, 15.2768, 15.277,
    15.2772, 15.2773, 15.2775, 15.2777, 15.2779, 15.278, 15.2782,
    15.2784, 15.2785, 15.2787, 15.2789, 15.2791, 15.2792, 15.2794,
    15.2796, 15.2798, 15.2441, 15.2434, 15.2433, 15.2438, 15.2448,
    15.2464, 15.2487, 15.2516, 15.2551, 15.2592, 15.2641, 15.2697,
    15.276, 15.2831, 15.2911, 15.2998, 15.3095, 15.32, 15.3314,
    15.3439, 15.3572, 15.3717, 15.3871, 15.4036, 15.4211, 15.4397,
    15.4593, 15.4798, 15.5014, 15.524, 15.5476, 15.5723, 15.5979,
    15.6246, 15.6523, 15.681, 15.7107, 15.7415, 15.7732, 15.8058,
    15.8394, 15.8738, 15.909, 15.9451, 15.9818, 16.0194, 16.0575,
    16.0964, 16.1358, 16.1759, 16.2166, 16.258, 16.2999, 16.3425,
    16.3858, 16.4298, 16.4746, 16.52, 16.5663, 16.6133, 16.6612,
    16.71, 16.7595, 16.81, 16.8614, 16.9136, 16.9667, 17.0208,
    17.0757, 17.1316, 17.1883, 17.2459, 17.3044, 17.3637, 17.4238,
    17.4847, 17.5464, 17.6088, 17.6719, 17.7357, 17.8001, 17.8651,
    17.9306, 17.9966, 18.063, 18.1297, 18.1967, 18.2639, 18.3312,
    18.3986, 18.466, 18.5333, 18.6006, 18.6677, 18.7346, 18.8012,
    18.8675, 18.9335, 18.9991, 19.0642, 19.1289, 19.1931, 19.2567,
    19.3197, 19.382, 19.4437, 19.5045, 19.5647, 19.624, 19.6824,
    19.74, 19.7966, 19.8523, 19.907, 19.9607, 20.0133, 20.0648,
    20.1152, 20.1644, 20.2125, 20.2595, 20.3053, 20.3499, 20.3934,
    20.4357, 20.4769, 20.517, 20.556, 20.5938, 20.6306, 20.6663,
    20.7008, 20.7344, 20.7668, 20.7982, 20.8286, 20.858, 20.8863,
    20.9137, 20.9401, 20.9656, 20.9901, 21.0138, 21.0367, 21.0587,
    21.0801, 21.1007, 21.1206, 21.1399, 21.1586, 21.1768, 21.1944,
    21.2116, 21.2282, 21.2444, 21.2603, 21.2757, 21.2908, 21.3055,
    21.32, 21.3341, 21.348, 21.3617, 21.3752, 21.3884, 21.4014,
    21.4143, 21.4269, 21.4269, 34.4618, 34.562, 34.6622, 34.7625,
    34.8627, 34.9629, 35.0631, 35.1634, 35.2636, 35.3638, 35.464,
    35.5643, 35.6645, 35.7647, 35.8649, 35.9652, 36.0632, 36.159,
    36.2526, 36.3441, 36.4338, 36.5216, 36.6078, 36.6922, 36.7751,
    36.8566, 36.9366, 37.0152, 37.0926, 37.1687, 37.2435, 37.3172,
    37.3898, 37.4612, 37.5316, 37.601, 37.6694, 37.7368, 37.8034,
    37.869, 37.9338, 37.9978, 38.0609, 38.1233, 38.185, 38.2459,
    38.3061, 38.3655, 38.4243, 38.4824, 38.5399, 38.5968, 38.653,
    38.7087, 38.7638, 38.8183, 38.8724, 38.9258, 38.9788, 39.0313,
    39.0834, 39.1349, 39.1861, 39.2368, 39.2871, 39.3369, 39.3863,
    39.4353, 39.4838, 39.532, 39.5797, 39.6271, 39.674, 39.7206,
    39.7668, 39.8127, 39.8581, 39.9033, 39.948, 39.9924, 40.0365,
    40.0803, 40.1237, 40.1668, 40.2096, 40.2521, 40.2943, 40.3362,
    40.3778, 40.4191, 40.4601, 40.5008, 40.5413, 40.5815, 40.6214,
    40.6611, 40.7005, 40.7396, 40.7785, 40.8172, 40.8555, 40.8936,
    40.9315, 40.9691, 41.0065, 41.0436, 41.0805, 41.1172, 41.1536,
    41.1898, 41.2257, 41.2615, 41.297, 41.3323, 41.3673, 41.4022,
    41.4368, 41.4712, 41.5054, 41.5394, 41.5731, 41.6067, 41.6401,
    41.6732, 41.7062, 41.7389, 41.7715, 41.8038, 41.836, 41.868,
    41.8997, 41.9313, 41.9627, 41.9939, 42.0249, 42.0557, 42.0864,
    42.1168, 42.1471, 42.1772, 42.2071, 42.2368, 42.2664, 42.2957,
    42.3249, 42.354, 42.3828, 42.4115, 42.44, 42.4684, 42.4965,
    42.5246, 42.5524, 42.5801, 42.6076, 42.6349, 42.6621, 42.6892,
    42.716, 42.7427, 42.7693, 42.7957, 42.8219, 42.848, 42.874,
    42.8997, 42.9254, 42.9509, 42.9762, 43.0014, 43.0264, 43.0513,
    43.0761, 43.1007, 43.1252, 43.1495, 43.1737, 43.1978, 43.2217,
    43.2455, 43.2691, 43.2927, 43.316, 43.3393, 43.3624, 43.3854,
    43.4083, 43.431, 43.4536, 43.4761, 43.4984, 43.5206, 43.5427,
    43.5647, 43.5865, 43.6082, 43.6298, 43.6513, 43.6727, 43.6939,
    43.715, 43.736, 43.7569, 43.7777, 43.7983, 43.8188, 43.8393,
    43.8596, 43.8798, 43.8998, 43.9198, 43.9397, 43.9594, 43.9791,
    43.9986, 44.0181, 44.0374, 44.0566, 44.0757, 44.0947, 44.1136,
    44.1325, 44.1512, 44.1698, 44.1883, 44.2067, 44.225, 44.2432,
    44.2613, 44.2793, 44.2972, 44.315, 44.3328, 44.3504, 44.3679,
    44.3854, 44.4027, 44.42, 44.4372, 44.4543, 44.4713, 44.4882,
    44.505, 44.5217, 44.5384, 44.5549, 44.5714, 44.5878, 44.6041,
    44.6203, 44.6365, 44.6525, 44.6685, 44.6844, 44.7002, 44.716,
    44.7316, 44.7472, 44.7627, 44.7781, 44.7935, 44.8088, 44.824,
    44.8391, 44.8542, 44.8691, 44.884, 44.8989, 44.9136, 44.9283,
    44.9429, 44.9575, 44.972, 44.9864, 45.0007, 45.015, 45.0292,
    45.0433, 45.0573, 45.0713, 45.0853, 45.0991, 45.1129, 45.1267,
    45.1403, 45.1539, 45.1674, 45.1809, 45.1943, 45.2077, 45.2209,
    45.2341, 45.2473, 45.2604, 45.2734, 45.2864, 45.2993, 45.3121,
    45.3249, 45.3377, 45.3503, 45.3629, 45.3755, 45.388, 45.4004,
    45.4128, 45.4251, 45.4374, 45.4496, 45.4618, 45.4739, 45.4859,
    45.4979, 45.5098, 45.5217, 45.5336, 45.5453, 45.5571, 45.5687,
    45.5803, 45.5919, 45.6034, 45.6149, 45.6263, 45.6376, 45.6489,
    45.6602, 45.6714, 45.6826, 45.6937, 45.7047, 45.7158, 45.7267,
    45.7376, 45.7485, 45.7593, 45.7701, 45.7808, 45.7915, 45.8022,
    45.8128, 45.8233, 45.8338, 45.8443, 45.8547, 45.8651, 45.8754,
    45.8857, 45.8959, 45.9061, 45.9163, 45.9264, 45.9364, 45.9465,
    45.9565, 45.9664, 45.9763, 45.9862, 45.996, 46.0058, 46.0155,
    46.0252, 46.0349, 46.0445, 46.0541, 46.0637, 46.0732, 46.0827,
    46.0921, 46.1015, 46.1109, 46.1202, 46.1295, 46.1387, 46.148,
    46.1572, 46.1663, 46.1754, 46.1845, 46.1935, 46.2025, 46.2115,
    46.2204, 46.2294, 46.2382, 46.2471, 46.2559, 46.2646, 46.2734,
    46.2821, 46.2908, 46.2994, 46.308, 46.3166, 46.3251, 46.3337,
    46.3421, 46.3506, 46.359, 46.3674, 46.3758, 46.3841, 46.3924,
    46.4007, 46.409, 46.4172, 46.4254, 46.4335, 46.4417, 46.4498,
    46.4578, 46.4659, 46.4739, 46.4819, 46.4899, 46.4978, 46.5057,
    46.5136, 46.5215, 46.5293, 46.5371, 46.5449, 46.5527, 46.5604,
    46.5681, 46.5758, 46.5834, 46.591, 46.5987, 46.6062, 46.6138,
    46.6213, 46.6288, 46.6363, 46.6438, 46.6512, 46.6586, 46.666,
    46.6734, 46.6807, 46.688, 46.6953, 46.7026, 46.7098, 46.7171,
    46.7243, 46.7314, 46.7386, 46.7457, 46.7529, 46.76, 46.767,
    46.7741, 46.7811, 46.7881, 46.7951, 46.8021, 46.809, 46.816,
    46.8229, 46.8298, 46.8366, 46.8435, 46.8503, 46.8571, 46.8639,
    46.8707, 46.8775, 46.8842, 46.8909, 46.8976, 46.9043, 46.911,
    46.9176, 46.9242, 46.9308, 46.9374, 46.944, 46.9505, 46.9571,
    46.9636, 46.9701, 46.9766, 46.9831, 46.9895, 46.996, 47.0024,
    47.0088, 47.0152, 47.0215, 47.0279, 47.0342, 47.0405, 47.0468,
    47.0531, 47.0594, 47.0657, 47.0719, 47.0781, 47.0843, 47.0905,
    47.0967, 47.1029, 47.109, 47.1152, 47.1213, 47.1274, 47.1335,
    47.1396, 47.1456, 47.1517, 47.1577, 47.1637, 47.1697, 47.1757,
    47.1817, 47.1877, 47.1936, 47.1995, 47.2055, 47.2114, 47.2173,
    47.2232, 47.229, 47.2349, 47.2407, 47.2466, 47.2524, 47.2582,
    47.264, 47.2698, 47.2755, 47.2813, 47.287, 47.2928, 47.2985,
    47.3042, 47.3099, 47.3156, 47.3213, 47.3269, 47.3326, 47.3382,
    47.3438, 47.3494, 47.3551, 47.3606, 47.3662, 47.3718, 47.3774,
    47.3829, 47.3884, 47.394, 47.3995, 47.405, 47.4105, 47.416,
    47.4215, 47.4269, 47.4324, 47.4378, 47.4432, 47.4487, 47.4541,
    47.4595, 47.4649, 47.4703, 47.4756, 47.481, 47.4863, 47.4917,
    47.497, 47.5023, 47.5077, 47.513, 47.5183, 47.5236, 47.5288,
    47.5341, 47.5394, 47.5446, 47.5498, 47.5551, 47.5603, 47.5655,
    47.5707, 47.5759, 47.5811, 47.5863, 47.5915, 47.5966, 47.6018,
    47.6069, 47.612, 47.6172, 47.6223, 47.6274, 47.6325, 47.6376,
    47.6427, 47.6478, 47.6528, 47.6579, 47.663, 47.668, 47.673,
    47.6781, 47.6831, 47.6881, 47.6931, 47.6981, 47.7031, 47.7081,
    47.7131, 47.718, 47.723, 47.728, 47.7329, 47.7378, 47.7428,
    47.7477, 47.7526, 47.7575, 47.7624, 47.7673, 47.7722, 47.7771,
    47.782, 47.7868, 47.7917, 47.7965, 47.8014, 47.8062, 47.811,
    47.8159, 47.8207, 47.8255, 47.8303, 47.8351, 47.8399, 47.8446,
    47.8494, 47.8542, 47.859, 47.8637, 47.8685, 47.8732, 47.8779,
    47.8827, 47.8874, 47.8921, 47.8968, 47.9015, 47.9062, 47.9109,
    47.9156, 47.9202, 47.9249, 47.9296, 47.9342, 47.9389, 47.9435,
    47.9482, 47.9528, 47.9574, 47.962, 47.9666, 47.9713, 47.9759,
    47.9804, 47.985, 47.9896, 47.9942, 47.9988, 48.0033, 48.0079,
    48.0124, 48.017, 48.0215, 48.026, 48.0306, 48.0351, 48.0396,
    48.0441, 48.0486, 48.0531, 48.0576, 48.0621, 48.0666, 48.071,
    48.0755, 48.08, 48.0844, 48.0889, 48.0933, 48.0977, 48.1022,
    48.1066, 48.111, 48.1154, 48.1198, 48.1242, 48.1286, 48.133,
    48.1374, 48.1418, 48.1462, 48.1505, 48.1549, 48.1592, 48.1636,
    48.1679, 48.1723, 48.1766, 48.1809, 48.1853, 48.1896, 48.1939,
    48.1982, 48.2025, 48.2068, 48.2111, 48.2153, 48.2196, 48.2239,
    48.2282, 48.2324, 48.2367, 48.2409, 48.2452, 48.2494, 48.2536,
    48.2579, 48.2621, 48.2663, 48.2705, 48.2747, 48.2789, 48.2831,
    48.2873, 48.2915, 48.2956, 48.2998, 48.304, 48.3081, 48.3123,
    48.3164, 48.3206, 48.3247, 48.3288, 48.333, 48.3371, 48.3412,
    48.3453, 48.3494, 48.3535, 48.3576, 48.3617, 48.3658, 48.3699,
    48.3739, 48.378, 48.3821, 48.3861, 48.3902, 48.3942, 48.3982,
    48.4023, 48.4063, 48.4103, 48.4143, 48.4184, 48.4224, 48.4264,
    48.4304, 48.4343, 48.4383, 48.4423, 48.4463, 48.4502, 48.4542,
    48.4582, 48.4621, 48.4661, 48.47, 48.4739, 48.4779, 48.4818,
    48.4857, 48.4896, 48.4935, 48.4974, 48.5013, 48.5052, 48.5091,
    48.513, 48.5169, 48.5207, 48.5246, 48.5285, 48.5323, 48.5362,
    48.54, 48.5438, 48.5477, 48.5515, 48.5553, 48.5591, 48.563,
    48.5668, 48.5706, 48.5744, 48.5782, 48.5819, 48.5857, 48.5895,
    48.5933, 48.597, 48.6008, 48.6045, 48.6083, 48.612, 48.6158,
    48.6195, 48.6232, 48.627, 48.6307, 48.6344, 48.6381, 48.6418,
    48.6455, 48.6492, 48.6529, 48.6566, 48.6602, 48.6639, 48.6676,
    48.6712, 48.6749, 48.6785, 48.6822, 48.6858, 48.6895, 48.6931,
    48.6967, 48.7003, 48.7039, 48.7076, 48.7112, 48.7148, 48.7184,
    48.7219, 48.7255, 48.7291, 48.7327, 48.7363, 48.7398, 48.7434,
    48.7469, 48.7505, 48.754, 48.7576, 48.7611, 48.7646, 48.7681,
    48.7717, 48.7752, 48.7787, 48.7822, 48.7857, 48.7892, 48.7927,
    48.7962, 48.7996, 48.8031, 48.8066, 48.81, 48.8135, 48.8169,
    48.8204, 48.8238, 48.8273, 48.8307, 48.8341, 48.8376, 48.841,
    48.8444, 48.8478, 48.8512, 48.8546, 48.858, 48.8614, 48.8648,
    48.8681, 48.8715, 48.8749, 48.8783, 48.8816, 48.885, 48.8883,
    48.8917, 48.895, 48.8983, 48.9017, 48.905, 48.9083, 48.9116,
    48.9149, 48.9182, 48.9215, 48.9248, 48.9281, 48.9314, 48.9347,
    48.938, 48.9413, 48.9445, 48.9478, 48.951, 48.9543, 48.9575,
    48.9608, 48.964, 48.9673, 48.9705, 48.9737, 48.9769, 48.9802,
    48.9834, 48.9866, 48.9898, 48.993, 48.9962, 48.9993, 49.0025,
    49.0057, 49.0089, 49.0121, 49.0152, 49.0184, 49.0215, 49.0247,
    49.0278, 49.031, 49.0341, 49.0372, 49.0404, 49.0435, 49.0466,
    49.0497, 49.0528, 49.0559, 49.059, 49.0621, 49.0652, 49.0683,
    49.0714, 49.0744, 49.0775, 49.0806, 49.0836, 49.0867, 49.0898,
    49.0928, 49.0958, 49.0989, 49.1019, 49.1049, 49.108, 49.111,
    49.114, 49.117, 49.12, 49.123, 49.126, 49.129, 49.132, 49.135,
    49.138, 49.141, 49.1439, 49.1469, 49.1499, 49.1528, 49.1558,
    49.1588, 49.1617, 49.1646, 49.1676, 49.1705, 49.1735, 49.1764,
    49.1793, 49.1822, 49.1851, 49.188, 49.1909, 49.1938, 49.1967,
    49.1996, 49.2025, 49.2054, 49.2083, 49.2112, 49.214, 49.2169,
    49.2198, 49.2226, 49.2255, 49.2283, 49.2312, 49.234, 49.2369,
    49.2397, 49.2425, 49.2454, 49.2482, 49.251, 49.2538, 49.2566,
    49.2594, 49.2622, 49.265, 49.2678, 49.2706, 49.2734, 49.2762,
    49.279, 49.2818, 49.2845, 49.2873, 49.2901, 49.2928, 49.2956,
    49.2983, 49.3011, 49.3038, 49.3066, 49.3093, 49.312, 49.3148,
    49.3175, 49.3202, 49.3229, 49.3257, 49.3284, 49.3311, 49.3338,
    49.3365, 49.3392, 49.3419, 49.3446, 49.3472, 49.3499, 49.3526,
    49.3553, 49.3579, 49.3606, 49.3633, 49.3659, 49.3686, 49.3712,
    49.3739, 49.3765, 49.3792, 49.3818, 49.3844, 49.3871, 49.3897,
    49.3923, 49.395, 49.3976, 49.4002, 49.4028, 49.4054, 49.408,
    49.4106, 49.4132, 49.4158, 49.4184, 49.421, 49.4235, 49.4261,
    49.4287, 49.4313, 49.4338, 49.4364, 49.439, 49.4415, 49.4441,
    49.4466, 49.4492, 49.4517, 49.4543, 49.4568, 49.4593, 49.4619,
    49.4644, 49.4669, 49.4694, 49.4719, 49.4745, 49.477, 49.4795,
    49.482, 49.4845, 49.487, 49.4895, 49.492, 49.4944, 49.4969,
    49.4994, 49.5019, 49.5044, 49.5068, 49.5093, 49.5118, 49.5142,
    49.5167, 49.5191, 49.5216, 49.524, 49.5265, 49.5289, 49.5314,
    49.5338, 49.5362, 49.5387, 49.5411, 49.5435, 49.5459, 49.5483,
    49.5508, 49.5532, 49.5556, 49.558, 49.5604, 49.5628, 49.5652,
    49.5676, 49.57, 49.5723, 49.5747, 49.5771, 49.5795, 49.5819,
    49.5842, 49.5866, 49.589, 49.5913, 49.5937, 49.5961, 49.5984,
    49.6008, 49.6031, 49.6054, 49.6078, 49.6101, 49.6125, 49.6148,
    49.6171, 49.6195, 49.6218, 49.6241, 49.6264, 49.6287, 49.6311,
    49.6334, 49.6357, 49.638, 49.6403, 49.6426, 49.6449, 49.6472,
    49.6495, 49.6517, 49.654, 49.6563, 49.6586, 49.6609, 49.6631,
    49.6654, 49.6677, 49.67, 49.6722, 49.6745, 49.6767, 49.679,
    49.6812, 49.6835, 49.6857, 49.688, 49.6902, 49.6925, 49.6947,
    49.6969, 49.6992, 49.7014, 49.7036, 49.7059, 49.7081, 49.7103,
    49.7125, 49.7147, 49.7169, 49.7191, 49.7213, 49.7235, 49.7257,
    49.7279, 49.7301, 49.7323, 49.7345, 49.7367, 49.7389, 49.7411,
    49.7433, 49.7454, 49.7476, 49.7498, 49.752, 49.7541, 49.7563,
    49.7584, 49.7606, 49.7628, 49.7649, 49.7671, 49.7692, 49.7714,
    49.7735, 49.7757, 49.7778, 49.7799, 49.7821, 49.7842, 49.7863,
    49.7885, 49.7906, 49.7927, 49.7948, 49.797, 49.7991, 49.8012,
    49.8033, 49.8054, 49.8075, 49.8096, 49.8117, 49.8138, 49.8159,
    49.818, 49.8201, 49.8222, 49.8243, 49.8264, 49.8285, 49.8305,
    49.8326, 49.8347, 49.8368, 49.8389, 49.8409, 49.843, 49.8451,
    49.8471, 49.8492, 49.8512, 49.8533, 49.8554, 49.8574, 49.8595,
    49.8615, 49.8635, 49.8656, 49.8676, 49.8697, 49.8717, 49.8737,
    49.8758, 49.8778, 49.8798, 49.8819, 49.8839, 49.8859, 49.8879,
    49.8899, 49.8919, 49.894, 49.896, 49.898, 49.9, 49.902, 49.904,
    49.906, 49.908, 49.91, 49.912, 49.914, 49.916, 49.9179, 49.9199,
    49.9219, 49.9239, 49.9259, 49.9278, 49.9298, 49.9318, 49.9338,
    49.9357, 49.9377, 49.9397, 49.9416, 49.9436, 49.9455, 49.9475,
    49.9494, 49.9514, 49.9533, 49.9553, 49.9572, 49.9592, 49.9611,
    49.963, 49.965, 49.9669, 49.9688, 49.9708, 49.9727, 49.9746,
    49.9765, 49.9785, 49.9804, 49.9823, 49.9842, 49.9861, 49.988,
    49.99, 49.9919, 49.9938, 49.9957, 49.9976, 49.9995, 50.0014,
    50.0033, 50.0051, 50.007, 50.0089, 50.0108, 50.0127, 50.0146,
    50.0165, 50.0183, 50.0202, 50.0221, 50.024, 50.0258, 50.0277,
    50.0296, 50.0314, 50.0333, 50.0351, 50.037, 50.0389, 50.0407,
    50.0426, 50.0444, 50.0463, 50.0481, 50.05, 50.0518, 50.0536,
    50.0555, 50.0573, 50.0591, 50.061, 50.0628, 50.0646, 50.0665,
    50.0683, 50.0701, 50.0719, 50.0737, 50.0756, 50.0774, 50.0792,
    50.081, 50.0828, 50.0846, 50.0864, 50.0882, 50.09, 50.0918,
    50.0936, 50.0954, 50.0972, 50.099, 50.1008, 50.1026, 50.1044,
    50.1062, 50.1079, 50.1097, 50.1115, 50.1133, 50.115, 50.1168,
    50.1186, 50.1204, 50.1221, 50.1239, 50.1257, 50.1274, 50.1292,
    50.1309, 50.1327, 50.1345, 50.1362, 50.138, 50.1397, 50.1415,
    50.1432, 50.1449, 50.1467, 50.1484, 50.1502, 50.1519, 50.1536,
    50.1554, 50.1571, 50.1588, 50.1606, 50.1623, 50.164, 50.1657,
    50.1674, 50.1692, 50.1709, 50.1726, 50.1743, 50.176, 50.1777,
    50.1794, 50.1811, 50.1828, 50.1845, 50.1862, 50.1879, 50.1896,
    50.1913, 50.193, 50.1947, 50.1964, 50.1981, 50.1998, 50.2015,
    50.2032, 50.2048, 50.2065, 50.2082, 50.2099, 50.2115, 50.2132,
    50.2149, 50.2166, 50.2182, 50.2199, 50.2216, 50.2232, 50.2249,
    50.2265, 50.2282, 50.2299, 50.2315, 50.2332, 50.2348, 50.2365,
    50.2381, 50.2398, 50.2414, 50.2431, 50.2447, 50.2463, 50.248,
    50.2496, 50.2512, 50.2529, 50.2545, 50.2561, 50.2578, 50.2594,
    50.261, 50.2627, 50.2643, 50.2659, 50.2675, 50.2691, 50.2707,
    50.2724, 50.274, 50.2756, 50.2772, 50.2788, 50.2804, 50.282,
    50.2836, 50.2852, 50.2868, 50.2884, 50.29, 50.2916, 50.2932,
    50.2948, 50.2964, 50.298, 50.2996, 50.3012, 50.3028, 50.3043,
    50.3059, 50.3075, 50.3091, 50.3107, 50.3122, 50.3138, 50.3154,
    50.317, 50.3185, 50.3201, 50.3217, 50.3232, 50.3248, 50.3264,
    50.3279, 50.3295, 50.3311, 50.3326, 50.3342, 50.3357, 50.3373,
    50.3388, 50.3404, 50.3419, 50.3435, 50.345, 50.3466, 50.3481,
    50.3497, 50.3512, 50.3527, 50.3543, 50.3558, 50.3573, 50.3589,
    50.3604, 50.3619, 50.3635, 50.365, 50.3665, 50.3681, 50.3696,
    50.3711, 50.3726, 50.3741, 50.3757, 50.3772, 50.3787, 50.3802,
    50.3817, 50.3832, 50.3848, 50.3863, 50.3878, 50.3893, 50.3908,
    50.3923, 50.3938, 50.3953, 50.3968, 50.3983, 50.3998, 50.4013,
    50.4028, 50.4043, 50.4058, 50.4073, 50.4088, 50.4102, 50.4117,
    50.4132, 50.4147, 50.4162, 50.4177, 50.4192, 50.4206, 50.4221,
    50.4236, 50.4251, 50.4265, 50.428, 50.4295, 50.431, 50.4324,
    50.4339, 50.4354, 50.4368, 50.4383, 50.4398, 50.4412, 50.4427,
    50.4442, 50.4456, 50.4471, 50.4485, 50.45, 50.4514, 50.4529,
    50.4543, 50.4558, 50.4573, 50.4587, 50.4601, 50.4616, 50.463,
    50.4645, 50.4659, 50.4674, 50.4688, 50.4702, 50.4717, 50.4731,
    50.4746, 50.476, 50.4774, 50.4789, 50.4803, 50.4817, 50.4832,
    50.4846, 50.486, 50.4874, 50.4889, 50.4903, 50.4917, 50.4931,
    50.4945, 50.496, 50.4974, 50.4988, 50.5002, 50.5016, 50.503,
    50.5045, 50.5059, 50.5073, 50.5087, 50.5101, 50.5115, 50.5129,
    50.5143, 50.5157, 50.5171, 50.5185, 50.5199, 50.5213, 50.5227,
    50.5241, 50.5255, 50.5269, 50.5283, 50.5297, 50.5311, 50.5325,
    50.5339, 50.5353, 50.5367, 50.5381, 50.5395, 50.5408, 50.5422,
    50.5436, 50.545, 50.5464, 50.5478, 50.5491, 50.5505, 50.5519,
    50.5533, 50.5547, 50.556, 50.5574, 50.5588, 50.5602, 50.5615,
    50.5629, 50.5643, 50.5656, 50.567, 50.5684, 50.5697, 50.5711,
    50.5725, 50.5738, 50.5752, 50.5766, 50.5779, 50.5793, 50.5807,
    50.582, 50.5834, 50.5847, 50.5861, 50.5874, 50.5888, 50.5901,
    50.5915, 50.5929, 50.5942, 50.5956, 50.5969, 50.5983, 50.5996,
    50.601, 50.6023, 50.6036, 50.605, 50.6063, 50.6077, 50.609,
    50.6104, 50.6117, 50.613, 50.6144, 50.6157, 50.6171, 50.6184,
    50.6197, 50.6211, 50.6224, 50.6237, 50.6251, 50.6264, 50.6277,
    50.6291, 50.6304, 50.6317, 50.6331, 50.6344, 50.6357, 50.637,
    50.6384, 50.6397, 50.641, 50.6423, 50.6437, 50.645, 50.6463,
    50.6476, 50.649, 50.6503, 50.6516, 50.6529, 50.6542, 50.6555,
    50.6569, 50.6582, 50.6595, 50.6608, 50.6621, 50.6634, 50.6647,
    50.6661, 50.6674, 50.6687, 50.67, 50.6713, 50.6726, 50.6739,
    50.6752, 50.6765, 50.6778, 50.6791, 50.6804, 50.6817, 50.683,
    50.6843, 50.6856, 50.6869, 50.6882, 50.6895, 50.6908, 50.6921,
    50.6934, 50.6947, 50.696, 50.6973, 50.6986, 50.6999, 50.7012,
    50.7025, 50.7038, 50.7051, 50.7064, 50.7077, 50.709, 50.7102,
    50.7115, 50.7128, 50.7141, 50.7154, 50.7167, 50.718, 50.7193,
    50.7205, 50.7218, 50.7231, 50.7244, 50.7257, 50.7269, 50.7282,
    50.7295, 50.7308, 50.7321, 50.7333, 50.7346, 50.7359, 50.7372,
    50.7384, 50.7397, 50.741, 50.7423, 50.7435, 50.7448, 50.7461,
    50.7474, 50.7486, 50.7499, 50.7512, 50.7524, 50.7537, 50.755,
    50.7562, 50.7575, 50.7588, 50.76, 50.7613, 50.7626, 50.7638,
    50.7651, 50.7664, 50.7676, 50.7689, 50.7701, 50.7714, 50.7727,
    50.7739, 50.7752, 33.8787, 33.975, 34.0714, 34.1677, 34.264,
    34.3603, 34.4566, 34.5529, 34.6493, 34.7456, 34.8419, 34.9382,
    35.0345, 35.1309, 35.2272, 35.3211, 35.413, 35.5028, 35.5906,
    35.6766, 35.7607, 35.843, 35.9237, 36.0028, 36.0803, 36.1563,
    36.2309, 36.3042, 36.3761, 36.4468, 36.5163, 36.5846, 36.6519,
    36.718, 36.7831, 36.8472, 36.9104, 36.9726, 37.034, 37.0945,
    37.1541, 37.213, 37.2711, 37.3284, 37.3851, 37.4411, 37.4964,
    37.551, 37.605, 37.6584, 37.7112, 37.7635, 37.8152, 37.8663,
    37.9169, 37.9671, 38.0167, 38.0658, 38.1145, 38.1628, 38.2106,
    38.258, 38.305, 38.3516, 38.3978, 38.4437, 38.4891, 38.5342,
    38.5789, 38.6233, 38.6673, 38.711, 38.7543, 38.7973, 38.84,
    38.8823, 38.9244, 38.9661, 39.0075, 39.0487, 39.0895, 39.1301,
    39.1704, 39.2104, 39.2501, 39.2896, 39.3288, 39.3677, 39.4064,
    39.4448, 39.483, 39.521, 39.5587, 39.5962, 39.6335, 39.6705,
    39.7073, 39.7438, 39.7802, 39.8163, 39.8522, 39.8879, 39.9233,
    39.9586, 39.9936, 40.0284, 40.063, 40.0974, 40.1316, 40.1656,
    40.1994, 40.233, 40.2664, 40.2995, 40.3325, 40.3653, 40.3979,
    40.4303, 40.4625, 40.4946, 40.5264, 40.5581, 40.5895, 40.6208,
    40.6519, 40.6829, 40.7136, 40.7442, 40.7746, 40.8048, 40.8348,
    40.8647, 40.8944, 40.9239, 40.9533, 40.9824, 41.0115, 41.0403,
    41.069, 41.0975, 41.1259, 41.1541, 41.1821, 41.21, 41.2378,
    41.2653, 41.2927, 41.32, 41.3471, 41.3741, 41.4009, 41.4275,
    41.454, 41.4804, 41.5066, 41.5327, 41.5586, 41.5844, 41.61,
    41.6355, 41.6609, 41.6861, 41.7112, 41.7362, 41.761, 41.7857,
    41.8102, 41.8346, 41.8589, 41.8831, 41.9071, 41.931, 41.9548,
    41.9784, 42.0019, 42.0253, 42.0485, 42.0717, 42.0947, 42.1176,
    42.1403, 42.163, 42.1855, 42.2079, 42.2302, 42.2523, 42.2744,
    42.2963, 42.3181, 42.3398, 42.3614, 42.3829, 42.4042, 42.4255,
    42.4466, 42.4676, 42.4885, 42.5093, 42.53, 42.5506, 42.5711,
    42.5915, 42.6117, 42.6319, 42.6519, 42.6719, 42.6917, 42.7115,
    42.7311, 42.7507, 42.7701, 42.7894, 42.8087, 42.8278, 42.8469,
    42.8658, 42.8846, 42.9034, 42.922, 42.9406, 42.9591, 42.9774,
    42.9957, 43.0139, 43.032, 43.05, 43.0679, 43.0857, 43.1034,
    43.1211, 43.1386, 43.1561, 43.1734, 43.1907, 43.2079, 43.225,
    43.2421, 43.259, 43.2759, 43.2926, 43.3093, 43.3259, 43.3424,
    43.3589, 43.3753, 43.3915, 43.4077, 43.4239, 43.4399, 43.4559,
    43.4717, 43.4876, 43.5033, 43.5189, 43.5345, 43.55, 43.5654,
    43.5808, 43.5961, 43.6113, 43.6264, 43.6415, 43.6564, 43.6714,
    43.6862, 43.701, 43.7157, 43.7303, 43.7449, 43.7594, 43.7738,
    43.7882, 43.8025, 43.8167, 43.8309, 43.845, 43.859, 43.873,
    43.8869, 43.9007, 43.9145, 43.9282, 43.9419, 43.9555, 43.969,
    43.9824, 43.9959, 44.0092, 44.0225, 44.0357, 44.0489, 44.062,
    44.0751, 44.088, 44.101, 44.1139, 44.1267, 44.1395, 44.1522,
    44.1648, 44.1774, 44.19, 44.2025, 44.2149, 44.2273, 44.2396,
    44.2519, 44.2641, 44.2763, 44.2884, 44.3005, 44.3125, 44.3245,
    44.3364, 44.3483, 44.3601, 44.3719, 44.3836, 44.3952, 44.4069,
    44.4184, 44.43, 44.4414, 44.4529, 44.4643, 44.4756, 44.4869,
    44.4981, 44.5093, 44.5205, 44.5316, 44.5427, 44.5537, 44.5646,
    44.5756, 44.5865, 44.5973, 44.6081, 44.6189, 44.6296, 44.6402,
    44.6509, 44.6615, 44.672, 44.6825, 44.693, 44.7034, 44.7138,
    44.7241, 44.7344, 44.7447, 44.7549, 44.7651, 44.7752, 44.7853,
    44.7954, 44.8054, 44.8154, 44.8254, 44.8353, 44.8452, 44.855,
    44.8648, 44.8746, 44.8844, 44.894, 44.9037, 44.9133, 44.9229,
    44.9325, 44.942, 44.9515, 44.9609, 44.9704, 44.9797, 44.9891,
    44.9984, 45.0077, 45.0169, 45.0262, 45.0353, 45.0445, 45.0536,
    45.0627, 45.0717, 45.0808, 45.0897, 45.0987, 45.1076, 45.1165,
    45.1254, 45.1342, 45.143, 45.1518, 45.1605, 45.1692, 45.1779,
    45.1866, 45.1952, 45.2038, 45.2124, 45.2209, 45.2294, 45.2379,
    45.2463, 45.2548, 45.2632, 45.2715, 45.2799, 45.2882, 45.2965,
    45.3047, 45.313, 45.3212, 45.3294, 45.3375, 45.3456, 45.3537,
    45.3618, 45.3699, 45.3779, 45.3859, 45.3939, 45.4018, 45.4097,
    45.4176, 45.4255, 45.4334, 45.4412, 45.449, 45.4568, 45.4645,
    45.4722, 45.48, 45.4876, 45.4953, 45.5029, 45.5105, 45.5181,
    45.5257, 45.5332, 45.5408, 45.5483, 45.5558, 45.5632, 45.5706,
    45.5781, 45.5854, 45.5928, 45.6002, 45.6075, 45.6148, 45.6221,
    45.6293, 45.6366, 45.6438, 45.651, 45.6582, 45.6654, 45.6725,
    45.6796, 45.6867, 45.6938, 45.7009, 45.7079, 45.715, 45.722,
    45.729, 45.7359, 45.7429, 45.7498, 45.7567, 45.7636, 45.7705,
    45.7774, 45.7842, 45.791, 45.7978, 45.8046, 45.8114, 45.8182,
    45.8249, 45.8316, 45.8383, 45.845, 45.8517, 45.8583, 45.865,
    45.8716, 45.8782, 45.8848, 45.8914, 45.8979, 45.9045, 45.911,
    45.9175, 45.924, 45.9305, 45.937, 45.9434, 45.9499, 45.9563,
    45.9627, 45.9691, 45.9755, 45.9818, 45.9882, 45.9945, 46.0008,
    46.0071, 46.0134, 46.0197, 46.026, 46.0322, 46.0385, 46.0447,
    46.0509, 46.0571, 46.0633, 46.0694, 46.0756, 46.0818, 46.0879,
    46.094, 46.1001, 46.1062, 46.1123, 46.1184, 46.1244, 46.1305,
    46.1365, 46.1425, 46.1485, 46.1545, 46.1605, 46.1665, 46.1725,
    46.1784, 46.1843, 46.1903, 46.1962, 46.2021, 46.208, 46.2139,
    46.2197, 46.2256, 46.2315, 46.2373, 46.2431, 46.249, 46.2548,
    46.2606, 46.2663, 46.2721, 46.2779, 46.2837, 46.2894, 46.2951,
    46.3009, 46.3066, 46.3123, 46.318, 46.3237, 46.3294, 46.335,
    46.3407, 46.3463, 46.352, 46.3576, 46.3632, 46.3689, 46.3745,
    46.3801, 46.3857, 46.3912, 46.3968, 46.4024, 46.4079, 46.4135,
    46.419, 46.4245, 46.4301, 46.4356, 46.4411, 46.4466, 46.4521,
    46.4575, 46.463, 46.4685, 46.4739, 46.4794, 46.4848, 46.4902,
    46.4957, 46.5011, 46.5065, 46.5119, 46.5173, 46.5227, 46.528,
    46.5334, 46.5388, 46.5441, 46.5495, 46.5548, 46.5601, 46.5655,
    46.5708, 46.5761, 46.5814, 46.5867, 46.592, 46.5973, 46.6026,
    46.6078, 46.6131, 46.6183, 46.6236, 46.6288, 46.6341, 46.6393,
    46.6445, 46.6497, 46.655, 46.6602, 46.6654, 46.6706, 46.6757,
    46.6809, 46.6861, 46.6913, 46.6964, 46.7016, 46.7067, 46.7119,
    46.717, 46.7221, 46.7273, 46.7324, 46.7375, 46.7426, 46.7477,
    46.7528, 46.7579, 46.763, 46.768, 46.7731, 46.7782, 46.7832,
    46.7883, 46.7933, 46.7984, 46.8034, 46.8084, 46.8135, 46.8185,
    46.8235, 46.8285, 46.8335, 46.8385, 46.8435, 46.8485, 46.8535,
    46.8584, 46.8634, 46.8684, 46.8733, 46.8783, 46.8832, 46.8882,
    46.8931, 46.8981, 46.903, 46.9079, 46.9128, 46.9177, 46.9227,
    46.9276, 46.9325, 46.9373, 46.9422, 46.9471, 46.952, 46.9569,
    46.9617, 46.9666, 46.9714, 46.9763, 46.9811, 46.986, 46.9908,
    46.9956, 47.0004, 47.0053, 47.0101, 47.0149, 47.0197, 47.0245,
    47.0293, 47.0341, 47.0388, 47.0436, 47.0484, 47.0532, 47.0579,
    47.0627, 47.0674, 47.0722, 47.0769, 47.0816, 47.0864, 47.0911,
    47.0958, 47.1005, 47.1052, 47.1099, 47.1146, 47.1193, 47.124,
    47.1287, 47.1334, 47.138, 47.1427, 47.1474, 47.152, 47.1567,
    47.1613, 47.166, 47.1706, 47.1752, 47.1799, 47.1845, 47.1891,
    47.1937, 47.1983, 47.2029, 47.2075, 47.2121, 47.2167, 47.2213,
    47.2258, 47.2304, 47.235, 47.2395, 47.2441, 47.2486, 47.2532,
    47.2577, 47.2622, 47.2668, 47.2713, 47.2758, 47.2803, 47.2848,
    47.2893, 47.2938, 47.2983, 47.3028, 47.3073, 47.3117, 47.3162,
    47.3207, 47.3251, 47.3296, 47.334, 47.3385, 47.3429, 47.3473,
    47.3517, 47.3562, 47.3606, 47.365, 47.3694, 47.3738, 47.3782,
    47.3826, 47.387, 47.3913, 47.3957, 47.4001, 47.4044, 47.4088,
    47.4131, 47.4175, 47.4218, 47.4261, 47.4305, 47.4348, 47.4391,
    47.4434, 47.4477, 47.452, 47.4563, 47.4606, 47.4649, 47.4692,
    47.4734, 47.4777, 47.482, 47.4862, 47.4905, 47.4947, 47.4989,
    47.5032, 47.5074, 47.5116, 47.5158, 47.52, 47.5242, 47.5284,
    47.5326, 47.5368, 47.541, 47.5452, 47.5493, 47.5535, 47.5577,
    47.5618, 47.566, 47.5701, 47.5742, 47.5784, 47.5825, 47.5866,
    47.5907, 47.5948, 47.5989, 47.603, 47.6071, 47.6112, 47.6153,
    47.6193, 47.6234, 47.6275, 47.6315, 47.6356, 47.6396, 47.6436,
    47.6477, 47.6517, 47.6557, 47.6597, 47.6637, 47.6677, 47.6717,
    47.6757, 47.6797, 47.6837, 47.6877, 47.6916, 47.6956, 47.6995,
    47.7035, 47.7074, 47.7114, 47.7153, 47.7192, 47.7232, 47.7271,
    47.731, 47.7349, 47.7388, 47.7427, 47.7466, 47.7504, 47.7543,
    47.7582, 47.762, 47.7659, 47.7698, 47.7736, 47.7774, 47.7813,
    47.7851, 47.7889, 47.7927, 47.7966, 47.8004, 47.8042, 47.808,
    47.8117, 47.8155, 47.8193, 47.8231, 47.8268, 47.8306, 47.8344,
    47.8381, 47.8418, 47.8456, 47.8493, 47.853, 47.8568, 47.8605,
    47.8642, 47.8679, 47.8716, 47.8753, 47.879, 47.8826, 47.8863,
    47.89, 47.8936, 47.8973, 47.9009, 47.9046, 47.9082, 47.9119,
    47.9155, 47.9191, 47.9227, 47.9264, 47.93, 47.9336, 47.9372,
    47.9407, 47.9443, 47.9479, 47.9515, 47.9551, 47.9586, 47.9622,
    47.9657, 47.9693, 47.9728, 47.9764, 47.9799, 47.9834, 47.9869,
    47.9904, 47.9939, 47.9975, 48.0009, 48.0044, 48.0079, 48.0114,
    48.0149, 48.0184, 48.0218, 48.0253, 48.0287, 48.0322, 48.0356,
    48.0391, 48.0425, 48.0459, 48.0494, 48.0528, 48.0562, 48.0596,
    48.063, 48.0664, 48.0698, 48.0732, 48.0766, 48.08, 48.0833,
    48.0867, 48.0901, 48.0934, 48.0968, 48.1001, 48.1035, 48.1068,
    48.1101, 48.1135, 48.1168, 48.1201, 48.1234, 48.1267, 48.13,
    48.1333, 48.1366, 48.1399, 48.1432, 48.1465, 48.1497, 48.153,
    48.1563, 48.1595, 48.1628, 48.166, 48.1693, 48.1725, 48.1757,
    48.179, 48.1822, 48.1854, 48.1886, 48.1919, 48.1951, 48.1983,
    48.2015, 48.2047, 48.2078, 48.211, 48.2142, 48.2174, 48.2205,
    48.2237, 48.2269, 48.23, 48.2332, 48.2363, 48.2395, 48.2426,
    48.2457, 48.2489, 48.252, 48.2551, 48.2582, 48.2613, 48.2644,
    48.2676, 48.2706, 48.2737, 48.2768, 48.2799, 48.283, 48.2861,
    48.2891, 48.2922, 48.2953, 48.2983, 48.3014, 48.3044, 48.3075,
    48.3105, 48.3136, 48.3166, 48.3196, 48.3226, 48.3257, 48.3287,
    48.3317, 48.3347, 48.3377, 48.3407, 48.3437, 48.3467, 48.3497,
    48.3527, 48.3556, 48.3586, 48.3616, 48.3645, 48.3675, 48.3705,
    48.3734, 48.3764, 48.3793, 48.3823, 48.3852, 48.3881, 48.3911,
    48.394, 48.3969, 48.3998, 48.4027, 48.4056, 48.4085, 48.4114,
    48.4143, 48.4172, 48.4201, 48.423, 48.4259, 48.4288, 48.4317,
    48.4345, 48.4374, 48.4403, 48.4431, 48.446, 48.4488, 48.4517,
    48.4545, 48.4574, 48.4602, 48.463, 48.4659, 48.4687, 48.4715,
    48.4743, 48.4771, 48.4799, 48.4828, 48.4856, 48.4884, 48.4912,
    48.4939, 48.4967, 48.4995, 48.5023, 48.5051, 48.5079, 48.5106,
    48.5134, 48.5162, 48.5189, 48.5217, 48.5244, 48.5272, 48.5299,
    48.5327, 48.5354, 48.5381, 48.5409, 48.5436, 48.5463, 48.5491,
    48.5518, 48.5545, 48.5572, 48.5599, 48.5626, 48.5653, 48.568,
    48.5707, 48.5734, 48.5761, 48.5788, 48.5814, 48.5841, 48.5868,
    48.5895, 48.5921, 48.5948, 48.5974, 48.6001, 48.6028, 48.6054,
    48.6081, 48.6107, 48.6133, 48.616, 48.6186, 48.6212, 48.6239,
    48.6265, 48.6291, 48.6317, 48.6343, 48.637, 48.6396, 48.6422,
    48.6448, 48.6474, 48.65, 48.6525, 48.6551, 48.6577, 48.6603,
    48.6629, 48.6655, 48.668, 48.6706, 48.6732, 48.6757, 48.6783,
    48.6808, 48.6834, 48.686, 48.6885, 48.691, 48.6936, 48.6961,
    48.6987, 48.7012, 48.7037, 48.7062, 48.7088, 48.7113, 48.7138,
    48.7163, 48.7188, 48.7213, 48.7238, 48.7263, 48.7288, 48.7313,
    48.7338, 48.7363, 48.7388, 48.7413, 48.7438, 48.7463, 48.7487,
    48.7512, 48.7537, 48.7561, 48.7586, 48.7611, 48.7635, 48.766,
    48.7684, 48.7709, 48.7733, 48.7758, 48.7782, 48.7806, 48.7831,
    48.7855, 48.7879, 48.7903, 48.7928, 48.7952, 48.7976, 48.8,
    48.8024, 48.8048, 48.8072, 48.8096, 48.812, 48.8144, 48.8168,
    48.8192, 48.8216, 48.824, 48.8264, 48.8288, 48.8311, 48.8335,
    48.8359, 48.8382, 48.8406, 48.843, 48.8453, 48.8477, 48.85,
    48.8524, 48.8547, 48.8571, 48.8594, 48.8618, 48.8641, 48.8664,
    48.8688, 48.8711, 48.8734, 48.8757, 48.8781, 48.8804, 48.8827,
    48.885, 48.8873, 48.8896, 48.8919, 48.8942, 48.8965, 48.8988,
    48.9011, 48.9034, 48.9057, 48.908, 48.9103, 48.9126, 48.9148,
    48.9171, 48.9194, 48.9217, 48.9239, 48.9262, 48.9284, 48.9307,
    48.933, 48.9352, 48.9375, 48.9397, 48.942, 48.9442, 48.9465,
    48.9487, 48.9509, 48.9532, 48.9554, 48.9576, 48.9598, 48.9621,
    48.9643, 48.9665, 48.9687, 48.9709, 48.9732, 48.9754, 48.9776,
    48.9798, 48.982, 48.9842, 48.9864, 48.9886, 48.9908, 48.9929,
    48.9951, 48.9973, 48.9995, 49.0017, 49.0039, 49.006, 49.0082,
    49.0104, 49.0125, 49.0147, 49.0169, 49.019, 49.0212, 49.0233,
    49.0255, 49.0276, 49.0298, 49.0319, 49.0341, 49.0362, 49.0384,
    49.0405, 49.0426, 49.0448, 49.0469, 49.049, 49.0511, 49.0533,
    49.0554, 49.0575, 49.0596, 49.0617, 49.0638, 49.066, 49.0681,
    49.0702, 49.0723, 49.0744, 49.0765, 49.0786, 49.0807, 49.0828,
    49.0848, 49.0869, 49.089, 49.0911, 49.0932, 49.0953, 49.0973,
    49.0994, 49.1015, 49.1035, 49.1056, 49.1077, 49.1097, 49.1118,
    49.1139, 49.1159, 49.118, 49.12, 49.1221, 49.1241, 49.1262,
    49.1282, 49.1303, 49.1323, 49.1343, 49.1364, 49.1384, 49.1404,
    49.1425, 49.1445, 49.1465, 49.1485, 49.1506, 49.1526, 49.1546,
    49.1566, 49.1586, 49.1607, 49.1627, 49.1647, 49.1667, 49.1687,
    49.1707, 49.1727, 49.1747, 49.1767, 49.1787, 49.1807, 49.1826,
    49.1846, 49.1866, 49.1886, 49.1906, 49.1926, 49.1945, 49.1965,
    49.1985, 49.2005, 49.2024, 49.2044, 49.2064, 49.2083, 49.2103,
    49.2123, 49.2142, 49.2162, 49.2181, 49.2201, 49.222, 49.224,
    49.2259, 49.2279, 49.2298, 49.2318, 49.2337, 49.2356, 49.2376,
    49.2395, 49.2414, 49.2434, 49.2453, 49.2472, 49.2492, 49.2511,
    49.253, 49.2549, 49.2568, 49.2588, 49.2607, 49.2626, 49.2645,
    49.2664, 49.2683, 49.2702, 49.2721, 49.274, 49.2759, 49.2778,
    49.2797, 49.2816, 49.2835, 49.2854, 49.2873, 49.2892, 49.2911,
    49.2929, 49.2948, 49.2967, 49.2986, 49.3005, 49.3023, 49.3042,
    49.3061, 49.308, 49.3098, 49.3117, 49.3136, 49.3154, 49.3173,
    49.3191, 49.321, 49.3229, 49.3247, 49.3266, 49.3284, 49.3303,
    49.3321, 49.334, 49.3358, 49.3377, 49.3395, 49.3414, 49.3432,
    49.345, 49.3469, 49.3487, 49.3505, 49.3524, 49.3542, 49.356,
    49.3579, 49.3597, 49.3615, 49.3633, 49.3652, 49.367, 49.3688,
    49.3706, 49.3724, 49.3742, 49.3761, 49.3779, 49.3797, 49.3815,
    49.3833, 49.3851, 49.3869, 49.3887, 49.3905, 49.3923, 49.3941,
    49.3959, 49.3977, 49.3995, 49.4013, 49.4031, 49.4048, 49.4066,
    49.4084, 49.4102, 49.412, 49.4138, 49.4155, 49.4173, 49.4191,
    49.4209, 49.4227, 49.4244, 49.4262, 49.428, 49.4297, 49.4315,
    49.4333, 49.435, 49.4368, 49.4386, 49.4403, 49.4421, 49.4438,
    49.4456, 49.4473, 49.4491, 49.4508, 49.4526, 49.4543, 49.4561,
    49.4578, 49.4596, 49.4613, 49.4631, 49.4648, 49.4666, 49.4683,
    49.47, 49.4718, 49.4735, 49.4752, 49.477, 49.4787, 49.4804,
    49.4821, 49.4839, 49.4856, 49.4873, 49.489, 49.4908, 49.4925,
    49.4942, 49.4959, 49.4976, 49.4993, 49.5011, 49.5028, 49.5045,
    49.5062, 49.5079, 49.5096, 49.5113, 49.513, 49.5147, 49.5164,
    49.5181, 49.5198, 49.5215, 49.5232, 49.5249, 49.5266, 49.5283,
    49.53, 49.5317, 49.5334, 49.5351, 49.5367, 49.5384, 49.5401,
    49.5418, 49.5435, 49.5452, 49.5468, 49.5485, 49.5502, 49.5519,
    49.5535, 49.5552, 49.5569, 49.5585, 49.5602, 49.5619, 49.5636,
    49.5652, 49.5669, 49.5685, 49.5702, 49.5719, 49.5735, 49.5752,
    49.5768, 49.5785, 49.5802, 49.5818, 49.5835, 49.5851, 49.5868,
    49.5884, 49.5901, 49.5917, 49.5933, 49.595, 49.5966, 49.5983,
    49.5999, 49.6015, 49.6032, 49.6048, 49.6065, 49.6081, 49.6097,
    49.6114, 49.613, 49.6146, 49.6162, 49.6179, 49.6195, 49.6211,
    49.6227, 49.6244, 49.626, 49.6276, 49.6292, 49.6308, 49.6325,
    49.6341, 49.6357, 49.6373, 49.6389, 49.6405, 49.6421, 49.6437,
    49.6454, 49.647, 49.6486, 49.6502, 49.6518, 49.6534, 49.655,
    49.6566, 49.6582, 49.6598, 49.6614, 49.663, 49.6646, 49.6661,
    49.6677, 49.6693, 49.6709, 49.6725, 49.6741, 49.6757, 49.6773,
    49.6788, 49.6804, 49.682, 49.6836, 49.6852, 49.6867, 49.6883,
    49.6899, 49.6915, 49.6931, 49.6946, 49.6962, 49.6978, 49.6993,
    49.7009, 49.7025, 49.704, 49.7056, 49.7072, 49.7087, 49.7103,
    49.7119, 49.7134, 49.715, 49.7165, 49.7181, 49.7196, 49.7212,
    49.7228, 49.7243, 49.7259, 49.7274, 49.729, 49.7305, 49.7321,
    49.7336, 49.7352, 49.7367, 49.7382, 49.7398, 49.7413, 49.7429,
    49.7444, 49.7459, 49.7475, 49.749, 49.7506, 49.7521, 49.7536,
    49.7552, 49.7567, 49.7582, 49.7597, 49.7613, 49.7628, 49.7643,
    49.7659, 49.7674, 49.7689, 49.7704, 49.7719, 49.7735, 49.775,
    49.7765, 49.778, 49.7795, 49.7811, 49.7826, 49.7841, 49.7856,
    49.7871, 49.7886, 49.7901, 49.7916, 49.7932, 49.7947, 49.7962,
    49.7977, 49.7992, 49.8007, 49.8022, 49.8037, 49.8052, 49.8067,
    49.8082, 49.8097, 49.8112, 49.8127, 49.8142, 49.8157, 49.8172,
    49.8187, 49.8201, 49.8216, 49.8231, 49.8246, 49.8261, 49.8276,
    49.8291, 49.8306, 49.8321, 49.8335, 49.835, 49.8365, 49.838,
    49.8395, 49.8409, 49.8424, 49.8439, 49.8454, 49.8469, 49.8483,
    49.8498, 49.8513, 49.8528, 49.8542, 49.8557, 49.8572, 49.8586,
    49.8601, 49.8616, 49.863, 49.8645, 49.866, 49.8674, 49.8689,
    49.8704, 49.8718, 49.8733, 49.8748, 49.8762, 49.8777, 49.8791,
    49.8806, 49.882, 49.8835, 49.885, 49.8864, 49.8879, 49.8893,
    49.8908, 49.8922, 49.8937, 49.8951, 49.8966, 49.898, 49.8995,
    49.9009, 49.9024, 49.9038, 49.9052, 49.9067, 49.9081, 49.9096,
    49.911, 49.9125, 49.9139, 49.9153, 49.9168, 49.9182, 49.9196,
    49.9211, 49.9225, 49.924, 49.9254, 49.9268, 49.9282, 49.9297,
    49.9311, 49.9325, 49.934, 49.9354, 49.9368, 49.9383, 49.9397,
    49.9411, 49.9425, 49.944, 49.9454, 49.9468, 49.9482, 49.9496,
    49.9511, 49.9525, 49.9539, 49.9553, 49.9567, 49.9582, 49.9596,
    49.961, 49.9624, 49.9638, 49.9652, 87.1303, 87.1587, 87.1871,
    87.2155, 87.2439, 87.2722, 87.3006, 87.3289, 87.3571, 87.3854,
    87.4136, 87.4419, 87.4701, 87.4982, 87.5264, 87.5545, 87.5826,
    87.6107, 87.6388, 87.6668, 87.6948, 87.7228, 87.7508, 87.7788,
    87.8067, 87.8346, 87.8625, 87.8903, 87.9181, 87.946, 87.9737,
    88.0015, 88.0292, 88.057, 88.0846, 88.1123, 88.14, 88.1676,
    88.1952, 88.2228, 88.2503, 88.2778, 88.3053, 88.3328, 88.3603,
    88.3877, 88.4151, 88.4425, 88.4699, 88.4972, 88.5245, 88.5518,
    88.5791, 88.6063, 88.6335, 88.6607, 88.6879, 88.715, 88.7422,
    88.7693, 88.7964, 88.8234, 88.8504, 88.8775, 88.9044, 88.9314,
    88.9584, 88.9853, 89.0122, 89.0391, 89.0659, 89.0927, 89.1195,
    89.1463, 89.1731, 89.1998, 89.2266, 89.2533, 89.2799, 89.3066,
    89.3332, 89.3598, 89.3864, 89.413, 89.4395, 89.466, 89.4925,
    89.519, 89.5455, 89.5719, 89.5983, 89.6247, 89.651, 89.6774,
    89.7037, 89.73, 89.7563, 89.7825, 89.8087, 89.8349, 89.8611,
    89.8873, 89.9134, 89.9395, 89.9656, 89.9917, 90.0177, 90.0437,
    90.0697, 90.0957, 90.1216, 90.1476, 90.1735, 90.1994, 90.2252,
    90.251, 90.2769, 90.3026, 90.3284, 90.3541, 90.3799, 90.4056,
    90.4312, 90.4569, 90.4825, 90.5081, 90.5337, 90.5592, 90.5848,
    90.6103, 90.6358, 90.6612, 90.6867, 90.7121, 90.7375, 90.7628,
    90.7882, 90.8135, 90.8388, 90.8641, 90.8893, 90.9146, 90.9398,
    90.965, 90.9901, 91.0153, 91.0404, 91.0655, 91.0905, 91.1156,
    91.1406, 91.1656, 91.1906, 91.2155, 91.2405, 91.2654, 91.2903,
    91.3151, 91.34, 91.3648, 91.3896, 91.4144, 91.4391, 91.4639,
    91.4886, 91.5133, 91.5379, 91.5626, 91.5872, 91.6118, 91.6364,
    91.6609, 91.6855, 91.71, 91.7345, 91.759, 91.7834, 91.8078,
    91.8323, 91.8566, 91.881, 91.9053, 91.9297, 91.954, 91.9783,
    92.0025, 92.0268, 92.051, 92.0752, 92.0993, 92.1235, 92.1476,
    92.1717, 92.1958, 92.2199, 92.244, 92.268, 92.292, 92.316,
    92.34, 92.3639, 92.3879, 92.4118, 92.4357, 92.4595, 92.4834,
    92.5072, 92.531, 92.5548, 92.5786, 92.6023, 92.6261, 92.6498,
    92.6735, 92.6971, 92.7208, 92.7444, 92.768, 92.7916, 92.8152,
    92.8388, 92.8623, 92.8858, 92.9093, 92.9328, 92.9562, 92.9797,
    93.0031, 93.0265, 93.0499, 93.0732, 93.0966, 93.1199, 93.1432,
    93.1665, 93.1898, 93.213, 93.2363, 93.2595, 93.2827, 93.3059,
    93.329, 93.3522, 93.3753, 93.3984, 93.4215, 93.4446, 93.4676,
    93.4906, 93.5137, 93.5367, 93.5596, 93.5826, 93.6056, 93.6285,
    93.6514, 93.6743, 93.6972, 93.7201, 93.7429, 93.7658, 93.7886,
    93.8114, 93.8342, 93.8569, 93.8797, 93.9024, 93.9252, 93.9479,
    93.9706, 93.9932, 94.0159, 94.0385, 94.0612, 94.0838, 94.1064,
    94.129, 94.1516, 94.1741, 94.1967, 94.2192, 94.2417, 94.2642,
    94.2867, 94.3092, 94.3317, 94.3541, 94.3765, 94.399, 94.4214,
    94.4438, 94.4662, 94.4885, 94.5109, 94.5332, 94.5556, 94.5779,
    94.6002, 94.6225, 94.6447, 94.667, 94.6893, 94.7115, 94.7337,
    94.7559, 94.7782, 94.8003, 94.8225, 94.8447, 94.8668, 94.889,
    94.9111, 94.9332, 94.9553, 94.9774, 94.9995, 95.0216, 95.0436,
    95.0657, 95.0877, 95.1097, 95.1317, 95.1537, 95.1757, 95.1977,
    95.2197, 95.2416, 95.2636, 95.2855, 95.3074, 95.3293, 95.3512,
    95.3731, 95.3949, 95.4168, 95.4386, 95.4605, 95.4823, 95.5041,
    95.5259, 95.5477, 95.5695, 95.5913, 95.613, 95.6348, 95.6565,
    95.6782, 95.6999, 95.7216, 95.7433, 95.765, 95.7867, 95.8083,
    95.83, 95.8516, 95.8732, 95.8948, 95.9165, 95.938, 95.9596,
    95.9812, 96.0028, 96.0243, 96.0459, 96.0674, 96.0889, 96.1104,
    96.1319, 96.1534, 96.1749, 96.1964, 96.2178, 96.2393, 96.2607,
    96.2821, 96.3035, 96.325, 96.3464, 96.3677, 96.3891, 96.4105,
    96.4318, 96.4532, 96.4745, 96.4958, 96.5172, 96.5385, 96.5598,
    96.581, 96.6023, 96.6236, 96.6448, 96.6661, 96.6873, 96.7085,
    96.7298, 96.751, 96.7722, 96.7933, 96.8145, 96.8357, 96.8568,
    96.878, 96.8991, 96.9203, 96.9414, 96.9625, 96.9836, 97.0047,
    97.0258, 97.0468, 97.0679, 97.0889, 97.11, 97.131, 97.1521,
    97.1731, 97.1941, 97.2151, 97.2361, 97.257, 97.278, 97.299,
    97.3199, 97.3409, 97.3618, 97.3827, 97.4036, 97.4245, 97.4454,
    97.4663, 97.4872, 97.5081, 97.5289, 97.5498, 97.5706, 97.5914,
    97.6123, 97.6331, 97.6539, 97.6747, 97.6954, 97.7162, 97.737,
    97.7577, 97.7785, 97.7992, 97.8199, 97.8406, 97.8614, 97.8821,
    97.9027, 97.9234, 97.9441, 97.9647, 97.9854, 98.006, 98.0267,
    98.0473, 98.0679, 98.0885, 98.1091, 98.1297, 98.1503, 98.1708,
    98.1914, 98.2119, 98.2325, 98.253, 98.2735, 98.294, 98.3145,
    98.335, 98.3555, 98.3759, 98.3964, 98.4169, 98.4373, 98.4577,
    98.4782, 98.4986, 98.519, 98.5394, 98.5598, 98.5801, 98.6005,
    98.6209, 98.6412, 98.6615, 98.6819, 98.7022, 98.7225, 98.7428,
    98.7631, 98.7834, 98.8036, 98.8239, 98.8442, 98.8644, 98.8846,
    98.9049, 98.9251, 98.9453, 98.9655, 98.9857, 99.0058, 99.026,
    99.0461, 99.0663, 99.0864, 99.1065, 99.1267, 99.1468, 99.1669,
    99.1869, 99.207, 99.2271, 99.2471, 99.2672, 99.2872, 99.3072,
    99.3272, 99.3472, 99.3672, 99.3872, 99.4072, 99.4272, 99.4471,
    99.4671, 99.487, 99.5069, 99.5268, 99.5467, 99.5666, 99.5865,
    99.6064, 99.6262, 99.6461, 99.666, 99.6858, 99.7056, 99.7254,
    99.7452, 99.765, 99.7848, 99.8046, 99.8244, 99.8441, 99.8639,
    99.8836, 99.9034, 99.9231, 99.9428, 99.9625, 99.9822, 100.0019,
    100.0216, 100.0412, 100.0609, 100.0805, 100.1002, 100.1198,
    100.1394, 100.1591, 100.1787, 100.1983, 100.2178, 100.2374,
    100.257, 100.2765, 100.2961, 100.3156, 100.3352, 100.3547,
    100.3742, 100.3937, 100.4132, 100.4327, 100.4522, 100.4717,
    100.4911, 100.5106, 100.53, 100.5495, 100.5689, 100.5883,
    100.6077, 100.6271, 100.6465, 100.6659, 100.6853, 100.7046,
    100.724, 100.7434, 100.7627, 100.782, 100.8013, 100.8207,
    100.84, 100.8593, 100.8786, 100.8978, 100.9171, 100.9364,
    100.9556, 100.9749, 100.9941, 101.0134, 101.0326, 101.0518,
    101.071, 101.0902, 101.1094, 101.1286, 101.1477, 101.1669,
    101.1861, 101.2052, 101.2244, 101.2435, 101.2626, 101.2817,
    101.3008, 101.32, 101.339, 101.3581, 101.3772, 101.3963,
    101.4153, 101.4344, 101.4535, 101.4725, 101.4915, 101.5106,
    101.5296, 101.5486, 101.5676, 101.5866, 101.6056, 101.6246,
    101.6435, 101.6625, 101.6815, 101.7004, 101.7194, 101.7383,
    101.7572, 101.7762, 101.7951, 101.814, 101.8329, 101.8518,
    101.8707, 101.8896, 101.9085, 101.9274, 101.9462, 101.9651,
    101.9839, 102.0028, 102.0216, 102.0405, 102.0593, 102.0781,
    102.097, 102.1158, 102.1346, 102.1534, 102.1722, 102.191,
    102.2097, 102.2285, 102.2473, 102.2661, 102.2848, 102.3036,
    102.3223, 102.3411, 102.3598, 102.3785, 102.3972, 102.416,
    102.4347, 102.4534, 102.4721, 102.4908, 102.5095, 102.5282,
    102.5469, 102.5655, 102.5842, 102.6029, 102.6215, 102.6402,
    102.6588, 102.6775, 102.6961, 102.7148, 102.7334, 102.752,
    102.7706, 102.7893, 102.8079, 102.8265, 102.8451, 102.8637,
    102.8823, 102.9009, 102.9195, 102.938, 102.9566, 102.9752,
    102.9938, 103.0123, 103.0309, 103.0494, 103.068, 103.0865,
    103.1051, 103.1236, 103.1421, 103.1607, 103.1792, 103.1977,
    103.2162, 103.2348, 103.2533, 103.2718, 103.2903, 103.3088,
    103.3273, 103.3458, 103.3643, 103.3827, 103.4012, 103.4197,
    103.4382, 103.4566, 103.4751, 103.4936, 103.512, 103.5305,
    103.5489, 103.5674, 103.5858, 103.6043, 103.6227, 103.6412,
    103.6596, 103.678, 103.6965, 103.7149, 103.7333, 103.7517,
    103.7701, 103.7885, 103.807, 103.8254, 103.8438, 103.8622,
    103.8806, 103.899, 103.9174, 103.9357, 103.9541, 103.9725,
    103.9909, 104.0093, 104.0277, 104.046, 104.0644, 104.0828,
    104.1011, 104.1195, 104.1379, 104.1562, 104.1746, 104.1929,
    104.2113, 104.2296, 104.248, 104.2663, 104.2847, 104.303,
    104.3213, 104.3397, 104.358, 104.3763, 104.3947, 104.413,
    104.4313, 104.4496, 104.4679, 104.4863, 104.5046, 104.5229,
    104.5412, 104.5595, 104.5778, 104.5961, 104.6144, 104.6327,
    104.651, 104.6693, 104.6876, 104.7059, 104.7242, 104.7425,
    104.7608, 104.7791, 104.7974, 104.8157, 104.8339, 104.8522,
    104.8705, 104.8888, 104.9071, 104.9253, 104.9436, 104.9619,
    104.9802, 104.9984, 105.0167, 105.035, 105.0532, 105.0715,
    105.0898, 105.108, 105.1263, 105.1445, 105.1628, 105.1811,
    105.1993, 105.2176, 105.2358, 105.2541, 105.2723, 105.2906,
    105.3088, 105.3271, 105.3453, 105.3635, 105.3818, 105.4,
    105.4183, 105.4365, 105.4547, 105.473, 105.4912, 105.5094,
    105.5277, 105.5459, 105.5641, 105.5824, 105.6006, 105.6188,
    105.637, 105.6553, 105.6735, 105.6917, 105.7099, 105.7281,
    105.7463, 105.7646, 105.7828, 105.801, 105.8192, 105.8374,
    105.8556, 105.8738, 105.892, 105.9102, 105.9284, 105.9466,
    105.9648, 105.983, 106.0012, 106.0194, 106.0376, 106.0558,
    106.074, 106.0922, 106.1104, 106.1286, 106.1467, 106.1649,
    106.1831, 106.2013, 106.2195, 106.2377, 106.2558, 106.274,
    106.2922, 106.3104, 106.3285, 106.3467, 106.3649, 106.3831,
    106.4012, 106.4194, 106.4376, 106.4557, 106.4739, 106.4921,
    106.5102, 106.5284, 106.5465, 106.5647, 106.5829, 106.601,
    106.6192, 106.6373, 106.6555, 106.6736, 106.6918, 106.7099,
    106.7281, 106.7462, 106.7644, 106.7825, 106.8006, 106.8188,
    106.8369, 106.8551, 106.8732, 106.8913, 106.9095, 106.9276,
    106.9457, 106.9639, 106.982, 107.0001, 107.0183, 107.0364,
    107.0545, 107.0727, 107.0908, 107.1089, 107.127, 107.1452,
    107.1633, 107.1814, 107.1995, 107.2176, 107.2358, 107.2539,
    107.272, 107.2901, 107.3082, 107.3263, 107.3444, 107.3625,
    107.3806, 107.3988, 107.4169, 107.435, 107.4531, 107.4712,
    107.4893, 107.5074, 107.5255, 107.5436, 107.5617, 107.5798,
    107.5979, 107.616, 107.6341, 107.6522, 107.6702, 107.6883,
    107.7064, 107.7245, 107.7426, 107.7607, 107.7788, 107.7969,
    107.8149, 107.833, 107.8511, 107.8692, 107.8873, 107.9053,
    107.9234, 107.9415, 107.9596, 107.9777, 107.9957, 108.0138,
    108.0319, 108.0499, 108.068, 108.0861, 108.1041, 108.1222,
    108.1403, 108.1583, 108.1764, 108.1945, 108.2125, 108.2306,
    108.2487, 108.2667, 108.2848, 108.3028, 108.3209, 108.3389,
    108.357, 108.375, 108.3931, 108.4112, 108.4292, 108.4473,
    108.4653, 108.4833, 108.5014, 108.5194, 108.5375, 108.5555,
    108.5736, 108.5916, 108.6097, 108.6277, 108.6457, 108.6638,
    108.6818, 108.6998, 108.7179, 108.7359, 108.7539, 108.772,
    108.79, 108.808, 108.8261, 108.8441, 108.8621, 108.8801,
    108.8982, 108.9162, 108.9342, 108.9522, 108.9702, 108.9883,
    109.0063, 109.0243, 109.0423, 109.0603, 109.0783, 109.0963,
    109.1144, 109.1324, 109.1504, 109.1684, 109.1864, 109.2044,
    109.2224, 109.2404, 109.2584, 109.2764, 109.2944, 109.3124,
    109.3304, 109.3484, 109.3664, 109.3843, 109.4023, 109.4203,
    109.4383, 109.4563, 109.4743, 109.4923, 109.5102, 109.5282,
    109.5462, 109.5642, 109.5822, 109.6001, 109.6181, 109.6361,
    109.654, 109.672, 109.69, 109.7079, 109.7259, 109.7439, 109.7618,
    109.7798, 109.7978, 109.8157, 109.8337, 109.8516, 109.8696,
    109.8875, 109.9055, 109.9234, 109.9414, 109.9593, 109.9773,
    109.9952, 110.0131, 110.0311, 110.049, 110.0669, 110.0849,
    110.1028, 110.1207, 110.1387, 110.1566, 110.1745, 110.1924,
    110.2104, 110.2283, 110.2462, 110.2641, 110.282, 110.3, 110.3179,
    110.3358, 110.3537, 110.3716, 110.3895, 110.4074, 110.4253,
    110.4432, 110.4611, 110.479, 110.4969, 110.2647, 110.8006,
    111.3338, 111.8636, 112.3895, 112.911, 113.428, 113.941,
    114.45, 114.9547, 115.4549, 115.9509, 116.4432, 116.9325,
    117.4196, 117.9046, 118.388, 118.87, 119.3508, 119.8303,
    120.3085, 120.7853, 121.2604, 121.7338, 122.2053, 122.675,
    123.1429, 123.6092, 124.0736, 124.5361, 124.9964, 125.4545,
    125.9104, 126.364, 126.8156, 127.2651, 127.7129, 128.159,
    128.6034, 129.0466, 129.4887, 129.93, 130.3705, 130.8103,
    131.2495, 131.6884, 132.1269, 132.5652, 133.0031, 133.4404,
    133.877, 134.313, 134.7483, 135.1829, 135.6168, 136.0501,
    136.4829, 136.9153, 137.3474, 137.7795, 138.2119, 138.6452,
    139.0797, 139.5158, 139.954, 140.3948, 140.8387, 141.2859,
    141.7368, 142.1916, 142.6501, 143.1126, 143.5795, 144.0511,
    144.5276, 145.0093, 145.4964, 145.9891, 146.4878, 146.9927,
    147.5041, 148.0224, 148.5478, 149.0807, 149.6212, 150.1694,
    150.7256, 151.2899, 151.8623, 152.4425, 153.0298, 153.6234,
    154.2223, 154.8258, 155.4329, 156.0426, 156.6539, 157.266,
    157.8775, 158.4871, 159.0937, 159.6962, 160.2939, 160.8861,
    161.472, 162.0505, 162.6207, 163.1816, 163.7321, 164.2717,
    164.7994, 165.3145, 165.8165, 166.305, 166.7799, 167.2415,
    167.6899, 168.1255, 168.5482, 168.958, 169.3549, 169.7389,
    170.1099, 170.468, 170.8136, 171.1468, 171.468, 171.7773,
    172.0748, 172.3606, 172.6345, 172.8967, 173.147, 173.3856,
    173.6126, 173.828, 174.0321, 174.2251, 174.4071, 174.5784,
    174.7392, 174.8896, 175.0301, 175.1609, 175.2824, 175.3951,
    175.4995, 175.5959, 175.685, 175.7672, 175.8432, 175.9133,
    175.9781, 176.038, 176.0935, 176.1449, 176.1925, 176.2368,
    176.2779, 176.3162, 176.3518, 176.3851, 176.4162, 176.4453,
    176.4724, 176.4976, 176.5211, 176.5432, 176.5432, 85.7299,
    85.7589, 85.788, 85.817, 85.846, 85.8749, 85.9039, 85.9328,
    85.9617, 85.9906, 86.0194, 86.0483, 86.0771, 86.1059, 86.1347,
    86.1634, 86.1921, 86.2209, 86.2495, 86.2782, 86.3069, 86.3355,
    86.3641, 86.3927, 86.4212, 86.4498, 86.4783, 86.5068, 86.5353,
    86.5638, 86.5922, 86.6206, 86.649, 86.6774, 86.7057, 86.7341,
    86.7624, 86.7907, 86.819, 86.8472, 86.8754, 86.9037, 86.9319,
    86.96, 86.9882, 87.0163, 87.0444, 87.0725, 87.1006, 87.1286,
    87.1567, 87.1847, 87.2126, 87.2406, 87.2686, 87.2965, 87.3244,
    87.3523, 87.3801, 87.408, 87.4358, 87.4636, 87.4914, 87.5192,
    87.5469, 87.5746, 87.6023, 87.63, 87.6577, 87.6853, 87.7129,
    87.7405, 87.7681, 87.7956, 87.8232, 87.8507, 87.8782, 87.9056,
    87.9331, 87.9605, 87.9879, 88.0153, 88.0427, 88.07, 88.0974,
    88.1247, 88.1519, 88.1792, 88.2065, 88.2337, 88.2609, 88.2881,
    88.3152, 88.3423, 88.3695, 88.3966, 88.4236, 88.4507, 88.4777,
    88.5047, 88.5317, 88.5587, 88.5856, 88.6126, 88.6395, 88.6664,
    88.6932, 88.7201, 88.7469, 88.7737, 88.8005, 88.8273, 88.854,
    88.8807, 88.9074, 88.9341, 88.9608, 88.9874, 89.014, 89.0406,
    89.0672, 89.0938, 89.1203, 89.1468, 89.1733, 89.1998, 89.2263,
    89.2527, 89.2791, 89.3055, 89.3319, 89.3583, 89.3846, 89.4109,
    89.4372, 89.4635, 89.4898, 89.516, 89.5422, 89.5684, 89.5946,
    89.6208, 89.6469, 89.673, 89.6991, 89.7252, 89.7513, 89.7773,
    89.8033, 89.8293, 89.8553, 89.8813, 89.9072, 89.9331, 89.9591,
    89.9849, 90.0108, 90.0366, 90.0625, 90.0883, 90.1141, 90.1398,
    90.1656, 90.1913, 90.217, 90.2427, 90.2684, 90.294, 90.3197,
    90.3453, 90.3709, 90.3965, 90.422, 90.4476, 90.4731, 90.4986,
    90.524, 90.5495, 90.575, 90.6004, 90.6258, 90.6512, 90.6765,
    90.7019, 90.7272, 90.7525, 90.7778, 90.8031, 90.8283, 90.8536,
    90.8788, 90.904, 90.9292, 90.9544, 90.9795, 91.0046, 91.0297,
    91.0548, 91.0799, 91.105, 91.13, 91.155, 91.18, 91.205, 91.23,
    91.2549, 91.2799, 91.3048, 91.3297, 91.3545, 91.3794, 91.4043,
    91.4291, 91.4539, 91.4787, 91.5035, 91.5282, 91.553, 91.5777,
    91.6024, 91.6271, 91.6518, 91.6764, 91.7011, 91.7257, 91.7503,
    91.7749, 91.7995, 91.8241, 91.8486, 91.8731, 91.8976, 91.9221,
    91.9466, 91.9711, 91.9955, 92.02, 92.0444, 92.0688, 92.0932,
    92.1175, 92.1419, 92.1662, 92.1906, 92.2149, 92.2392, 92.2635,
    92.2877, 92.312, 92.3362, 92.3604, 92.3846, 92.4088, 92.433,
    92.4572, 92.4813, 92.5054, 92.5295, 92.5536, 92.5777, 92.6018,
    92.6259, 92.6499, 92.6739, 92.698, 92.722, 92.7459, 92.7699,
    92.7939, 92.8178, 92.8418, 92.8657, 92.8896, 92.9135, 92.9373,
    92.9612, 92.985, 93.0089, 93.0327, 93.0565, 93.0803, 93.1041,
    93.1278, 93.1516, 93.1753, 93.1991, 93.2228, 93.2465, 93.2702,
    93.2938, 93.3175, 93.3411, 93.3648, 93.3884, 93.412, 93.4356,
    93.4592, 93.4827, 93.5063, 93.5298, 93.5534, 93.5769, 93.6004,
    93.6239, 93.6473, 93.6708, 93.6943, 93.7177, 93.7411, 93.7646,
    93.788, 93.8113, 93.8347, 93.8581, 93.8814, 93.9048, 93.9281,
    93.9514, 93.9747, 93.998, 94.0213, 94.0446, 94.0678, 94.0911,
    94.1143, 94.1376, 94.1608, 94.184, 94.2071, 94.2303, 94.2535,
    94.2766, 94.2998, 94.3229, 94.346, 94.3691, 94.3922, 94.4153,
    94.4384, 94.4615, 94.4845, 94.5075, 94.5306, 94.5536, 94.5766,
    94.5996, 94.6226, 94.6455, 94.6685, 94.6914, 94.7144, 94.7373,
    94.7602, 94.7831, 94.806, 94.8289, 94.8518, 94.8747, 94.8975,
    94.9203, 94.9432, 94.966, 94.9888, 95.0116, 95.0344, 95.0572,
    95.0799, 95.1027, 95.1254, 95.1482, 95.1709, 95.1936, 95.2163,
    95.239, 95.2617, 95.2844, 95.307, 95.3297, 95.3523, 95.375,
    95.3976, 95.4202, 95.4428, 95.4654, 95.488, 95.5105, 95.5331,
    95.5556, 95.5782, 95.6007, 95.6232, 95.6457, 95.6682, 95.6907,
    95.7132, 95.7356, 95.7581, 95.7805, 95.803, 95.8254, 95.8478,
    95.8702, 95.8926, 95.915, 95.9374, 95.9597, 95.9821, 96.0044,
    96.0268, 96.0491, 96.0714, 96.0937, 96.116, 96.1383, 96.1606,
    96.1828, 96.2051, 96.2273, 96.2495, 96.2718, 96.294, 96.3162,
    96.3384, 96.3606, 96.3827, 96.4049, 96.427, 96.4492, 96.4713,
    96.4934, 96.5156, 96.5377, 96.5598, 96.5818, 96.6039, 96.626,
    96.648, 96.6701, 96.6921, 96.7141, 96.7362, 96.7582, 96.7802,
    96.8021, 96.8241, 96.8461, 96.868, 96.89, 96.9119, 96.9339,
    96.9558, 96.9777, 96.9996, 97.0215, 97.0434, 97.0652, 97.0871,
    97.1089, 97.1308, 97.1526, 97.1744, 97.1963, 97.2181, 97.2399,
    97.2616, 97.2834, 97.3052, 97.3269, 97.3487, 97.3704, 97.3922,
    97.4139, 97.4356, 97.4573, 97.479, 97.5007, 97.5223, 97.544,
    97.5657, 97.5873, 97.6089, 97.6306, 97.6522, 97.6738, 97.6954,
    97.717, 97.7385, 97.7601, 97.7817, 97.8032, 97.8248, 97.8463,
    97.8678, 97.8893, 97.9108, 97.9323, 97.9538, 97.9753, 97.9968,
    98.0182, 98.0397, 98.0611, 98.0825, 98.1039, 98.1253, 98.1467,
    98.1681, 98.1895, 98.2109, 98.2322, 98.2536, 98.2749, 98.2963,
    98.3176, 98.3389, 98.3602, 98.3815, 98.4028, 98.4241, 98.4453,
    98.4666, 98.4878, 98.5091, 98.5303, 98.5515, 98.5727, 98.5939,
    98.6151, 98.6363, 98.6575, 98.6786, 98.6998, 98.7209, 98.7421,
    98.7632, 98.7843, 98.8054, 98.8265, 98.8476, 98.8687, 98.8897,
    98.9108, 98.9318, 98.9529, 98.9739, 98.9949, 99.0159, 99.0369,
    99.0579, 99.0789, 99.0999, 99.1208, 99.1418, 99.1628, 99.1837,
    99.2046, 99.2255, 99.2464, 99.2673, 99.2882, 99.3091, 99.33,
    99.3509, 99.3717, 99.3926, 99.4134, 99.4342, 99.455, 99.4758,
    99.4966, 99.5174, 99.5382, 99.559, 99.5798, 99.6005, 99.6212,
    99.642, 99.6627, 99.6834, 99.7041, 99.7248, 99.7455, 99.7662,
    99.7869, 99.8075, 99.8282, 99.8488, 99.8695, 99.8901, 99.9107,
    99.9313, 99.9519, 99.9725, 99.9931, 100.0137, 100.0342, 100.0548,
    100.0753, 100.0959, 100.1164, 100.1369, 100.1574, 100.1779,
    100.1984, 100.2189, 100.2394, 100.2598, 100.2803, 100.3007,
    100.3212, 100.3416, 100.362, 100.3824, 100.4028, 100.4232,
    100.4436, 100.464, 100.4843, 100.5047, 100.525, 100.5454,
    100.5657, 100.586, 100.6063, 100.6266, 100.6469, 100.6672,
    100.6875, 100.7077, 100.728, 100.7482, 100.7685, 100.7887,
    100.8089, 100.8291, 100.8493, 100.8695, 100.8897, 100.9099,
    100.9301, 100.9502, 100.9704, 100.9905, 101.0107, 101.0308,
    101.0509, 101.071, 101.0911, 101.1112, 101.1313, 101.1514,
    101.1714, 101.1915, 101.2115, 101.2316, 101.2516, 101.2716,
    101.2917, 101.3117, 101.3317, 101.3517, 101.3716, 101.3916,
    101.4116, 101.4315, 101.4515, 101.4714, 101.4914, 101.5113,
    101.5312, 101.5511, 101.571, 101.5909, 101.6108, 101.6306,
    101.6505, 101.6704, 101.6902, 101.7101, 101.7299, 101.7497,
    101.7695, 101.7893, 101.8091, 101.8289, 101.8487, 101.8685,
    101.8883, 101.908, 101.9278, 101.9475, 101.9673, 101.987,
    102.0067, 102.0264, 102.0461, 102.0658, 102.0855, 102.1052,
    102.1249, 102.1446, 102.1642, 102.1839, 102.2035, 102.2232,
    102.2428, 102.2624, 102.282, 102.3016, 102.3212, 102.3408,
    102.3604, 102.38, 102.3996, 102.4191, 102.4387, 102.4582,
    102.4778, 102.4973, 102.5168, 102.5364, 102.5559, 102.5754,
    102.5949, 102.6144, 102.6338, 102.6533, 102.6728, 102.6923,
    102.7117, 102.7312, 102.7506, 102.77, 102.7895, 102.8089,
    102.8283, 102.8477, 102.8671, 102.8865, 102.9059, 102.9252,
    102.9446, 102.964, 102.9833, 103.0027, 103.022, 103.0414,
    103.0607, 103.08, 103.0993, 103.1186, 103.1379, 103.1572,
    103.1765, 103.1958, 103.2151, 103.2343, 103.2536, 103.2728,
    103.2921, 103.3113, 103.3306, 103.3498, 103.369, 103.3882,
    103.4074, 103.4266, 103.4458, 103.465, 103.4842, 103.5034,
    103.5225, 103.5417, 103.5608, 103.58, 103.5991, 103.6183,
    103.6374, 103.6565, 103.6756, 103.6947, 103.7138, 103.7329,
    103.752, 103.7711, 103.7902, 103.8092, 103.8283, 103.8473,
    103.8664, 103.8854, 103.9045, 103.9235, 103.9425, 103.9616,
    103.9806, 103.9996, 104.0186, 104.0376, 104.0565, 104.0755,
    104.0945, 104.1135, 104.1324, 104.1514, 104.1703, 104.1893,
    104.2082, 104.2271, 104.2461, 104.265, 104.2839, 104.3028,
    104.3217, 104.3406, 104.3595, 104.3784, 104.3972, 104.4161,
    104.435, 104.4538, 104.4727, 104.4915, 104.5104, 104.5292,
    104.548, 104.5668, 104.5856, 104.6045, 104.6233, 104.6421,
    104.6608, 104.6796, 104.6984, 104.7172, 104.736, 104.7547,
    104.7735, 104.7922, 104.811, 104.8297, 104.8484, 104.8672,
    104.8859, 104.9046, 104.9233, 104.942, 104.9607, 104.9794,
    104.9981, 105.0167, 105.0354, 105.0541, 105.0727, 105.0914,
    105.11, 105.1287, 105.1473, 105.166, 105.1846, 105.2032,
    105.2218, 105.2404, 105.259, 105.2776, 105.2962, 105.3148,
    105.3334, 105.352, 105.3705, 105.3891, 105.4076, 105.4262,
    105.4447, 105.4633, 105.4818, 105.5003, 105.5189, 105.5374,
    105.5559, 105.5744, 105.5929, 105.6114, 105.6299, 105.6483,
    105.6668, 105.6853, 105.7037, 105.7222, 105.7406, 105.7591,
    105.7775, 105.796, 105.8144, 105.8328, 105.8512, 105.8696,
    105.888, 105.9064, 105.9248, 105.9432, 105.9616, 105.98,
    105.9983, 106.0167, 106.0351, 106.0534, 106.0718, 106.0901,
    106.1084, 106.1268, 106.1451, 106.1634, 106.1817, 106.2,
    106.2183, 106.2366, 106.2549, 106.2732, 106.2915, 106.3097,
    106.328, 106.3463, 106.3645, 106.3828, 106.401, 106.4192,
    106.4375, 106.4557, 106.4739, 106.4921, 106.5103, 106.5285,
    106.5467, 106.5649, 106.5831, 106.6013, 106.6195, 106.6376,
    106.6558, 106.6739, 106.6921, 106.7102, 106.7284, 106.7465,
    106.7646, 106.7828, 106.8009, 106.819, 106.8371, 106.8552,
    106.8733, 106.8914, 106.9094, 106.9275, 106.9456, 106.9636,
    106.9817, 106.9998, 107.0178, 107.0358, 107.0539, 107.0719,
    107.0899, 107.1079, 107.126, 107.144, 107.162, 107.1799,
    107.1979, 107.2159, 107.2339, 107.2519, 107.2698, 107.2878,
    107.3057, 107.3237, 107.3416, 107.3596, 107.3775, 107.3954,
    107.4133, 107.4312, 107.4492, 107.4671, 107.4849, 107.5028,
    107.5207, 107.5386, 107.5565, 107.5743, 107.5922, 107.61,
    107.6279, 107.6457, 107.6636, 107.6814, 107.6992, 107.717,
    107.7349, 107.7527, 107.7705, 107.7883, 107.806, 107.8238,
    107.8416, 107.8594, 107.8772, 107.8949, 107.9127, 107.9304,
    107.9482, 107.9659, 107.9836, 108.0014, 108.0191, 108.0368,
    108.0545, 108.0722, 108.0899, 108.1076, 108.1253, 108.143,
    108.1607, 108.1783, 108.196, 108.2137, 108.2313, 108.249,
    108.2666, 108.2842, 108.3019, 108.3195, 108.3371, 108.3547,
    108.3723, 108.3899, 108.4075, 108.4251, 108.4427, 108.4603,
    108.4779, 108.4954, 108.513, 108.5306, 108.5481, 108.5657,
    108.5832, 108.6008, 108.6183, 108.6358, 108.6533, 108.6709,
    108.6884, 108.7059, 108.7234, 108.7409, 108.7583, 108.7758,
    108.7933, 108.8108, 108.8282, 108.8457, 108.8632, 108.8806,
    108.8981, 108.9155, 108.9329, 108.9504, 108.9678, 108.9852,
    109.0026, 109.02, 109.0374, 109.0548, 109.0722, 109.0896,
    109.107, 109.1244, 109.1417, 109.1591, 109.1764, 109.1938,
    109.2112, 109.2285, 109.2458, 109.2632, 109.2805, 109.2978,
    109.3151, 109.3324, 109.3498, 109.3671, 109.3844, 109.4016,
    109.4189, 109.4362, 109.4535, 109.4708, 109.488, 109.5053,
    109.5225, 109.5398, 109.557, 109.5743, 109.5915, 109.6088,
    109.626, 109.6432, 109.6604, 109.6776, 109.6948, 109.712,
    109.7292, 109.7464, 109.7636, 109.7808, 109.798, 109.8151,
    109.8323, 109.8494, 109.8666, 109.8837, 109.9009, 109.918,
    109.9352, 109.6016, 110.1258, 110.6451, 111.1596, 111.6696,
    112.1753, 112.6767, 113.174, 113.6672, 114.1565, 114.6421,
    115.1244, 115.6039, 116.0812, 116.5568, 117.0311, 117.5044,
    117.9769, 118.4489, 118.9208, 119.3926, 119.8648, 120.3374,
    120.8105, 121.2843, 121.7587, 122.2338, 122.7098, 123.1868,
    123.6646, 124.1435, 124.6234, 125.1045, 125.5869, 126.0706,
    126.5558, 127.0424, 127.5304, 128.0199, 128.5109, 129.0035,
    129.4975, 129.9932, 130.4904, 130.9891, 131.4895, 131.9912,
    132.4944, 132.9989, 133.5046, 134.0118, 134.5202, 135.0299,
    135.541, 136.0533, 136.567, 137.0821, 137.5987, 138.1167,
    138.6363, 139.1575, 139.6803, 140.2049, 140.7313, 141.2594,
    141.7892, 142.3206, 142.8534, 143.3874, 143.9222, 144.4575,
    144.9929, 145.528, 146.0622, 146.5951, 147.1262, 147.6548,
    148.1804, 148.7023, 149.2197, 149.7322, 150.239, 150.7394,
    151.2327, 151.7182, 152.1951, 152.6628, 153.1206, 153.5678,
    154.0041, 154.429, 154.8423, 155.2437, 155.633, 156.0101,
    156.3748, 156.7269, 157.0666, 157.3936, 157.7082, 158.0102,
    158.2997, 158.5771, 158.8425, 159.0961, 159.3382, 159.5691,
    159.789, 159.9983, 160.1971, 160.3857, 160.5643, 160.7332,
    160.8927, 161.043, 161.1845, 161.3176, 161.4425, 161.5596,
    161.6692, 161.7717, 161.8673, 161.9564, 162.0393, 162.1164,
    162.188, 162.2542, 162.3154, 162.3719, 162.4239, 162.4717,
    162.5156, 162.556, 162.5933, 162.6276, 162.6594, 162.689,
    162.7165, 162.7425, 162.767, 162.7904, 162.8126, 162.834,
    162.8545, 162.8743, 162.8935, 162.912, 162.93, 162.9476,
    162.9649, 162.9817, 162.9983, 163.0144, 163.03, 163.0451,
    163.0595, 163.0733, 163.0862, 163.0982, 163.1092, 163.1192,
    163.1279, 163.1355, 163.1418, 163.1469, 163.1508, 163.1534,
    163.1548, 163.1548, 49.8842, 50.0601, 50.2359, 50.4118, 50.5876,
    50.7635, 50.9393, 51.1152, 51.291, 51.4669, 51.6427, 51.8186,
    51.9944, 52.1702, 52.3461, 52.4978, 52.6488, 52.799, 52.9483,
    53.0967, 53.2441, 53.3905, 53.536, 53.6805, 53.8239, 53.9664,
    54.1079, 54.2485, 54.3881, 54.5268, 54.6645, 54.8012, 54.9368,
    55.0714, 55.2049, 55.3374, 55.4688, 55.5992, 55.7285, 55.8568,
    55.9841, 56.1104, 56.2357, 56.3599, 56.4833, 56.6056, 56.7269,
    56.8472, 56.9666, 57.0851, 57.2026, 57.3192, 57.4349, 57.5497,
    57.6637, 57.7767, 57.8889, 58.0003, 58.1109, 58.2207, 58.3299,
    58.4384, 58.5463, 58.6536, 58.7603, 58.8664, 58.9718, 59.0766,
    59.1808, 59.2843, 59.3872, 59.4894, 59.591, 59.692, 59.7923,
    59.892, 59.991, 60.0894, 60.1872, 60.2843, 60.3808, 60.4767,
    60.5719, 60.6665, 60.7605, 60.8539, 60.9466, 61.0388, 61.1303,
    61.2212, 61.3115, 61.4013, 61.4904, 61.579, 61.667, 61.7543,
    61.8411, 61.9274, 62.013, 62.0981, 62.1826, 62.2665, 62.3499,
    62.4327, 62.5149, 62.5966, 62.6778, 62.7584, 62.8384, 62.918,
    62.9969, 63.0754, 63.1533, 63.2307, 63.3076, 63.3839, 63.4598,
    63.5351, 63.6099, 63.6842, 63.758, 63.8313, 63.9041, 63.9765,
    64.0483, 64.1197, 64.1906, 64.261, 64.331, 64.4006, 64.4697,
    64.5383, 64.6066, 64.6744, 64.7418, 64.8088, 64.8755, 64.9417,
    65.0075, 65.073, 65.138, 65.2027, 65.2671, 65.331, 65.3946,
    65.4579, 65.5208, 65.5834, 65.6456, 65.7075, 65.769, 65.8303,
    65.8912, 65.9518, 66.0121, 66.0721, 66.1317, 66.1911, 66.2502,
    66.3089, 66.3674, 66.4256, 66.4835, 66.5412, 66.5985, 66.6556,
    66.7125, 66.7691, 66.8254, 66.8815, 66.9373, 66.993, 67.0483,
    67.1035, 67.1584, 67.2132, 67.2677, 67.3219, 67.376, 67.4299,
    67.4836, 67.5371, 67.5904, 67.6435, 67.6964, 67.7491, 67.8017,
    67.8541, 67.9062, 67.9583, 68.0101, 68.0618, 68.1133, 68.1647,
    68.2158, 68.2669, 68.3177, 68.3685, 68.419, 68.4695, 68.5198,
    68.5699, 68.6199, 68.6698, 68.7195, 68.7691, 68.8186, 68.8679,
    68.9171, 68.9662, 69.0152, 69.0641, 69.1128, 69.1615, 69.21,
    69.2584, 69.3067, 69.3549, 69.4031, 69.4511, 69.499, 69.5468,
    69.5945, 69.6421, 69.6896, 69.737, 69.7844, 69.8316, 69.8787,
    69.9258, 69.9728, 70.0197, 70.0665, 70.1132, 70.1599, 70.2064,
    70.2529, 70.2994, 70.3457, 70.392, 70.4382, 70.4843, 70.5304,
    70.5764, 70.6224, 70.6683, 70.7141, 70.7598, 70.8055, 70.8511,
    70.8967, 70.9422, 70.9876, 71.033, 71.0783, 71.1235, 71.1687,
    71.2138, 71.2589, 71.3039, 71.3488, 71.3937, 71.4385, 71.4832,
    71.5279, 71.5725, 71.6171, 71.6616, 71.706, 71.7504, 71.7947,
    71.839, 71.8832, 71.9273, 71.9714, 72.0154, 72.0594, 72.1033,
    72.1472, 72.1909, 72.2347, 72.2783, 72.3219, 72.3655, 72.4089,
    72.4523, 72.4957, 72.539, 72.5822, 72.6253, 72.6684, 72.7115,
    72.7544, 72.7974, 72.8402, 72.883, 72.9257, 72.9684, 73.011,
    73.0535, 73.096, 73.1384, 73.1808, 73.2231, 73.2653, 73.3075,
    73.3497, 73.3917, 73.4337, 73.4757, 73.5176, 73.5594, 73.6012,
    73.6429, 73.6845, 73.7261, 73.7677, 73.8091, 73.8506, 73.8919,
    73.9333, 73.9745, 74.0157, 74.0569, 74.0979, 74.139, 74.18,
    74.2209, 74.2618, 74.3026, 74.3433, 74.3841, 74.4247, 74.4653,
    74.5059, 74.5464, 74.5868, 74.6272, 74.6676, 74.7079, 74.7481,
    74.7883, 74.8285, 74.8686, 74.9086, 74.9486, 74.9886, 75.0285,
    75.0683, 75.1081, 75.1479, 75.1876, 75.2273, 75.2669, 75.3065,
    75.346, 75.3855, 75.425, 75.4644, 75.5037, 75.5431, 75.5824,
    75.6216, 75.6608, 75.6999, 75.7391, 75.7781, 75.8172, 75.8562,
    75.8951, 75.934, 75.9729, 76.0117, 76.0505, 76.0892, 76.1279,
    76.1665, 76.2051, 76.2437, 76.2822, 76.3207, 76.3591, 76.3975,
    76.4358, 76.4741, 76.5124, 76.5506, 76.5888, 76.6269, 76.665,
    76.703, 76.741, 76.779, 76.8169, 76.8548, 76.8926, 76.9304,
    76.9682, 77.0059, 77.0435, 77.0812, 77.1187, 77.1563, 77.1938,
    77.2313, 77.2687, 77.306, 77.3434, 77.3807, 77.4179, 77.4551,
    77.4923, 77.5295, 77.5665, 77.6036, 77.6406, 77.6776, 77.7145,
    77.7514, 77.7883, 77.8251, 77.8618, 77.8986, 77.9353, 77.9719,
    78.0085, 78.0451, 78.0817, 78.1182, 78.1546, 78.1911, 78.2275,
    78.2638, 78.3001, 78.3364, 78.3727, 78.4089, 78.4451, 78.4812,
    78.5173, 78.5534, 78.5894, 78.6254, 78.6614, 78.6973, 78.7332,
    78.7691, 78.8049, 78.8407, 78.8764, 78.9122, 78.9479, 78.9835,
    79.0191, 79.0547, 79.0903, 79.1258, 79.1613, 79.1968, 79.2322,
    79.2676, 79.303, 79.3383, 79.3736, 79.4089, 79.4441, 79.4793,
    79.5145, 79.5496, 79.5847, 79.6198, 79.6548, 79.6898, 79.7248,
    79.7598, 79.7947, 79.8296, 79.8644, 79.8993, 79.9341, 79.9688,
    80.0036, 80.0383, 80.0729, 80.1076, 80.1422, 80.1768, 80.2113,
    80.2459, 80.2804, 80.3148, 80.3493, 80.3837, 80.4181, 80.4524,
    80.4867, 80.521, 80.5553, 80.5895, 80.6237, 80.6578, 80.692,
    80.7261, 80.7602, 80.7942, 80.8282, 80.8622, 80.8961, 80.9301,
    80.964, 80.9978, 81.0317, 81.0655, 81.0992, 81.133, 81.1667,
    81.2004, 81.234, 81.2677, 81.3013, 81.3348, 81.3684, 81.4019,
    81.4353, 81.4688, 81.5022, 81.5356, 81.569, 81.6023, 81.6356,
    81.6689, 81.7021, 81.7353, 81.7685, 81.8017, 81.8348, 81.8679,
    81.9009, 81.934, 81.967, 82, 82.0329, 82.0659, 82.0987, 82.1316,
    82.1644, 82.1973, 82.23, 82.2628, 82.2955, 82.3282, 82.3609,
    82.3935, 82.4261, 82.4587, 82.4912, 82.5237, 82.5562, 82.5887,
    82.6211, 82.6535, 82.6859, 82.7182, 82.7505, 82.7828, 82.8151,
    82.8473, 82.8795, 82.9117, 82.9438, 82.9759, 83.008, 83.04,
    83.0721, 83.1041, 83.136, 83.168, 83.1999, 83.2318, 83.2637,
    83.2955, 83.3273, 83.3591, 83.3908, 83.4226, 83.4543, 83.4859,
    83.5176, 83.5492, 83.5808, 83.6124, 83.6439, 83.6754, 83.7069,
    83.7384, 83.7698, 83.8012, 83.8326, 83.864, 83.8953, 83.9267,
    83.9579, 83.9892, 84.0205, 84.0517, 84.0829, 84.114, 84.1452,
    84.1763, 84.2074, 84.2385, 84.2695, 84.3006, 84.3316, 84.3626,
    84.3935, 84.4245, 84.4554, 84.4862, 84.5171, 84.5479, 84.5787,
    84.6095, 84.6403, 84.671, 84.7017, 84.7324, 84.7631, 84.7937,
    84.8243, 84.8549, 84.8855, 84.916, 84.9465, 84.977, 85.0075,
    85.0379, 85.0683, 85.0987, 85.1291, 85.1594, 85.1897, 85.22,
    85.2503, 85.2805, 85.3108, 85.341, 85.3711, 85.4013, 85.4314,
    85.4615, 85.4916, 85.5217, 85.5517, 85.5817, 85.6117, 85.6417,
    85.6716, 85.7015, 85.7314, 85.7613, 85.7912, 85.821, 85.8508,
    85.8806, 85.9104, 85.9401, 85.9698, 85.9995, 86.0292, 86.0589,
    86.0885, 86.1181, 86.1477, 86.1773, 86.2068, 86.2363, 86.2659,
    86.2954, 86.3248, 86.3543, 86.3837, 86.4131, 86.4425, 86.4719,
    86.5012, 86.5306, 86.5599, 86.5892, 86.6184, 86.6477, 86.6769,
    86.7061, 86.7353, 86.7645, 86.7937, 86.8228, 86.8519, 86.881,
    86.9101, 86.9392, 86.9682, 86.9972, 87.0262, 87.0552, 87.0842,
    87.1131, 87.142, 87.1709, 87.1998, 87.2287, 87.2575, 87.2863,
    87.3151, 87.3439, 87.3727, 87.4014, 87.4302, 87.4589, 87.4876,
    87.5162, 87.5449, 87.5735, 87.6021, 87.6307, 87.6593, 87.6878,
    87.7164, 87.7449, 87.7734, 87.8018, 49.1477, 49.3166, 49.4854,
    49.6543, 49.8232, 49.9921, 50.1609, 50.3298, 50.4987, 50.6676,
    50.8365, 51.0053, 51.1742, 51.3431, 51.512, 51.651, 51.7895,
    51.9272, 52.0641, 52.2002, 52.3353, 52.4695, 52.6027, 52.7349,
    52.8661, 52.9963, 53.1255, 53.2537, 53.3809, 53.5072, 53.6326,
    53.7571, 53.8806, 54.0031, 54.1247, 54.2454, 54.3651, 54.4839,
    54.6018, 54.7187, 54.8348, 54.9499, 55.0642, 55.1777, 55.2903,
    55.4021, 55.513, 55.623, 55.7322, 55.8406, 55.9482, 56.0549,
    56.1609, 56.266, 56.3704, 56.4739, 56.5767, 56.6788, 56.78,
    56.8806, 56.9805, 57.0796, 57.1782, 57.2761, 57.3733, 57.4699,
    57.5659, 57.6613, 57.756, 57.8501, 57.9436, 58.0365, 58.1288,
    58.2206, 58.3117, 58.4022, 58.4922, 58.5816, 58.6705, 58.7588,
    58.8465, 58.9337, 59.0204, 59.1066, 59.1922, 59.2773, 59.3619,
    59.4459, 59.5295, 59.6126, 59.6952, 59.7773, 59.8589, 59.9401,
    60.0209, 60.1011, 60.181, 60.2603, 60.3393, 60.4178, 60.4958,
    60.5734, 60.6506, 60.7273, 60.8036, 60.8795, 60.955, 61.0301,
    61.1047, 61.1789, 61.2527, 61.3261, 61.3991, 61.4717, 61.5439,
    61.6156, 61.687, 61.758, 61.8286, 61.8988, 61.9686, 62.0381,
    62.1071, 62.1758, 62.2441, 62.312, 62.3795, 62.4467, 62.5135,
    62.58, 62.6461, 62.7118, 62.7772, 62.8423, 62.907, 62.9714,
    63.0354, 63.0991, 63.1626, 63.2257, 63.2884, 63.3509, 63.4131,
    63.475, 63.5365, 63.5978, 63.6588, 63.7196, 63.78, 63.8402,
    63.9, 63.9597, 64.019, 64.0781, 64.137, 64.1956, 64.2539,
    64.312, 64.3699, 64.4276, 64.485, 64.5422, 64.5991, 64.6559,
    64.7124, 64.7688, 64.8249, 64.8808, 64.9366, 64.9921, 65.0474,
    65.1026, 65.1576, 65.2123, 65.267, 65.3214, 65.3757, 65.4298,
    65.4837, 65.5375, 65.5911, 65.6445, 65.6978, 65.751, 65.804,
    65.8568, 65.9095, 65.9621, 66.0145, 66.0668, 66.1189, 66.1709,
    66.2228, 66.2745, 66.3261, 66.3776, 66.429, 66.4802, 66.5313,
    66.5823, 66.6331, 66.6839, 66.7345, 66.785, 66.8354, 66.8857,
    66.9359, 66.9859, 67.0359, 67.0858, 67.1355, 67.1852, 67.2347,
    67.2842, 67.3335, 67.3828, 67.432, 67.481, 67.53, 67.5789,
    67.6277, 67.6764, 67.725, 67.7735, 67.8219, 67.8703, 67.9185,
    67.9667, 68.0148, 68.0628, 68.1107, 68.1585, 68.2063, 68.254,
    68.3016, 68.3491, 68.3965, 68.4439, 68.4911, 68.5383, 68.5855,
    68.6325, 68.6795, 68.7264, 68.7732, 68.82, 68.8666, 68.9133,
    68.9598, 69.0063, 69.0527, 69.099, 69.1452, 69.1914, 69.2376,
    69.2836, 69.3296, 69.3755, 69.4214, 69.4672, 69.5129, 69.5585,
    69.6041, 69.6496, 69.6951, 69.7405, 69.7858, 69.8311, 69.8763,
    69.9215, 69.9666, 70.0116, 70.0566, 70.1015, 70.1463, 70.1911,
    70.2358, 70.2805, 70.3251, 70.3697, 70.4142, 70.4586, 70.503,
    70.5474, 70.5917, 70.6359, 70.68, 70.7241, 70.7682, 70.8122,
    70.8561, 70.9, 70.9439, 70.9876, 71.0314, 71.075, 71.1187,
    71.1622, 71.2057, 71.2492, 71.2926, 71.3359, 71.3792, 71.4224,
    71.4656, 71.5088, 71.5518, 71.5949, 71.6378, 71.6808, 71.7236,
    71.7664, 71.8092, 71.8519, 71.8946, 71.9372, 71.9798, 72.0223,
    72.0647, 72.1071, 72.1495, 72.1918, 72.234, 72.2762, 72.3184,
    72.3605, 72.4025, 72.4445, 72.4865, 72.5284, 72.5702, 72.612,
    72.6538, 72.6955, 72.7372, 72.7788, 72.8203, 72.8618, 72.9033,
    72.9447, 72.9861, 73.0274, 73.0686, 73.1099, 73.151, 73.1922,
    73.2332, 73.2743, 73.3152, 73.3562, 73.3971, 73.4379, 73.4787,
    73.5195, 73.5602, 73.6008, 73.6414, 73.682, 73.7225, 73.763,
    73.8034, 73.8438, 73.8842, 73.9245, 73.9647, 74.0049, 74.0451,
    74.0852, 74.1253, 74.1653, 74.2053, 74.2452, 74.2851, 74.325,
    74.3648, 74.4045, 74.4443, 74.4839, 74.5236, 74.5632, 74.6027,
    74.6422, 74.6817, 74.7211, 74.7605, 74.7998, 74.8391, 74.8784,
    74.9176, 74.9567, 74.9959, 75.0349, 75.074, 75.113, 75.1519,
    75.1908, 75.2297, 75.2686, 75.3073, 75.3461, 75.3848, 75.4235,
    75.4621, 75.5007, 75.5392, 75.5777, 75.6162, 75.6546, 75.693,
    75.7313, 75.7696, 75.8079, 75.8461, 75.8843, 75.9224, 75.9605,
    75.9986, 76.0366, 76.0746, 76.1125, 76.1504, 76.1883, 76.2261,
    76.2639, 76.3016, 76.3393, 76.377, 76.4146, 76.4522, 76.4897,
    76.5272, 76.5647, 76.6021, 76.6395, 76.6769, 76.7142, 76.7515,
    76.7887, 76.8259, 76.8631, 76.9002, 76.9373, 76.9744, 77.0114,
    77.0484, 77.0853, 77.1222, 77.1591, 77.1959, 77.2327, 77.2695,
    77.3062, 77.3429, 77.3796, 77.4162, 77.4528, 77.4893, 77.5258,
    77.5623, 77.5988, 77.6352, 77.6716, 77.7079, 77.7442, 77.7805,
    77.8167, 77.8529, 77.8891, 77.9252, 77.9613, 77.9974, 78.0334,
    78.0694, 78.1054, 78.1413, 78.1772, 78.2131, 78.249, 78.2848,
    78.3205, 78.3563, 78.392, 78.4276, 78.4633, 78.4989, 78.5345,
    78.57, 78.6055, 78.641, 78.6764, 78.7118, 78.7472, 78.7826,
    78.8179, 78.8532, 78.8884, 78.9236, 78.9588, 78.994, 79.0291,
    79.0642, 79.0993, 79.1343, 79.1693, 79.2042, 79.2392, 79.2741,
    79.3089, 79.3438, 79.3786, 79.4134, 79.4481, 79.4828, 79.5175,
    79.5521, 79.5868, 79.6213, 79.6559, 79.6904, 79.7249, 79.7594,
    79.7938, 79.8282, 79.8626, 79.8969, 79.9312, 79.9655, 79.9998,
    80.034, 80.0682, 80.1023, 80.1365, 80.1706, 80.2046, 80.2387,
    80.2727, 80.3067, 80.3406, 80.3745, 80.4084, 80.4423, 80.4761,
    80.5099, 80.5437, 80.5774, 80.6112, 80.6448, 80.6785, 80.7121,
    80.7457, 80.7793, 80.8128, 80.8464, 80.8798, 80.9133, 80.9467,
    80.9801, 81.0135, 81.0468, 81.0802, 81.1134, 81.1467, 81.1799,
    81.2131, 81.2463, 81.2795, 81.3126, 81.3457, 81.3788, 81.4118,
    81.4448, 81.4778, 81.5108, 81.5437, 81.5766, 81.6095, 81.6423,
    81.6752, 81.708, 81.7407, 81.7735, 81.8062, 81.8389, 81.8715,
    81.9042, 81.9368, 81.9694, 82.0019, 82.0345, 82.067, 82.0994,
    82.1319, 82.1643, 82.1967, 82.2291, 82.2614, 82.2938, 82.3261,
    82.3583, 82.3906, 82.4228, 82.455, 82.4872, 82.5193, 82.5514,
    82.5835, 82.6156, 82.6476, 82.6796, 82.7116, 82.7436, 82.7755,
    82.8074, 82.8393, 82.8712, 82.903, 82.9348, 82.9666, 82.9984,
    83.0301, 83.0618, 83.0935, 83.1251, 83.1568, 83.1884, 83.22,
    83.2515, 83.2831, 83.3146, 83.3461, 83.3775, 83.4089, 83.4403,
    83.4717, 83.5031, 83.5344, 83.5657, 83.597, 83.6283, 83.6595,
    83.6907, 83.7219, 83.753, 83.7842, 83.8153, 83.8464, 83.8774,
    83.9085, 83.9395, 83.9705, 84.0014, 84.0324, 84.0633, 84.0941,
    84.125, 84.1558, 84.1867, 84.2174, 84.2482, 84.2789, 84.3096,
    84.3403, 84.371, 84.4016, 84.4323, 84.4628, 84.4934, 84.5239,
    84.5545, 84.585, 84.6154, 84.6459, 84.6763, 84.7067, 84.737,
    84.7674, 84.7977, 84.828, 84.8583, 84.8885, 84.9188, 84.949,
    84.9791, 85.0093, 85.0394, 85.0695, 85.0996, 85.1297, 85.1597,
    85.1897, 85.2197, 85.2497, 85.2796, 85.3096, 85.3395, 85.3693,
    85.3992, 85.429, 85.4588, 85.4886, 85.5184, 85.5481, 85.5778,
    85.6075, 85.6372, 85.6668, 85.6964, 85.726, 85.7556, 85.7852,
    85.8147, 85.8442, 85.8737, 85.9032, 85.9326, 85.9621, 85.9915,
    86.0208, 86.0502, 86.0795, 86.1089, 86.1381, 86.1674, 86.1967,
    86.2259, 86.2551, 86.2843, 86.3134, 86.3426, 86.3717, 86.4008,
    13.4779, 13.49, 13.502, 13.5139, 13.5258, 13.5375, 13.5492,
    13.5607, 13.5722, 13.5836, 13.5949, 13.6061, 13.6172, 13.6283,
    13.6392, 13.6501, 13.6609, 13.6716, 13.6822, 13.6927, 13.7031,
    13.7134, 13.7237, 13.7339, 13.7439, 13.7539, 13.7638, 13.7736,
    13.7834, 13.793, 13.8026, 13.812, 13.8214, 13.8307, 13.8399,
    13.849, 13.8581, 13.867, 13.8759, 13.8847, 13.8934, 13.902,
    13.9105, 13.919, 13.9273, 13.9356, 13.9438, 13.9519, 13.96,
    13.9679, 13.9758, 13.9836, 13.9913, 13.9989, 14.0065, 14.014,
    14.0214, 14.0287, 14.0359, 14.0431, 14.0502, 14.0572, 14.0642,
    14.071, 14.0778, 14.0845, 14.0912, 14.0977, 14.1042, 14.1107,
    14.117, 14.1233, 14.1295, 14.1357, 14.1418, 14.1478, 14.1538,
    14.1597, 14.1655, 14.1713, 14.177, 14.1826, 14.1882, 14.1937,
    14.1992, 14.2046, 14.2099, 14.2152, 14.2205, 14.2256, 14.2307,
    14.2358, 14.2408, 14.2458, 14.2507, 14.2555, 14.2603, 14.265,
    14.2697, 14.2743, 14.2789, 14.2834, 14.2879, 14.2923, 14.2967,
    14.3011, 14.3053, 14.3096, 14.3137, 14.3179, 14.322, 14.326,
    14.33, 14.334, 14.3379, 14.3417, 14.3456, 14.3493, 14.3531,
    14.3568, 14.3604, 14.364, 14.3676, 14.3711, 14.3746, 14.3781,
    14.3815, 14.3849, 14.3882, 14.3915, 14.3947, 14.398, 14.4012,
    14.4043, 14.4074, 14.4105, 14.4135, 14.4165, 14.4195, 14.4225,
    14.4254, 14.4282, 14.4311, 14.4339, 14.4367, 14.4394, 14.4421,
    14.4448, 14.4475, 14.4501, 14.4527, 14.4553, 14.4578, 14.4604,
    14.4628, 14.4653, 14.4677, 14.4702, 14.4725, 14.4749, 14.4772,
    14.4795, 14.4818, 14.4841, 14.4863, 14.4885, 14.4907, 14.4929,
    14.495, 14.4971, 14.4992, 14.5013, 14.5034, 14.5054, 14.5074,
    14.5094, 14.5114, 14.5133, 14.5153, 14.5172, 14.5191, 14.521,
    14.5228, 14.5247, 14.5265, 14.5283, 14.5301, 14.5319, 14.5336,
    14.5354, 14.5371, 14.5388, 14.5405, 14.5422, 14.5438, 14.5455,
    14.5471, 14.5487, 14.5503, 14.5519, 14.5535, 14.555, 14.5566,
    14.5581, 14.5596, 14.5611, 14.5626, 14.5641, 14.5656, 14.567,
    14.5685, 14.5699, 14.5713, 14.5728, 14.5742, 14.5756, 14.5769,
    14.5783, 14.5797, 14.581, 14.5824, 14.5837, 14.585, 14.5863,
    14.5876, 14.5889, 14.5902, 14.5915, 14.5928, 14.594, 14.5953,
    14.5965, 14.5978, 14.599, 14.6002, 14.6014, 14.6026, 14.6038,
    14.605, 14.6062, 14.6074, 14.6086, 14.6098, 14.6109, 14.6121,
    14.6132, 14.6144, 14.6155, 14.6167, 14.6178, 14.6189, 14.62,
    14.6211, 14.6223, 14.6234, 14.6245, 14.6256, 14.6267, 14.6277,
    14.6288, 14.6299, 14.631, 14.6321, 14.6331, 14.6342, 14.6353,
    14.6363, 14.6374, 14.6384, 14.6395, 14.6405, 14.6416, 14.6426,
    14.6436, 14.6447, 14.6457, 14.6468, 14.6478, 14.6488, 14.6498,
    14.6509, 14.6519, 14.6529, 14.6539, 14.655, 14.656, 14.657,
    14.658, 14.659, 14.66, 14.661, 14.662, 14.6631, 14.6641,
    14.6651, 14.6661, 14.6671, 14.6681, 14.6691, 14.6701, 14.6711,
    14.6721, 14.6731, 14.6741, 14.6751, 14.6761, 14.6771, 14.6781,
    14.6791, 14.6801, 14.6811, 14.6821, 14.683, 14.684, 14.685,
    14.686, 14.687, 14.688, 14.689, 14.69, 14.691, 14.692, 14.693,
    14.694, 14.695, 14.696, 14.6971, 14.6981, 14.6991, 14.7001,
    14.7011, 14.7021, 14.7031, 14.7041, 14.7051, 14.7061, 14.7072,
    14.7082, 14.7092, 14.7102, 14.7112, 14.7123, 14.7133, 14.7143,
    14.7153, 14.7164, 14.7174, 14.7184, 14.7195, 14.7205, 14.7216,
    14.7226, 14.7236, 14.7247, 14.7257, 14.7268, 14.7278, 14.7289,
    14.73, 14.731, 14.7321, 14.7331, 14.7342, 14.7353, 14.7364,
    14.7374, 14.7385, 14.7396, 14.7407, 14.7418, 14.7429, 14.7439,
    14.745, 14.7461, 14.7472, 14.7483, 14.7495, 14.7506, 14.7517,
    14.7528, 14.7539, 14.755, 14.7562, 14.7573, 14.7584, 14.7596,
    14.7607, 14.7618, 14.763, 14.7641, 14.7653, 14.7664, 14.7676,
    14.7688, 14.7699, 14.7711, 14.7723, 14.7734, 14.7746, 14.7758,
    14.777, 14.7782, 14.7794, 14.7805, 14.7817, 14.7829, 14.7842,
    14.7854, 14.7866, 14.7878, 14.789, 14.7902, 14.7914, 14.7927,
    14.7939, 14.7951, 14.7964, 14.7976, 14.7989, 14.8001, 14.8013,
    14.8026, 14.8039, 14.8051, 14.8064, 14.8076, 14.8089, 14.8102,
    14.8115, 14.8127, 14.814, 14.8153, 14.8166, 14.8179, 14.8192,
    14.8205, 14.8218, 14.8231, 14.8244, 14.8257, 14.827, 14.8283,
    14.8296, 14.8309, 14.8323, 14.8336, 14.8349, 14.8362, 14.8376,
    14.8389, 14.8403, 14.8416, 14.843, 14.8443, 14.8457, 14.847,
    14.8484, 14.8497, 14.8511, 14.8525, 14.8539, 14.8552, 14.8566,
    14.858, 14.8594, 14.8608, 14.8622, 14.8635, 14.8649, 14.8663,
    14.8677, 14.8692, 14.8706, 14.872, 14.8734, 14.8748, 14.8762,
    14.8777, 14.8791, 14.8805, 14.882, 14.8834, 14.8848, 14.8863,
    14.8877, 14.8892, 14.8906, 14.8921, 14.8936, 14.895, 14.8965,
    14.898, 14.8995, 14.9009, 14.9024, 14.9039, 14.9054, 14.9069,
    14.9084, 14.9099, 14.9114, 14.9129, 14.9144, 14.916, 14.9175,
    14.919, 14.9205, 14.9221, 14.9236, 14.9251, 14.9267, 14.9282,
    14.9298, 14.9313, 14.9329, 14.9345, 14.936, 14.9376, 14.9392,
    14.9407, 14.9423, 14.9439, 14.9455, 14.9471, 14.9487, 14.9503,
    14.9519, 14.9535, 14.9551, 14.9567, 14.9583, 14.9599, 14.9616,
    14.9632, 14.9648, 14.9665, 14.9681, 14.9697, 14.9714, 14.973,
    14.9747, 14.9763, 14.978, 14.9797, 14.9813, 14.983, 14.9847,
    14.9863, 14.988, 14.9897, 14.9914, 14.9931, 14.9948, 14.9965,
    14.9982, 14.9999, 15.0016, 15.0033, 15.005, 15.0067, 15.0084,
    15.0101, 15.0119, 15.0136, 15.0153, 15.0171, 15.0188, 15.0205,
    15.0223, 15.024, 15.0258, 15.0275, 15.0293, 15.0311, 15.0328,
    15.0346, 15.0364, 15.0381, 15.0399, 15.0417, 15.0435, 15.0453,
    15.0471, 15.0488, 15.0506, 15.0524, 15.0542, 15.056, 15.0578,
    15.0597, 15.0615, 15.0633, 15.0651, 15.0669, 15.0687, 15.0706,
    15.0724, 15.0742, 15.076, 15.0779, 15.0797, 15.0815, 15.0834,
    15.0852, 15.0871, 15.0889, 15.0908, 15.0926, 15.0945, 15.0963,
    15.0982, 15.1, 15.1019, 15.1037, 15.1056, 15.1075, 15.1093,
    15.1112, 15.1131, 15.1149, 15.1168, 15.1187, 15.1206, 15.1224,
    15.1243, 15.1262, 15.1281, 15.13, 15.1318, 15.1337, 15.1356,
    15.1375, 15.1394, 15.1413, 15.1432, 15.1451, 15.147, 15.1488,
    15.1507, 15.1526, 15.1545, 15.1564, 15.1583, 15.1602, 15.1621,
    15.164, 15.1659, 15.1678, 15.1697, 15.1716, 15.1735, 15.1754,
    15.1774, 15.1793, 15.1812, 15.1831, 15.185, 15.1869, 15.1888,
    15.1907, 15.1926, 15.1945, 15.1964, 15.1983, 15.2002, 15.2021,
    15.204, 15.2059, 15.2079, 15.2098, 15.2117, 15.2136, 15.2155,
    15.2174, 15.2193, 15.2212, 15.2231, 15.225, 15.2269, 15.2288,
    15.2307, 15.2326, 15.2345, 15.2364, 15.2383, 15.2402, 15.2421,
    15.244, 15.2459, 15.2478, 15.2497, 15.2516, 15.2535, 15.2554,
    15.2573, 15.2591, 15.261, 15.2629, 15.2648, 15.2667, 15.2686,
    15.2705, 15.2723, 15.2742, 15.2761, 15.278, 15.2799, 15.2817,
    15.2836, 15.2855, 15.2873, 15.2892, 15.2911, 15.293, 15.2948,
    15.2967, 15.2985, 15.3004, 15.3023, 15.3041, 15.306, 15.3078,
    15.3097, 15.3115, 15.3134, 15.3152, 15.3171, 15.3189, 15.3207,
    15.3226, 15.3244, 15.3263, 15.3281, 15.3299, 15.3318, 15.3336,
    15.3354, 15.3372, 15.3391, 15.3409, 15.3427, 15.3445, 15.3463,
    15.3481, 15.3499, 15.3517, 15.3536, 15.3554, 15.3572, 15.359,
    15.3608, 15.3625, 15.3643, 15.3661, 15.3679, 15.3697, 15.3715,
    15.3733, 15.375, 15.3768, 15.3786, 15.3804, 15.3821, 15.3839,
    15.3857, 15.3874, 15.3892, 15.391, 15.3927, 15.3945, 15.3962,
    15.398, 15.3997, 15.4014, 15.4032, 15.4049, 15.4067, 15.4084,
    15.4101, 15.4119, 15.4136, 15.4153, 15.417, 15.4187, 15.4205,
    15.4222, 15.4239, 15.4256, 15.4273, 15.429, 15.4307, 15.4324,
    15.4341, 15.4358, 15.4375, 15.4391, 15.4408, 15.4425, 15.4442,
    15.4459, 15.4475, 15.4492, 15.4509, 15.4525, 15.4542, 15.4559,
    15.4575, 15.4592, 15.4608, 15.4625, 15.4641, 15.4658, 15.4674,
    15.469, 15.4707, 15.4723, 15.4739, 15.4756, 15.4772, 15.4788,
    15.4804, 15.4821, 15.4837, 15.4853, 15.4869, 15.4885, 15.4901,
    15.4917, 15.4933, 15.4949, 15.4965, 15.4981, 15.4997, 15.5013,
    15.5028, 15.5044, 15.506, 15.5076, 15.5091, 15.5107, 15.5123,
    15.5138, 15.5154, 15.5169, 15.5185, 15.5201, 15.5216, 15.5232,
    15.5247, 15.5262, 15.5278, 15.5293, 15.5308, 15.5324, 15.5339,
    15.5354, 15.537, 15.5385, 15.54, 15.5415, 15.543, 15.5445,
    15.546, 15.5475, 15.549, 15.5505, 15.552, 15.5535, 15.555,
    15.5565, 15.558, 15.5595, 15.561, 15.5624, 15.5639, 15.5654,
    15.5669, 15.5683, 15.5698, 15.5712, 15.5727, 15.5742, 15.5756,
    15.5771, 15.5785, 15.58, 15.5814, 15.5829, 15.5843, 15.5857,
    15.5872, 15.5886, 15.59, 15.5915, 15.5929, 15.5943, 15.5957,
    15.5971, 15.5986, 15.6, 15.6014, 15.6028, 15.6042, 15.6056,
    15.607, 15.6084, 15.6098, 15.6112, 15.6126, 15.614, 15.6154,
    15.6167, 15.6181, 15.6195, 15.6209, 15.6223, 15.6236, 15.625,
    15.6264, 15.6277, 15.6291, 15.6305, 15.6318, 15.6332, 15.6345,
    15.6359, 15.6372, 15.6386, 15.6399, 15.6413, 15.6426, 15.644,
    15.6453, 15.6467, 15.648, 15.6493, 15.6507, 15.652, 15.6533,
    15.6546, 15.656, 15.6573, 15.6586, 15.6599, 15.6612, 15.6625,
    15.6639, 15.6652, 15.6665, 15.6678, 15.6691, 15.6704, 15.6717,
    15.673, 15.6743, 15.6756, 15.6769, 15.6782, 15.6795, 15.6807,
    15.682, 15.6833, 15.6846, 15.6859, 15.6872, 15.6884, 15.6897,
    15.691, 15.6923, 15.6935, 15.6948, 15.6961, 15.6973, 15.6986,
    15.6999, 15.7011, 15.7024, 15.7036, 15.7049, 15.7062, 15.7074,
    15.7087, 15.7099, 15.7112, 15.7124, 15.7137, 15.7149, 15.7161,
    15.7174, 15.7186, 15.7199, 15.7211, 15.7223, 15.7236, 15.7248,
    15.726, 15.7273, 15.7285, 15.7297, 15.731, 15.7322, 15.7334,
    15.7346, 15.7358, 15.7371, 15.7383, 15.7395, 15.7407, 15.7419,
    15.7431, 15.7444, 15.7456, 15.7468, 15.748, 15.7492, 15.7504,
    15.7516, 15.7528, 15.754, 15.7552, 15.7564, 15.7576, 15.7588,
    15.76, 15.7612, 15.7624, 15.7636, 15.7648, 15.766, 15.7672,
    15.7684, 15.7695, 15.7707, 15.7719, 15.7731, 15.7743, 15.7755,
    15.7767, 15.7778, 15.779, 15.7802, 15.7814, 15.7825, 15.7837,
    15.7849, 15.7861, 15.7872, 15.7884, 15.7896, 15.7908, 15.7919,
    15.7931, 15.7943, 15.7954, 15.7966, 15.7978, 15.7989, 15.8001,
    15.8013, 15.8024, 15.8036, 15.8047, 15.8059, 15.8071, 15.8082,
    15.8094, 15.8105, 15.8117, 15.8129, 15.814, 15.8152, 15.8163,
    15.8175, 15.8186, 15.8198, 15.8209, 15.8221, 15.8232, 15.8244,
    15.8255, 15.8267, 15.8278, 15.829, 15.8301, 15.8312, 15.8324,
    15.8335, 15.8347, 15.8358, 15.837, 15.8381, 15.8392, 15.8404,
    15.8415, 15.8427, 15.8438, 15.8449, 15.8461, 15.8472, 15.8483,
    15.8495, 15.8506, 15.8517, 15.8529, 15.854, 15.8551, 15.8563,
    15.8574, 15.8585, 15.8597, 15.8608, 15.8619, 15.863, 15.8642,
    15.8653, 15.8664, 15.8676, 15.8687, 15.8698, 15.8709, 15.8721,
    15.8732, 15.8743, 15.8754, 15.8765, 15.8777, 15.8788, 15.8799,
    15.881, 15.8821, 15.8833, 15.8844, 15.8855, 15.8866, 15.8877,
    15.8888, 15.89, 15.8911, 15.8922, 15.8933, 15.8944, 15.8955,
    15.8966, 15.8977, 15.8989, 15.9, 15.9011, 15.9022, 15.9033,
    15.9044, 15.9055, 15.9066, 15.9077, 15.9088, 15.91, 15.9111,
    15.9122, 15.9133, 15.9144, 15.9155, 15.9166, 15.9177, 15.9188,
    15.9199, 15.921, 15.9221, 15.9232, 15.9243, 15.9254, 15.9265,
    15.9276, 15.9287, 15.9298, 15.9309, 15.932, 15.9331, 15.9342,
    15.9353, 15.9364, 15.9375, 15.9386, 15.9397, 15.9408, 15.9419,
    15.943, 15.9441, 15.9451, 15.9462, 15.9473, 15.9484, 15.9495,
    15.9506, 15.9517, 15.9528, 15.9539, 15.955, 15.9561, 15.9572,
    15.9582, 15.9593, 15.9604, 15.9615, 15.9626, 15.9637, 15.9648,
    15.9658, 15.9669, 15.968, 15.9691, 15.9702, 15.9713, 15.9724,
    15.9734, 15.9745, 15.9756, 15.9767, 15.9778, 15.9788, 15.9799,
    15.981, 15.9821, 15.9832, 15.9842, 15.9853, 15.9864, 15.9875,
    15.9885, 15.9896, 15.9907, 15.9918, 15.9928, 15.9939, 15.995,
    15.9961, 15.9971, 15.9982, 15.9993, 16.0004, 16.0014, 16.0025,
    16.0036, 16.0046, 16.0057, 16.0068, 16.0079, 16.0089, 16.01,
    16.0111, 16.0121, 16.0132, 16.0143, 16.0153, 16.0164, 16.0175,
    16.0185, 16.0196, 16.0207, 16.0217, 16.0228, 16.0239, 16.0249,
    16.026, 16.027, 16.0281, 16.0292, 16.0302, 16.0313, 16.0324,
    16.0334, 16.0345, 16.0355, 16.0366, 16.0377, 16.0387, 16.0398,
    16.0408, 16.0419, 16.0429, 16.044, 16.0451, 16.0461, 16.0472,
    16.0482, 16.0493, 16.0503, 16.0514, 16.0524, 16.0535, 16.0546,
    16.0556, 16.0567, 16.0577, 16.0588, 16.0598, 16.0609, 16.0619,
    16.063, 16.064, 16.0651, 16.0661, 16.0672, 16.0682, 16.0693,
    16.0703, 16.0714, 16.0724, 16.0735, 16.0745, 16.0756, 16.0766,
    16.0777, 16.0787, 16.0798, 16.0808, 16.0818, 16.0829, 16.0839,
    16.085, 16.086, 16.0871, 16.0881, 16.0892, 16.0902, 16.0912,
    16.0923, 16.0933, 16.0944, 16.0954, 16.0965, 16.0975, 16.0985,
    16.0996, 16.1006, 16.1017, 16.1027, 16.1038, 16.1048, 16.1058,
    16.1069, 16.1079, 16.109, 16.11, 16.111, 16.1121, 16.1131,
    16.1141, 16.1152, 16.1162, 16.1173, 16.1183, 16.1193, 16.1204,
    16.1214, 16.1224, 16.1235, 16.1245, 16.1255, 16.1266, 16.1276,
    16.1287, 16.1297, 16.1307, 16.1318, 16.1328, 16.1338, 16.1349,
    16.1359, 16.1369, 16.138, 16.139, 16.14, 16.1411, 16.1421,
    16.1431, 16.1442, 16.1452, 16.1462, 16.1473, 16.1483, 16.1493,
    16.1504, 16.1514, 16.1524, 16.1534, 16.1545, 16.1555, 16.1565,
    16.1576, 16.1586, 16.1596, 16.1607, 16.1617, 16.1627, 16.1638,
    16.1648, 16.1658, 16.1668, 16.1679, 16.1689, 16.1699, 16.171,
    16.172, 16.173, 16.174, 16.1751, 16.1761, 16.1771, 16.1782,
    16.1792, 16.1802, 16.1813, 16.1823, 16.1833, 16.1843, 16.1854,
    16.1864, 16.1874, 16.1885, 16.1895, 16.1905, 16.1915, 16.1926,
    16.1936, 16.1946, 16.1956, 16.1967, 16.1977, 16.1987, 16.1998,
    16.2008, 16.2018, 16.2028, 16.2039, 16.2049, 16.2059, 16.207,
    16.208, 16.209, 16.21, 16.2111, 16.2121, 16.2131, 16.2141,
    16.2152, 16.2162, 16.2172, 16.2183, 16.2193, 16.2203, 16.2213,
    16.2224, 16.2234, 16.2244, 16.2255, 16.2265, 16.2275, 16.2285,
    16.2296, 16.2306, 16.2316, 16.2327, 16.2337, 16.2347, 16.2357,
    16.2368, 16.2378, 16.2388, 16.2399, 16.2409, 16.2419, 16.2429,
    16.244, 16.245, 16.246, 16.2471, 16.2481, 16.2491, 16.2501,
    16.2512, 16.2522, 16.2532, 16.2543, 16.2553, 16.2563, 16.2574,
    16.2584, 16.2594, 16.2605, 16.2615, 16.2625, 16.2636, 16.2646,
    16.2656, 16.2666, 16.2677, 16.2687, 16.2697, 16.2708, 16.2718,
    16.2728, 16.2739, 16.2749, 16.2759, 16.277, 16.278, 16.279,
    16.2801, 16.2811, 16.2821, 16.2832, 16.2842, 16.2852, 16.2863,
    16.2873, 16.2883, 16.2894, 16.2904, 16.2914, 16.2925, 16.2935,
    16.2945, 16.2956, 16.2966, 16.2976, 16.2987, 16.2997, 16.3007,
    16.3018, 16.3028, 16.3039, 16.3049, 16.3059, 16.307, 16.308,
    16.309, 16.3101, 16.3111, 16.3121, 16.3132, 16.3142, 16.3152,
    16.3163, 16.3173, 16.3184, 16.3194, 16.3204, 16.3215, 16.3225,
    16.3235, 16.3246, 16.3256, 16.3266, 16.3277, 16.3287, 16.3298,
    16.3308, 16.3318, 16.3329, 16.3339, 16.3349, 16.336, 16.337,
    16.3381, 16.3391, 16.3401, 16.3412, 16.3422, 16.3432, 16.3443,
    16.3453, 16.3464, 16.3474, 16.3484, 16.3495, 16.3505, 16.3515,
    16.3526, 16.3536, 16.3547, 16.3557, 16.3567, 16.3578, 16.3588,
    16.3599, 16.3609, 16.3619, 16.363, 16.364, 16.3651, 16.3661,
    16.3671, 16.3682, 16.3692, 16.3703, 16.3713, 16.3723, 16.3734,
    16.3744, 16.3754, 16.3765, 16.3775, 16.3786, 16.3796, 16.3806,
    16.3817, 16.3827, 16.3838, 16.3848, 16.3859, 16.3869, 16.3879,
    16.389, 16.39, 16.3911, 16.3921, 16.3931, 16.3942, 16.3952,
    16.3963, 16.3973, 16.3983, 16.3994, 16.4004, 16.4015, 16.4025,
    16.4035, 16.4046, 16.4056, 16.4067, 16.4077, 16.4088, 16.4098,
    16.4108, 16.4119, 16.4129, 16.414, 16.415, 16.4161, 16.4171,
    16.4181, 16.4192, 16.4202, 16.4213, 16.4223, 16.4234, 16.4244,
    16.4254, 16.4265, 16.4275, 16.4286, 16.4296, 16.4307, 16.4317,
    16.4328, 16.4338, 16.4348, 16.4359, 16.4369, 16.438, 16.439,
    16.4401, 16.4411, 16.4422, 16.4432, 16.4442, 16.4453, 16.4463,
    16.4474, 16.4484, 16.4495, 16.4505, 16.4516, 16.4526, 16.4537,
    16.4547, 16.4558, 16.4568, 16.4579, 16.4589, 16.46, 16.461,
    16.4621, 16.4631, 16.4641, 16.4652, 16.4662, 16.4673, 16.4683,
    16.4694, 16.4704, 16.4715, 16.4725, 16.4736, 16.4746, 16.4757,
    16.4767, 16.4778, 16.4788, 16.4799, 16.4809, 16.482, 16.483,
    16.4841, 16.4851, 16.4862, 16.4873, 16.4883, 16.4894, 16.4904,
    16.4915, 16.4925, 16.4936, 16.4946, 16.4957, 16.4967, 16.4978,
    16.4988, 16.4999, 16.5009, 16.502, 16.503, 16.5041, 16.5051,
    16.5062, 16.5073, 16.5083, 16.5094, 16.5104, 16.5115, 16.5125,
    16.5136, 16.5146, 16.5157, 16.5167, 16.5178, 16.51891, 16.5189,
    16.5199, 16.521, 16.522, 16.5231, 16.5241, 16.5252, 16.5262,
    16.5273, 16.5284, 16.5294, 16.5305, 16.5315, 16.5326, 16.5336,
    16.5347, 16.5358, 16.5368, 16.5379, 16.5389, 16.54, 16.541,
    16.5421, 16.5432, 16.5442, 16.5453, 16.5463, 16.5474, 16.5484,
    16.5495, 16.55158, 16.5506, 16.58562, 16.62121, 16.65854,
    16.69781, 16.73915, 16.78248, 16.82768, 16.87463, 16.92319,
    16.97324, 17.02466, 17.07731, 17.13106, 17.18581, 17.2414,
    17.29773, 17.35466, 17.41207, 17.46982, 17.52784, 17.58607,
    17.64449, 17.70307, 17.76178, 17.82059, 17.87946, 17.93836,
    17.99727, 18.05615, 18.11498, 18.17371, 18.23233, 18.2908,
    18.34908, 18.40721, 18.46524, 18.52324, 18.58127, 18.63939,
    18.69765, 18.75613, 18.81489, 18.87398, 18.93347, 18.99342,
    19.05389, 19.11495, 19.17665, 19.23906, 19.30221, 19.36613,
    19.43088, 19.49646, 19.56293, 19.63031, 19.69863, 19.76794,
    19.83825, 19.90962, 19.98207, 20.05563, 20.13034, 20.20623,
    20.28334, 20.36166, 20.44122, 20.52201, 20.60406, 20.68738,
    20.77196, 20.85783, 20.94498, 21.03344, 21.12321, 21.21431,
    21.30673, 21.4005, 21.49562, 21.59208, 21.68983, 21.78883,
    21.88905, 21.99043, 22.09294, 22.19654, 22.30118, 22.40682,
    22.51341, 22.62092, 22.72931, 22.83852, 22.94852, 23.05927,
    23.17069, 23.28271, 23.39523, 23.50818, 23.62148, 23.73504,
    23.84879, 23.96263, 24.07649, 24.19029, 24.30394, 24.41736,
    24.53048, 24.6432, 24.75546, 24.8672, 24.97838, 25.08897,
    25.19891, 25.30817, 25.4167, 25.52447, 25.63143, 25.73753,
    25.84274, 25.94701, 26.0503, 26.15257, 26.25377, 26.35388,
    26.45289, 26.55079, 26.64757, 26.74322, 26.83773, 26.9311,
    27.02332, 27.11438, 27.20427, 27.29299, 27.38052, 27.46686,
    27.552, 27.63593, 27.71865, 27.80016, 27.88048, 27.95959,
    28.03751, 28.11425, 28.1898, 28.26416, 28.33735, 28.40937,
    28.48021, 28.54989, 28.61841, 28.68577, 28.75198, 28.81703,
    28.88093, 28.94368, 29.00529, 29.06574, 29.12505, 29.18321,
    29.24023, 29.29611, 29.35084, 29.40443, 29.45689, 29.5082,
    29.55838, 29.60742, 13.0245, 13.0371, 13.0496, 13.062, 13.0744,
    13.0866, 13.0987, 13.1107, 13.1226, 13.1345, 13.1462, 13.1578,
    13.1693, 13.1806, 13.1919, 13.2031, 13.2142, 13.2251, 13.236,
    13.2467, 13.2574, 13.2679, 13.2783, 13.2886, 13.2988, 13.3089,
    13.3189, 13.3288, 13.3386, 13.3482, 13.3578, 13.3672, 13.3766,
    13.3858, 13.3949, 13.4039, 13.4129, 13.4217, 13.4304, 13.439,
    13.4475, 13.4559, 13.4642, 13.4724, 13.4805, 13.4886, 13.4965,
    13.5043, 13.5121, 13.5197, 13.5273, 13.5348, 13.5422, 13.5495,
    13.5567, 13.5638, 13.5709, 13.5778, 13.5847, 13.5915, 13.5983,
    13.6049, 13.6115, 13.618, 13.6244, 13.6308, 13.6371, 13.6433,
    13.6494, 13.6555, 13.6616, 13.6675, 13.6734, 13.6792, 13.685,
    13.6907, 13.6963, 13.7019, 13.7074, 13.7129, 13.7183, 13.7237,
    13.7289, 13.7342, 13.7394, 13.7445, 13.7496, 13.7546, 13.7595,
    13.7645, 13.7693, 13.7741, 13.7789, 13.7836, 13.7883, 13.7929,
    13.7975, 13.802, 13.8065, 13.8109, 13.8153, 13.8197, 13.824,
    13.8282, 13.8324, 13.8366, 13.8407, 13.8448, 13.8489, 13.8529,
    13.8569, 13.8608, 13.8647, 13.8685, 13.8723, 13.8761, 13.8799,
    13.8836, 13.8872, 13.8909, 13.8945, 13.898, 13.9016, 13.9051,
    13.9085, 13.912, 13.9154, 13.9187, 13.9221, 13.9254, 13.9287,
    13.9319, 13.9351, 13.9383, 13.9415, 13.9446, 13.9477, 13.9508,
    13.9539, 13.9569, 13.9599, 13.9628, 13.9658, 13.9687, 13.9716,
    13.9744, 13.9773, 13.9801, 13.9829, 13.9857, 13.9884, 13.9911,
    13.9938, 13.9965, 13.9991, 14.0018, 14.0044, 14.007, 14.0095,
    14.012, 14.0146, 14.017, 14.0195, 14.022, 14.0244, 14.0268,
    14.0292, 14.0315, 14.0339, 14.0362, 14.0385, 14.0408, 14.043,
    14.0453, 14.0475, 14.0497, 14.0519, 14.054, 14.0562, 14.0583,
    14.0604, 14.0625, 14.0646, 14.0666, 14.0687, 14.0707, 14.0727,
    14.0747, 14.0766, 14.0786, 14.0805, 14.0824, 14.0844, 14.0862,
    14.0881, 14.09, 14.0918, 14.0937, 14.0955, 14.0973, 14.0991,
    14.1008, 14.1026, 14.1043, 14.1061, 14.1078, 14.1095, 14.1112,
    14.1129, 14.1146, 14.1162, 14.1179, 14.1195, 14.1211, 14.1228,
    14.1244, 14.126, 14.1275, 14.1291, 14.1307, 14.1322, 14.1338,
    14.1353, 14.1368, 14.1383, 14.1398, 14.1413, 14.1428, 14.1443,
    14.1458, 14.1472, 14.1487, 14.1501, 14.1516, 14.153, 14.1544,
    14.1558, 14.1572, 14.1586, 14.16, 14.1614, 14.1628, 14.1642,
    14.1656, 14.1669, 14.1683, 14.1696, 14.171, 14.1723, 14.1737,
    14.175, 14.1763, 14.1777, 14.179, 14.1803, 14.1816, 14.1829,
    14.1842, 14.1855, 14.1869, 14.1882, 14.1894, 14.1907, 14.192,
    14.1933, 14.1946, 14.1959, 14.1972, 14.1985, 14.1998, 14.201,
    14.2023, 14.2036, 14.2049, 14.2062, 14.2074, 14.2087, 14.21,
    14.2113, 14.2126, 14.2138, 14.2151, 14.2164, 14.2177, 14.2189,
    14.2202, 14.2215, 14.2228, 14.224, 14.2253, 14.2266, 14.2279,
    14.2292, 14.2304, 14.2317, 14.233, 14.2343, 14.2356, 14.2369,
    14.2381, 14.2394, 14.2407, 14.242, 14.2433, 14.2446, 14.2459,
    14.2472, 14.2485, 14.2498, 14.2511, 14.2524, 14.2537, 14.255,
    14.2563, 14.2576, 14.2589, 14.2602, 14.2615, 14.2629, 14.2642,
    14.2655, 14.2668, 14.2682, 14.2695, 14.2708, 14.2722, 14.2735,
    14.2749, 14.2762, 14.2775, 14.2789, 14.2803, 14.2816, 14.283,
    14.2843, 14.2857, 14.2871, 14.2884, 14.2898, 14.2912, 14.2926,
    14.294, 14.2953, 14.2967, 14.2981, 14.2995, 14.3009, 14.3023,
    14.3037, 14.3051, 14.3065, 14.308, 14.3094, 14.3108, 14.3122,
    14.3136, 14.3151, 14.3165, 14.3179, 14.3194, 14.3208, 14.3223,
    14.3237, 14.3252, 14.3266, 14.3281, 14.3295, 14.331, 14.3325,
    14.3339, 14.3354, 14.3369, 14.3384, 14.3399, 14.3414, 14.3429,
    14.3444, 14.3459, 14.3474, 14.3489, 14.3504, 14.3519, 14.3534,
    14.355, 14.3565, 14.358, 14.3596, 14.3611, 14.3627, 14.3642,
    14.3658, 14.3673, 14.3689, 14.3705, 14.372, 14.3736, 14.3752,
    14.3768, 14.3784, 14.38, 14.3816, 14.3832, 14.3848, 14.3864,
    14.388, 14.3896, 14.3913, 14.3929, 14.3945, 14.3962, 14.3978,
    14.3995, 14.4011, 14.4028, 14.4044, 14.4061, 14.4078, 14.4094,
    14.4111, 14.4128, 14.4145, 14.4162, 14.4179, 14.4196, 14.4213,
    14.423, 14.4247, 14.4264, 14.4281, 14.4298, 14.4316, 14.4333,
    14.435, 14.4368, 14.4385, 14.4403, 14.442, 14.4438, 14.4455,
    14.4473, 14.4491, 14.4508, 14.4526, 14.4544, 14.4562, 14.458,
    14.4597, 14.4615, 14.4633, 14.4651, 14.4669, 14.4688, 14.4706,
    14.4724, 14.4742, 14.476, 14.4779, 14.4797, 14.4815, 14.4834,
    14.4852, 14.4871, 14.4889, 14.4908, 14.4926, 14.4945, 14.4964,
    14.4983, 14.5001, 14.502, 14.5039, 14.5058, 14.5077, 14.5096,
    14.5115, 14.5134, 14.5153, 14.5172, 14.5192, 14.5211, 14.523,
    14.5249, 14.5269, 14.5288, 14.5308, 14.5327, 14.5347, 14.5366,
    14.5386, 14.5406, 14.5425, 14.5445, 14.5465, 14.5484, 14.5504,
    14.5524, 14.5544, 14.5564, 14.5584, 14.5604, 14.5624, 14.5644,
    14.5664, 14.5685, 14.5705, 14.5725, 14.5745, 14.5766, 14.5786,
    14.5806, 14.5827, 14.5847, 14.5868, 14.5889, 14.5909, 14.593,
    14.5951, 14.5971, 14.5992, 14.6013, 14.6034, 14.6055, 14.6076,
    14.6097, 14.6118, 14.6139, 14.616, 14.6181, 14.6202, 14.6223,
    14.6245, 14.6266, 14.6287, 14.6309, 14.633, 14.6352, 14.6373,
    14.6395, 14.6416, 14.6438, 14.646, 14.6481, 14.6503, 14.6525,
    14.6547, 14.6569, 14.6591, 14.6613, 14.6635, 14.6657, 14.6679,
    14.6701, 14.6723, 14.6746, 14.6768, 14.679, 14.6813, 14.6835,
    14.6857, 14.688, 14.6902, 14.6925, 14.6948, 14.697, 14.6993,
    14.7016, 14.7038, 14.7061, 14.7084, 14.7107, 14.713, 14.7152,
    14.7175, 14.7198, 14.7221, 14.7245, 14.7268, 14.7291, 14.7314,
    14.7337, 14.736, 14.7384, 14.7407, 14.743, 14.7454, 14.7477,
    14.7501, 14.7524, 14.7548, 14.7571, 14.7595, 14.7618, 14.7642,
    14.7665, 14.7689, 14.7713, 14.7737, 14.776, 14.7784, 14.7808,
    14.7832, 14.7856, 14.788, 14.7904, 14.7928, 14.7952, 14.7976,
    14.8, 14.8024, 14.8048, 14.8072, 14.8096, 14.812, 14.8145,
    14.8169, 14.8193, 14.8217, 14.8242, 14.8266, 14.829, 14.8315,
    14.8339, 14.8364, 14.8388, 14.8413, 14.8437, 14.8462, 14.8486,
    14.8511, 14.8535, 14.856, 14.8585, 14.8609, 14.8634, 14.8659,
    14.8683, 14.8708, 14.8733, 14.8758, 14.8783, 14.8808, 14.8832,
    14.8857, 14.8882, 14.8907, 14.8932, 14.8957, 14.8982, 14.9007,
    14.9032, 14.9057, 14.9082, 14.9107, 14.9132, 14.9157, 14.9183,
    14.9208, 14.9233, 14.9258, 14.9283, 14.9308, 14.9333, 14.9359,
    14.9384, 14.9409, 14.9434, 14.9459, 14.9485, 14.951, 14.9535,
    14.956, 14.9585, 14.9611, 14.9636, 14.9661, 14.9686, 14.9712,
    14.9737, 14.9762, 14.9787, 14.9813, 14.9838, 14.9863, 14.9889,
    14.9914, 14.9939, 14.9964, 14.999, 15.0015, 15.004, 15.0065,
    15.0091, 15.0116, 15.0141, 15.0166, 15.0192, 15.0217, 15.0242,
    15.0267, 15.0292, 15.0318, 15.0343, 15.0368, 15.0393, 15.0418,
    15.0443, 15.0468, 15.0494, 15.0519, 15.0544, 15.0569, 15.0594,
    15.0619, 15.0644, 15.0669, 15.0694, 15.0719, 15.0743, 15.0768,
    15.0793, 15.0818, 15.0843, 15.0868, 15.0892, 15.0917, 15.0942,
    15.0967, 15.0991, 15.1016, 15.1041, 15.1065, 15.109, 15.1114,
    15.1139, 15.1163, 15.1188, 15.1212, 15.1236, 15.1261, 15.1285,
    15.1309, 15.1334, 15.1358, 15.1382, 15.1406, 15.143, 15.1454,
    15.1478, 15.1502, 15.1526, 15.155, 15.1574, 15.1598, 15.1622,
    15.1646, 15.167, 15.1693, 15.1717, 15.1741, 15.1764, 15.1788,
    15.1811, 15.1835, 15.1858, 15.1882, 15.1905, 15.1928, 15.1952,
    15.1975, 15.1998, 15.2021, 15.2045, 15.2068, 15.2091, 15.2114,
    15.2137, 15.216, 15.2183, 15.2205, 15.2228, 15.2251, 15.2274,
    15.2296, 15.2319, 15.2342, 15.2364, 15.2387, 15.2409, 15.2432,
    15.2454, 15.2476, 15.2499, 15.2521, 15.2543, 15.2565, 15.2587,
    15.2609, 15.2631, 15.2653, 15.2675, 15.2697, 15.2719, 15.2741,
    15.2762, 15.2784, 15.2806, 15.2827, 15.2849, 15.287, 15.2892,
    15.2913, 15.2934, 15.2956, 15.2977, 15.2998, 15.3019, 15.304,
    15.3061, 15.3082, 15.3103, 15.3124, 15.3145, 15.3166, 15.3187,
    15.3207, 15.3228, 15.3248, 15.3269, 15.329, 15.331, 15.333,
    15.3351, 15.3371, 15.3391, 15.3412, 15.3432, 15.3452, 15.3472,
    15.3492, 15.3512, 15.3532, 15.3552, 15.3572, 15.3591, 15.3611,
    15.3631, 15.3651, 15.367, 15.369, 15.3709, 15.3729, 15.3748,
    15.3768, 15.3787, 15.3806, 15.3826, 15.3845, 15.3864, 15.3883,
    15.3902, 15.3922, 15.3941, 15.396, 15.3979, 15.3997, 15.4016,
    15.4035, 15.4054, 15.4073, 15.4092, 15.411, 15.4129, 15.4148,
    15.4166, 15.4185, 15.4203, 15.4222, 15.424, 15.4259, 15.4277,
    15.4296, 15.4314, 15.4332, 15.4351, 15.4369, 15.4387, 15.4405,
    15.4424, 15.4442, 15.446, 15.4478, 15.4496, 15.4514, 15.4532,
    15.455, 15.4568, 15.4586, 15.4604, 15.4622, 15.464, 15.4658,
    15.4675, 15.4693, 15.4711, 15.4729, 15.4747, 15.4764, 15.4782,
    15.48, 15.4817, 15.4835, 15.4853, 15.487, 15.4888, 15.4905,
    15.4923, 15.494, 15.4958, 15.4975, 15.4993, 15.501, 15.5028,
    15.5045, 15.5063, 15.508, 15.5097, 15.5115, 15.5132, 15.5149,
    15.5167, 15.5184, 15.5201, 15.5219, 15.5236, 15.5253, 15.527,
    15.5288, 15.5305, 15.5322, 15.5339, 15.5356, 15.5374, 15.5391,
    15.5408, 15.5425, 15.5442, 15.5459, 15.5476, 15.5493, 15.5511,
    15.5528, 15.5545, 15.5562, 15.5579, 15.5596, 15.5613, 15.563,
    15.5647, 15.5664, 15.5681, 15.5698, 15.5715, 15.5732, 15.5749,
    15.5766, 15.5783, 15.58, 15.5817, 15.5834, 15.5851, 15.5868,
    15.5885, 15.5902, 15.5919, 15.5936, 15.5953, 15.597, 15.5987,
    15.6004, 15.602, 15.6037, 15.6054, 15.6071, 15.6088, 15.6105,
    15.6122, 15.6139, 15.6156, 15.6173, 15.619, 15.6206, 15.6223,
    15.624, 15.6257, 15.6274, 15.6291, 15.6308, 15.6325, 15.6342,
    15.6358, 15.6375, 15.6392, 15.6409, 15.6426, 15.6443, 15.646,
    15.6477, 15.6494, 15.651, 15.6527, 15.6544, 15.6561, 15.6578,
    15.6595, 15.6612, 15.6629, 15.6645, 15.6662, 15.6679, 15.6696,
    15.6713, 15.673, 15.6747, 15.6764, 15.678, 15.6797, 15.6814,
    15.6831, 15.6848, 15.6865, 15.6882, 15.6899, 15.6916, 15.6932,
    15.6949, 15.6966, 15.6983, 15.7, 15.7017, 15.7034, 15.7051,
    15.7067, 15.7084, 15.7101, 15.7118, 15.7135, 15.7152, 15.7169,
    15.7186, 15.7203, 15.7219, 15.7236, 15.7253, 15.727, 15.7287,
    15.7304, 15.7321, 15.7338, 15.7355, 15.7371, 15.7388, 15.7405,
    15.7422, 15.7439, 15.7456, 15.7473, 15.749, 15.7507, 15.7524,
    15.754, 15.7557, 15.7574, 15.7591, 15.7608, 15.7625, 15.7642,
    15.7659, 15.7676, 15.7692, 15.7709, 15.7726, 15.7743, 15.776,
    15.7777, 15.7794, 15.7811, 15.7828, 15.7844, 15.7861, 15.7878,
    15.7895, 15.7912, 15.7929, 15.7946, 15.7963, 15.7979, 15.7996,
    15.8013, 15.803, 15.8047, 15.8064, 15.808, 15.8097, 15.8114,
    15.8131, 15.8148, 15.8165, 15.8182, 15.8198, 15.8215, 15.8232,
    15.8249, 15.8266, 15.8282, 15.8299, 15.8316, 15.8333, 15.835,
    15.8366, 15.8383, 15.84, 15.8417, 15.8433, 15.845, 15.8467,
    15.8484, 15.85, 15.8517, 15.8534, 15.8551, 15.8567, 15.8584,
    15.8601, 15.8618, 15.8634, 15.8651, 15.8668, 15.8684, 15.8701,
    15.8718, 15.8734, 15.8751, 15.8768, 15.8784, 15.8801, 15.8818,
    15.8834, 15.8851, 15.8868, 15.8884, 15.8901, 15.8918, 15.8934,
    15.8951, 15.8967, 15.8984, 15.9001, 15.9017, 15.9034, 15.905,
    15.9067, 15.9084, 15.91, 15.9117, 15.9133, 15.915, 15.9166,
    15.9183, 15.9199, 15.9216, 15.9232, 15.9249, 15.9265, 15.9282,
    15.9298, 15.9315, 15.9331, 15.9348, 15.9364, 15.9381, 15.9397,
    15.9414, 15.943, 15.9447, 15.9463, 15.9479, 15.9496, 15.9512,
    15.9529, 15.9545, 15.9561, 15.9578, 15.9594, 15.9611, 15.9627,
    15.9643, 15.966, 15.9676, 15.9693, 15.9709, 15.9725, 15.9742,
    15.9758, 15.9774, 15.9791, 15.9807, 15.9823, 15.984, 15.9856,
    15.9872, 15.9888, 15.9905, 15.9921, 15.9937, 15.9954, 15.997,
    15.9986, 16.0002, 16.0019, 16.0035, 16.0051, 16.0067, 16.0084,
    16.01, 16.0116, 16.0132, 16.0149, 16.0165, 16.0181, 16.0197,
    16.0214, 16.023, 16.0246, 16.0262, 16.0278, 16.0295, 16.0311,
    16.0327, 16.0343, 16.0359, 16.0376, 16.0392, 16.0408, 16.0424,
    16.044, 16.0457, 16.0473, 16.0489, 16.0505, 16.0521, 16.0538,
    16.0554, 16.057, 16.0586, 16.0602, 16.0618, 16.0635, 16.0651,
    16.0667, 16.0683, 16.0699, 16.0715, 16.0731, 16.0748, 16.0764,
    16.078, 16.0796, 16.0812, 16.0828, 16.0844, 16.0861, 16.0877,
    16.0893, 16.0909, 16.0925, 16.0941, 16.0957, 16.0974, 16.099,
    16.1006, 16.1022, 16.1038, 16.1054, 16.107, 16.1086, 16.1103,
    16.1119, 16.1135, 16.1151, 16.1167, 16.1183, 16.1199, 16.1215,
    16.1232, 16.1248, 16.1264, 16.128, 16.1296, 16.1312, 16.1328,
    16.1344, 16.136, 16.1377, 16.1393, 16.1409, 16.1425, 16.1441,
    16.1457, 16.1473, 16.1489, 16.1506, 16.1522, 16.1538, 16.1554,
    16.157, 16.1586, 16.1602, 16.1619, 16.1635, 16.1651, 16.1667,
    16.1683, 16.1699, 16.1715, 16.1732, 16.1748, 16.1764, 16.178,
    16.1796, 16.1812, 16.1828, 16.1845, 16.1861, 16.1877, 16.1893,
    16.1909, 16.1925, 16.1942, 16.1958, 16.1974, 16.199, 16.2006,
    16.2022, 16.2039, 16.2055, 16.2071, 16.2087, 16.2103, 16.212,
    16.2136, 16.2152, 16.2168, 16.2184, 16.2201, 16.2217, 16.2233,
    16.2249, 16.2266, 16.2282, 16.2298, 16.2314, 16.2331, 16.2347,
    16.2363, 16.2379, 16.2396, 16.2412, 16.2428, 16.2444, 16.2461,
    16.2477, 16.2493, 16.2509, 16.2526, 16.2542, 16.2558, 16.2575,
    16.2591, 16.2607, 16.2624, 16.264, 16.2656, 16.2673, 16.2689,
    16.2705, 16.2722, 16.2738, 16.2754, 16.2771, 16.2787, 16.2803,
    16.282, 16.2836, 16.2852, 16.2869, 16.2885, 16.2901, 16.2918,
    16.2934, 16.2951, 16.2967, 16.2983, 16.3, 16.3016, 16.3033,
    16.3049, 16.3065, 16.3082, 16.3098, 16.3115, 16.3131, 16.3148,
    16.3164, 16.318, 16.3197, 16.3213, 16.323, 16.3246, 16.3263,
    16.3279, 16.3296, 16.3312, 16.3329, 16.3345, 16.3362, 16.3378,
    16.3395, 16.3411, 16.3428, 16.3444, 16.3461, 16.3477, 16.3494,
    16.351, 16.3527, 16.3544, 16.356, 16.3577, 16.3593, 16.361,
    16.3626, 16.3643, 16.366, 16.3676, 16.3693, 16.3709, 16.3726,
    16.3742, 16.3759, 16.3776, 16.3792, 16.3809, 16.3826, 16.3842,
    16.3859, 16.3875, 16.3892, 16.3909, 16.3925, 16.3942, 16.3959,
    16.3975, 16.3992, 16.4009, 16.4025, 16.4042, 16.4059, 16.4075,
    16.4092, 16.4109, 16.4125, 16.4142, 16.4159, 16.4176, 16.4192,
    16.4209, 16.4226, 16.4242, 16.4259, 16.4276, 16.4293, 16.4309,
    16.4326, 16.4343, 16.436, 16.4376, 16.4393, 16.441, 16.4427,
    16.4443, 16.446, 16.4477, 16.4494, 16.4511, 16.4527, 16.4544,
    16.4561, 16.4578, 16.4595, 16.4611, 16.4628, 16.4645, 16.4662,
    16.4679, 16.4695, 16.4712, 16.4729, 16.4746, 16.4763, 16.4779,
    16.4796, 16.4813, 16.483, 16.4847, 16.4864, 16.488, 16.4897,
    16.4914, 16.4931, 16.4948, 16.4965, 16.4981, 16.4998, 16.5015,
    16.5032, 16.5049, 16.5066, 16.5082, 16.5099, 16.5116, 16.5133,
    16.515, 16.5167, 16.5184, 16.52, 16.5217, 16.5234, 16.5251,
    16.5268, 16.5285, 16.5302, 16.5318, 16.5335, 16.5352, 16.5369,
    16.5386, 16.5403, 16.5419, 16.5436, 16.5453, 16.547, 16.5487,
    16.5504, 16.5521, 16.5537, 16.5554, 16.5571, 16.5588, 16.5605,
    16.5622, 16.5638, 16.5655, 16.5672, 16.5689, 16.5706, 16.5722,
    16.5739, 16.5756, 16.5773, 16.579, 16.5807, 16.5823, 16.584,
    16.5857, 16.5874, 16.5891, 16.5907, 16.5924, 16.5941, 16.5958,
    16.5975, 16.5991, 16.6008, 16.6025, 16.6042, 16.6058, 16.6075,
    16.6092, 16.6109, 16.6125, 16.6142, 16.6159, 16.6176, 16.6192,
    16.6209, 16.6226, 16.6243, 16.6259, 16.6276, 16.6293, 16.6309,
    16.6326, 16.6343, 16.6359, 16.6376, 16.6393, 16.641, 16.6426,
    16.6443, 16.646, 16.6476, 16.6493, 16.651, 16.6526, 16.6543,
    16.6559, 16.6576, 16.6593, 16.6609, 16.6626, 16.6643, 16.6659,
    16.6676, 16.6692, 16.6709, 16.6726, 16.6742, 16.6759, 16.6775,
    16.6792, 16.6808, 16.6825, 16.6842, 16.6858, 16.6875, 16.6891,
    16.6908, 16.6924, 16.6941, 16.6957, 16.6974, 16.699, 16.7007,
    16.7023, 16.704, 16.7056, 16.7073, 16.7089, 16.7106, 16.7122,
    16.7139, 16.7155, 16.7172, 16.7188, 16.7204, 16.7221, 16.7237,
    16.7254, 16.727, 16.7287, 16.7303, 16.7319, 16.7336, 16.7352,
    16.7369, 16.7385, 16.7402, 16.7418, 16.7434, 16.7451, 16.7467,
    16.7483, 16.75, 16.7516, 16.7533, 16.7549, 16.7565, 16.7582,
    16.7598, 16.7614, 16.7631, 16.7647, 16.7663, 16.768, 16.7696,
    16.7712, 16.7728, 16.7745, 16.7761, 16.7777, 16.7794, 16.781,
    16.7826, 16.7842, 16.7859, 16.7875, 16.7891, 16.7908, 16.7924,
    16.794, 16.7956, 16.7973, 16.7989, 16.8005, 16.8021, 16.8037,
    16.8054, 16.807, 16.8086, 16.8102, 16.8119, 16.8135, 16.8151,
    16.8167, 16.8183, 16.82, 16.8216, 16.8232, 16.8248, 16.8264,
    16.828, 16.8297, 16.8313, 16.8329, 16.8345, 16.8361, 16.8377,
    16.8393, 16.841, 16.8426, 16.8442, 16.8458, 16.8474, 16.849,
    16.8506, 16.81684, 16.8522, 16.8538, 16.8555, 16.8571, 16.8587,
    16.8603, 16.8619, 16.8635, 16.8651, 16.8667, 16.8683, 16.8699,
    16.8715, 16.8731, 16.8747, 16.8763, 16.878, 16.8796, 16.8812,
    16.8828, 16.8844, 16.886, 16.8876, 16.8892, 16.8908, 16.8924,
    16.894, 16.8956, 16.8972, 16.8988, 16.86234, 16.9004, 16.90778,
    16.95319, 16.99859, 17.044, 17.08945, 17.13499, 17.18065,
    17.22647, 17.2725, 17.31876, 17.36531, 17.41218, 17.45942,
    17.50705, 17.55514, 17.6037, 17.65279, 17.70244, 17.7527,
    17.80359, 17.85514, 17.90734, 17.96022, 18.01378, 18.06804,
    18.123, 18.17868, 18.2351, 18.29225, 18.35016, 18.40883,
    18.46827, 18.5285, 18.58953, 18.65136, 18.71396, 18.77734,
    18.84147, 18.90633, 18.97192, 19.03822, 19.10522, 19.17289,
    19.24123, 19.31023, 19.37986, 19.45011, 19.52097, 19.59243,
    19.66448, 19.73712, 19.81035, 19.88418, 19.95861, 20.03364,
    20.10928, 20.18551, 20.26235, 20.33979, 20.41785, 20.49651,
    20.57578, 20.65567, 20.73616, 20.81724, 20.89887, 20.98103,
    21.0637, 21.14683, 21.23041, 21.31441, 21.3988, 21.48355,
    21.56863, 21.65401, 21.73968, 21.82559, 21.91173, 21.99804,
    22.08447, 22.17095, 22.25742, 22.3438, 22.43004, 22.51607,
    22.60182, 22.68723, 22.77224, 22.85678, 22.94077, 23.02417,
    23.1069, 23.1889, 23.27013, 23.35053, 23.43008, 23.50874,
    23.58647, 23.66323, 23.73898, 23.81369, 23.88732, 23.95982,
    24.03118, 24.10133, 24.17025, 24.2379, 24.30425, 24.36928,
    24.433, 24.49541, 24.55649, 24.61626, 24.6747, 24.73182,
    24.78761, 24.84208, 24.89521, 24.94702, 24.99749, 25.04663,
    25.09442, 25.14089, 25.18605, 25.22993, 25.27255, 25.31393,
    25.3541, 25.39309, 25.43091, 25.4676, 25.50317, 25.53766,
    25.57108, 25.60346, 25.63483, 25.6652, 25.69462, 25.7231,
    25.75069, 25.77741, 25.80329, 25.82837, 25.85269, 25.87626,
    25.89913, 25.92133, 25.94288, 25.96382, 25.98419, 26.00401,
    26.02332, 26.04213, 26.06047, 26.07835, 26.0958, 26.11283,
    26.12947, 26.14572, 26.16161, 26.17717, 26.1924, 26.20732,
    26.22197, 26.23634, 26.25047, 26.26437, 7.692, 7.6853, 7.6787,
    7.6721, 7.6654, 7.6589, 7.6523, 7.6458, 7.6393, 7.6328, 7.6263,
    7.6198, 7.6134, 7.607, 7.6006, 7.5943, 7.588, 7.5816, 7.5753,
    7.5691, 7.5628, 7.5566, 7.5504, 7.5442, 7.538, 7.5318, 7.5257,
    7.5196, 7.5135, 7.5074, 7.5013, 7.4953, 7.4893, 7.4833, 7.4773,
    7.4713, 7.4653, 7.4594, 7.4535, 7.4476, 7.4417, 7.4358, 7.43,
    7.4241, 7.4183, 7.4125, 7.4067, 7.4009, 7.3952, 7.3894, 7.3837,
    7.378, 7.3723, 7.3666, 7.361, 7.3553, 7.3497, 7.3441, 7.3385,
    7.3329, 7.3273, 7.3218, 7.3162, 7.3107, 7.3052, 7.2997, 7.2942,
    7.2887, 7.2833, 7.2778, 7.2724, 7.267, 7.2616, 7.2562, 7.2509,
    7.2455, 7.2402, 7.2349, 7.2296, 7.2243, 7.219, 7.2137, 7.2085,
    7.2033, 7.1981, 7.1929, 7.1877, 7.1825, 7.1773, 7.1722, 7.1671,
    7.162, 7.1569, 7.1518, 7.1467, 7.1417, 7.1366, 7.1316, 7.1266,
    7.1216, 7.1166, 7.1116, 7.1067, 7.1018, 7.0968, 7.0919, 7.087,
    7.0822, 7.0773, 7.0724, 7.0676, 7.0628, 7.058, 7.0532, 7.0484,
    7.0436, 7.0389, 7.0342, 7.0294, 7.0247, 7.0201, 7.0154, 7.0107,
    7.0061, 7.0014, 6.9968, 6.9922, 6.9876, 6.983, 6.9785, 6.9739,
    6.9694, 6.9649, 6.9604, 6.9559, 6.9514, 6.9469, 6.9425, 6.9381,
    6.9336, 6.9292, 6.9248, 6.9205, 6.9161, 6.9117, 6.9074, 6.9031,
    6.8988, 6.8945, 6.8902, 6.8859, 6.8817, 6.8774, 6.8732, 6.869,
    6.8648, 6.8606, 6.8564, 6.8523, 6.8481, 6.844, 6.8399, 6.8358,
    6.8317, 6.8276, 6.8236, 6.8195, 6.8155, 6.8115, 6.8074, 6.8034,
    6.7995, 6.7955, 6.7915, 6.7876, 6.7837, 6.7798, 6.7759, 6.772,
    6.7681, 6.7642, 6.7604, 6.7565, 6.7527, 6.7489, 6.7451, 6.7413,
    6.7376, 6.7338, 6.7301, 6.7263, 6.7226, 6.7189, 6.7152, 6.7116,
    6.7079, 6.7042, 6.7006, 6.697, 6.6934, 6.6898, 6.6862, 6.6826,
    6.679, 6.6755, 6.6719, 6.6684, 6.6649, 6.6614, 6.6579, 6.6544,
    6.651, 6.6475, 6.6441, 6.6407, 6.6373, 6.6339, 6.6305, 6.6271,
    6.6237, 6.6204, 6.6171, 6.6137, 6.6104, 6.6071, 6.6038, 6.6006,
    6.5973, 6.594, 6.5908, 6.5876, 6.5844, 6.5812, 6.578, 6.5748,
    6.5716, 6.5685, 6.5653, 6.5622, 6.5591, 6.5559, 6.5528, 6.5498,
    6.5467, 6.5436, 6.5406, 6.5375, 6.5345, 6.5315, 6.5285, 6.5255,
    6.5225, 6.5195, 6.5165, 6.5136, 6.5107, 6.5077, 6.5048, 6.5019,
    6.499, 6.4961, 6.4932, 6.4904, 6.4875, 6.4847, 6.4819, 6.479,
    6.4762, 6.4734, 6.4706, 6.4679, 6.4651, 6.4624, 6.4596, 6.4569,
    6.4542, 6.4514, 6.4487, 6.446, 6.4434, 6.4407, 6.438, 6.4354,
    6.4328, 6.4301, 6.4275, 6.4249, 6.4223, 6.4197, 6.4171, 6.4146,
    6.412, 6.4095, 6.4069, 6.4044, 6.4019, 6.3994, 6.3969, 6.3944,
    6.3919, 6.3894, 6.387, 6.3845, 6.3821, 6.3796, 6.3772, 6.3748,
    6.3724, 6.37, 6.3676, 6.3653, 6.3629, 6.3605, 6.3582, 6.3558,
    6.3535, 6.3512, 6.3489, 6.3466, 6.3443, 6.342, 6.3397, 6.3375,
    6.3352, 6.333, 6.3307, 6.3285, 6.3263, 6.324, 6.3218, 6.3196,
    6.3175, 6.3153, 6.3131, 6.3109, 6.3088, 6.3066, 6.3045, 6.3024,
    6.3003, 6.2981, 6.296, 6.2939, 6.2918, 6.2898, 6.2877, 6.2856,
    6.2836, 6.2815, 6.2795, 6.2775, 6.2754, 6.2734, 6.2714, 6.2694,
    6.2674, 6.2654, 6.2635, 6.2615, 6.2595, 6.2576, 6.2556, 6.2537,
    6.2518, 6.2498, 6.2479, 6.246, 6.2441, 6.2422, 6.2403, 6.2384,
    6.2366, 6.2347, 6.2329, 6.231, 6.2292, 6.2273, 6.2255, 6.2237,
    6.2219, 6.2201, 6.2183, 6.2165, 6.2147, 6.2129, 6.2111, 6.2094,
    6.2076, 6.2059, 6.2041, 6.2024, 6.2006, 6.1989, 6.1972, 6.1955,
    6.1938, 6.1921, 6.1904, 6.1887, 6.1871, 6.1854, 6.1837, 6.1821,
    6.1804, 6.1788, 6.1771, 6.1755, 6.1739, 6.1723, 6.1706, 6.169,
    6.1674, 6.1658, 6.1643, 6.1627, 6.1611, 6.1595, 6.158, 6.1564,
    6.1549, 6.1533, 6.1518, 6.1502, 6.1487, 6.1472, 6.1457, 6.1442,
    6.1427, 6.1412, 6.1397, 6.1382, 6.1367, 6.1352, 6.1338, 6.1323,
    6.1308, 6.1294, 6.1279, 6.1265, 6.1251, 6.1236, 6.1222, 6.1208,
    6.1194, 6.118, 6.1166, 6.1152, 6.1138, 6.1124, 6.111, 6.1096,
    6.1082, 6.1069, 6.1055, 6.1041, 6.1028, 6.1014, 6.1001, 6.0988,
    6.0974, 6.0961, 6.0948, 6.0934, 6.0921, 6.0908, 6.0895, 6.0882,
    6.0869, 6.0856, 6.0843, 6.0831, 6.0818, 6.0805, 6.0793, 6.078,
    6.0767, 6.0755, 6.0742, 6.073, 6.0718, 6.0705, 6.0693, 6.0681,
    6.0669, 6.0656, 6.0644, 6.0632, 6.062, 6.0608, 6.0597, 6.0585,
    6.0573, 6.0561, 6.0549, 6.0538, 6.0526, 6.0515, 6.0503, 6.0492,
    6.048, 6.0469, 6.0457, 6.0446, 6.0435, 6.0424, 6.0413, 6.0401,
    6.039, 6.0379, 6.0368, 6.0357, 6.0347, 6.0336, 6.0325, 6.0314,
    6.0303, 6.0293, 6.0282, 6.0272, 6.0261, 6.0251, 6.024, 6.023,
    6.0219, 6.0209, 6.0199, 6.0189, 6.0178, 6.0168, 6.0158, 6.0148,
    6.0138, 6.0128, 6.0118, 6.0108, 6.0098, 6.0089, 6.0079, 6.0069,
    6.0059, 6.005, 6.004, 6.0031, 6.0021, 6.0012, 6.0002, 5.9993,
    5.9983, 5.9974, 5.9965, 5.9955, 5.9946, 5.9937, 5.9928, 5.9919,
    5.991, 5.9901, 5.9892, 5.9883, 5.9874, 5.9865, 5.9856, 5.9847,
    5.9839, 5.983, 5.9821, 5.9812, 5.9804, 5.9795, 5.9787, 5.9778,
    5.977, 5.9761, 5.9753, 5.9744, 5.9736, 5.9728, 5.9719, 5.9711,
    5.9703, 5.9695, 5.9687, 5.9678, 5.967, 5.9662, 5.9654, 5.9646,
    5.9638, 5.963, 5.9622, 5.9615, 5.9607, 5.9599, 5.9591, 5.9583,
    5.9576, 5.9568, 5.956, 5.9553, 5.9545, 5.9537, 5.953, 5.9522,
    5.9515, 5.9507, 5.95, 5.9492, 5.9485, 5.9478, 5.947, 5.9463,
    5.9456, 5.9448, 5.9441, 5.9434, 5.9427, 5.942, 5.9412, 5.9405,
    5.9398, 5.9391, 5.9384, 5.9377, 5.937, 5.9363, 5.9356, 5.9349,
    5.9342, 5.9336, 5.9329, 5.9322, 5.9315, 5.9308, 5.9302, 5.9295,
    5.9288, 5.9281, 5.9275, 5.9268, 5.9261, 5.9255, 5.9248, 5.9242,
    5.9235, 5.9229, 5.9222, 5.9216, 5.9209, 5.9203, 5.9196, 5.919,
    5.9184, 5.9177, 5.9171, 5.9165, 5.9158, 5.9152, 5.9146, 5.914,
    5.9133, 5.9127, 5.9121, 5.9115, 5.9109, 5.9103, 5.9097, 5.909,
    5.9084, 5.9078, 5.9072, 5.9066, 5.906, 5.9054, 5.9048, 5.9042,
    5.9036, 5.9031, 5.9025, 5.9019, 5.9013, 5.9007, 5.9001, 5.8995,
    5.899, 5.8984, 5.8978, 5.8972, 5.8967, 5.8961, 5.8955, 5.895,
    5.8944, 5.8938, 5.8933, 5.8927, 5.8921, 5.8916, 5.891, 5.8905,
    5.8899, 5.8893, 5.8888, 5.8882, 5.8877, 5.8871, 5.8866, 5.8861,
    5.8855, 5.885, 5.8844, 5.8839, 5.8833, 5.8828, 5.8823, 5.8817,
    5.8812, 5.8807, 5.8801, 5.8796, 5.8791, 5.8785, 5.878, 5.8775,
    5.8769, 5.8764, 5.8759, 5.8754, 5.8749, 5.8743, 5.8738, 5.8733,
    5.8728, 5.8723, 5.8717, 5.8712, 5.8707, 5.8702, 5.8697, 5.8692,
    5.8687, 5.8682, 5.8677, 5.8672, 5.8666, 5.8661, 5.8656, 5.8651,
    5.8646, 5.8641, 5.8636, 5.8631, 5.8626, 5.8621, 5.8617, 5.8612,
    5.8607, 5.8602, 5.8597, 5.8592, 5.8587, 5.8582, 5.8577, 5.8572,
    5.8567, 5.8563, 5.8558, 5.8553, 5.8548, 5.8543, 5.8538, 5.8534,
    5.8529, 5.8524, 5.8519, 5.8514, 5.851, 5.8505, 5.85, 5.8495,
    5.849, 5.8486, 5.8481, 5.8476, 5.8472, 5.8467, 5.8462, 5.8457,
    5.8453, 5.8448, 5.8443, 5.8439, 5.8434, 5.8429, 5.8424, 5.842,
    5.8415, 5.841, 5.8406, 5.8401, 5.8396, 5.8392, 5.8387, 5.8382,
    5.8378, 5.8373, 5.8369, 5.8364, 5.8359, 5.8355, 5.835, 5.8345,
    5.8341, 5.8336, 5.8332, 5.8327, 5.8322, 5.8318, 5.8313, 5.8309,
    5.8304, 5.8299, 5.8295, 5.829, 5.8286, 5.8281, 5.8276, 5.8272,
    5.8267, 5.8263, 5.8258, 5.8253, 5.8249, 5.8244, 5.824, 5.8235,
    5.8231, 5.8226, 5.8221, 5.8217, 5.8212, 5.8208, 5.8203, 5.8199,
    5.8194, 5.8189, 5.8185, 5.818, 5.8176, 5.8171, 5.8167, 5.8162,
    5.8157, 5.8153, 5.8148, 5.8144, 5.8139, 5.8135, 5.813, 5.8125,
    5.8121, 5.8116, 5.8112, 5.8107, 5.8103, 5.8098, 5.8093, 5.8089,
    5.8084, 5.808, 5.8075, 5.8071, 5.8066, 5.8061, 5.8057, 5.8052,
    5.8048, 5.8043, 5.8038, 5.8034, 5.8029, 5.8025, 5.802, 5.8015,
    5.8011, 5.8006, 5.8002, 5.7997, 5.7993, 5.7988, 5.7983, 5.7979,
    5.7974, 5.797, 5.7965, 5.796, 5.7956, 5.7951, 5.7946, 5.7942,
    5.7937, 5.7933, 5.7928, 5.7923, 5.7919, 5.7914, 5.7909, 5.7905,
    5.79, 5.7896, 5.7891, 5.7886, 5.7882, 5.7877, 5.7872, 5.7868,
    5.7863, 5.7858, 5.7854, 5.7849, 5.7844, 5.784, 5.7835, 5.783,
    5.7825, 5.7821, 5.7816, 5.7811, 5.7807, 5.7802, 5.7797, 5.7793,
    5.7788, 5.7783, 5.7778, 5.7774, 5.7769, 5.7764, 5.7759, 5.7755,
    5.775, 5.7745, 5.774, 5.7736, 5.7731, 5.7726, 5.7721, 5.7717,
    5.7712, 5.7707, 5.7702, 5.7697, 5.7693, 5.7688, 5.7683, 5.7678,
    5.7673, 5.7669, 5.7664, 5.7659, 5.7654, 5.7649, 5.7644, 5.764,
    5.7635, 5.763, 5.7625, 5.762, 5.7615, 5.761, 5.7606, 5.7601,
    5.7596, 5.7591, 5.7586, 5.7581, 5.7576, 5.7572, 5.7567, 5.7562,
    5.7557, 5.7552, 5.7547, 5.7542, 5.7537, 5.7532, 5.7527, 5.7523,
    5.7518, 5.7513, 5.7508, 5.7503, 5.7498, 5.7493, 5.7488, 5.7483,
    5.7478, 5.7473, 5.7468, 5.7463, 5.7458, 5.7453, 5.7449, 5.7444,
    5.7439, 5.7434, 5.7429, 5.7424, 5.7419, 5.7414, 5.7409, 5.7404,
    5.7399, 5.7394, 5.7389, 5.7384, 5.7379, 5.7374, 5.7369, 5.7364,
    5.7359, 5.7354, 5.7349, 5.7344, 5.7339, 5.7334, 5.7329, 5.7324,
    5.7319, 5.7314, 5.7309, 5.7304, 5.7299, 5.7294, 5.7289, 5.7284,
    5.7279, 5.7274, 5.7269, 5.7264, 5.7259, 5.7254, 5.7249, 5.7244,
    5.7239, 5.7234, 5.7229, 5.7224, 5.7219, 5.7214, 5.7209, 5.7204,
    5.7199, 5.7194, 5.7189, 5.7184, 5.7179, 5.7174, 5.7169, 5.7163,
    5.7158, 5.7153, 5.7148, 5.7143, 5.7138, 5.7133, 5.7128, 5.7123,
    5.7118, 5.7113, 5.7108, 5.7103, 5.7098, 5.7093, 5.7088, 5.7083,
    5.7078, 5.7073, 5.7068, 5.7063, 5.7057, 5.7052, 5.7047, 5.7042,
    5.7037, 5.7032, 5.7027, 5.7022, 5.7017, 5.7012, 5.7007, 5.7002,
    5.6997, 5.6991, 5.6986, 5.6981, 5.6976, 5.6971, 5.6966, 5.6961,
    5.6956, 5.6951, 5.6946, 5.6941, 5.6935, 5.693, 5.6925, 5.692,
    5.6915, 5.691, 5.6905, 5.69, 5.6895, 5.689, 5.6884, 5.6879,
    5.6874, 5.6869, 5.6864, 5.6859, 5.6854, 5.6849, 5.6843, 5.6838,
    5.6833, 5.6828, 5.6823, 5.6818, 5.6813, 5.6808, 5.6802, 5.6797,
    5.6792, 5.6787, 5.6782, 5.6777, 5.6772, 5.6766, 5.6761, 5.6756,
    5.6751, 5.6746, 5.6741, 5.6736, 5.673, 5.6725, 5.672, 5.6715,
    5.671, 5.6705, 5.67, 5.6694, 5.6689, 5.6684, 5.6679, 5.6674,
    5.6668, 5.6663, 5.6658, 5.6653, 5.6648, 5.6643, 5.6637, 5.6632,
    5.6627, 5.6622, 5.6617, 5.6611, 5.6606, 5.6601, 5.6596, 5.6591,
    5.6585, 5.658, 5.6575, 5.657, 5.6565, 5.6559, 5.6554, 5.6549,
    5.6544, 5.6538, 5.6533, 5.6528, 5.6523, 5.6518, 5.6512, 5.6507,
    5.6502, 5.6497, 5.6491, 5.6486, 5.6481, 5.6475, 5.647, 5.6465,
    5.646, 5.6454, 5.6449, 5.6444, 5.6439, 5.6433, 5.6428, 5.6423,
    5.6417, 5.6412, 5.6407, 5.6402, 5.6396, 5.6391, 5.6386, 5.638,
    5.6375, 5.637, 5.6364, 5.6359, 5.6354, 5.6348, 5.6343, 5.6338,
    5.6332, 5.6327, 5.6322, 5.6316, 5.6311, 5.6305, 5.63, 5.6295,
    5.6289, 5.6284, 5.6279, 5.6273, 5.6268, 5.6262, 5.6257, 5.6252,
    5.6246, 5.6241, 5.6235, 5.623, 5.6224, 5.6219, 5.6214, 5.6208,
    5.6203, 5.6197, 5.6192, 5.6186, 5.6181, 5.6175, 5.617, 5.6164,
    5.6159, 5.6153, 5.6148, 5.6143, 5.6137, 5.6132, 5.6126, 5.6121,
    5.6115, 5.611, 5.6104, 5.6098, 5.6093, 5.6087, 5.6082, 5.6076,
    5.6071, 5.6065, 5.606, 5.6054, 5.6049, 5.6043, 5.6037, 5.6032,
    5.6026, 5.6021, 5.6015, 5.601, 5.6004, 5.5998, 5.5993, 5.5987,
    5.5982, 5.5976, 5.597, 5.5965, 5.5959, 5.5954, 5.5948, 5.5942,
    5.5937, 5.5931, 5.5925, 5.592, 5.5914, 5.5908, 5.5903, 5.5897,
    5.5891, 5.5886, 5.588, 5.5874, 5.5869, 5.5863, 5.5857, 5.5852,
    5.5846, 5.584, 5.5835, 5.5829, 5.5823, 5.5818, 5.5812, 5.5806,
    5.58, 5.5795, 5.5789, 5.5783, 5.5777, 5.5772, 5.5766, 5.576,
    5.5755, 5.5749, 5.5743, 5.5737, 5.5732, 5.5726, 5.572, 5.5714,
    5.5709, 5.5703, 5.5697, 5.5691, 5.5685, 5.568, 5.5674, 5.5668,
    5.5662, 5.5657, 5.5651, 5.5645, 5.5639, 5.5633, 5.5628, 5.5622,
    5.5616, 5.561, 5.5604, 5.5599, 5.5593, 5.5587, 5.5581, 5.5575,
    5.5569, 5.5564, 5.5558, 5.5552, 5.5546, 5.554, 5.5534, 5.5529,
    5.5523, 5.5517, 5.5511, 5.5505, 5.5499, 5.5494, 5.5488, 5.5482,
    5.5476, 5.547, 5.5464, 5.5458, 5.5453, 5.5447, 5.5441, 5.5435,
    5.5429, 5.5423, 5.5417, 5.5412, 5.5406, 5.54, 5.5394, 5.5388,
    5.5382, 5.5376, 5.537, 5.5365, 5.5359, 5.5353, 5.5347, 5.5341,
    5.5335, 5.5329, 5.5323, 5.5318, 5.5312, 5.5306, 5.53, 5.5294,
    5.5288, 5.5282, 5.5276, 5.5271, 5.5265, 5.5259, 5.5253, 5.5247,
    5.5241, 5.5235, 5.5229, 5.5224, 5.5218, 5.5212, 5.5206, 5.52,
    5.5194, 5.5188, 5.5183, 5.5177, 5.5171, 5.5165, 5.5159, 5.5153,
    5.5147, 5.5142, 5.5136, 5.513, 5.5124, 5.5118, 5.5112, 5.5106,
    5.5101, 5.5095, 5.5089, 5.5083, 5.5077, 5.5071, 5.5066, 5.506,
    5.5054, 5.5048, 5.5042, 5.5036, 5.5031, 5.5025, 5.5019, 5.5013,
    5.5007, 5.5002, 5.4996, 5.499, 5.4984, 5.4978, 5.4973, 5.4967,
    5.4961, 5.4955, 5.495, 5.4944, 5.4938, 5.4932, 5.4926, 5.4921,
    5.4915, 5.4909, 5.4904, 5.4898, 5.4892, 5.4886, 5.4881, 5.4875,
    5.4869, 5.4863, 5.4858, 5.4852, 5.4846, 5.4841, 5.4835, 5.4829,
    5.4824, 5.4818, 5.4812, 5.4807, 5.4801, 5.4795, 5.479, 5.4784,
    5.4778, 5.4773, 5.4767, 5.4762, 5.4756, 5.475, 5.4745, 5.4739,
    5.4734, 5.4728, 5.4722, 5.4717, 5.4711, 5.4706, 5.47, 5.4695,
    5.4689, 5.4683, 5.4678, 5.4672, 5.4667, 5.4661, 5.4656, 5.465,
    5.4645, 5.4639, 5.4634, 5.4628, 5.4623, 5.4618, 5.4612, 5.4607,
    5.4601, 5.4596, 5.459, 5.4585, 5.4579, 5.4574, 5.4569, 5.4563,
    5.4558, 5.4553, 5.4547, 5.4542, 5.4536, 5.4531, 5.4526, 5.452,
    5.4515, 5.451, 5.4504, 5.4499, 5.4494, 5.4489, 5.4483, 5.4478,
    5.4473, 5.4467, 5.4462, 5.4457, 5.4452, 5.4446, 5.4441, 5.4436,
    5.4431, 5.4426, 5.442, 5.4415, 5.441, 5.4405, 5.44, 5.4395,
    5.4389, 5.4384, 5.4379, 5.4374, 5.4369, 5.4364, 5.4359, 5.4354,
    5.4349, 5.4343, 5.4338, 5.4333, 5.4328, 5.4323, 5.4318, 5.4313,
    5.4308, 5.4303, 5.4298, 5.4293, 5.4288, 5.4283, 5.4278, 5.4273,
    5.4268, 5.4263, 5.4258, 5.4253, 5.4249, 5.4244, 5.4239, 5.4234,
    5.4229, 5.4224, 5.4219, 5.4214, 5.4209, 5.4205, 5.42, 5.4195,
    5.419, 5.4185, 5.4181, 5.4176, 5.4171, 5.4166, 5.4161, 5.4157,
    5.4152, 5.4147, 5.4142, 5.4138, 5.4133, 5.4128, 5.4124, 5.4119,
    5.4114, 5.411, 5.4105, 5.41, 5.4096, 5.4091, 5.4086, 5.4082,
    5.4077, 5.4072, 5.4068, 5.4063, 5.4059, 5.4054, 5.405, 5.4045,
    5.404, 5.4036, 5.4031, 5.4027, 5.4022, 5.4018, 5.4013, 5.4009,
    5.4004, 5.4, 5.3995, 5.3991, 5.3987, 5.3982, 5.3978, 5.3973,
    5.3969, 5.3964, 5.396, 5.3956, 5.3951, 5.3947, 5.3943, 5.3938,
    5.3934, 5.393, 5.3925, 5.3921, 5.3917, 5.3912, 5.3908, 5.3904,
    5.39, 5.3895, 5.3891, 5.3887, 5.3883, 5.3878, 5.3874, 5.387,
    5.3866, 5.3862, 5.3857, 5.3853, 5.3849, 5.3845, 5.3841, 5.3837,
    5.3832, 5.3828, 5.3824, 5.382, 5.3816, 5.3812, 5.3808, 5.3804,
    5.38, 5.3796, 5.3792, 5.3788, 5.3784, 5.378, 5.3775, 5.3771,
    5.3767, 5.3764, 5.376, 5.3756, 5.3752, 5.3748, 5.3744, 5.374,
    5.3736, 5.3732, 5.3728, 5.3724, 5.372, 5.3716, 5.3712, 5.3708,
    5.3705, 5.3701, 5.3697, 5.3693, 5.3689, 5.3685, 5.3682, 5.3678,
    5.3674, 5.367, 5.3666, 5.3662, 5.3659, 5.3655, 5.3651, 5.3647,
    5.3644, 5.364, 5.3636, 5.3632, 5.3629, 5.3625, 5.3621, 5.3618,
    5.3614, 5.361, 5.3606, 5.3603, 5.3599, 5.3595, 5.3592, 5.3588,
    5.3585, 5.3581, 5.3577, 5.3574, 5.357, 5.3566, 5.3563, 5.3559,
    5.3556, 5.3552, 5.3549, 5.3545, 5.3541, 5.3538, 5.3534, 5.3531,
    5.3527, 5.3524, 5.352, 7.7874, 7.7784, 7.7694, 7.7606, 7.7518,
    7.7431, 7.7345, 7.7259, 7.7174, 7.709, 7.7007, 7.6924, 7.6842,
    7.676, 7.6679, 7.6599, 7.652, 7.644, 7.6362, 7.6284, 7.6206,
    7.6129, 7.6053, 7.5977, 7.5902, 7.5827, 7.5752, 7.5678, 7.5605,
    7.5532, 7.5459, 7.5387, 7.5315, 7.5244, 7.5173, 7.5103, 7.5033,
    7.4963, 7.4894, 7.4825, 7.4756, 7.4688, 7.462, 7.4553, 7.4486,
    7.4419, 7.4352, 7.4286, 7.4221, 7.4155, 7.409, 7.4026, 7.3961,
    7.3897, 7.3833, 7.377, 7.3707, 7.3644, 7.3581, 7.3519, 7.3457,
    7.3396, 7.3334, 7.3273, 7.3212, 7.3152, 7.3091, 7.3031, 7.2972,
    7.2912, 7.2853, 7.2794, 7.2735, 7.2677, 7.2619, 7.2561, 7.2504,
    7.2446, 7.2389, 7.2332, 7.2276, 7.222, 7.2164, 7.2108, 7.2052,
    7.1997, 7.1942, 7.1887, 7.1833, 7.1778, 7.1724, 7.167, 7.1617,
    7.1564, 7.1511, 7.1458, 7.1405, 7.1353, 7.1301, 7.1249, 7.1197,
    7.1146, 7.1095, 7.1044, 7.0993, 7.0943, 7.0892, 7.0843, 7.0793,
    7.0743, 7.0694, 7.0645, 7.0596, 7.0548, 7.0499, 7.0451, 7.0403,
    7.0356, 7.0308, 7.0261, 7.0214, 7.0168, 7.0121, 7.0075, 7.0029,
    6.9983, 6.9937, 6.9892, 6.9847, 6.9802, 6.9757, 6.9712, 6.9668,
    6.9624, 6.958, 6.9537, 6.9493, 6.945, 6.9407, 6.9364, 6.9322,
    6.9279, 6.9237, 6.9195, 6.9153, 6.9112, 6.907, 6.9029, 6.8988,
    6.8948, 6.8907, 6.8867, 6.8827, 6.8787, 6.8747, 6.8708, 6.8668,
    6.8629, 6.859, 6.8551, 6.8513, 6.8474, 6.8436, 6.8398, 6.836,
    6.8323, 6.8285, 6.8248, 6.8211, 6.8174, 6.8138, 6.8101, 6.8065,
    6.8029, 6.7993, 6.7957, 6.7921, 6.7886, 6.785, 6.7815, 6.778,
    6.7746, 6.7711, 6.7677, 6.7642, 6.7608, 6.7574, 6.7541, 6.7507,
    6.7474, 6.744, 6.7407, 6.7374, 6.7341, 6.7309, 6.7276, 6.7244,
    6.7212, 6.718, 6.7148, 6.7116, 6.7085, 6.7054, 6.7022, 6.6991,
    6.696, 6.693, 6.6899, 6.6869, 6.6838, 6.6808, 6.6778, 6.6748,
    6.6718, 6.6689, 6.6659, 6.663, 6.6601, 6.6572, 6.6543, 6.6514,
    6.6485, 6.6457, 6.6429, 6.64, 6.6372, 6.6344, 6.6316, 6.6289,
    6.6261, 6.6234, 6.6206, 6.6179, 6.6152, 6.6125, 6.6098, 6.6072,
    6.6045, 6.6019, 6.5992, 6.5966, 6.594, 6.5914, 6.5888, 6.5862,
    6.5837, 6.5811, 6.5786, 6.5761, 6.5736, 6.571, 6.5686, 6.5661,
    6.5636, 6.5612, 6.5587, 6.5563, 6.5539, 6.5514, 6.549, 6.5467,
    6.5443, 6.5419, 6.5396, 6.5372, 6.5349, 6.5326, 6.5303, 6.528,
    6.5257, 6.5234, 6.5211, 6.5189, 6.5166, 6.5144, 6.5121, 6.5099,
    6.5077, 6.5055, 6.5033, 6.5012, 6.499, 6.4968, 6.4947, 6.4926,
    6.4904, 6.4883, 6.4862, 6.4841, 6.482, 6.48, 6.4779, 6.4758,
    6.4738, 6.4718, 6.4697, 6.4677, 6.4657, 6.4637, 6.4617, 6.4597,
    6.4577, 6.4558, 6.4538, 6.4519, 6.4499, 6.448, 6.4461, 6.4442,
    6.4423, 6.4404, 6.4385, 6.4366, 6.4347, 6.4329, 6.431, 6.4292,
    6.4273, 6.4255, 6.4237, 6.4219, 6.4201, 6.4183, 6.4165, 6.4147,
    6.4129, 6.4112, 6.4094, 6.4077, 6.4059, 6.4042, 6.4025, 6.4008,
    6.3991, 6.3974, 6.3957, 6.394, 6.3923, 6.3906, 6.389, 6.3873,
    6.3857, 6.384, 6.3824, 6.3808, 6.3792, 6.3775, 6.3759, 6.3743,
    6.3727, 6.3712, 6.3696, 6.368, 6.3665, 6.3649, 6.3633, 6.3618,
    6.3603, 6.3587, 6.3572, 6.3557, 6.3542, 6.3527, 6.3512, 6.3497,
    6.3482, 6.3468, 6.3453, 6.3438, 6.3424, 6.3409, 6.3395, 6.338,
    6.3366, 6.3352, 6.3338, 6.3324, 6.331, 6.3296, 6.3282, 6.3268,
    6.3254, 6.324, 6.3227, 6.3213, 6.32, 6.3186, 6.3173, 6.3159,
    6.3146, 6.3133, 6.312, 6.3106, 6.3093, 6.308, 6.3067, 6.3055,
    6.3042, 6.3029, 6.3016, 6.3004, 6.2991, 6.2978, 6.2966, 6.2954,
    6.2941, 6.2929, 6.2917, 6.2904, 6.2892, 6.288, 6.2868, 6.2856,
    6.2844, 6.2832, 6.2821, 6.2809, 6.2797, 6.2785, 6.2774, 6.2762,
    6.2751, 6.2739, 6.2728, 6.2717, 6.2705, 6.2694, 6.2683, 6.2672,
    6.2661, 6.265, 6.2639, 6.2628, 6.2617, 6.2606, 6.2596, 6.2585,
    6.2574, 6.2564, 6.2553, 6.2543, 6.2532, 6.2522, 6.2511, 6.2501,
    6.2491, 6.2481, 6.2471, 6.246, 6.245, 6.244, 6.2431, 6.2421,
    6.2411, 6.2401, 6.2391, 6.2381, 6.2372, 6.2362, 6.2353, 6.2343,
    6.2334, 6.2324, 6.2315, 6.2306, 6.2296, 6.2287, 6.2278, 6.2269,
    6.226, 6.2251, 6.2242, 6.2233, 6.2224, 6.2215, 6.2206, 6.2197,
    6.2188, 6.218, 6.2171, 6.2162, 6.2154, 6.2145, 6.2137, 6.2128,
    6.212, 6.2112, 6.2103, 6.2095, 6.2087, 6.2079, 6.2071, 6.2062,
    6.2054, 6.2046, 6.2038, 6.2031, 6.2023, 6.2015, 6.2007, 6.1999,
    6.1991, 6.1984, 6.1976, 6.1968, 6.1961, 6.1953, 6.1946, 6.1938,
    6.1931, 6.1924, 6.1916, 6.1909, 6.1902, 6.1894, 6.1887, 6.188,
    6.1873, 6.1866, 6.1859, 6.1852, 6.1845, 6.1838, 6.1831, 6.1824,
    6.1817, 6.1811, 6.1804, 6.1797, 6.179, 6.1784, 6.1777, 6.1771,
    6.1764, 6.1758, 6.1751, 6.1745, 6.1738, 6.1732, 6.1726, 6.1719,
    6.1713, 6.1707, 6.1701, 6.1694, 6.1688, 6.1682, 6.1676, 6.167,
    6.1664, 6.1658, 6.1652, 6.1646, 6.164, 6.1634, 6.1629, 6.1623,
    6.1617, 6.1611, 6.1606, 6.16, 6.1594, 6.1589, 6.1583, 6.1578,
    6.1572, 6.1567, 6.1561, 6.1556, 6.155, 6.1545, 6.154, 6.1534,
    6.1529, 6.1524, 6.1518, 6.1513, 6.1508, 6.1503, 6.1498, 6.1493,
    6.1488, 6.1482, 6.1477, 6.1472, 6.1467, 6.1462, 6.1458, 6.1453,
    6.1448, 6.1443, 6.1438, 6.1433, 6.1429, 6.1424, 6.1419, 6.1414,
    6.141, 6.1405, 6.14, 6.1396, 6.1391, 6.1387, 6.1382, 6.1378,
    6.1373, 6.1369, 6.1364, 6.136, 6.1355, 6.1351, 6.1347, 6.1342,
    6.1338, 6.1334, 6.133, 6.1325, 6.1321, 6.1317, 6.1313, 6.1309,
    6.1305, 6.13, 6.1296, 6.1292, 6.1288, 6.1284, 6.128, 6.1276,
    6.1272, 6.1269, 6.1265, 6.1261, 6.1257, 6.1253, 6.1249, 6.1245,
    6.1242, 6.1238, 6.1234, 6.1231, 6.1227, 6.1223, 6.122, 6.1216,
    6.1212, 6.1209, 6.1205, 6.1202, 6.1198, 6.1195, 6.1191, 6.1188,
    6.1184, 6.1181, 6.1177, 6.1174, 6.1171, 6.1167, 6.1164, 6.1161,
    6.1157, 6.1154, 6.1151, 6.1148, 6.1144, 6.1141, 6.1138, 6.1135,
    6.1132, 6.1129, 6.1125, 6.1122, 6.1119, 6.1116, 6.1113, 6.111,
    6.1107, 6.1104, 6.1101, 6.1098, 6.1095, 6.1092, 6.1089, 6.1086,
    6.1084, 6.1081, 6.1078, 6.1075, 6.1072, 6.1069, 6.1067, 6.1064,
    6.1061, 6.1058, 6.1056, 6.1053, 6.105, 6.1048, 6.1045, 6.1042,
    6.104, 6.1037, 6.1034, 6.1032, 6.1029, 6.1027, 6.1024, 6.1022,
    6.1019, 6.1017, 6.1014, 6.1012, 6.1009, 6.1007, 6.1004, 6.1002,
    6.1, 6.0997, 6.0995, 6.0992, 6.099, 6.0988, 6.0985, 6.0983,
    6.0981, 6.0978, 6.0976, 6.0974, 6.0972, 6.0969, 6.0967, 6.0965,
    6.0963, 6.0961, 6.0958, 6.0956, 6.0954, 6.0952, 6.095, 6.0948,
    6.0945, 6.0943, 6.0941, 6.0939, 6.0937, 6.0935, 6.0933, 6.0931,
    6.0929, 6.0927, 6.0925, 6.0923, 6.0921, 6.0919, 6.0917, 6.0915,
    6.0913, 6.0911, 6.0909, 6.0907, 6.0905, 6.0903, 6.0902, 6.09,
    6.0898, 6.0896, 6.0894, 6.0892, 6.089, 6.0889, 6.0887, 6.0885,
    6.0883, 6.0881, 6.088, 6.0878, 6.0876, 6.0874, 6.0873, 6.0871,
    6.0869, 6.0868, 6.0866, 6.0864, 6.0862, 6.0861, 6.0859, 6.0857,
    6.0856, 6.0854, 6.0853, 6.0851, 6.0849, 6.0848, 6.0846, 6.0844,
    6.0843, 6.0841, 6.084, 6.0838, 6.0837, 6.0835, 6.0834, 6.0832,
    6.0831, 6.0829, 6.0827, 6.0826, 6.0824, 6.0823, 6.0822, 6.082,
    6.0819, 6.0817, 6.0816, 6.0814, 6.0813, 6.0811, 6.081, 6.0809,
    6.0807, 6.0806, 6.0804, 6.0803, 6.0802, 6.08, 6.0799, 6.0798,
    6.0796, 6.0795, 6.0794, 6.0792, 6.0791, 6.079, 6.0788, 6.0787,
    6.0786, 6.0784, 6.0783, 6.0782, 6.0781, 6.0779, 6.0778, 6.0777,
    6.0776, 6.0774, 6.0773, 6.0772, 6.0771, 6.0769, 6.0768, 6.0767,
    6.0766, 6.0765, 6.0763, 6.0762, 6.0761, 6.076, 6.0759, 6.0758,
    6.0757, 6.0755, 6.0754, 6.0753, 6.0752, 6.0751, 6.075, 6.0749,
    6.0748, 6.0747, 6.0746, 6.0744, 6.0743, 6.0742, 6.0741, 6.074,
    6.0739, 6.0738, 6.0737, 6.0736, 6.0735, 6.0734, 6.0733, 6.0732,
    6.0731, 6.073, 6.0729, 6.0728, 6.0727, 6.0726, 6.0725, 6.0724,
    6.0723, 6.0722, 6.0721, 6.0721, 6.072, 6.0719, 6.0718, 6.0717,
    6.0716, 6.0715, 6.0714, 6.0713, 6.0712, 6.0712, 6.0711, 6.071,
    6.0709, 6.0708, 6.0707, 6.0706, 6.0706, 6.0705, 6.0704, 6.0703,
    6.0702, 6.0702, 6.0701, 6.07, 6.0699, 6.0698, 6.0698, 6.0697,
    6.0696, 6.0695, 6.0695, 6.0694, 6.0693, 6.0692, 6.0692, 6.0691,
    6.069, 6.0689, 6.0689, 6.0688, 6.0687, 6.0687, 6.0686, 6.0685,
    6.0685, 6.0684, 6.0683, 6.0683, 6.0682, 6.0681, 6.0681, 6.068,
    6.0679, 6.0679, 6.0678, 6.0678, 6.0677, 6.0676, 6.0676, 6.0675,
    6.0675, 6.0674, 6.0673, 6.0673, 6.0672, 6.0672, 6.0671, 6.0671,
    6.067, 6.0669, 6.0669, 6.0668, 6.0668, 6.0667, 6.0667, 6.0666,
    6.0666, 6.0665, 6.0665, 6.0664, 6.0664, 6.0663, 6.0663, 6.0662,
    6.0662, 6.0661, 6.0661, 6.066, 6.066, 6.066, 6.0659, 6.0659,
    6.0658, 6.0658, 6.0657, 6.0657, 6.0656, 6.0656, 6.0656, 6.0655,
    6.0655, 6.0654, 6.0654, 6.0654, 6.0653, 6.0653, 6.0653, 6.0652,
    6.0652, 6.0651, 6.0651, 6.0651, 6.065, 6.065, 6.065, 6.0649,
    6.0649, 6.0649, 6.0648, 6.0648, 6.0648, 6.0647, 6.0647, 6.0647,
    6.0647, 6.0646, 6.0646, 6.0646, 6.0645, 6.0645, 6.0645, 6.0645,
    6.0644, 6.0644, 6.0644, 6.0643, 6.0643, 6.0643, 6.0643, 6.0642,
    6.0642, 6.0642, 6.0642, 6.0642, 6.0641, 6.0641, 6.0641, 6.0641,
    6.064, 6.064, 6.064, 6.064, 6.064, 6.0639, 6.0639, 6.0639,
    6.0639, 6.0639, 6.0638, 6.0638, 6.0638, 6.0638, 6.0638, 6.0638,
    6.0637, 6.0637, 6.0637, 6.0637, 6.0637, 6.0637, 6.0636, 6.0636,
    6.0636, 6.0636, 6.0636, 6.0636, 6.0636, 6.0636, 6.0635, 6.0635,
    6.0635, 6.0635, 6.0635, 6.0635, 6.0635, 6.0635, 6.0635, 6.0634,
    6.0634, 6.0634, 6.0634, 6.0634, 6.0634, 6.0634, 6.0634, 6.0634,
    6.0634, 6.0634, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633,
    6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633,
    6.0633, 6.0633, 6.0633, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632,
    6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632,
    6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632,
    6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632,
    6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632,
    6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632, 6.0632,
    6.0632, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633,
    6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633, 6.0633,
    6.0633, 6.0633, 6.0633, 6.0633, 6.0634, 6.0634, 6.0634, 6.0634,
    6.0634, 6.0634, 6.0634, 6.0634, 6.0634, 6.0634, 6.0634, 6.0634,
    6.0634, 6.0634, 6.0635, 6.0635, 6.0635, 6.0635, 6.0635, 6.0635,
    6.0635, 6.0635, 6.0635, 6.0635, 6.0635, 6.0636, 6.0636, 6.0636,
    6.0636, 6.0636, 6.0636, 6.0636, 6.0636, 6.0636, 6.0637, 6.0637,
    6.0637, 6.0637, 6.0637, 6.0637, 6.0637, 6.0637, 6.0637, 6.0638,
    6.0638, 6.0638, 6.0638, 6.0638, 6.0638, 6.0638, 6.0638, 6.0639,
    6.0639, 6.0639, 6.0639, 6.0639, 6.0639, 6.0639, 6.0639, 6.064,
    6.064, 6.064, 6.064, 6.064, 6.064, 6.0641, 6.0641, 6.0641,
    6.0641, 6.0641, 6.0641, 6.0641, 6.0642, 6.0642, 6.0642, 6.0642,
    6.0642, 6.0642, 6.0643, 6.0643, 6.0643, 6.0643, 6.0643, 6.0643,
    6.0644, 6.0644, 6.0644, 6.0644, 6.0644, 6.0644, 6.0645, 6.0645,
    6.0645, 6.0645, 6.0645, 6.0646, 6.0646, 6.0646, 6.0646, 6.0646,
    6.0646, 6.0647, 6.0647, 6.0647, 6.0647, 6.0647, 6.0648, 6.0648,
    6.0648, 6.0648, 6.0648, 6.0649, 6.0649, 6.0649, 6.0649, 6.0649,
    6.065, 6.065, 6.065, 6.065, 6.0651, 6.0651, 6.0651, 6.0651,
    6.0651, 6.0652, 6.0652, 6.0652, 6.0652, 6.0653, 6.0653, 6.0653,
    6.0653, 6.0653, 6.0654, 6.0654, 6.0654, 6.0654, 6.0655, 6.0655,
    6.0655, 6.0655, 6.0656, 6.0656, 6.0656, 6.0656, 6.0657, 6.0657,
    6.0657, 6.0657, 6.0658, 6.0658, 6.0658, 6.0658, 6.0659, 6.0659,
    6.0659, 6.0659, 6.066, 6.066, 6.066, 6.066, 6.0661, 6.0661,
    6.0661, 6.0661, 6.0662, 6.0662, 6.0662, 6.0663, 6.0663, 6.0663,
    6.0663, 6.0664, 6.0664, 6.0664, 6.0664, 6.0665, 6.0665, 6.0665,
    6.0666, 6.0666, 6.0666, 6.0666, 6.0667, 6.0667, 6.0667, 6.0668,
    6.0668, 6.0668, 6.0669, 6.0669, 6.0669, 6.0669, 6.067, 6.067,
    6.067, 6.0671, 6.0671, 6.0671, 6.0672, 6.0672, 6.0672, 6.0673,
    6.0673, 6.0673, 6.0673, 6.0674, 6.0674, 6.0674, 6.0675, 6.0675,
    6.0675, 6.0676, 6.0676, 6.0676, 6.0677, 6.0677, 6.0677, 6.0678,
    6.0678, 6.0678, 6.0679, 6.0679, 6.0679, 6.068, 6.068, 6.068,
    6.0681, 6.0681, 6.0682, 6.0682, 6.0682, 6.0683, 6.0683, 6.0683,
    6.0684, 6.0684, 6.0684, 6.0685, 6.0685, 6.0685, 6.0686, 6.0686,
    6.0687, 6.0687, 6.0687, 6.0688, 6.0688, 6.0688, 6.0689, 6.0689,
    6.069, 6.069, 6.069, 6.0691, 6.0691, 6.0692, 6.0692, 6.0692,
    6.0693, 6.0693, 6.0694, 6.0694, 6.0694, 6.0695, 6.0695, 6.0696,
    6.0696, 6.0696, 6.0697, 6.0697, 6.0698, 6.0698, 6.0698, 6.0699,
    6.0699, 6.07, 6.07, 6.07, 6.0701, 6.0701, 6.0702, 6.0702,
    6.0703, 6.0703, 6.0703, 6.0704, 6.0704, 6.0705, 6.0705, 6.0706,
    6.0706, 6.0707, 6.0707, 6.0707, 6.0708, 6.0708, 6.0709, 6.0709,
    6.071, 6.071, 6.0711, 6.0711, 6.0712, 6.0712, 6.0712, 6.0713,
    6.0713, 6.0714, 6.0714, 6.0715, 6.0715, 6.0716, 6.0716, 6.0717,
    6.0717, 6.0718, 6.0718, 6.0719, 6.0719, 6.072, 6.072, 6.072,
    6.0721, 6.0721, 6.0722, 6.0722, 6.0723, 6.0723, 6.0724, 6.0724,
    6.0725, 6.0725, 6.0726, 6.0726, 6.0727, 6.0727, 6.0728, 6.0728,
    6.0729, 6.0729, 6.073, 6.0731, 6.0731, 6.0732, 6.0732, 6.0733,
    6.0733, 6.0734, 6.0734, 6.0735, 6.0735, 6.0736, 6.0736, 6.0737,
    6.0737, 6.0738, 6.0738, 6.0739, 6.0739, 6.074, 6.0741, 6.0741,
    6.0742, 6.0742, 6.0743, 6.0743, 6.0744, 6.0744, 6.0745, 6.0745,
    6.0746, 6.0747, 6.0747, 6.0748, 6.0748, 6.0749, 6.0749, 6.075,
    6.075, 6.0751, 6.0752, 6.0752, 6.0753, 6.0753, 6.0754, 6.0754,
    6.0755, 6.0756, 6.0756, 6.0757, 6.0757, 6.0758, 6.0758, 6.0759,
    6.076, 6.076, 6.0761, 6.0761, 6.0762, 6.0762, 6.0763, 6.0764,
    6.0764, 6.0765, 6.0765, 6.0766, 6.0767, 6.0767, 6.0768, 6.0768,
    6.0769, 6.077, 6.077, 6.0771, 6.0771, 6.0772, 6.0773, 6.0773,
    6.0774, 6.0774, 6.0775, 6.0776, 6.0776, 6.0777, 6.0777, 6.0778,
    6.0779, 6.0779, 6.078, 6.0781, 6.0781, 6.0782, 6.0782, 6.0783,
    6.0784, 6.0784, 6.0785, 6.0786, 6.0786, 6.0787, 6.0787, 6.0788,
    6.0789, 6.0789, 6.079, 6.0791, 6.0791, 6.0792, 6.0792, 6.0793,
    6.0794, 6.0794, 6.0795, 6.0796, 6.0796, 6.0797, 6.0798, 6.0798,
    6.0799, 6.08, 6.08, 6.0801, 6.0801, 6.0802, 6.0803, 6.0803,
    6.0804, 6.0805, 6.0805, 6.0806, 6.0807, 6.0807, 6.0808, 6.0809,
    6.0809, 6.081, 6.0811, 6.0811, 6.0812, 6.0813, 6.0813, 6.0814,
    6.0815, 6.0815, 6.0816, 6.0816, 6.0817, 6.0818, 6.0818, 6.0819,
    6.082, 6.082, 6.0821, 6.0822, 6.0822, 6.0823, 6.0824, 6.0824,
    6.0825, 6.0826, 6.0827, 6.0827, 6.0828, 6.0829, 6.0829, 6.083,
    6.0831, 6.0831, 6.0832, 6.0833, 6.0833, 6.0834, 6.0835, 6.0835,
    6.0836, 6.0837, 6.0837, 6.0838, 6.0839, 6.0839, 6.084, 6.0841,
    6.0841, 6.0842, 6.0843, 6.0844, 6.0844, 6.0845, 6.0846, 6.0846,
    6.0847, 6.0848, 6.0848, 6.0849, 6.085, 6.085, 6.0851, 6.0852,
    6.0852, 6.0853, 6.0854, 6.0855, 6.0855, 6.0856, 6.0857, 6.0857,
    6.0858, 6.0859, 6.0859, 6.086, 6.0861, 6.0862, 6.0862, 6.0863,
    6.0864, 6.0864, 6.0865, 6.0866, 6.0866, 6.0867, 6.0868, 6.0869,
    6.0869, 6.087, 6.0871, 6.0871, 6.0872, 6.0873, 6.0874, 6.0874,
    6.0875, 6.0876, 6.0876, 6.0877, 6.0878, 6.0878, 6.0879, 6.088,
    6.0881, 6.0881, 6.0882, 6.0883, 6.0883, 6.0884, 6.0885, 6.0886,
    6.0886, 9.7658, 9.7596, 9.7535, 9.7475, 9.7415, 9.7355, 9.7295,
    9.7236, 9.7177, 9.7118, 9.7059, 9.7001, 9.6942, 9.6884, 9.6826,
    9.6768, 9.671, 9.6652, 9.6593, 9.6535, 9.6477, 9.6418, 9.636,
    9.6301, 9.6242, 9.6183, 9.6124, 9.6065, 9.6005, 9.5946, 9.5885,
    9.5825, 9.5765, 9.5704, 9.5643, 9.5581, 9.552, 9.5458, 9.5396,
    9.5333, 9.5271, 9.5208, 9.5145, 9.5082, 9.5018, 9.4954, 9.489,
    9.4826, 9.4761, 9.4697, 9.4631, 9.4566, 9.4501, 9.4435, 9.4368,
    9.4302, 9.4235, 9.4168, 9.4101, 9.4034, 9.3966, 9.3898, 9.3829,
    9.3761, 9.3692, 9.3623, 9.3554, 9.3484, 9.3415, 9.3345, 9.3275,
    9.3205, 9.3134, 9.3064, 9.2993, 9.2922, 9.2851, 9.278, 9.2709,
    9.2638, 9.2566, 9.2495, 9.2423, 9.2351, 9.2279, 9.2208, 9.2135,
    9.2063, 9.1991, 9.1919, 9.1847, 9.1775, 9.1702, 9.163, 9.1557,
    9.1485, 9.1413, 9.134, 9.1268, 9.1195, 9.1123, 9.1051, 9.0978,
    9.0906, 9.0833, 9.0761, 9.0689, 9.0616, 9.0544, 9.0472, 9.04,
    9.0328, 9.0256, 9.0184, 9.0112, 9.004, 8.9968, 8.9897, 8.9825,
    8.9754, 8.9682, 8.9611, 8.9539, 8.9468, 8.9397, 8.9326, 8.9255,
    8.9185, 8.9114, 8.9044, 8.8973, 8.8903, 8.8833, 8.8763, 8.8694,
    8.8624, 8.8555, 8.8485, 8.8416, 8.8347, 8.8279, 8.821, 8.8142,
    8.8073, 8.8005, 8.7938, 8.787, 8.7802, 8.7735, 8.7668, 8.7601,
    8.7535, 8.7468, 8.7402, 8.7336, 8.727, 8.7204, 8.7139, 8.7074,
    8.7009, 8.6944, 8.6879, 8.6815, 8.6751, 8.6687, 8.6623, 8.656,
    8.6496, 8.6433, 8.637, 8.6308, 8.6245, 8.6183, 8.6121, 8.606,
    8.5998, 8.5937, 8.5876, 8.5815, 8.5754, 8.5694, 8.5634, 8.5574,
    8.5514, 8.5454, 8.5395, 8.5336, 8.5277, 8.5219, 8.5161, 8.5103,
    8.5045, 8.4987, 8.493, 8.4873, 8.4816, 8.4759, 8.4703, 8.4646,
    8.4591, 8.4535, 8.4479, 8.4424, 8.4369, 8.4314, 8.426, 8.4205,
    8.4151, 8.4098, 8.4044, 8.3991, 8.3937, 8.3885, 8.3832, 8.3779,
    8.3727, 8.3675, 8.3624, 8.3572, 8.3521, 8.347, 8.3419, 8.3368,
    8.3318, 8.3268, 8.3218, 8.3169, 8.3119, 8.307, 8.3021, 8.2972,
    8.2924, 8.2876, 8.2828, 8.278, 8.2732, 8.2685, 8.2638, 8.2591,
    8.2544, 8.2498, 8.2452, 8.2406, 8.236, 8.2314, 8.2269, 8.2224,
    8.2179, 8.2135, 8.209, 8.2046, 8.2002, 8.1958, 8.1914, 8.1871,
    8.1828, 8.1785, 8.1742, 8.17, 8.1658, 8.1616, 8.1574, 8.1532,
    8.1491, 8.145, 8.1409, 8.1368, 8.1328, 8.1287, 8.1247, 8.1208,
    8.1168, 8.1128, 8.1089, 8.105, 8.1012, 8.0973, 8.0935, 8.0897,
    8.0859, 8.0821, 8.0784, 8.0746, 8.0709, 8.0673, 8.0636, 8.06,
    8.0564, 8.0528, 8.0492, 8.0456, 8.0421, 8.0386, 8.0351, 8.0316,
    8.0282, 8.0248, 8.0213, 8.018, 8.0146, 8.0113, 8.0079, 8.0046,
    8.0013, 7.9981, 7.9948, 7.9916, 7.9884, 7.9852, 7.9821, 7.9789,
    7.9758, 7.9727, 7.9696, 7.9666, 7.9635, 7.9605, 7.9575, 7.9545,
    7.9515, 7.9486, 7.9457, 7.9428, 7.9399, 7.937, 7.9342, 7.9314,
    7.9285, 7.9258, 7.923, 7.9202, 7.9175, 7.9148, 7.9121, 7.9094,
    7.9068, 7.9041, 7.9015, 7.8989, 7.8964, 7.8938, 7.8913, 7.8887,
    7.8862, 7.8837, 7.8813, 7.8788, 7.8764, 7.874, 7.8716, 7.8692,
    7.8669, 7.8645, 7.8622, 7.8599, 7.8576, 7.8553, 7.8531, 7.8508,
    7.8486, 7.8464, 7.8442, 7.8421, 7.8399, 7.8378, 7.8357, 7.8336,
    7.8315, 7.8294, 7.8274, 7.8254, 7.8233, 7.8213, 7.8194, 7.8174,
    7.8154, 7.8135, 7.8116, 7.8097, 7.8078, 7.8059, 7.8041, 7.8022,
    7.8004, 7.7986, 7.7968, 7.795, 7.7933, 7.7915, 7.7898, 7.7881,
    7.7864, 7.7847, 7.783, 7.7814, 7.7797, 7.7781, 7.7765, 7.7749,
    7.7733, 7.7717, 7.7702, 7.7686, 7.7671, 7.7656, 7.7641, 7.7626,
    7.7611, 7.7597, 7.7582, 7.7568, 7.7554, 7.754, 7.7526, 7.7512,
    7.7498, 7.7485, 7.7471, 7.7458, 7.7445, 7.7432, 7.7419, 7.7406,
    7.7393, 7.7381, 7.7369, 7.7356, 7.7344, 7.7332, 7.732, 7.7309,
    7.7297, 7.7285, 7.7274, 7.7263, 7.7251, 7.724, 7.7229, 7.7219,
    7.7208, 7.7197, 7.7187, 7.7177, 7.7166, 7.7156, 7.7146, 7.7136,
    7.7127, 7.7117, 7.7107, 7.7098, 7.7088, 7.7079, 7.707, 7.7061,
    7.7052, 7.7043, 7.7035, 7.7026, 7.7018, 7.7009, 7.7001, 7.6993,
    7.6985, 7.6977, 7.6969, 7.6961, 7.6954, 7.6946, 7.6939, 7.6931,
    7.6924, 7.6917, 7.691, 7.6903, 7.6896, 7.689, 7.6883, 7.6877,
    7.687, 7.6864, 7.6858, 7.6852, 7.6846, 7.684, 7.6834, 7.6828,
    7.6823, 7.6817, 7.6812, 7.6806, 7.6801, 7.6796, 7.6791, 7.6786,
    7.6781, 7.6776, 7.6772, 7.6767, 7.6763, 7.6758, 7.6754, 7.675,
    7.6746, 7.6742, 7.6738, 7.6734, 7.6731, 7.6727, 7.6724, 7.672,
    7.6717, 7.6713, 7.671, 7.6707, 7.6704, 7.6701, 7.6699, 7.6696,
    7.6693, 7.6691, 7.6688, 7.6686, 7.6684, 7.6681, 7.6679, 7.6677,
    7.6675, 7.6673, 7.6672, 7.667, 7.6668, 7.6667, 7.6665, 7.6664,
    7.6663, 7.6661, 7.666, 7.6659, 7.6658, 7.6657, 7.6656, 7.6656,
    7.6655, 7.6654, 7.6654, 7.6653, 7.6653, 7.6652, 7.6652, 7.6652,
    7.6652, 7.6652, 7.6652, 7.6652, 7.6652, 7.6653, 7.6653, 7.6653,
    7.6654, 7.6654, 7.6655, 7.6655, 7.6656, 7.6657, 7.6658, 7.6659,
    7.666, 7.6661, 7.6662, 7.6663, 7.6664, 7.6665, 7.6667, 7.6668,
    7.667, 7.6671, 7.6673, 7.6674, 7.6676, 7.6678, 7.6679, 7.6681,
    7.6683, 7.6685, 7.6687, 7.6689, 7.6691, 7.6693, 7.6696, 7.6698,
    7.67, 7.6702, 7.6705, 7.6707, 7.671, 7.6712, 7.6715, 7.6718,
    7.672, 7.6723, 7.6726, 7.6729, 7.6732, 7.6734, 7.6737, 7.674,
    7.6743, 7.6747, 7.675, 7.6753, 7.6756, 7.6759, 7.6763, 7.6766,
    7.6769, 7.6773, 7.6776, 7.678, 7.6783, 7.6787, 7.679, 7.6794,
    7.6798, 7.6801, 7.6805, 7.6809, 7.6813, 7.6817, 7.6821, 7.6824,
    7.6828, 7.6832, 7.6836, 7.684, 7.6845, 7.6849, 7.6853, 7.6857,
    7.6861, 7.6865, 7.687, 7.6874, 7.6878, 7.6883, 7.6887, 7.6891,
    7.6896, 7.69, 7.6905, 7.6909, 7.6914, 7.6918, 7.6923, 7.6927,
    7.6932, 7.6937, 7.6941, 7.6946, 7.6951, 7.6955, 7.696, 7.6965,
    7.6969, 7.6974, 7.6979, 7.6984, 7.6989, 7.6993, 7.6998, 7.7003,
    7.7008, 7.7013, 7.7018, 7.7023, 7.7028, 7.7033, 7.7038, 7.7043,
    7.7048, 7.7053, 7.7058, 7.7063, 7.7068, 7.7073, 7.7078, 7.7083,
    7.7088, 7.7093, 7.7098, 7.7103, 7.7108, 7.7113, 7.7118, 7.7123,
    7.7129, 7.7134, 7.7139, 7.7144, 7.7149, 7.7154, 7.7159, 7.7164,
    7.717, 7.7175, 7.718, 7.7185, 7.719, 7.7195, 7.72, 7.7205,
    7.7211, 7.7216, 7.7221, 7.7226, 7.7231, 7.7236, 7.7241, 7.7247,
    7.7252, 7.7257, 7.7262, 7.7267, 7.7272, 7.7277, 7.7282, 7.7287,
    7.7293, 7.7298, 7.7303, 7.7308, 7.7313, 7.7318, 7.7323, 7.7328,
    7.7333, 7.7338, 7.7343, 7.7348, 7.7353, 7.7358, 7.7363, 7.7368,
    7.7373, 7.7378, 7.7383, 7.7388, 7.7393, 7.7398, 7.7403, 7.7408,
    7.7413, 7.7418, 7.7423, 7.7428, 7.7433, 7.7437, 7.7442, 7.7447,
    7.7452, 7.7457, 7.7462, 7.7466, 7.7471, 7.7476, 7.7481, 7.7486,
    7.749, 7.7495, 7.75, 7.7504, 7.7509, 7.7514, 7.7518, 7.7523,
    7.7528, 7.7532, 7.7537, 7.7541, 7.7546, 7.7551, 7.7555, 7.756,
    7.7564, 7.7569, 7.7573, 7.7577, 7.7582, 7.7586, 7.7591, 7.7595,
    7.7599, 7.7604, 7.7608, 7.7612, 7.7617, 7.7621, 7.7625, 7.7629,
    7.7634, 7.7638, 7.7642, 7.7646, 7.765, 7.7654, 7.7659, 7.7663,
    7.7667, 7.7671, 7.7675, 7.7679, 7.7683, 7.7687, 7.7691, 7.7695,
    7.7699, 7.7703, 7.7707, 7.771, 7.7714, 7.7718, 7.7722, 7.7726,
    7.773, 7.7733, 7.7737, 7.7741, 7.7744, 7.7748, 7.7752, 7.7755,
    7.7759, 7.7763, 7.7766, 7.777, 7.7773, 7.7777, 7.778, 7.7784,
    7.7787, 7.7791, 7.7794, 7.7798, 7.7801, 7.7804, 7.7808, 7.7811,
    7.7814, 7.7818, 7.7821, 7.7824, 7.7827, 7.7831, 7.7834, 7.7837,
    7.784, 7.7843, 7.7846, 7.7849, 7.7852, 7.7856, 7.7859, 7.7862,
    7.7865, 7.7867, 7.787, 7.7873, 7.7876, 7.7879, 7.7882, 7.7885,
    7.7888, 7.789, 7.7893, 7.7896, 7.7899, 7.7901, 7.7904, 7.7907,
    7.791, 7.7912, 7.7915, 7.7917, 7.792, 7.7923, 7.7925, 7.7928,
    7.793, 7.7933, 7.7935, 7.7937, 7.794, 7.7942, 7.7945, 7.7947,
    7.7949, 7.7952, 7.7954, 7.7956, 7.7959, 7.7961, 7.7963, 7.7965,
    7.7967, 7.797, 7.7972, 7.7974, 7.7976, 7.7978, 7.798, 7.7982,
    7.7984, 7.7986, 7.7988, 7.799, 7.7992, 7.7994, 7.7996, 7.7998,
    7.8, 7.8002, 7.8004, 7.8005, 7.8007, 7.8009, 7.8011, 7.8012,
    7.8014, 7.8016, 7.8018, 7.8019, 7.8021, 7.8022, 7.8024, 7.8026,
    7.8027, 7.8029, 7.803, 7.8032, 7.8033, 7.8035, 7.8036, 7.8038,
    7.8039, 7.804, 7.8042, 7.8043, 7.8045, 7.8046, 7.8047, 7.8048,
    7.805, 7.8051, 7.8052, 7.8053, 7.8055, 7.8056, 7.8057, 7.8058,
    7.8059, 7.806, 7.8061, 7.8063, 7.8064, 7.8065, 7.8066, 7.8067,
    7.8068, 7.8069, 7.807, 7.807, 7.8071, 7.8072, 7.8073, 7.8074,
    7.8075, 7.8076, 7.8077, 7.8077, 7.8078, 7.8079, 7.808, 7.8081,
    7.8081, 7.8082, 7.8083, 7.8083, 7.8084, 7.8085, 7.8085, 7.8086,
    7.8087, 7.8087, 7.8088, 7.8088, 7.8089, 7.809, 7.809, 7.8091,
    7.8091, 7.8092, 7.8092, 7.8093, 7.8093, 7.8094, 7.8094, 7.8094,
    7.8095, 7.8095, 7.8096, 7.8096, 7.8096, 7.8097, 7.8097, 7.8097,
    7.8098, 7.8098, 7.8098, 7.8098, 7.8099, 7.8099, 7.8099, 7.8099,
    7.8099, 7.81, 7.81, 7.81, 7.81, 7.81, 7.81, 7.81, 7.8101,
    7.8101, 7.8101, 7.8101, 7.8101, 7.8101, 7.8101, 7.8101, 7.8101,
    7.8101, 7.8101, 7.8101, 7.8101, 7.8101, 7.8101, 7.8101, 7.81,
    7.81, 7.81, 7.81, 7.81, 7.81, 7.81, 7.8099, 7.8099, 7.8099,
    7.8099, 7.8098, 7.8098, 7.8098, 7.8098, 7.8097, 7.8097, 7.8097,
    7.8096, 7.8096, 7.8096, 7.8095, 7.8095, 7.8095, 7.8094, 7.8094,
    7.8093, 7.8093, 7.8092, 7.8092, 7.8092, 7.8091, 7.8091, 7.809,
    7.8089, 7.8089, 7.8088, 7.8088, 7.8087, 7.8087, 7.8086, 7.8085,
    7.8085, 7.8084, 7.8083, 7.8083, 7.8082, 7.8081, 7.8081, 7.808,
    7.8079, 7.8078, 7.8078, 7.8077, 7.8076, 7.8075, 7.8074, 7.8073,
    7.8073, 7.8072, 7.8071, 7.807, 7.8069, 7.8068, 7.8067, 7.8066,
    7.8065, 7.8064, 7.8063, 7.8062, 7.8061, 7.806, 7.8059, 7.8058,
    7.8057, 7.8056, 7.8055, 7.8054, 7.8053, 7.8051, 7.805, 7.8049,
    7.8048, 7.8047, 7.8045, 7.8044, 7.8043, 7.8042, 7.804, 7.8039,
    7.8038, 7.8036, 7.8035, 7.8034, 7.8032, 7.8031, 7.803, 7.8028,
    7.8027, 7.8025, 7.8024, 7.8022, 7.8021, 7.802, 7.8018, 7.8016,
    7.8015, 7.8013, 7.8012, 7.801, 7.8009, 7.8007, 7.8005, 7.8004,
    7.8002, 7.8001, 7.7999, 7.7997, 7.7995, 7.7994, 7.7992, 7.799,
    7.7989, 7.7987, 7.7985, 7.7983, 7.7981, 7.798, 7.7978, 7.7976,
    7.7974, 7.7972, 7.797, 7.7968, 7.7966, 7.7964, 7.7962, 7.796,
    7.7958, 7.7956, 7.7954, 7.7952, 7.795, 7.7948, 7.7946, 7.7944,
    7.7942, 7.794, 7.7938, 7.7936, 7.7933, 7.7931, 7.7929, 7.7927,
    7.7925, 7.7922, 7.792, 7.7918, 7.7916, 7.7913, 7.7911, 7.7909,
    7.7906, 7.7904, 7.7902, 7.7899, 7.7897, 7.7895, 7.7892, 7.789,
    7.7887, 7.7885, 7.7882, 7.788, 7.7877, 7.7875, 7.7872, 7.787,
    7.7867, 7.7865, 7.7862, 7.786, 7.7857, 7.7854, 7.7852, 7.7849,
    7.7846, 7.7844, 7.7841, 7.7838, 7.7836, 7.7833, 7.783, 7.7827,
    7.7825, 7.7822, 7.7819, 7.7816, 7.7813, 7.781, 7.7808, 7.7805,
    7.7802, 7.7799, 7.7796, 7.7793, 7.779, 7.7787, 7.7784, 7.7781,
    7.7778, 7.7775, 7.7772, 7.7769, 7.7766, 7.7763, 7.776, 7.7757,
    7.7754, 7.7751, 7.7748, 7.7745, 7.7741, 7.7738, 7.7735, 7.7732,
    7.7729, 7.7725, 7.7722, 7.7719, 7.7716, 7.7712, 7.7709, 7.7706,
    7.7703, 7.7699, 7.7696, 7.7693, 7.7689, 7.7686, 7.7683, 7.7679,
    7.7676, 7.7672, 7.7669, 7.7666, 7.7662, 7.7659, 7.7655, 7.7652,
    7.7648, 7.7645, 7.7641, 7.7638, 7.7634, 7.7631, 7.7627, 7.7623,
    7.762, 7.7616, 7.7613, 7.7609, 7.7605, 7.7602, 7.7598, 7.7594,
    7.7591, 7.7587, 7.7583, 7.758, 7.7576, 7.7572, 7.7569, 7.7565,
    7.7561, 7.7557, 7.7553, 7.755, 7.7546, 7.7542, 7.7538, 7.7534,
    7.7531, 7.7527, 7.7523, 7.7519, 7.7515, 7.7511, 7.7507, 7.7503,
    7.7499, 7.7495, 7.7492, 7.7488, 7.7484, 7.748, 7.7476, 7.7472,
    7.7468, 7.7464, 7.746, 7.7456, 7.7451, 7.7447, 7.7443, 7.7439,
    7.7435, 7.7431, 7.7427, 7.7423, 7.7419, 7.7415, 7.741, 7.7406,
    7.7402, 7.7398, 7.7394, 7.739, 7.7385, 7.7381, 7.7377, 7.7373,
    7.7369, 7.7364, 7.736, 7.7356, 7.7352, 7.7347, 7.7343, 7.7339,
    7.7335, 7.733, 7.7326, 7.7322, 7.7317, 7.7313, 7.7309, 7.7305,
    7.73, 7.7296, 7.7291, 7.7287, 7.7283, 7.7278, 7.7274, 7.727,
    7.7265, 7.7261, 7.7257, 7.7252, 7.7248, 7.7243, 7.7239, 7.7234,
    7.723, 7.7226, 7.7221, 7.7217, 7.7212, 7.7208, 7.7203, 7.7199,
    7.7194, 7.719, 7.7185, 7.7181, 7.7177, 7.7172, 7.7168, 7.7163,
    7.7159, 7.7154, 7.7149, 7.7145, 7.714, 7.7136, 7.7131, 7.7127,
    7.7122, 7.7118, 7.7113, 7.7109, 7.7104, 7.71, 7.7095, 7.709,
    7.7086, 7.7081, 7.7077, 7.7072, 7.7067, 7.7063, 7.7058, 7.7054,
    7.7049, 7.7044, 7.704, 7.7035, 7.7031, 7.7026, 7.7021, 7.7017,
    7.7012, 7.7007, 7.7003, 7.6998, 7.6994, 7.6989, 7.6984, 7.698,
    7.6975, 7.697, 7.6966, 7.6961, 7.6956, 7.6952, 7.6947, 7.6942,
    7.6938, 7.6933, 7.6928, 7.6924, 7.6919, 7.6914, 7.691, 7.6905,
    7.69, 7.6896, 7.6891, 7.6886, 7.6882, 7.6877, 7.6872, 7.6867,
    7.6863, 7.6858, 7.6853, 7.6849, 7.6844, 7.6839, 7.6835, 7.683,
    7.6825, 7.6821, 7.6816, 7.6811, 7.6806, 7.6802, 7.6797, 7.6792,
    7.6788, 7.6783, 7.6778, 7.6773, 7.6769, 7.6764, 7.6759, 7.6755,
    7.675, 7.6745, 7.674, 7.6736, 7.6731, 7.6726, 7.6722, 7.6717,
    7.6712, 7.6707, 7.6703, 7.6698, 7.6693, 7.6689, 7.6684, 7.6679,
    7.6674, 7.667, 7.6665, 7.666, 7.6656, 7.6651, 7.6646, 7.6641,
    7.6637, 7.6632, 7.6627, 7.6623, 7.6618, 7.6613, 7.6608, 7.6604,
    7.6599, 7.6594, 7.659, 7.6585, 7.658, 7.6575, 7.6571, 7.6566,
    7.6561, 7.6557, 7.6552, 7.6547, 7.6542, 7.6538, 7.6533, 7.6528,
    7.6524, 7.6519, 7.6514, 7.651, 7.6505, 7.65, 7.6495, 7.6491,
    7.6486, 7.6481, 7.6477, 7.6472, 7.6467, 7.6463, 7.6458, 7.6453,
    7.6449, 7.6444, 7.6439, 7.6435, 7.643, 7.6425, 7.6421, 7.6416,
    7.6411, 7.6407, 7.6402, 7.6397, 7.6393, 7.6388, 7.6383, 7.6379,
    7.6374, 7.6369, 7.6365, 7.636, 7.6355, 7.6351, 7.6346, 7.6341,
    7.6337, 7.6332, 7.6328, 7.6323, 7.6318, 7.6314, 7.6309, 7.6304,
    7.63, 7.6295, 7.6291, 7.6286, 7.6281, 7.6277, 7.6272, 7.6267,
    7.6263, 7.6258, 7.6254, 7.6249, 7.6244, 7.624, 7.6235, 7.6231,
    7.6226, 7.6221, 7.6217, 7.6212, 7.6208, 7.6203, 7.6199, 7.6194,
    7.6189, 7.6185, 7.618, 7.6176, 7.6171, 7.6167, 7.6162, 7.6158,
    7.6153, 7.6148, 7.6144, 7.6139, 7.6135, 7.613, 7.6126, 7.6121,
    7.6117, 7.6112, 7.6108, 7.6103, 7.6099, 7.6094, 7.609, 7.6085,
    7.6081, 7.6076, 7.6072, 7.6067, 7.6063, 7.6058, 7.6054, 7.6049,
    7.6045, 7.604, 7.6036, 7.6031, 7.6027, 7.6023, 7.6018, 7.6014,
    7.6009, 7.6005, 7.6, 7.5996, 7.5991, 7.5987, 7.5983, 7.5978,
    7.5974, 7.5969, 7.5965, 7.5961, 7.5956, 7.5952, 7.5947, 7.5943,
    7.5939, 7.5934, 7.593, 7.5925, 7.5921, 7.5917, 7.5912, 7.5908,
    7.5904, 7.5899, 7.5895, 7.5891, 7.5886, 7.5882, 7.5878, 7.5873,
    7.5869, 7.5865, 7.586, 7.5856, 7.5852, 7.5847, 7.5843, 7.5839,
    7.5834, 7.583, 7.5826, 7.5822, 7.5817, 7.5813, 7.5809, 7.5805,
    7.58, 7.5796, 7.5792, 7.5787, 7.5783, 7.5779, 7.5775, 7.577,
    7.5766, 7.5762, 7.5758, 7.5754, 7.5749, 7.5745, 7.5741, 7.5737,
    7.5732, 7.5728, 7.5724, 7.572, 7.5716, 7.5712, 7.5707, 7.5703,
    7.5699, 7.5695, 7.5691, 7.5686, 7.5682, 7.5678, 7.5674, 7.567,
    7.5666, 7.5662, 7.5657, 7.5653, 7.5649, 7.5645, 7.5641, 7.5637,
    7.5633, 7.5628, 7.5624, 7.562, 7.5616, 7.5612, 7.5608, 7.5604,
    7.56, 7.5596, 7.5591, 7.5587, 7.5583, 9.7533, 9.748, 9.7427,
    9.7375, 9.7323, 9.7272, 9.722, 9.7169, 9.7118, 9.7067, 9.7015,
    9.6964, 9.6913, 9.6861, 9.6809, 9.6756, 9.6704, 9.6651, 9.6597,
    9.6543, 9.6489, 9.6434, 9.6379, 9.6323, 9.6266, 9.6209, 9.6151,
    9.6092, 9.6033, 9.5973, 9.5912, 9.5851, 9.5789, 9.5726, 9.5662,
    9.5598, 9.5533, 9.5468, 9.5402, 9.5335, 9.5268, 9.52, 9.5132,
    9.5063, 9.4993, 9.4923, 9.4853, 9.4782, 9.471, 9.4638, 9.4565,
    9.4492, 9.4418, 9.4344, 9.4269, 9.4193, 9.4118, 9.4041, 9.3964,
    9.3887, 9.3809, 9.373, 9.3652, 9.3572, 9.3493, 9.3413, 9.3332,
    9.3252, 9.3171, 9.3089, 9.3008, 9.2926, 9.2844, 9.2761, 9.2679,
    9.2596, 9.2513, 9.2429, 9.2346, 9.2262, 9.2178, 9.2094, 9.201,
    9.1926, 9.1842, 9.1757, 9.1672, 9.1588, 9.1503, 9.1418, 9.1333,
    9.1247, 9.1162, 9.1077, 9.0992, 9.0906, 9.0821, 9.0736, 9.065,
    9.0565, 9.048, 9.0395, 9.0309, 9.0224, 9.0139, 9.0054, 8.9969,
    8.9884, 8.98, 8.9715, 8.9631, 8.9546, 8.9462, 8.9378, 8.9293,
    8.921, 8.9126, 8.9042, 8.8959, 8.8875, 8.8792, 8.8709, 8.8626,
    8.8543, 8.8461, 8.8379, 8.8297, 8.8215, 8.8134, 8.8052, 8.7971,
    8.7891, 8.781, 8.773, 8.765, 8.757, 8.7491, 8.7412, 8.7333,
    8.7255, 8.7177, 8.7099, 8.7022, 8.6944, 8.6868, 8.6791, 8.6715,
    8.6639, 8.6564, 8.6489, 8.6414, 8.6339, 8.6265, 8.6192, 8.6118,
    8.6045, 8.5973, 8.5901, 8.5829, 8.5757, 8.5686, 8.5616, 8.5545,
    8.5475, 8.5406, 8.5337, 8.5268, 8.52, 8.5132, 8.5064, 8.4997,
    8.493, 8.4864, 8.4798, 8.4732, 8.4667, 8.4602, 8.4538, 8.4474,
    8.441, 8.4347, 8.4285, 8.4222, 8.416, 8.4099, 8.4037, 8.3977,
    8.3916, 8.3856, 8.3797, 8.3738, 8.3679, 8.3621, 8.3563, 8.3505,
    8.3448, 8.3391, 8.3335, 8.3279, 8.3224, 8.3168, 8.3114, 8.3059,
    8.3005, 8.2952, 8.2899, 8.2846, 8.2794, 8.2742, 8.269, 8.2639,
    8.2588, 8.2537, 8.2487, 8.2437, 8.2388, 8.2339, 8.229, 8.2242,
    8.2194, 8.2147, 8.21, 8.2053, 8.2006, 8.196, 8.1914, 8.1869,
    8.1824, 8.1779, 8.1734, 8.169, 8.1647, 8.1603, 8.156, 8.1517,
    8.1475, 8.1433, 8.1391, 8.1349, 8.1308, 8.1267, 8.1226, 8.1186,
    8.1146, 8.1106, 8.1067, 8.1028, 8.0989, 8.0951, 8.0913, 8.0875,
    8.0837, 8.08, 8.0763, 8.0727, 8.069, 8.0654, 8.0618, 8.0583,
    8.0547, 8.0512, 8.0478, 8.0443, 8.0409, 8.0375, 8.0341, 8.0308,
    8.0275, 8.0242, 8.0209, 8.0177, 8.0145, 8.0113, 8.0081, 8.005,
    8.0019, 7.9988, 7.9957, 7.9927, 7.9896, 7.9867, 7.9837, 7.9807,
    7.9778, 7.9749, 7.972, 7.9691, 7.9663, 7.9635, 7.9607, 7.9579,
    7.9552, 7.9524, 7.9497, 7.947, 7.9444, 7.9417, 7.9391, 7.9365,
    7.9339, 7.9314, 7.9288, 7.9263, 7.9238, 7.9213, 7.9189, 7.9164,
    7.914, 7.9116, 7.9093, 7.9069, 7.9046, 7.9022, 7.8999, 7.8977,
    7.8954, 7.8932, 7.8909, 7.8887, 7.8866, 7.8844, 7.8822, 7.8801,
    7.878, 7.8759, 7.8738, 7.8718, 7.8697, 7.8677, 7.8657, 7.8637,
    7.8618, 7.8598, 7.8579, 7.856, 7.8541, 7.8522, 7.8503, 7.8485,
    7.8467, 7.8449, 7.8431, 7.8413, 7.8395, 7.8378, 7.8361, 7.8344,
    7.8327, 7.831, 7.8293, 7.8277, 7.826, 7.8244, 7.8228, 7.8213,
    7.8197, 7.8181, 7.8166, 7.8151, 7.8136, 7.8121, 7.8106, 7.8092,
    7.8077, 7.8063, 7.8049, 7.8035, 7.8021, 7.8007, 7.7994, 7.798,
    7.7967, 7.7954, 7.7941, 7.7928, 7.7916, 7.7903, 7.7891, 7.7878,
    7.7866, 7.7854, 7.7842, 7.7831, 7.7819, 7.7808, 7.7796, 7.7785,
    7.7774, 7.7763, 7.7753, 7.7742, 7.7732, 7.7721, 7.7711, 7.7701,
    7.7691, 7.7681, 7.7671, 7.7662, 7.7653, 7.7643, 7.7634, 7.7625,
    7.7616, 7.7607, 7.7599, 7.759, 7.7582, 7.7574, 7.7565, 7.7557,
    7.755, 7.7542, 7.7534, 7.7527, 7.7519, 7.7512, 7.7505, 7.7498,
    7.7491, 7.7484, 7.7478, 7.7471, 7.7465, 7.7458, 7.7452, 7.7446,
    7.744, 7.7434, 7.7429, 7.7423, 7.7418, 7.7412, 7.7407, 7.7402,
    7.7397, 7.7392, 7.7387, 7.7382, 7.7378, 7.7373, 7.7369, 7.7365,
    7.7361, 7.7357, 7.7353, 7.7349, 7.7345, 7.7342, 7.7338, 7.7335,
    7.7332, 7.7329, 7.7326, 7.7323, 7.732, 7.7317, 7.7315, 7.7312,
    7.731, 7.7308, 7.7306, 7.7303, 7.7302, 7.73, 7.7298, 7.7296,
    7.7295, 7.7293, 7.7292, 7.7291, 7.729, 7.7289, 7.7288, 7.7287,
    7.7287, 7.7286, 7.7286, 7.7285, 7.7285, 7.7285, 7.7285, 7.7285,
    7.7285, 7.7285, 7.7285, 7.7286, 7.7286, 7.7287, 7.7288, 7.7288,
    7.7289, 7.729, 7.7291, 7.7293, 7.7294, 7.7295, 7.7297, 7.7298,
    7.73, 7.7302, 7.7303, 7.7305, 7.7307, 7.7309, 7.7312, 7.7314,
    7.7316, 7.7319, 7.7321, 7.7324, 7.7326, 7.7329, 7.7332, 7.7335,
    7.7338, 7.7341, 7.7344, 7.7347, 7.7351, 7.7354, 7.7358, 7.7361,
    7.7365, 7.7369, 7.7373, 7.7377, 7.7381, 7.7385, 7.7389, 7.7393,
    7.7397, 7.7402, 7.7406, 7.7411, 7.7415, 7.742, 7.7425, 7.743,
    7.7435, 7.744, 7.7445, 7.745, 7.7456, 7.7461, 7.7466, 7.7472,
    7.7478, 7.7483, 7.7489, 7.7495, 7.7501, 7.7507, 7.7513, 7.7519,
    7.7525, 7.7531, 7.7538, 7.7544, 7.7551, 7.7557, 7.7564, 7.757,
    7.7577, 7.7584, 7.7591, 7.7598, 7.7605, 7.7612, 7.7619, 7.7626,
    7.7634, 7.7641, 7.7649, 7.7656, 7.7664, 7.7671, 7.7679, 7.7687,
    7.7695, 7.7702, 7.771, 7.7718, 7.7726, 7.7735, 7.7743, 7.7751,
    7.7759, 7.7768, 7.7776, 7.7785, 7.7793, 7.7802, 7.7811, 7.7819,
    7.7828, 7.7837, 7.7846, 7.7855, 7.7864, 7.7873, 7.7882, 7.7891,
    7.7901, 7.791, 7.7919, 7.7929, 7.7938, 7.7948, 7.7957, 7.7967,
    7.7977, 7.7986, 7.7996, 7.8006, 7.8016, 7.8026, 7.8036, 7.8046,
    7.8056, 7.8066, 7.8076, 7.8087, 7.8097, 7.8107, 7.8118, 7.8128,
    7.8139, 7.8149, 7.816, 7.817, 7.8181, 7.8192, 7.8202, 7.8213,
    7.8224, 7.8235, 7.8246, 7.8257, 7.8268, 7.8279, 7.829, 7.8301,
    7.8312, 7.8324, 7.8335, 7.8346, 7.8358, 7.8369, 7.8381, 7.8392,
    7.8403, 7.8415, 7.8427, 7.8438, 7.845, 7.8462, 7.8473, 7.8485,
    7.8497, 7.8509, 7.852, 7.8532, 7.8544, 7.8556, 7.8568, 7.858,
    7.8592, 7.8604, 7.8616, 7.8628, 7.864, 7.8653, 7.8665, 7.8677,
    7.8689, 7.8701, 7.8714, 7.8726, 7.8738, 7.8751, 7.8763, 7.8775,
    7.8788, 7.88, 7.8813, 7.8825, 7.8838, 7.885, 7.8863, 7.8875,
    7.8888, 7.89, 7.8913, 7.8926, 7.8938, 7.8951, 7.8963, 7.8976,
    7.8989, 7.9001, 7.9014, 7.9027, 7.904, 7.9052, 7.9065, 7.9078,
    7.9091, 7.9103, 7.9116, 7.9129, 7.9142, 7.9155, 7.9167, 7.918,
    7.9193, 7.9206, 7.9219, 7.9232, 7.9244, 7.9257, 7.927, 7.9283,
    7.9296, 7.9309, 7.9322, 7.9334, 7.9347, 7.936, 7.9373, 7.9386,
    7.9399, 7.9412, 7.9424, 7.9437, 7.945, 7.9463, 7.9476, 7.9489,
    7.9502, 7.9514, 7.9527, 7.954, 7.9553, 7.9566, 7.9579, 7.9591,
    7.9604, 7.9617, 7.963, 7.9643, 7.9655, 7.9668, 7.9681, 7.9694,
    7.9706, 7.9719, 7.9732, 7.9745, 7.9757, 7.977, 7.9783, 7.9795,
    7.9808, 7.9821, 7.9833, 7.9846, 7.9859, 7.9871, 7.9884, 7.9897,
    7.9909, 7.9922, 7.9934, 7.9947, 7.9959, 7.9972, 7.9985, 7.9997,
    8.001, 8.0022, 8.0035, 8.0047, 8.0059, 8.0072, 8.0084, 8.0097,
    8.0109, 8.0122, 8.0134, 8.0146, 8.0159, 8.0171, 8.0183, 8.0196,
    8.0208, 8.022, 8.0232, 8.0245, 8.0257, 8.0269, 8.0281, 8.0293,
    8.0306, 8.0318, 8.033, 8.0342, 8.0354, 8.0366, 8.0378, 8.039,
    8.0402, 8.0414, 8.0426, 8.0438, 8.045, 8.0462, 8.0474, 8.0486,
    8.0498, 8.051, 8.0522, 8.0534, 8.0546, 8.0557, 8.0569, 8.0581,
    8.0593, 8.0604, 8.0616, 8.0628, 8.064, 8.0651, 8.0663, 8.0675,
    8.0686, 8.0698, 8.0709, 8.0721, 8.0733, 8.0744, 8.0756, 8.0767,
    8.0779, 8.079, 8.0801, 8.0813, 8.0824, 8.0836, 8.0847, 8.0858,
    8.087, 8.0881, 8.0892, 8.0904, 8.0915, 8.0926, 8.0937, 8.0949,
    8.096, 8.0971, 8.0982, 8.0993, 8.1004, 8.1016, 8.1027, 8.1038,
    8.1049, 8.106, 8.1071, 8.1082, 8.1093, 8.1104, 8.1115, 8.1126,
    8.1137, 8.1148, 8.1158, 8.1169, 8.118, 8.1191, 8.1202, 8.1213,
    8.1224, 8.1234, 8.1245, 8.1256, 8.1267, 8.1277, 8.1288, 8.1299,
    8.1309, 8.132, 8.1331, 8.1341, 8.1352, 8.1363, 8.1373, 8.1384,
    8.1394, 8.1405, 8.1415, 8.1426, 8.1436, 8.1447, 8.1457, 8.1468,
    8.1478, 8.1489, 8.1499, 8.151, 8.152, 8.153, 8.1541, 8.1551,
    8.1562, 8.1572, 8.1582, 8.1592, 8.1603, 8.1613, 8.1623, 8.1634,
    8.1644, 8.1654, 8.1664, 8.1675, 8.1685, 8.1695, 8.1705, 8.1715,
    8.1725, 8.1736, 8.1746, 8.1756, 8.1766, 8.1776, 8.1786, 8.1796,
    8.1806, 8.1816, 8.1826, 8.1836, 8.1846, 8.1856, 8.1866, 8.1876,
    8.1886, 8.1896, 8.1906, 8.1916, 8.1926, 8.1936, 8.1946, 8.1956,
    8.1966, 8.1976, 8.1986, 8.1996, 8.2006, 8.2015, 8.2025, 8.2035,
    8.2045, 8.2055, 8.2065, 8.2074, 8.2084, 8.2094, 8.2104, 8.2114,
    8.2123, 8.2133, 8.2143, 8.2153, 8.2162, 8.2172, 8.2182, 8.2192,
    8.2201, 8.2211, 8.2221, 8.2231, 8.224, 8.225, 8.226, 8.2269,
    8.2279, 8.2289, 8.2298, 8.2308, 8.2318, 8.2327, 8.2337, 8.2346,
    8.2356, 8.2366, 8.2375, 8.2385, 8.2395, 8.2404, 8.2414, 8.2423,
    8.2433, 8.2442, 8.2452, 8.2462, 8.2471, 8.2481, 8.249, 8.25,
    8.2509, 8.2519, 8.2528, 8.2538, 8.2547, 8.2557, 8.2566, 8.2576,
    8.2585, 8.2595, 8.2604, 8.2614, 8.2623, 8.2632, 8.2642, 8.2651,
    8.2661, 8.267, 8.268, 8.2689, 8.2698, 8.2708, 8.2717, 8.2727,
    8.2736, 8.2745, 8.2755, 8.2764, 8.2773, 8.2783, 8.2792, 8.2801,
    8.2811, 8.282, 8.2829, 8.2838, 8.2848, 8.2857, 8.2866, 8.2876,
    8.2885, 8.2894, 8.2903, 8.2913, 8.2922, 8.2931, 8.294, 8.2949,
    8.2959, 8.2968, 8.2977, 8.2986, 8.2995, 8.3004, 8.3014, 8.3023,
    8.3032, 8.3041, 8.305, 8.3059, 8.3068, 8.3077, 8.3086, 8.3096,
    8.3105, 8.3114, 8.3123, 8.3132, 8.3141, 8.315, 8.3159, 8.3168,
    8.3177, 8.3186, 8.3195, 8.3204, 8.3213, 8.3222, 8.3231, 8.324,
    8.3249, 8.3257, 8.3266, 8.3275, 8.3284, 8.3293, 8.3302, 8.3311,
    8.332, 8.3329, 8.3337, 8.3346, 8.3355, 8.3364, 8.3373, 8.3381,
    8.339, 8.3399, 8.3408, 8.3417, 8.3425, 8.3434, 8.3443, 8.3451,
    8.346, 8.3469, 8.3478, 8.3486, 8.3495, 8.3504, 8.3512, 8.3521,
    8.353, 8.3538, 8.3547, 8.3555, 8.3564, 8.3573, 8.3581, 8.359,
    8.3598, 8.3607, 8.3615, 8.3624, 8.3633, 8.3641, 8.365, 8.3658,
    8.3667, 8.3675, 8.3684, 8.3692, 8.3701, 8.3709, 8.3717, 8.3726,
    8.3734, 8.3743, 8.3751, 8.376, 8.3768, 8.3776, 8.3785, 8.3793,
    8.3801, 8.381, 8.3818, 8.3826, 8.3835, 8.3843, 8.3851, 8.386,
    8.3868, 8.3876, 8.3885, 8.3893, 8.3901, 8.3909, 8.3918, 8.3926,
    8.3934, 8.3942, 8.395, 8.3959, 8.3967, 8.3975, 8.3983, 8.3991,
    8.4, 8.4008, 8.4016, 8.4024, 8.4032, 8.404, 8.4048, 8.4057,
    8.4065, 8.4073, 8.4081, 8.4089, 8.4097, 8.4105, 8.4113, 8.4121,
    8.4129, 8.4137, 8.4145, 8.4153, 8.4161, 8.4169, 8.4177, 8.4185,
    8.4193, 8.4201, 8.4209, 8.4217, 8.4225, 8.4233, 8.4241, 8.4249,
    8.4257, 8.4265, 8.4273, 8.4281, 8.4289, 8.4297, 8.4305, 8.4313,
    8.4321, 8.4329, 8.4337, 8.4344, 8.4352, 8.436, 8.4368, 8.4376,
    8.4384, 8.4392, 8.44, 8.4407, 8.4415, 8.4423, 8.4431, 8.4439,
    8.4447, 8.4455, 8.4462, 8.447, 8.4478, 8.4486, 8.4494, 8.4501,
    8.4509, 8.4517, 8.4525, 8.4533, 8.454, 8.4548, 8.4556, 8.4564,
    8.4572, 8.4579, 8.4587, 8.4595, 8.4603, 8.461, 8.4618, 8.4626,
    8.4634, 8.4641, 8.4649, 8.4657, 8.4665, 8.4672, 8.468, 8.4688,
    8.4696, 8.4703, 8.4711, 8.4719, 8.4727, 8.4734, 8.4742, 8.475,
    8.4757, 8.4765, 8.4773, 8.4781, 8.4788, 8.4796, 8.4804, 8.4811,
    8.4819, 8.4827, 8.4834, 8.4842, 8.485, 8.4857, 8.4865, 8.4873,
    8.488, 8.4888, 8.4896, 8.4903, 8.4911, 8.4919, 8.4926, 8.4934,
    8.4942, 8.4949, 8.4957, 8.4965, 8.4972, 8.498, 8.4987, 8.4995,
    8.5003, 8.501, 8.5018, 8.5026, 8.5033, 8.5041, 8.5048, 8.5056,
    8.5064, 8.5071, 8.5079, 8.5087, 8.5094, 8.5102, 8.5109, 8.5117,
    8.5125, 8.5132, 8.514, 8.5147, 8.5155, 8.5163, 8.517, 8.5178,
    8.5185, 8.5193, 8.5201, 8.5208, 8.5216, 8.5223, 8.5231, 8.5238,
    8.5246, 8.5254, 8.5261, 8.5269, 8.5276, 8.5284, 8.5292, 8.5299,
    8.5307, 8.5314, 8.5322, 8.5329, 8.5337, 8.5345, 8.5352, 8.536,
    8.5367, 8.5375, 8.5382, 8.539, 8.5398, 8.5405, 8.5413, 8.542,
    8.5428, 8.5435, 8.5443, 8.5451, 8.5458, 8.5466, 8.5473, 8.5481,
    8.5488, 8.5496, 8.5504, 8.5511, 8.5519, 8.5526, 8.5534, 8.5541,
    8.5549, 8.5556, 8.5564, 8.5572, 8.5579, 8.5587, 8.5594, 8.5602,
    8.5609, 8.5617, 8.5625, 8.5632, 8.564, 8.5647, 8.5655, 8.5662,
    8.567, 8.5678, 8.5685, 8.5693, 8.57, 8.5708, 8.5715, 8.5723,
    8.5731, 8.5738, 8.5746, 8.5753, 8.5761, 8.5768, 8.5776, 8.5784,
    8.5791, 8.5799, 8.5806, 8.5814, 8.5821, 8.5829, 8.5837, 8.5844,
    8.5852, 8.5859, 8.5867, 8.5875, 8.5882, 8.589, 8.5897, 8.5905,
    8.5913, 8.592, 8.5928, 8.5935, 8.5943, 8.595, 8.5958, 8.5966,
    8.5973, 8.5981, 8.5988, 8.5996, 8.6004, 8.6011, 8.6019, 8.6026,
    8.6034, 8.6042, 8.6049, 8.6057, 8.6065, 8.6072, 8.608, 8.6087,
    8.6095, 8.6103, 8.611, 8.6118, 8.6125, 8.6133, 8.6141, 8.6148,
    8.6156, 8.6164, 8.6171, 8.6179, 8.6186, 8.6194, 8.6202, 8.6209,
    8.6217, 8.6225, 8.6232, 8.624, 8.6248, 8.6255, 8.6263, 8.627,
    8.6278, 8.6286, 8.6293, 8.6301, 8.6309, 8.6316, 8.6324, 8.6332,
    8.6339, 8.6347, 8.6355, 8.6362, 8.637, 8.6378, 8.6385, 8.6393,
    8.6401, 8.6408, 8.6416, 8.6424, 8.6431, 8.6439, 8.6447, 8.6454,
    8.6462, 8.647, 8.6477, 8.6485, 8.6493, 8.65, 8.6508, 8.6516,
    8.6524, 8.6531, 8.6539, 8.6547, 8.6554, 8.6562, 8.657, 8.6577,
    8.6585, 8.6593, 8.6601, 8.6608, 8.6616, 8.6624, 8.6631, 8.6639,
    8.6647, 8.6654, 8.6662, 8.667, 8.6678, 8.6685, 8.6693, 8.6701,
    8.6708, 8.6716, 8.6724, 8.6732, 8.6739, 8.6747, 8.6755, 8.6763,
    8.677, 8.6778, 8.6786, 8.6794, 8.6801, 8.6809, 8.6817, 8.6824,
    8.6832, 8.684, 8.6848, 8.6855, 8.6863, 8.6871, 8.6879, 8.6886,
    8.6894, 8.6902, 8.691, 8.6917, 8.6925, 8.6933, 8.6941, 8.6948,
    8.6956, 8.6964, 8.6972, 8.698, 8.6987, 8.6995, 8.7003, 8.7011,
    8.7018, 8.7026, 8.7034, 8.7042, 8.7049, 8.7057, 8.7065, 8.7073,
    8.7081, 8.7088, 8.7096, 8.7104, 8.7112, 8.7119, 8.7127, 8.7135,
    8.7143, 8.7151, 8.7158, 8.7166, 8.7174, 8.7182, 8.7189, 8.7197,
    8.7205, 8.7213, 8.7221, 8.7228, 8.7236, 8.7244, 8.7252, 8.7259,
    8.7267, 8.7275, 8.7283, 8.7291, 8.7298, 8.7306, 8.7314, 8.7322,
    8.733, 8.7337, 8.7345, 8.7353, 8.7361, 8.7369, 8.7376, 8.7384,
    8.7392, 8.74, 8.7408, 8.7415, 8.7423, 8.7431, 8.7439, 8.7446,
    8.7454, 8.7462, 8.747, 8.7478, 8.7485, 8.7493, 8.7501, 8.7509,
    8.7517, 8.7524, 8.7532, 8.754, 8.7548, 8.7556, 8.7563, 8.7571,
    8.7579, 8.7587, 8.7595, 8.7602, 8.761, 8.7618, 8.7626, 8.7634,
    8.7641, 8.7649, 8.7657, 8.7665, 8.7673, 8.768, 8.7688, 8.7696,
    8.7704, 8.7712, 8.7719, 8.7727, 8.7735, 8.7743, 8.7751, 8.7758,
    8.7766, 8.7774, 8.7782, 8.779, 8.7797, 8.7805, 8.7813, 8.7821,
    8.7829, 8.7836, 8.7844, 8.7852, 8.786, 8.7868, 8.7875, 8.7883,
    8.7891, 8.7899, 8.7907, 8.7914, 8.7922, 8.793, 8.7938, 8.7945,
    8.7953, 8.7961, 8.7969, 8.7977, 8.7984, 8.7992, 8.8, 8.8008,
    8.8016, 8.8023, 8.8031, 8.8039, 8.8047, 8.8055, 8.8062, 8.807,
    8.8078, 8.8086, 8.8093, 8.8101, 8.8109, 8.8117, 8.8125, 8.8132,
    8.814, 8.8148, 8.8156, 8.8164, 8.8171, 8.8179, 8.8187, 8.8195,
    8.8202, 8.821, 8.8218, 8.8226, 8.8234, 8.8241, 8.8249, 8.8257,
    8.8265, 8.8272, 8.828, 8.8288, 8.8296, 8.8303, 8.8311, 8.8319,
    8.8327, 8.8334, 8.8342, 8.835, 8.8358, 8.8365, 8.8373, 8.8381,
    8.8389, 8.8396, 8.8404, 8.8412, 8.842, 8.8427, 8.8435, 8.8443,
    8.8451, 8.8458, 8.8466, 8.8474, 8.8482, 8.8489, 8.8497, 8.8505,
    8.8512, 8.852, 8.8528, 3.3464, 3.3174, 3.337, 3.3627, 3.3915,
    3.4223, 3.4545, 3.4879, 3.5222, 3.5576, 3.5941, 3.6319, 3.671,
    3.7113, 3.7529, 3.7956, 3.8389, 3.8828, 3.927, 3.9714, 4.0158,
    4.0603, 4.1046, 4.1489, 4.193, 4.2369, 4.2806, 4.324, 4.3671,
    4.41, 4.4525, 4.4946, 4.5363, 4.5776, 4.6185, 4.659, 4.699,
    4.7386, 4.7778, 4.8166, 4.8549, 4.8928, 4.9303, 4.9674, 5.0041,
    5.0404, 5.0763, 5.1118, 5.1469, 5.1817, 5.2161, 5.2501, 5.2837,
    5.3171, 5.35, 5.3826, 5.4149, 5.4468, 5.4784, 5.5097, 5.5407,
    5.5714, 5.6018, 5.6319, 5.6617, 5.6912, 5.7205, 5.7494, 5.7781,
    5.8065, 5.8346, 5.8625, 5.8901, 5.9174, 5.9445, 5.9713, 5.9979,
    6.0242, 6.0503, 6.0762, 6.1018, 6.1272, 6.1523, 6.1772, 6.2019,
    6.2264, 6.2507, 6.2748, 6.2986, 6.3223, 6.3457, 6.369, 6.3921,
    6.4149, 6.4376, 6.4601, 6.4824, 6.5046, 6.5265, 6.5483, 6.5699,
    6.5914, 6.6126, 6.6338, 6.6547, 6.6755, 6.6962, 6.7166, 6.737,
    6.7572, 6.7772, 6.7971, 6.8168, 6.8365, 6.8559, 6.8753, 6.8945,
    6.9135, 6.9325, 6.9513, 6.9699, 6.9885, 7.0069, 7.0252, 7.0434,
    7.0615, 7.0794, 7.0972, 7.1149, 7.1325, 7.15, 7.1674, 7.1846,
    7.2018, 7.2188, 7.2357, 7.2525, 7.2692, 7.2858, 7.3023, 7.3187,
    7.335, 7.3512, 7.3673, 7.3833, 7.3992, 7.415, 7.4307, 7.4463,
    7.4618, 7.4772, 7.4925, 7.5077, 7.5228, 7.5379, 7.5528, 7.5677,
    7.5824, 7.5971, 7.6117, 7.6262, 7.6406, 7.655, 7.6692, 7.6834,
    7.6975, 7.7115, 7.7255, 7.7394, 7.7532, 7.7669, 7.7805, 7.7941,
    7.8076, 7.821, 7.8344, 7.8477, 7.8609, 7.8741, 7.8871, 7.9002,
    7.9131, 7.926, 7.9389, 7.9516, 7.9643, 7.977, 7.9895, 8.0021,
    8.0145, 8.0269, 8.0392, 8.0515, 8.0637, 8.0759, 8.0879, 8.1,
    8.112, 8.1239, 8.1357, 8.1475, 8.1593, 8.171, 8.1826, 8.1942,
    8.2058, 8.2173, 8.2287, 8.2401, 8.2514, 8.2627, 8.2739, 8.2851,
    8.2963, 8.3074, 8.3184, 8.3294, 8.3404, 8.3513, 8.3621, 8.3729,
    8.3837, 8.3944, 8.4051, 8.4157, 8.4263, 8.4369, 8.4474, 8.4578,
    8.4683, 8.4787, 8.489, 8.4993, 8.5096, 8.5198, 8.53, 8.5401,
    8.5502, 8.5603, 8.5704, 8.5804, 8.5903, 8.6003, 8.6102, 8.62,
    8.6299, 8.6397, 8.6494, 8.6592, 8.6689, 8.6785, 8.6882, 8.6978,
    8.7073, 8.7169, 8.7264, 8.7359, 8.7453, 8.7548, 8.7642, 8.7735,
    8.7829, 8.7922, 8.8015, 8.8107, 8.82, 8.8292, 8.8384, 8.8475,
    8.8567, 8.8658, 8.8748, 8.8839, 8.8929, 8.9019, 8.9109, 8.9199,
    8.9288, 8.9377, 8.9466, 8.9555, 8.9643, 8.9731, 8.9819, 8.9907,
    8.9995, 9.0082, 9.0169, 9.0256, 9.0342, 9.0429, 9.0515, 9.0601,
    9.0687, 9.0772, 9.0858, 9.0943, 9.1028, 9.1113, 9.1198, 9.1282,
    9.1366, 9.145, 9.1534, 9.1618, 9.1701, 9.1785, 9.1868, 9.1951,
    9.2034, 9.2117, 9.2199, 9.2282, 9.2364, 9.2446, 9.2528, 9.261,
    9.2691, 9.2773, 9.2854, 9.2935, 9.3016, 9.3097, 9.3178, 9.3258,
    9.3339, 9.3419, 9.3499, 9.3579, 9.3659, 9.3739, 9.3819, 9.3898,
    9.3978, 9.4057, 9.4136, 9.4215, 9.4294, 9.4373, 9.4452, 9.453,
    9.4609, 9.4687, 9.4765, 9.4844, 9.4922, 9.4999, 9.5077, 9.5155,
    9.5232, 9.531, 9.5387, 9.5464, 9.5542, 9.5619, 9.5696, 9.5772,
    9.5849, 9.5926, 9.6002, 9.6079, 9.6155, 9.6231, 9.6308, 9.6384,
    9.646, 9.6535, 9.6611, 9.6687, 9.6763, 9.6838, 9.6914, 9.6989,
    9.7064, 9.7139, 9.7214, 9.7289, 9.7364, 9.7439, 9.7514, 9.7588,
    9.7663, 9.7738, 9.7812, 9.7886, 9.796, 9.8035, 9.8109, 9.8183,
    9.8257, 9.833, 9.8404, 9.8478, 9.8551, 9.8625, 9.8699, 9.8772,
    9.8845, 9.8918, 9.8992, 9.9065, 9.9138, 9.9211, 9.9284, 9.9357,
    9.9429, 9.9502, 9.9575, 9.9647, 9.972, 9.9792, 9.9865, 9.9937,
    10.0009, 10.0082, 10.0154, 10.0226, 10.0298, 10.037, 10.0442,
    10.0514, 10.0586, 10.0657, 10.0729, 10.0801, 10.0872, 10.0944,
    10.1015, 10.1087, 10.1158, 10.123, 10.1301, 10.1372, 10.1443,
    10.1515, 10.1586, 10.1657, 10.1728, 10.1799, 10.187, 10.1941,
    10.2011, 10.2082, 10.2153, 10.2224, 10.2294, 10.2365, 10.2435,
    10.2506, 10.2576, 10.2647, 10.2717, 10.2788, 10.2858, 10.2928,
    10.2998, 10.3069, 10.3139, 10.3209, 10.3279, 10.3349, 10.3419,
    10.3489, 10.3559, 10.3629, 10.3699, 10.3769, 10.3839, 10.3908,
    10.3978, 10.4048, 10.4118, 10.4187, 10.4257, 10.4326, 10.4396,
    10.4465, 10.4535, 10.4604, 10.4674, 10.4743, 10.4813, 10.4882,
    10.4951, 10.502, 10.509, 10.5159, 10.5228, 10.5297, 10.5366,
    10.5435, 10.5505, 10.5574, 10.5643, 10.5712, 10.578, 10.5849,
    10.5918, 10.5987, 10.6056, 10.6125, 10.6193, 10.6262, 10.6331,
    10.6399, 10.6468, 10.6537, 10.6605, 10.6674, 10.6742, 10.6811,
    10.6879, 10.6948, 10.7016, 10.7084, 10.7153, 10.7221, 10.7289,
    10.7357, 10.7426, 10.7494, 10.7562, 10.763, 10.7698, 10.7766,
    10.7835, 10.7903, 10.7971, 10.8039, 10.8107, 10.8174, 10.8242,
    10.831, 10.8378, 10.8446, 10.8514, 10.8582, 10.8649, 10.8717,
    10.8785, 10.8852, 10.892, 10.8988, 10.9055, 10.9123, 10.9191,
    10.9258, 10.9326, 10.9393, 10.9461, 10.9528, 10.9596, 10.9663,
    10.973, 10.9798, 10.9865, 10.9932, 11, 11.0067, 11.0134,
    11.0202, 11.0269, 11.0336, 11.0403, 11.047, 11.0537, 11.0605,
    11.0672, 11.0739, 11.0806, 11.0873, 11.094, 11.1007, 11.1074,
    11.1141, 11.1208, 11.1275, 11.1342, 11.1409, 11.1476, 11.1543,
    11.161, 11.1676, 11.1743, 11.181, 11.1877, 11.1944, 11.2011,
    11.2077, 11.2144, 11.2211, 11.2278, 11.2345, 11.2411, 11.2478,
    11.2545, 11.2612, 11.2678, 11.2745, 11.2812, 11.2878, 11.2945,
    11.3012, 11.3078, 11.3145, 11.3212, 11.3278, 11.3345, 11.3412,
    11.3478, 11.3545, 11.3612, 11.3678, 11.3745, 11.3811, 11.3878,
    11.3945, 11.4011, 11.4078, 11.4144, 11.4211, 11.4277, 11.4344,
    11.441, 11.4477, 11.4543, 11.461, 11.4676, 11.4743, 11.4809,
    11.4876, 11.4942, 11.5009, 11.5075, 11.5142, 11.5208, 11.5274,
    11.5341, 11.5407, 11.5474, 11.554, 11.5606, 11.5673, 11.5739,
    11.5806, 11.5872, 11.5938, 11.6005, 11.6071, 11.6137, 11.6204,
    11.627, 11.6336, 11.6403, 11.6469, 11.6535, 11.6601, 11.6668,
    11.6734, 11.68, 11.6866, 11.6933, 11.6999, 11.7065, 11.7131,
    11.7198, 11.7264, 11.733, 11.7396, 11.7462, 11.7528, 11.7595,
    11.7661, 11.7727, 11.7793, 11.7859, 11.7925, 11.7991, 11.8057,
    11.8124, 11.819, 11.8256, 11.8322, 11.8388, 11.8454, 11.852,
    11.8586, 11.8652, 11.8718, 11.8784, 11.885, 11.8916, 11.8982,
    11.9048, 11.9114, 11.918, 11.9246, 11.9312, 11.9378, 11.9444,
    11.951, 11.9576, 11.9642, 11.9707, 11.9773, 11.9839, 11.9905,
    11.9971, 12.0037, 12.0103, 12.0168, 12.0234, 12.03, 12.0366,
    12.0431, 12.0497, 12.0563, 12.0629, 12.0694, 12.076, 12.0826,
    12.0891, 12.0957, 12.1023, 12.1088, 12.1154, 12.122, 12.1285,
    12.1351, 12.1416, 12.1482, 12.1548, 12.1613, 12.1679, 12.1744,
    12.181, 12.1875, 12.1941, 12.2006, 12.2072, 12.2137, 12.2202,
    12.2268, 12.2333, 12.2398, 12.2464, 12.2529, 12.2594, 12.266,
    12.2725, 12.279, 12.2855, 12.292, 12.2986, 12.3051, 12.3116,
    12.3181, 12.3246, 12.3311, 12.3376, 12.3441, 12.3506, 12.3571,
    12.3636, 12.3701, 12.3766, 12.383, 12.3895, 12.396, 12.4025,
    12.409, 12.4154, 12.4219, 12.4284, 12.4348, 12.4413, 12.4477,
    12.4542, 12.4606, 12.4671, 12.4735, 12.48, 12.4864, 12.4929,
    12.4993, 12.5057, 12.5121, 12.5186, 12.525, 12.5314, 12.5378,
    12.5442, 12.5506, 12.557, 12.5634, 12.5698, 12.5762, 12.5826,
    12.589, 12.5954, 12.6018, 12.6082, 12.6145, 12.6209, 12.6273,
    12.6336, 12.64, 12.6464, 12.6527, 12.6591, 12.6654, 12.6718,
    12.6781, 12.6844, 12.6908, 12.6971, 12.7034, 12.7098, 12.7161,
    12.7224, 12.7287, 12.735, 12.7413, 12.7476, 12.7539, 12.7602,
    12.7665, 12.7728, 12.7791, 12.7854, 12.7916, 12.7979, 12.8042,
    12.8104, 12.8167, 12.823, 12.8292, 12.8355, 12.8417, 12.848,
    12.8542, 12.8604, 12.8667, 12.8729, 12.8791, 12.8853, 12.8915,
    12.8978, 12.904, 12.9102, 12.9164, 12.9226, 12.9288, 12.935,
    12.9411, 12.9473, 12.9535, 12.9597, 12.9658, 12.972, 12.9782,
    12.9843, 12.9905, 12.9966, 13.0028, 13.0089, 13.0151, 13.0212,
    13.0273, 13.0334, 13.0396, 13.0457, 13.0518, 13.0579, 13.064,
    13.0701, 13.0762, 13.0823, 13.0884, 13.0945, 13.1006, 13.1067,
    13.1127, 13.1188, 13.1249, 13.131, 13.137, 13.1431, 13.1491,
    13.1552, 13.1612, 13.1673, 13.1733, 13.1793, 13.1854, 13.1914,
    13.1974, 13.2034, 13.2095, 13.2155, 13.2215, 13.2275, 13.2335,
    13.2395, 13.2455, 13.2515, 13.2575, 13.2634, 13.2694, 13.2754,
    13.2814, 13.2873, 13.2933, 13.2993, 13.3052, 13.3112, 13.3171,
    13.3231, 13.329, 13.335, 13.3409, 13.3468, 13.3528, 13.3587,
    13.3646, 13.3705, 13.3765, 13.3824, 13.3883, 13.3942, 13.4001,
    13.406, 13.4119, 13.4178, 13.4237, 13.4296, 13.4354, 13.4413,
    13.4472, 13.4531, 13.4589, 13.4648, 13.4707, 13.4765, 13.4824,
    13.4883, 13.4941, 13.5, 13.5058, 13.5116, 13.5175, 13.5233,
    13.5291, 13.535, 13.5408, 13.5466, 13.5524, 13.5583, 13.5641,
    13.5699, 13.5757, 13.5815, 13.5873, 13.5931, 13.5989, 13.6047,
    13.6105, 13.6163, 13.622, 13.6278, 13.6336, 13.6394, 13.6452,
    13.6509, 13.6567, 13.6625, 13.6682, 13.674, 13.6797, 13.6855,
    13.6912, 13.697, 13.7027, 13.7085, 13.7142, 13.7199, 13.7257,
    13.7314, 13.7371, 13.7429, 13.7486, 13.7543, 13.76, 13.7657,
    13.7715, 13.7772, 13.7829, 13.7886, 13.7943, 13.8, 13.8057,
    13.8114, 13.8171, 13.8228, 13.8285, 13.8341, 13.8398, 13.8455,
    13.8512, 13.8569, 13.8625, 13.8682, 13.8739, 13.8796, 13.8852,
    13.8909, 13.8966, 13.9022, 13.9079, 13.9135, 13.9192, 13.9248,
    13.9305, 13.9361, 13.9418, 13.9474, 13.9531, 13.9587, 13.9644,
    13.97, 13.9756, 13.9813, 13.9869, 13.9925, 13.9982, 14.0038,
    14.0094, 14.015, 14.0207, 14.0263, 14.0319, 14.0375, 14.0431,
    14.0488, 14.0544, 14.06, 14.0656, 14.0712, 14.0768, 14.0824,
    14.088, 14.0936, 14.0992, 14.1048, 14.1104, 14.116, 14.1216,
    14.1272, 14.1328, 14.1384, 14.144, 14.1495, 14.1551, 14.1607,
    14.1663, 14.1719, 14.1775, 14.183, 14.1886, 14.1942, 14.1998,
    14.2053, 14.2109, 14.2165, 14.2221, 14.2276, 14.2332, 14.2388,
    14.2443, 14.2499, 14.2554, 14.261, 14.2666, 14.2721, 14.2777,
    14.2832, 14.2888, 14.2944, 14.2999, 14.3055, 14.311, 14.3166,
    14.3221, 14.3277, 14.3332, 14.3387, 14.3443, 14.3498, 14.3554,
    14.3609, 14.3665, 14.372, 14.3775, 14.3831, 14.3886, 14.3942,
    14.3997, 14.4052, 14.4108, 14.4163, 14.4218, 14.4274, 14.4329,
    14.4384, 14.4439, 14.4495, 14.455, 14.4605, 14.4661, 14.4716,
    14.4771, 14.4826, 14.4881, 14.4937, 14.4992, 14.5047, 14.5102,
    14.5158, 14.5213, 14.5268, 14.5323, 14.5378, 14.5433, 14.5489,
    14.5544, 14.5599, 14.5654, 14.5709, 14.5764, 14.5819, 14.5875,
    14.593, 14.5985, 14.604, 14.6095, 14.615, 14.6205, 14.626,
    14.6315, 14.6371, 14.6426, 14.6481, 14.6536, 14.6591, 14.6646,
    14.6701, 14.6756, 14.6811, 14.6866, 14.6921, 14.6976, 14.7032,
    14.7087, 14.7142, 14.7197, 14.7252, 14.7307, 14.7362, 14.7417,
    14.7472, 14.7527, 14.7582, 14.7637, 14.7692, 14.7747, 14.7802,
    14.7857, 14.7912, 14.7967, 14.8022, 14.8077, 14.8132, 14.8187,
    14.8242, 14.8297, 14.8352, 14.8407, 14.8462, 14.8517, 14.8572,
    14.8627, 14.8682, 14.8737, 14.8792, 14.8847, 14.8902, 14.8957,
    14.9012, 14.9067, 14.9122, 14.9177, 14.9232, 14.9287, 14.9342,
    14.9397, 14.9452, 14.9507, 14.9562, 14.9617, 14.9672, 14.9727,
    14.9782, 14.9837, 14.9892, 14.9947, 15.0002, 15.0057, 15.0112,
    15.0167, 15.0222, 15.0277, 15.0332, 15.0387, 15.0442, 15.0497,
    15.0552, 15.0607, 15.0662, 15.0717, 15.0772, 15.0827, 15.0882,
    15.0937, 15.0992, 15.1047, 15.1102, 15.1157, 15.1212, 15.1267,
    15.1322, 15.1377, 15.1432, 15.1487, 15.1542, 15.1596, 15.1651,
    15.1706, 15.1761, 15.1816, 15.1871, 15.1926, 15.1981, 15.2036,
    15.2091, 15.2146, 15.2201, 15.2256, 15.2311, 15.2366, 15.2421,
    15.2476, 15.2531, 15.2586, 15.2641, 15.2696, 15.2751, 15.2806,
    15.2861, 15.2916, 15.2971, 15.3026, 15.3081, 15.3135, 15.319,
    15.3245, 15.33, 15.3355, 15.341, 15.3465, 15.352, 15.3575,
    15.363, 15.3685, 15.374, 15.3795, 15.385, 15.3905, 15.396,
    15.4015, 15.407, 15.4125, 15.4179, 15.4234, 15.4289, 15.4344,
    15.4399, 15.4454, 15.4509, 15.4564, 15.4619, 15.4674, 15.4729,
    15.4784, 15.4839, 15.4894, 15.4948, 15.5003, 15.5058, 15.5113,
    15.5168, 15.5223, 15.5278, 15.5333, 15.5388, 15.5443, 15.5498,
    15.5552, 15.5607, 15.5662, 15.5717, 15.5772, 15.5827, 15.5882,
    15.5937, 15.5992, 15.6047, 15.6101, 15.6156, 15.6211, 15.6266,
    15.6321, 15.6376, 15.6431, 15.6486, 15.654, 15.6595, 15.665,
    15.6705, 15.676, 15.6815, 15.687, 15.6924, 15.6979, 15.7034,
    15.7089, 15.7144, 15.7199, 15.7253, 15.7308, 15.7363, 15.7418,
    15.7473, 15.7528, 15.7582, 15.7637, 15.7692, 15.7747, 15.7802,
    15.7856, 15.7911, 15.7966, 15.8021, 15.8076, 15.813, 15.8185,
    15.824, 15.8295, 15.835, 15.8404, 15.8459, 15.8514, 15.8569,
    15.8623, 15.8678, 15.8733, 15.8788, 15.8842, 15.8897, 15.8952,
    15.9007, 15.9061, 15.9116, 15.9171, 15.9226, 15.928, 15.9335,
    15.939, 15.9445, 15.9499, 15.9554, 15.9609, 15.9664, 15.9718,
    15.9773, 15.9828, 15.9882, 15.9937, 15.9992, 16.0047, 16.0101,
    16.0156, 16.0211, 16.0265, 16.032, 16.0375, 16.043, 16.0484,
    16.0539, 16.0594, 16.0648, 16.0703, 16.0758, 16.0812, 16.0867,
    16.0922, 16.0976, 16.1031, 16.1086, 16.114, 16.1195, 16.125,
    16.1304, 16.1359, 16.1414, 16.1468, 16.1523, 16.1578, 16.1632,
    16.1687, 16.1742, 16.1796, 16.1851, 16.1906, 16.196, 16.2015,
    16.2069, 16.2124, 16.2179, 16.2233, 16.2288, 16.2343, 16.2397,
    16.2452, 16.2506, 16.2561, 16.2616, 16.267, 16.2725, 16.2779,
    16.2834, 16.2889, 16.2943, 16.2998, 16.3053, 16.3107, 16.3162,
    16.3216, 16.3271, 16.3325, 16.338, 16.3435, 16.3489, 16.3544,
    16.3598, 16.3653, 16.3708, 16.3762, 16.3817, 16.3871, 16.3926,
    16.3981, 16.4035, 16.409, 16.4144, 16.4199, 16.4253, 16.4308,
    16.4363, 16.4417, 16.4472, 16.4526, 16.4581, 16.4635, 16.469,
    16.4745, 16.4799, 16.4854, 16.4908, 16.4963, 16.5017, 16.5072,
    16.5126, 16.5181, 16.5236, 16.529, 16.5345, 16.5399, 16.5454,
    16.5508, 16.5563, 16.5618, 16.5672, 16.5727, 16.5781, 16.5836,
    16.589, 16.5945, 16.5999, 16.6054, 16.6109, 16.6163, 16.6218,
    16.6272, 16.6327, 16.6381, 16.6436, 16.649, 16.6545, 16.6599,
    16.6654, 16.6709, 16.6763, 16.6818, 16.6872, 16.6927, 16.6981,
    16.7036, 16.709, 16.7145, 16.72, 16.7254, 16.7309, 16.7363,
    16.7418, 16.7472, 16.7527, 16.7581, 16.7636, 16.769, 16.7745,
    16.78, 16.7854, 16.7909, 16.7963, 16.8018, 16.8072, 16.8127,
    16.8181, 16.8236, 16.829, 16.8345, 16.84, 16.8454, 16.8509,
    16.8563, 16.8618, 16.8672, 16.8727, 16.8781, 16.8836, 16.8891,
    16.8945, 16.9, 16.9054, 16.9109, 16.9163, 16.9218, 16.9272,
    16.9327, 16.9382, 16.9436, 16.9491, 16.9545, 16.96, 16.9654,
    16.9709, 16.9763, 16.9818, 16.9873, 16.9927, 16.9982, 17.0036,
    17.0091, 17.0145, 17.02, 17.0255, 17.0309, 17.0364, 17.0418,
    17.0473, 17.0527, 17.0582, 17.0636, 17.0691, 17.0746, 17.08,
    17.0855, 17.0909, 17.0964, 17.1018, 17.1073, 17.1127, 17.1182,
    17.1237, 17.1291, 17.1346, 17.14, 17.1455, 17.1509, 17.1564,
    17.1618, 17.1673, 17.1728, 17.1782, 17.1837, 17.1891, 17.1946,
    17.2, 17.2055, 17.2109, 17.2164, 17.2218, 17.2273, 17.2328,
    17.2382, 17.2437, 17.2491, 17.2546, 17.26, 17.2655, 17.2709,
    17.2764, 17.2818, 17.2873, 17.2927, 17.2982, 17.3037, 17.3091,
    17.3146, 17.32, 17.3255, 17.3309, 17.3364, 17.3418, 17.3473,
    17.3527, 17.3582, 17.3636, 17.3691, 17.3745, 17.38, 17.3854,
    17.3909, 17.3963, 17.4018, 17.4072, 17.4127, 17.4181, 17.4236,
    17.429, 17.4345, 17.4399, 17.4454, 17.4508, 17.4563, 17.4617,
    17.4672, 17.4726, 17.4781, 17.4835, 17.489, 17.4944, 17.4999,
    17.5053, 17.5107, 17.5162, 17.5216, 17.5271, 17.5325, 17.538,
    17.5434, 17.5489, 17.5543, 17.5598, 17.5652, 17.5706, 17.5761,
    17.5815, 17.587, 17.5924, 17.5979, 17.6033, 17.6087, 17.6142,
    17.6196, 17.6251, 17.6305, 17.636, 17.6414, 17.6468, 17.6523,
    17.6577, 17.6632, 17.6686, 17.674, 17.6795, 17.6849, 17.6904,
    17.6958, 17.7012, 17.7067, 17.7121, 17.7175, 17.723, 17.7284,
    17.7339, 17.7393, 17.7447, 17.7502, 17.7556, 17.761, 17.7665,
    17.7719, 17.7773, 17.7828, 17.7882, 17.7936, 17.7991, 17.8045,
    17.8099, 17.8154, 17.8208, 17.8262, 17.8317, 17.8371, 17.8425,
    17.848, 17.8534, 17.8588, 17.8642, 17.8697, 17.8751, 17.8805,
    17.886, 17.8914, 17.8968, 17.9022, 17.9077, 17.9131, 17.9185,
    17.924, 17.9294, 17.9348, 17.9402, 17.9457, 17.9511, 17.9565,
    17.9619, 17.9674, 17.9728, 17.9782, 17.9836, 17.989, 17.9945,
    17.9999, 18.0053, 18.0107, 18.0162, 18.0216, 18.027, 18.0324,
    18.0378, 18.0432, 18.0487, 18.0541, 18.0595, 18.0649, 18.0703,
    18.0758, 18.0812, 18.0866, 18.092, 18.0974, 18.1028, 18.1082,
    18.1137, 18.1191, 18.1245, 18.1299, 18.1353, 18.1407, 18.1461,
    18.1515, 18.157, 18.1624, 18.1678, 18.1732, 18.1786, 18.184,
    18.1894, 18.1948, 18.2002, 18.2056, 18.211, 18.2164, 18.2218,
    18.2272, 18.2327, 18.2381, 18.2435, 18.2489, 18.2543, 18.2597,
    18.2651, 18.2705, 18.2759, 18.2813, 18.2867, 18.2921, 18.2975,
    18.3029, 18.3083, 18.3137, 18.319, 18.3244, 18.3298, 18.3352,
    18.3406, 18.346, 18.3514, 18.3568, 18.3622, 18.3676, 18.373,
    18.3784, 18.3838, 18.3891, 18.3945, 18.3999, 18.4053, 18.4107,
    18.4161, 18.4215, 18.4268, 18.4322, 18.4376, 18.443, 18.4484,
    18.4538, 18.4591, 18.4645, 18.4699, 18.4753, 18.4807, 18.486,
    18.4914, 18.4968, 18.5057, 18.6802, 18.8563, 19.034, 19.2132,
    19.394, 19.5765, 19.7607, 19.9468, 20.1344, 20.3235, 20.5137,
    20.7052, 20.8979, 21.0918, 21.287, 21.4833, 21.681, 21.8799,
    22.08, 22.2813, 22.4837, 22.6872, 22.8915, 23.0968, 23.3029,
    23.5101, 23.7182, 23.9272, 24.1371, 24.3479, 24.5595, 24.7722,
    24.9858, 25.2005, 25.4163, 25.6332, 25.8513, 26.0706, 26.2911,
    26.5128, 26.7358, 26.9602, 27.1861, 27.4137, 27.6432, 27.875,
    28.1092, 28.3459, 28.5854, 28.8277, 29.0731, 29.3217, 29.5736,
    29.8289, 30.0877, 30.3501, 30.616, 30.8854, 31.1586, 31.1586,
    3.2322, 3.1957, 3.2104, 3.2315, 3.2558, 3.2821, 3.3099, 3.3388,
    3.3687, 3.3995, 3.4314, 3.4643, 3.4983, 3.5333, 3.5693, 3.6063,
    3.6438, 3.6818, 3.7201, 3.7584, 3.7968, 3.8352, 3.8735, 3.9116,
    3.9495, 3.9872, 4.0247, 4.0618, 4.0987, 4.1353, 4.1716, 4.2075,
    4.2431, 4.2783, 4.3131, 4.3476, 4.3818, 4.4155, 4.449, 4.482,
    4.5148, 4.5472, 4.5793, 4.611, 4.6425, 4.6736, 4.7044, 4.7349,
    4.7651, 4.795, 4.8245, 4.8538, 4.8828, 4.9115, 4.9399, 4.968,
    4.9959, 5.0235, 5.0509, 5.078, 5.1049, 5.1315, 5.158, 5.1842,
    5.2102, 5.236, 5.2616, 5.287, 5.3121, 5.337, 5.3618, 5.3863,
    5.4107, 5.4348, 5.4587, 5.4825, 5.5061, 5.5295, 5.5527, 5.5757,
    5.5986, 5.6213, 5.6438, 5.6662, 5.6883, 5.7104, 5.7322, 5.7539,
    5.7755, 5.7969, 5.8181, 5.8393, 5.8602, 5.881, 5.9017, 5.9223,
    5.9427, 5.9629, 5.9831, 6.0031, 6.0229, 6.0426, 6.0622, 6.0817,
    6.101, 6.1202, 6.1393, 6.1582, 6.1771, 6.1958, 6.2143, 6.2328,
    6.2511, 6.2693, 6.2874, 6.3054, 6.3232, 6.341, 6.3586, 6.3761,
    6.3935, 6.4108, 6.428, 6.445, 6.462, 6.4788, 6.4956, 6.5122,
    6.5288, 6.5452, 6.5615, 6.5777, 6.5939, 6.6099, 6.6258, 6.6416,
    6.6573, 6.6729, 6.6884, 6.7039, 6.7192, 6.7344, 6.7495, 6.7646,
    6.7795, 6.7944, 6.8091, 6.8238, 6.8384, 6.8529, 6.8673, 6.8816,
    6.8959, 6.91, 6.9241, 6.9381, 6.952, 6.9659, 6.9797, 6.9934,
    7.007, 7.0205, 7.034, 7.0474, 7.0607, 7.074, 7.0872, 7.1003,
    7.1133, 7.1263, 7.1393, 7.1521, 7.1649, 7.1776, 7.1903, 7.2029,
    7.2154, 7.2279, 7.2403, 7.2527, 7.265, 7.2772, 7.2894, 7.3016,
    7.3136, 7.3256, 7.3376, 7.3495, 7.3614, 7.3732, 7.3849, 7.3966,
    7.4082, 7.4198, 7.4314, 7.4429, 7.4543, 7.4657, 7.477, 7.4883,
    7.4995, 7.5107, 7.5219, 7.533, 7.544, 7.5551, 7.566, 7.5769,
    7.5878, 7.5986, 7.6094, 7.6202, 7.6309, 7.6416, 7.6522, 7.6628,
    7.6733, 7.6838, 7.6943, 7.7047, 7.7151, 7.7254, 7.7357, 7.746,
    7.7562, 7.7664, 7.7766, 7.7867, 7.7968, 7.8068, 7.8169, 7.8268,
    7.8368, 7.8467, 7.8566, 7.8664, 7.8762, 7.886, 7.8957, 7.9054,
    7.9151, 7.9247, 7.9343, 7.9439, 7.9534, 7.9629, 7.9724, 7.9819,
    7.9913, 8.0007, 8.01, 8.0193, 8.0286, 8.0379, 8.0471, 8.0563,
    8.0655, 8.0746, 8.0837, 8.0928, 8.1019, 8.1109, 8.1199, 8.1289,
    8.1378, 8.1468, 8.1557, 8.1645, 8.1734, 8.1822, 8.191, 8.1998,
    8.2085, 8.2172, 8.2259, 8.2346, 8.2432, 8.2519, 8.2605, 8.269,
    8.2776, 8.2861, 8.2946, 8.3031, 8.3116, 8.3201, 8.3285, 8.3369,
    8.3453, 8.3536, 8.362, 8.3703, 8.3786, 8.3869, 8.3952, 8.4035,
    8.4117, 8.4199, 8.4281, 8.4363, 8.4445, 8.4526, 8.4607, 8.4688,
    8.4769, 8.485, 8.4931, 8.5011, 8.5092, 8.5172, 8.5252, 8.5332,
    8.5411, 8.5491, 8.557, 8.565, 8.5729, 8.5808, 8.5887, 8.5965,
    8.6044, 8.6122, 8.6201, 8.6279, 8.6357, 8.6435, 8.6512, 8.659,
    8.6667, 8.6745, 8.6822, 8.6899, 8.6976, 8.7053, 8.713, 8.7207,
    8.7283, 8.736, 8.7436, 8.7512, 8.7588, 8.7664, 8.774, 8.7816,
    8.7892, 8.7968, 8.8043, 8.8119, 8.8194, 8.8269, 8.8344, 8.842,
    8.8495, 8.8569, 8.8644, 8.8719, 8.8794, 8.8868, 8.8943, 8.9017,
    8.9092, 8.9166, 8.924, 8.9314, 8.9388, 8.9462, 8.9536, 8.961,
    8.9684, 8.9757, 8.9831, 8.9904, 8.9978, 9.0051, 9.0125, 9.0198,
    9.0271, 9.0344, 9.0417, 9.049, 9.0563, 9.0636, 9.0709, 9.0782,
    9.0854, 9.0927, 9.0999, 9.1072, 9.1144, 9.1217, 9.1289, 9.1361,
    9.1434, 9.1506, 9.1578, 9.165, 9.1722, 9.1794, 9.1866, 9.1938,
    9.2009, 9.2081, 9.2153, 9.2225, 9.2296, 9.2368, 9.2439, 9.2511,
    9.2582, 9.2654, 9.2725, 9.2796, 9.2867, 9.2939, 9.301, 9.3081,
    9.3152, 9.3223, 9.3294, 9.3365, 9.3436, 9.3507, 9.3578, 9.3649,
    9.372, 9.379, 9.3861, 9.3932, 9.4002, 9.4073, 9.4144, 9.4214,
    9.4285, 9.4355, 9.4426, 9.4496, 9.4567, 9.4637, 9.4707, 9.4778,
    9.4848, 9.4918, 9.4988, 9.5058, 9.5129, 9.5199, 9.5269, 9.5339,
    9.5409, 9.5479, 9.5549, 9.5619, 9.5689, 9.5759, 9.5829, 9.5898,
    9.5968, 9.6038, 9.6108, 9.6178, 9.6247, 9.6317, 9.6387, 9.6457,
    9.6526, 9.6596, 9.6665, 9.6735, 9.6805, 9.6874, 9.6944, 9.7013,
    9.7083, 9.7152, 9.7222, 9.7291, 9.7361, 9.743, 9.75, 9.7569,
    9.7638, 9.7708, 9.7777, 9.7846, 9.7916, 9.7985, 9.8054, 9.8124,
    9.8193, 9.8262, 9.8331, 9.8401, 9.847, 9.8539, 9.8608, 9.8677,
    9.8746, 9.8816, 9.8885, 9.8954, 9.9023, 9.9092, 9.9161, 9.923,
    9.9299, 9.9368, 9.9437, 9.9506, 9.9575, 9.9644, 9.9713, 9.9782,
    9.9851, 9.992, 9.9989, 10.0058, 10.0127, 10.0196, 10.0265,
    10.0334, 10.0402, 10.0471, 10.054, 10.0609, 10.0678, 10.0746,
    10.0815, 10.0884, 10.0953, 10.1021, 10.109, 10.1159, 10.1227,
    10.1296, 10.1365, 10.1433, 10.1502, 10.157, 10.1639, 10.1707,
    10.1776, 10.1845, 10.1913, 10.1982, 10.205, 10.2119, 10.2187,
    10.2255, 10.2324, 10.2392, 10.2461, 10.2529, 10.2597, 10.2666,
    10.2734, 10.2803, 10.2871, 10.2939, 10.3008, 10.3076, 10.3144,
    10.3213, 10.3281, 10.3349, 10.3417, 10.3486, 10.3554, 10.3622,
    10.369, 10.3759, 10.3827, 10.3895, 10.3963, 10.4031, 10.41,
    10.4168, 10.4236, 10.4304, 10.4372, 10.444, 10.4508, 10.4577,
    10.4645, 10.4713, 10.4781, 10.4849, 10.4917, 10.4985, 10.5053,
    10.5121, 10.5189, 10.5257, 10.5325, 10.5393, 10.5461, 10.5529,
    10.5597, 10.5665, 10.5733, 10.5801, 10.5869, 10.5937, 10.6005,
    10.6073, 10.6141, 10.6209, 10.6277, 10.6345, 10.6413, 10.6481,
    10.6549, 10.6617, 10.6685, 10.6753, 10.6821, 10.6889, 10.6957,
    10.7025, 10.7093, 10.7161, 10.7229, 10.7297, 10.7365, 10.7433,
    10.7501, 10.7569, 10.7637, 10.7705, 10.7773, 10.7841, 10.7909,
    10.7977, 10.8045, 10.8113, 10.8181, 10.8249, 10.8317, 10.8385,
    10.8453, 10.8521, 10.8589, 10.8657, 10.8725, 10.8793, 10.8861,
    10.8929, 10.8997, 10.9065, 10.9133, 10.9202, 10.927, 10.9338,
    10.9406, 10.9474, 10.9542, 10.961, 10.9679, 10.9747, 10.9815,
    10.9883, 10.9951, 11.0019, 11.0088, 11.0156, 11.0224, 11.0292,
    11.036, 11.0429, 11.0497, 11.0565, 11.0633, 11.0702, 11.077,
    11.0838, 11.0906, 11.0975, 11.1043, 11.1111, 11.118, 11.1248,
    11.1316, 11.1384, 11.1453, 11.1521, 11.1589, 11.1658, 11.1726,
    11.1795, 11.1863, 11.1931, 11.2, 11.2068, 11.2137, 11.2205,
    11.2273, 11.2342, 11.241, 11.2479, 11.2547, 11.2616, 11.2684,
    11.2753, 11.2821, 11.2889, 11.2958, 11.3026, 11.3095, 11.3163,
    11.3232, 11.33, 11.3369, 11.3438, 11.3506, 11.3575, 11.3643,
    11.3712, 11.378, 11.3849, 11.3917, 11.3986, 11.4055, 11.4123,
    11.4192, 11.426, 11.4329, 11.4397, 11.4466, 11.4535, 11.4603,
    11.4672, 11.4741, 11.4809, 11.4878, 11.4946, 11.5015, 11.5084,
    11.5152, 11.5221, 11.529, 11.5358, 11.5427, 11.5496, 11.5564,
    11.5633, 11.5702, 11.577, 11.5839, 11.5907, 11.5976, 11.6045,
    11.6113, 11.6182, 11.6251, 11.6319, 11.6388, 11.6456, 11.6525,
    11.6594, 11.6662, 11.6731, 11.6799, 11.6868, 11.6937, 11.7005,
    11.7074, 11.7142, 11.7211, 11.7279, 11.7348, 11.7416, 11.7485,
    11.7553, 11.7622, 11.769, 11.7759, 11.7827, 11.7896, 11.7964,
    11.8033, 11.8101, 11.817, 11.8238, 11.8307, 11.8375, 11.8443,
    11.8512, 11.858, 11.8648, 11.8717, 11.8785, 11.8853, 11.8922,
    11.899, 11.9058, 11.9126, 11.9194, 11.9263, 11.9331, 11.9399,
    11.9467, 11.9535, 11.9603, 11.9671, 11.9739, 11.9808, 11.9876,
    11.9944, 12.0011, 12.0079, 12.0147, 12.0215, 12.0283, 12.0351,
    12.0419, 12.0487, 12.0554, 12.0622, 12.069, 12.0758, 12.0825,
    12.0893, 12.0961, 12.1028, 12.1096, 12.1163, 12.1231, 12.1298,
    12.1366, 12.1433, 12.15, 12.1568, 12.1635, 12.1702, 12.177,
    12.1837, 12.1904, 12.1971, 12.2039, 12.2106, 12.2173, 12.224,
    12.2307, 12.2374, 12.2441, 12.2508, 12.2575, 12.2642, 12.2709,
    12.2775, 12.2842, 12.2909, 12.2976, 12.3042, 12.3109, 12.3176,
    12.3242, 12.3309, 12.3375, 12.3442, 12.3508, 12.3575, 12.3641,
    12.3707, 12.3774, 12.384, 12.3906, 12.3973, 12.4039, 12.4105,
    12.4171, 12.4237, 12.4303, 12.4369, 12.4435, 12.4501, 12.4567,
    12.4633, 12.4699, 12.4765, 12.4831, 12.4896, 12.4962, 12.5028,
    12.5093, 12.5159, 12.5225, 12.529, 12.5356, 12.5421, 12.5487,
    12.5552, 12.5617, 12.5683, 12.5748, 12.5813, 12.5879, 12.5944,
    12.6009, 12.6074, 12.6139, 12.6204, 12.6269, 12.6334, 12.6399,
    12.6464, 12.6529, 12.6594, 12.6659, 12.6723, 12.6788, 12.6853,
    12.6918, 12.6982, 12.7047, 12.7111, 12.7176, 12.724, 12.7305,
    12.7369, 12.7434, 12.7498, 12.7563, 12.7627, 12.7691, 12.7755,
    12.782, 12.7884, 12.7948, 12.8012, 12.8076, 12.814, 12.8204,
    12.8268, 12.8332, 12.8396, 12.846, 12.8524, 12.8588, 12.8651,
    12.8715, 12.8779, 12.8843, 12.8906, 12.897, 12.9033, 12.9097,
    12.9161, 12.9224, 12.9288, 12.9351, 12.9415, 12.9478, 12.9541,
    12.9605, 12.9668, 12.9732, 12.9795, 12.9858, 12.9921, 12.9985,
    13.0048, 13.0111, 13.0174, 13.0237, 13.03, 13.0363, 13.0427,
    13.049, 13.0553, 13.0616, 13.0679, 13.0742, 13.0804, 13.0867,
    13.093, 13.0993, 13.1056, 13.1119, 13.1182, 13.1245, 13.1307,
    13.137, 13.1433, 13.1496, 13.1558, 13.1621, 13.1684, 13.1746,
    13.1809, 13.1872, 13.1934, 13.1997, 13.2059, 13.2122, 13.2185,
    13.2247, 13.231, 13.2372, 13.2435, 13.2497, 13.256, 13.2622,
    13.2684, 13.2747, 13.2809, 13.2872, 13.2934, 13.2996, 13.3059,
    13.3121, 13.3183, 13.3246, 13.3308, 13.337, 13.3433, 13.3495,
    13.3557, 13.3619, 13.3682, 13.3744, 13.3806, 13.3868, 13.3931,
    13.3993, 13.4055, 13.4117, 13.4179, 13.4242, 13.4304, 13.4366,
    13.4428, 13.449, 13.4552, 13.4614, 13.4677, 13.4739, 13.4801,
    13.4863, 13.4925, 13.4987, 13.5049, 13.5111, 13.5173, 13.5235,
    13.5297, 13.5359, 13.5421, 13.5483, 13.5545, 13.5607, 13.5669,
    13.5731, 13.5793, 13.5855, 13.5917, 13.5979, 13.6041, 13.6103,
    13.6165, 13.6227, 13.6289, 13.6351, 13.6413, 13.6475, 13.6537,
    13.6599, 13.6661, 13.6723, 13.6785, 13.6847, 13.6909, 13.6971,
    13.7033, 13.7095, 13.7157, 13.7218, 13.728, 13.7342, 13.7404,
    13.7466, 13.7528, 13.759, 13.7652, 13.7714, 13.7776, 13.7838,
    13.7899, 13.7961, 13.8023, 13.8085, 13.8147, 13.8209, 13.8271,
    13.8333, 13.8395, 13.8456, 13.8518, 13.858, 13.8642, 13.8704,
    13.8766, 13.8828, 13.8889, 13.8951, 13.9013, 13.9075, 13.9137,
    13.9199, 13.9261, 13.9322, 13.9384, 13.9446, 13.9508, 13.957,
    13.9632, 13.9693, 13.9755, 13.9817, 13.9879, 13.9941, 14.0003,
    14.0064, 14.0126, 14.0188, 14.025, 14.0312, 14.0373, 14.0435,
    14.0497, 14.0559, 14.0621, 14.0682, 14.0744, 14.0806, 14.0868,
    14.093, 14.0991, 14.1053, 14.1115, 14.1177, 14.1238, 14.13,
    14.1362, 14.1424, 14.1485, 14.1547, 14.1609, 14.1671, 14.1732,
    14.1794, 14.1856, 14.1917, 14.1979, 14.2041, 14.2103, 14.2164,
    14.2226, 14.2288, 14.2349, 14.2411, 14.2473, 14.2534, 14.2596,
    14.2658, 14.2719, 14.2781, 14.2843, 14.2904, 14.2966, 14.3028,
    14.3089, 14.3151, 14.3213, 14.3274, 14.3336, 14.3397, 14.3459,
    14.3521, 14.3582, 14.3644, 14.3705, 14.3767, 14.3829, 14.389,
    14.3952, 14.4013, 14.4075, 14.4136, 14.4198, 14.4259, 14.4321,
    14.4382, 14.4444, 14.4505, 14.4567, 14.4628, 14.469, 14.4751,
    14.4813, 14.4874, 14.4936, 14.4997, 14.5059, 14.512, 14.5181,
    14.5243, 14.5304, 14.5366, 14.5427, 14.5488, 14.555, 14.5611,
    14.5673, 14.5734, 14.5795, 14.5857, 14.5918, 14.5979, 14.6041,
    14.6102, 14.6163, 14.6225, 14.6286, 14.6347, 14.6408, 14.647,
    14.6531, 14.6592, 14.6653, 14.6715, 14.6776, 14.6837, 14.6898,
    14.696, 14.7021, 14.7082, 14.7143, 14.7204, 14.7265, 14.7327,
    14.7388, 14.7449, 14.751, 14.7571, 14.7632, 14.7693, 14.7754,
    14.7816, 14.7877, 14.7938, 14.7999, 14.806, 14.8121, 14.8182,
    14.8243, 14.8304, 14.8365, 14.8426, 14.8487, 14.8548, 14.8609,
    14.867, 14.8731, 14.8792, 14.8853, 14.8913, 14.8974, 14.9035,
    14.9096, 14.9157, 14.9218, 14.9279, 14.934, 14.94, 14.9461,
    14.9522, 14.9583, 14.9644, 14.9704, 14.9765, 14.9826, 14.9887,
    14.9948, 15.0008, 15.0069, 15.013, 15.019, 15.0251, 15.0312,
    15.0373, 15.0433, 15.0494, 15.0555, 15.0615, 15.0676, 15.0736,
    15.0797, 15.0858, 15.0918, 15.0979, 15.1039, 15.11, 15.1161,
    15.1221, 15.1282, 15.1342, 15.1403, 15.1463, 15.1524, 15.1584,
    15.1645, 15.1705, 15.1766, 15.1826, 15.1887, 15.1947, 15.2008,
    15.2068, 15.2128, 15.2189, 15.2249, 15.231, 15.237, 15.243,
    15.2491, 15.2551, 15.2611, 15.2672, 15.2732, 15.2792, 15.2853,
    15.2913, 15.2973, 15.3034, 15.3094, 15.3154, 15.3214, 15.3275,
    15.3335, 15.3395, 15.3455, 15.3516, 15.3576, 15.3636, 15.3696,
    15.3756, 15.3817, 15.3877, 15.3937, 15.3997, 15.4057, 15.4117,
    15.4178, 15.4238, 15.4298, 15.4358, 15.4418, 15.4478, 15.4538,
    15.4598, 15.4658, 15.4719, 15.4779, 15.4839, 15.4899, 15.4959,
    15.5019, 15.5079, 15.5139, 15.5199, 15.5259, 15.5319, 15.5379,
    15.5439, 15.5499, 15.5559, 15.5619, 15.5679, 15.5739, 15.5799,
    15.5859, 15.5918, 15.5978, 15.6038, 15.6098, 15.6158, 15.6218,
    15.6278, 15.6338, 15.6398, 15.6458, 15.6517, 15.6577, 15.6637,
    15.6697, 15.6757, 15.6817, 15.6877, 15.6936, 15.6996, 15.7056,
    15.7116, 15.7176, 15.7236, 15.7295, 15.7355, 15.7415, 15.7475,
    15.7534, 15.7594, 15.7654, 15.7714, 15.7774, 15.7833, 15.7893,
    15.7953, 15.8013, 15.8072, 15.8132, 15.8192, 15.8252, 15.8311,
    15.8371, 15.8431, 15.849, 15.855, 15.861, 15.8669, 15.8729,
    15.8789, 15.8849, 15.8908, 15.8968, 15.9028, 15.9087, 15.9147,
    15.9207, 15.9266, 15.9326, 15.9386, 15.9445, 15.9505, 15.9565,
    15.9624, 15.9684, 15.9744, 15.9803, 15.9863, 15.9922, 15.9982,
    16.0042, 16.0101, 16.0161, 16.0221, 16.028, 16.034, 16.0399,
    16.0459, 16.0519, 16.0578, 16.0638, 16.0697, 16.0757, 16.0817,
    16.0876, 16.0936, 16.0995, 16.1055, 16.1115, 16.1174, 16.1234,
    16.1293, 16.1353, 16.1413, 16.1472, 16.1532, 16.1591, 16.1651,
    16.171, 16.177, 16.1829, 16.1889, 16.1949, 16.2008, 16.2068,
    16.2127, 16.2187, 16.2246, 16.2306, 16.2365, 16.2425, 16.2485,
    16.2544, 16.2604, 16.2663, 16.2723, 16.2782, 16.2842, 16.2901,
    16.2961, 16.302, 16.308, 16.314, 16.3199, 16.3259, 16.3318,
    16.3378, 16.3437, 16.3497, 16.3556, 16.3616, 16.3675, 16.3735,
    16.3794, 16.3854, 16.3913, 16.3973, 16.4032, 16.4092, 16.4151,
    16.4211, 16.427, 16.433, 16.4389, 16.4449, 16.4508, 16.4568,
    16.4627, 16.4687, 16.4746, 16.4806, 16.4865, 16.4925, 16.4984,
    16.5044, 16.5103, 16.5163, 16.5222, 16.5282, 16.5341, 16.5401,
    16.546, 16.552, 16.5579, 16.5639, 16.5698, 16.5758, 16.5817,
    16.5876, 16.5936, 16.5995, 16.6055, 16.6114, 16.6174, 16.6233,
    16.6293, 16.6352, 16.6412, 16.6471, 16.653, 16.659, 16.6649,
    16.6709, 16.6768, 16.6828, 16.6887, 16.6947, 16.7006, 16.7065,
    16.7125, 16.7184, 16.7244, 16.7303, 16.7363, 16.7422, 16.7481,
    16.7541, 16.76, 16.766, 16.7719, 16.7778, 16.7838, 16.7897,
    16.7957, 16.8016, 16.8075, 16.8135, 16.8194, 16.8254, 16.8313,
    16.8372, 16.8432, 16.8491, 16.855, 16.861, 16.8669, 16.8729,
    16.8788, 16.8847, 16.8907, 16.8966, 16.9025, 16.9085, 16.9144,
    16.9203, 16.9263, 16.9322, 16.9381, 16.9441, 16.95, 16.9559,
    16.9619, 16.9678, 16.9737, 16.9796, 16.9856, 16.9915, 16.9974,
    17.0034, 17.0093, 17.0152, 17.0211, 17.0271, 17.033, 17.0389,
    17.0448, 17.0508, 17.0567, 17.0626, 17.0685, 17.0744, 17.0804,
    17.0863, 17.0922, 17.0981, 17.104, 17.11, 17.1159, 17.1218,
    17.1277, 17.1336, 17.1395, 17.1455, 17.1514, 17.1573, 17.1632,
    17.1691, 17.175, 17.1809, 17.1868, 17.1927, 17.1987, 17.2046,
    17.2105, 17.2164, 17.2223, 17.2282, 17.2341, 17.24, 17.2459,
    17.2518, 17.2577, 17.2636, 17.2695, 17.2754, 17.2813, 17.2872,
    17.2931, 17.299, 17.3049, 17.3108, 17.3167, 17.3226, 17.3285,
    17.3344, 17.3402, 17.3461, 17.352, 17.3579, 17.3638, 17.3697,
    17.3756, 17.3815, 17.3873, 17.3932, 17.3991, 17.405, 17.4109,
    17.4167, 17.4226, 17.4285, 17.4344, 17.4403, 17.4461, 17.452,
    17.4579, 17.4637, 17.4696, 17.4755, 17.4814, 17.4872, 17.4931,
    17.499, 17.5048, 17.5107, 17.5166, 17.5224, 17.5283, 17.5341,
    17.54, 17.5459, 17.5517, 17.5576, 17.5634, 17.5693, 17.5751,
    17.581, 17.5868, 17.5927, 17.5985, 17.6044, 17.6102, 17.6161,
    17.6219, 17.6278, 17.6336, 17.6394, 17.6453, 17.6511, 17.657,
    17.6628, 17.6686, 17.6745, 17.6803, 17.6861, 17.692, 17.6978,
    17.7036, 17.7095, 17.7153, 17.7211, 17.7269, 17.7328, 17.7386,
    17.7444, 17.7502, 17.7561, 17.7619, 17.7677, 17.7735, 17.7793,
    17.7851, 17.791, 17.7968, 17.8026, 17.8084, 17.8142, 17.82,
    17.8258, 17.8316, 17.8374, 17.8432, 17.849, 17.8548, 17.8606,
    17.8664, 17.8722, 17.878, 17.8838, 17.8896, 17.8954, 17.9012,
    17.907, 17.9128, 17.9186, 17.9243, 17.9301, 17.9359, 17.9417,
    17.9475, 17.9533, 17.959, 17.9648, 17.9706, 17.9764, 17.9821,
    17.9879, 17.9937, 17.9995, 18.0052, 18.011, 18.0168, 18.0225,
    18.0283, 18.0341, 18.0398, 18.0456, 18.0513, 18.0571, 18.0629,
    18.0686, 18.0744, 18.0801, 18.0859, 18.0916, 18.0974, 18.1031,
    18.1089, 18.1146, 18.1204, 18.1261, 18.1319, 18.1376, 18.1434,
    18.1491, 18.1548, 18.1606, 18.1663, 18.172, 18.1778, 18.1835,
    18.1892, 18.195, 18.2007, 18.2064, 18.2122, 18.2179, 18.2236,
    18.2293, 18.235, 18.2408, 18.2465, 18.2522, 18.2579, 18.2636,
    18.2693, 18.2751, 18.2808, 18.2865, 18.2922, 18.2979, 18.3036,
    18.3093, 18.315, 18.3207, 18.3264, 18.3321, 18.3378, 18.3435,
    18.3492, 18.3549, 18.3606, 18.3663, 18.372, 18.3777, 18.3834,
    18.389, 18.2579, 18.4329, 18.6073, 18.7811, 18.9545, 19.1276,
    19.3004, 19.473, 19.6455, 19.818, 19.9908, 20.1639, 20.3377,
    20.5124, 20.6885, 20.8661, 21.0457, 21.2274, 21.4113, 21.5979,
    21.7872, 21.9795, 22.1751, 22.374, 22.5762, 22.7816, 22.9904,
    23.2025, 23.418, 23.6369, 23.8593, 24.0853, 24.3149, 24.5482,
    24.7853, 25.0262, 25.271, 25.5197, 25.7721, 26.0284, 26.2883,
    26.5519, 26.819, 27.0896, 27.3635, 27.6406, 27.9208, 28.204,
    28.4901, 28.7791, 29.0711, 29.3663, 29.6646, 29.9663, 30.2715,
    30.5805, 30.8934, 31.2105, 31.5319, 31.8578, 31.8578, 2.441,
    2.4577, 2.4744, 2.4911, 2.5078, 2.5244, 2.5411, 2.5578, 2.5744,
    2.5911, 2.6077, 2.6244, 2.6411, 2.6578, 2.6745, 2.6913, 2.7081,
    2.7249, 2.7417, 2.7586, 2.7755, 2.7925, 2.8095, 2.8266, 2.8437,
    2.8609, 2.8782, 2.8955, 2.9129, 2.9304, 2.948, 2.9657, 2.9835,
    3.0014, 3.0195, 3.0377, 3.056, 3.0745, 3.0931, 3.1119, 3.1308,
    3.1499, 3.1691, 3.1884, 3.2079, 3.2276, 3.2473, 3.2672, 3.2873,
    3.3075, 3.3278, 3.3482, 3.3688, 3.3894, 3.4102, 3.4311, 3.4522,
    3.4733, 3.4946, 3.5161, 3.5376, 3.5593, 3.5812, 3.6032, 3.6254,
    3.6477, 3.6702, 3.6929, 3.7157, 3.7388, 3.762, 3.7855, 3.8092,
    3.833, 3.8571, 3.8814, 3.9059, 3.9306, 3.9555, 3.9806, 4.006,
    4.0315, 4.0572, 4.0831, 4.1092, 4.1354, 4.1619, 4.1885, 4.2153,
    4.2422, 4.2693, 4.2965, 4.3239, 4.3513, 4.3789, 4.4066, 4.4344,
    4.4623, 4.4903, 4.5185, 4.5467, 4.575, 4.6034, 4.6319, 4.6605,
    4.6892, 4.718, 4.7469, 4.7758, 4.8048, 4.8338, 4.8629, 4.892,
    4.9212, 4.9504, 4.9796, 5.0088, 5.0381, 5.0673, 5.0966, 5.1259,
    5.1551, 5.1844, 5.2137, 5.2429, 5.2721, 5.3014, 5.3306, 5.3598,
    5.3889, 5.418, 5.4471, 5.4762, 5.5053, 5.5343, 5.5632, 5.5922,
    5.621, 5.6499, 5.6787, 5.7074, 5.7361, 5.7647, 5.7933, 5.8217,
    5.8501, 5.8784, 5.9067, 5.9348, 5.9628, 5.9907, 6.0185, 6.0461,
    6.0737, 6.1011, 6.1284, 6.1556, 6.1827, 6.2096, 6.2365, 6.2632,
    6.2899, 6.3164, 6.3428, 6.3692, 6.3954, 6.4215, 6.4475, 6.4735,
    6.4993, 6.5251, 6.5508, 6.5764, 6.6019, 6.6273, 6.6527, 6.678,
    6.7033, 6.7284, 6.7535, 6.7786, 6.8035, 6.8285, 6.8533, 6.8781,
    6.9028, 6.9275, 6.9521, 6.9766, 7.0011, 7.0255, 7.0499, 7.0742,
    7.0984, 7.1226, 7.1467, 7.1708, 7.1948, 7.2188, 7.2427, 7.2666,
    7.2905, 7.3143, 7.338, 7.3617, 7.3854, 7.4091, 7.4327, 7.4563,
    7.4799, 7.5034, 7.5269, 7.5504, 7.5738, 7.5973, 7.6206, 7.644,
    7.6673, 7.6906, 7.7138, 7.737, 7.7602, 7.7834, 7.8065, 7.8296,
    7.8526, 7.8757, 7.8986, 7.9216, 7.9445, 7.9674, 7.9903, 8.0132,
    8.036, 8.0588, 8.0816, 8.1044, 8.1272, 8.15, 8.1727, 8.1955,
    8.2183, 8.241, 8.2638, 8.2865, 8.3092, 8.332, 8.3547, 8.3774,
    8.4001, 8.4227, 8.4454, 8.468, 8.4906, 8.5132, 8.5358, 8.5583,
    8.5808, 8.6032, 8.6257, 8.648, 8.6704, 8.6927, 8.715, 8.7372,
    8.7594, 8.7815, 8.8036, 8.8257, 8.8477, 8.8697, 8.8916, 8.9135,
    8.9353, 8.9571, 8.9788, 9.0005, 9.0221, 9.0436, 9.0651, 9.0865,
    9.1079, 9.1292, 9.1504, 9.1716, 9.1927, 9.2137, 9.2347, 9.2557,
    9.2766, 9.2974, 9.3182, 9.339, 9.3597, 9.3803, 9.401, 9.4215,
    9.442, 9.4625, 9.4829, 9.5032, 9.5235, 9.5438, 9.5639, 9.5841,
    9.6041, 9.6241, 9.644, 9.6639, 9.6836, 9.7033, 9.723, 9.7425,
    9.762, 9.7814, 9.8007, 9.82, 9.8392, 9.8583, 9.8773, 9.8963,
    9.9152, 9.9341, 9.9528, 9.9716, 9.9902, 10.0088, 10.0274,
    10.0459, 10.0643, 10.0827, 10.1011, 10.1194, 10.1377, 10.1559,
    10.1741, 10.1923, 10.2105, 10.2286, 10.2468, 10.2649, 10.2831,
    10.3012, 10.3194, 10.3376, 10.3558, 10.3741, 10.3923, 10.4107,
    10.4291, 10.4475, 10.466, 10.4845, 10.5031, 10.5217, 10.5405,
    10.5592, 10.5781, 10.597, 10.6161, 10.6352, 10.6544, 10.6737,
    10.6931, 10.7126, 10.7322, 10.752, 10.7718, 10.7918, 10.8119,
    10.8321, 10.8524, 10.8728, 10.8934, 10.9142, 10.935, 10.956,
    10.9772, 10.9985, 11.0199, 11.0415, 11.0632, 11.0851, 11.1071,
    11.1293, 11.1516, 11.174, 11.1966, 11.2193, 11.2422, 11.2651,
    11.2882, 11.3114, 11.3347, 11.3581, 11.3817, 11.4053, 11.429,
    11.4529, 11.4768, 11.5007, 11.5248, 11.549, 11.5732, 11.5975,
    11.6218, 11.6462, 11.6707, 11.6952, 11.7198, 11.7444, 11.769,
    11.7937, 11.8184, 11.8431, 11.8678, 11.8926, 11.9173, 11.9421,
    11.9668, 11.9916, 12.0163, 12.0411, 12.0658, 12.0905, 12.1152,
    12.1398, 12.1645, 12.1891, 12.2136, 12.2382, 12.2627, 12.2871,
    12.3116, 12.336, 12.3603, 12.3846, 12.4089, 12.4332, 12.4574,
    12.4815, 12.5057, 12.5298, 12.5538, 12.5778, 12.6017, 12.6257,
    12.6495, 12.6734, 12.6972, 12.7209, 12.7446, 12.7683, 12.792,
    12.8156, 12.8392, 12.8628, 12.8864, 12.9099, 12.9334, 12.9569,
    12.9804, 13.0038, 13.0273, 13.0507, 13.0742, 13.0976, 13.1209,
    13.1443, 13.1677, 13.191, 13.2143, 13.2376, 13.2609, 13.2842,
    13.3075, 13.3308, 13.3541, 13.3773, 13.4006, 13.4239, 13.4472,
    13.4705, 13.4937, 13.5171, 13.5404, 13.5637, 13.587, 13.6104,
    13.6338, 13.6572, 13.6806, 13.7041, 13.7275, 13.751, 13.7746,
    13.7981, 13.8217, 13.8454, 13.8691, 13.8928, 13.9165, 13.9403,
    13.9642, 13.9881, 14.012, 14.036, 14.06, 14.0841, 14.1083,
    14.1325, 14.1567, 14.1811, 14.2055, 14.2299, 14.2544, 14.279,
    14.3037, 14.3284, 14.3533, 14.3782, 14.4031, 14.4282, 14.4533,
    14.4785, 14.5038, 14.5292, 14.5547, 14.5802, 14.6058, 14.6316,
    14.6574, 14.6832, 14.7092, 14.7353, 14.7614, 14.7877, 14.814,
    14.8404, 14.8669, 14.8934, 14.9201, 14.9468, 14.9736, 15.0005,
    15.0275, 15.0546, 15.0818, 15.109, 15.1363, 15.1637, 15.1912,
    15.2187, 15.2463, 15.274, 15.3018, 15.3297, 15.3576, 15.3856,
    15.4137, 15.4419, 15.4701, 15.4985, 15.5268, 15.5553, 15.5838,
    15.6125, 15.6412, 15.6699, 15.6987, 15.7276, 15.7566, 15.7857,
    15.8148, 15.844, 15.8732, 15.9026, 15.932, 15.9615, 15.991,
    16.0206, 16.0503, 16.0801, 16.1099, 16.1398, 16.1697, 16.1997,
    16.2298, 16.26, 16.2902, 16.3204, 16.3508, 16.3812, 16.4117,
    16.4422, 16.4728, 16.5035, 16.5342, 16.565, 16.5959, 16.6268,
    16.6579, 16.6889, 16.7201, 16.7513, 16.7826, 16.8139, 16.8454,
    16.8769, 16.9084, 16.9401, 16.9718, 17.0036, 17.0355, 17.0674,
    17.0995, 17.1316, 17.1637, 17.196, 17.2283, 17.2607, 17.2931,
    17.3256, 17.3582, 17.3909, 17.4237, 17.4565, 17.4894, 17.5224,
    17.5554, 17.5885, 17.6217, 17.655, 17.6884, 17.7218, 17.7553,
    17.7889, 17.8226, 17.8564, 17.8903, 17.9242, 17.9583, 17.9924,
    18.0267, 18.061, 18.0954, 18.1299, 18.1645, 18.1992, 18.234,
    18.2689, 2.4607, 2.4777, 2.4947, 2.5117, 2.5287, 2.5457,
    2.5627, 2.5797, 2.5967, 2.6137, 2.6306, 2.6476, 2.6646, 2.6816,
    2.6986, 2.7155, 2.7326, 2.7496, 2.7666, 2.7837, 2.8007, 2.8179,
    2.835, 2.8522, 2.8694, 2.8867, 2.9041, 2.9215, 2.939, 2.9565,
    2.9741, 2.9918, 3.0096, 3.0275, 3.0455, 3.0636, 3.0818, 3.1001,
    3.1186, 3.1372, 3.156, 3.1749, 3.1939, 3.2131, 3.2325, 3.252,
    3.2717, 3.2915, 3.3114, 3.3316, 3.3518, 3.3723, 3.3929, 3.4136,
    3.4346, 3.4557, 3.4769, 3.4983, 3.5199, 3.5417, 3.5636, 3.5856,
    3.6078, 3.6302, 3.6527, 3.6754, 3.6982, 3.7212, 3.7444, 3.7677,
    3.7911, 3.8147, 3.8385, 3.8623, 3.8863, 3.9105, 3.9348, 3.9592,
    3.9837, 4.0084, 4.0332, 4.0581, 4.0832, 4.1084, 4.1337, 4.1591,
    4.1846, 4.2102, 4.2359, 4.2617, 4.2875, 4.3135, 4.3395, 4.3655,
    4.3917, 4.4179, 4.4442, 4.4705, 4.4969, 4.5233, 4.5498, 4.5763,
    4.6029, 4.6295, 4.6561, 4.6827, 4.7094, 4.7361, 4.7628, 4.7895,
    4.8162, 4.843, 4.8697, 4.8964, 4.9232, 4.95, 4.9767, 5.0034,
    5.0302, 5.0569, 5.0837, 5.1104, 5.1371, 5.1639, 5.1906, 5.2173,
    5.244, 5.2707, 5.2974, 5.324, 5.3507, 5.3773, 5.4039, 5.4304,
    5.4569, 5.4834, 5.5098, 5.5362, 5.5625, 5.5888, 5.6151, 5.6413,
    5.6674, 5.6935, 5.7195, 5.7454, 5.7713, 5.7971, 5.8229, 5.8485,
    5.8742, 5.8997, 5.9252, 5.9507, 5.9761, 6.0014, 6.0266, 6.0518,
    6.0769, 6.102, 6.127, 6.1519, 6.1768, 6.2017, 6.2264, 6.2511,
    6.2758, 6.3004, 6.3249, 6.3494, 6.3738, 6.3981, 6.4224, 6.4466,
    6.4708, 6.4948, 6.5189, 6.5429, 6.5668, 6.5906, 6.6144, 6.6382,
    6.6619, 6.6856, 6.7092, 6.7328, 6.7563, 6.7798, 6.8033, 6.8267,
    6.8501, 6.8734, 6.8967, 6.9199, 6.9431, 6.9662, 6.9893, 7.0124,
    7.0354, 7.0583, 7.0812, 7.1041, 7.1269, 7.1497, 7.1724, 7.195,
    7.2177, 7.2402, 7.2627, 7.2852, 7.3076, 7.33, 7.3523, 7.3745,
    7.3967, 7.4189, 7.441, 7.463, 7.485, 7.5069, 7.5288, 7.5507,
    7.5724, 7.5942, 7.6158, 7.6375, 7.659, 7.6806, 7.702, 7.7234,
    7.7448, 7.7661, 7.7874, 7.8086, 7.8298, 7.8509, 7.872, 7.893,
    7.914, 7.935, 7.9559, 7.9768, 7.9976, 8.0184, 8.0392, 8.0599,
    8.0806, 8.1012, 8.1218, 8.1424, 8.163, 8.1835, 8.2039, 8.2244,
    8.2448, 8.2651, 8.2855, 8.3058, 8.3261, 8.3464, 8.3666, 8.3869,
    8.4071, 8.4273, 8.4474, 8.4676, 8.4877, 8.5078, 8.5278, 8.5479,
    8.5679, 8.5879, 8.6078, 8.6277, 8.6476, 8.6674, 8.6872, 8.707,
    8.7267, 8.7464, 8.7661, 8.7857, 8.8053, 8.8248, 8.8443, 8.8638,
    8.8831, 8.9025, 8.9217, 8.941, 8.9601, 8.9792, 8.9983, 9.0173,
    9.0363, 9.0552, 9.074, 9.0928, 9.1116, 9.1303, 9.149, 9.1676,
    9.1862, 9.2048, 9.2233, 9.2418, 9.2602, 9.2786, 9.297, 9.3154,
    9.3337, 9.352, 9.3703, 9.3886, 9.4069, 9.4252, 9.4435, 9.4617,
    9.48, 9.4983, 9.5166, 9.535, 9.5533, 9.5717, 9.5901, 9.6086,
    9.6271, 9.6456, 9.6642, 9.6828, 9.7015, 9.7202, 9.739, 9.7578,
    9.7767, 9.7957, 9.8147, 9.8338, 9.853, 9.8722, 9.8915, 9.9109,
    9.9303, 9.9499, 9.9695, 9.9892, 10.009, 10.0289, 10.0489,
    10.069, 10.0891, 10.1094, 10.1298, 10.1503, 10.1709, 10.1916,
    10.2123, 10.2332, 10.2542, 10.2753, 10.2965, 10.3178, 10.3393,
    10.3608, 10.3824, 10.4041, 10.4258, 10.4477, 10.4697, 10.4918,
    10.514, 10.5363, 10.5586, 10.5811, 10.6037, 10.6263, 10.6491,
    10.6719, 10.6948, 10.7178, 10.741, 10.7641, 10.7874, 10.8108,
    10.8343, 10.8578, 10.8814, 10.9051, 10.9289, 10.9527, 10.9767,
    11.0007, 11.0248, 11.0489, 11.0731, 11.0974, 11.1218, 11.1462,
    11.1707, 11.1952, 11.2198, 11.2444, 11.2691, 11.2939, 11.3187,
    11.3435, 11.3684, 11.3934, 11.4183, 11.4434, 11.4684, 11.4935,
    11.5186, 11.5437, 11.5689, 11.594, 11.6192, 11.6444, 11.6696,
    11.6948, 11.7201, 11.7453, 11.7705, 11.7957, 11.8209, 11.8461,
    11.8713, 11.8965, 11.9217, 11.9468, 11.972, 11.9971, 12.0223,
    12.0474, 12.0725, 12.0976, 12.1227, 12.1478, 12.1728, 12.1978,
    12.2229, 12.2479, 12.2729, 12.2978, 12.3228, 12.3477, 12.3727,
    12.3976, 12.4225, 12.4474, 12.4723, 12.4971, 12.522, 12.5468,
    12.5717, 12.5965, 12.6213, 12.6461, 12.6709, 12.6957, 12.7205,
    12.7453, 12.77, 12.7948, 12.8196, 12.8443, 12.8691, 12.8939,
    12.9186, 12.9434, 12.9681, 12.9929, 13.0177, 13.0424, 13.0672,
    13.092, 13.1167, 13.1415, 13.1663, 13.1911, 13.2158, 13.2406,
    13.2654, 13.2902, 13.3151, 13.3399, 13.3647, 13.3896, 13.4145,
    13.4394, 13.4643, 13.4892, 13.5142, 13.5391, 13.5641, 13.5892,
    13.6142, 13.6393, 13.6644, 13.6895, 13.7146, 13.7398, 13.765,
    13.7902, 13.8155, 13.8408, 13.8661, 13.8914, 13.9168, 13.9422,
    13.9676, 13.9931, 14.0186, 14.0441, 14.0697, 14.0953, 14.1209,
    14.1466, 14.1724, 14.1981, 14.2239, 14.2498, 14.2757, 14.3016,
    14.3276, 14.3537, 14.3798, 14.4059, 14.4321, 14.4584, 14.4848,
    14.5112, 14.5376, 14.5642, 14.5908, 14.6174, 14.6442, 14.671,
    14.6979, 14.7248, 14.7519, 14.779, 14.8062, 14.8334, 14.8608,
    14.8882, 14.9157, 14.9434, 14.9711, 14.9989, 15.0267, 15.0547,
    15.0828, 15.1109, 15.1392, 15.1676, 15.196, 15.2246, 15.2532,
    15.2819, 15.3108, 15.3397, 15.3687, 15.3979, 15.4271, 15.4564,
    15.4858, 15.5154, 15.545, 15.5747, 15.6046, 15.6345, 15.6646,
    15.6947, 15.725, 15.7553, 15.7858, 15.8164, 15.847, 15.8778,
    15.9087, 15.9396, 15.9707, 16.0019, 16.0332, 16.0645, 16.096,
    16.1276, 16.1593, 16.191, 16.2229, 16.2549, 16.287, 16.3191,
    16.3514, 16.3837, 16.4162, 16.4488, 16.4814, 16.5142, 16.547,
    16.58, 16.6131, 16.6462, 16.6795, 16.7129, 16.7464, 16.78,
    16.8137, 16.8475, 16.8814, 16.9154, 16.9496, 16.9838, 17.0182,
    17.0527, 17.0873, 17.122, 17.1569, 17.1918, 17.2269, 17.262,
    17.2973, 17.3327, 17.3683, 17.4039, 17.4397, 17.4755, 17.5115,
    17.5476, 17.5839, 17.6202, 17.6567, 17.6932, 17.7299, 17.7668,
    17.8037, 17.8407, 17.8779, 17.9152, 17.9526, 17.9901, 18.0277,
    18.0654, 18.1033, 18.1412, 18.1792, 18.2174, 18.2556, 18.294,
    18.3324, 7.4327, 7.4563, 7.4799, 7.5034, 7.5269, 7.5504,
    7.5738, 7.5973, 7.6206, 7.644, 7.6673, 7.6906, 7.7138, 7.737,
    7.7602, 7.7834, 7.8065, 7.8296, 7.8526, 7.8757, 7.8986, 7.9216,
    7.9445, 7.9674, 7.9903, 8.0132, 8.036, 8.0588, 8.0816, 8.1044,
    8.1272, 8.15, 8.1727, 8.1955, 8.2183, 8.241, 8.2638, 8.2865,
    8.3092, 8.332, 8.3547, 8.3774, 8.4001, 8.4227, 8.4454, 8.468,
    8.4906, 8.5132, 8.5358, 8.5583, 8.5808, 8.6032, 8.6257, 8.648,
    8.6704, 8.6927, 8.715, 8.7372, 8.7594, 8.7815, 8.8036, 8.8257,
    8.8477, 8.8697, 8.8916, 8.9135, 8.9353, 8.9571, 8.9788, 9.0005,
    9.0221, 9.0436, 9.0651, 9.0865, 9.1079, 9.1292, 9.1504, 9.1716,
    9.1927, 9.2137, 9.2347, 9.2557, 9.2766, 9.2974, 9.3182, 9.339,
    9.3597, 9.3803, 9.401, 9.4215, 9.442, 9.4625, 9.4829, 9.5032,
    9.5235, 9.5438, 9.5639, 9.5841, 9.6041, 9.6241, 9.644, 9.6639,
    9.6836, 9.7033, 9.723, 9.7425, 9.762, 9.7814, 9.8007, 9.82,
    9.8392, 9.8583, 9.8773, 9.8963, 9.9152, 9.9341, 9.9528, 9.9716,
    9.9902, 10.0088, 10.0274, 10.0459, 10.0643, 10.0827, 10.1011,
    10.1194, 10.1377, 10.1559, 10.1741, 10.1923, 10.2105, 10.2286,
    10.2468, 10.2649, 10.2831, 10.3012, 10.3194, 10.3376, 10.3558,
    10.3741, 10.3923, 10.4107, 10.4291, 10.4475, 10.466, 10.4845,
    10.5031, 10.5217, 10.5405, 10.5592, 10.5781, 10.597, 10.6161,
    10.6352, 10.6544, 10.6737, 10.6931, 10.7126, 10.7322, 10.752,
    10.7718, 10.7918, 10.8119, 10.8321, 10.8524, 10.8728, 10.8934,
    10.9142, 10.935, 10.956, 10.9772, 10.9985, 11.0199, 11.0415,
    11.0632, 11.0851, 11.1071, 11.1293, 11.1516, 11.174, 11.1966,
    11.2193, 11.2422, 11.2651, 11.2882, 11.3114, 11.3347, 11.3581,
    11.3817, 11.4053, 11.429, 11.4529, 11.4768, 11.5007, 11.5248,
    11.549, 11.5732, 11.5975, 11.6218, 11.6462, 11.6707, 11.6952,
    11.7198, 11.7444, 11.769, 11.7937, 11.8184, 11.8431, 11.8678,
    11.8926, 11.9173, 11.9421, 11.9668, 11.9916, 12.0163, 12.0411,
    12.0658, 12.0905, 12.1152, 12.1398, 12.1645, 12.1891, 12.2136,
    12.2382, 12.2627, 12.2871, 12.3116, 12.336, 12.3603, 12.3846,
    12.4089, 12.4332, 12.4574, 12.4815, 12.5057, 12.5298, 12.5538,
    12.5778, 12.6017, 12.6257, 12.6495, 12.6734, 12.6972, 12.7209,
    12.7446, 12.7683, 12.792, 12.8156, 12.8392, 12.8628, 12.8864,
    12.9099, 12.9334, 12.9569, 12.9804, 13.0038, 13.0273, 13.0507,
    13.0742, 13.0976, 13.1209, 13.1443, 13.1677, 13.191, 13.2143,
    13.2376, 13.2609, 13.2842, 13.3075, 13.3308, 13.3541, 13.3773,
    13.4006, 13.4239, 13.4472, 13.4705, 13.4937, 13.5171, 13.5404,
    13.5637, 13.587, 13.6104, 13.6338, 13.6572, 13.6806, 13.7041,
    13.7275, 13.751, 13.7746, 13.7981, 13.8217, 13.8454, 13.8691,
    13.8928, 13.9165, 13.9403, 13.9642, 13.9881, 14.012, 14.036,
    14.06, 14.0841, 14.1083, 14.1325, 14.1567, 14.1811, 14.2055,
    14.2299, 14.2544, 14.279, 14.3037, 14.3284, 14.3533, 14.3782,
    14.4031, 14.4282, 14.4533, 14.4785, 14.5038, 14.5292, 14.5547,
    14.5802, 14.6058, 14.6316, 14.6574, 14.6832, 14.7092, 14.7353,
    14.7614, 14.7877, 14.814, 14.8404, 14.8669, 14.8934, 14.9201,
    14.9468, 14.9736, 15.0005, 15.0275, 15.0546, 15.0818, 15.109,
    15.1363, 15.1637, 15.1912, 15.2187, 15.2463, 15.274, 15.3018,
    15.3297, 15.3576, 15.3856, 15.4137, 15.4419, 15.4701, 15.4985,
    15.5268, 15.5553, 15.5838, 15.6125, 15.6412, 15.6699, 15.6987,
    15.7276, 15.7566, 15.7857, 15.8148, 15.844, 15.8732, 15.9026,
    15.932, 15.9615, 15.991, 16.0206, 16.0503, 16.0801, 16.1099,
    16.1398, 16.1697, 16.1997, 16.2298, 16.26, 16.2902, 16.3204,
    16.3508, 16.3812, 16.4117, 16.4422, 16.4728, 16.5035, 16.5342,
    16.565, 16.5959, 16.6268, 16.6579, 16.6889, 16.7201, 16.7513,
    16.7826, 16.8139, 16.8454, 16.8769, 16.9084, 16.9401, 16.9718,
    17.0036, 17.0355, 17.0674, 17.0995, 17.1316, 17.1637, 17.196,
    17.2283, 17.2607, 17.2931, 17.3256, 17.3582, 17.3909, 17.4237,
    17.4565, 17.4894, 17.5224, 17.5554, 17.5885, 17.6217, 17.655,
    17.6884, 17.7218, 17.7553, 17.7889, 17.8226, 17.8564, 17.8903,
    17.9242, 17.9583, 17.9924, 18.0267, 18.061, 18.0954, 18.1299,
    18.1645, 18.1992, 18.234, 18.2689, 18.3039, 18.339, 18.3742,
    18.4094, 18.4448, 18.4802, 18.5158, 18.5514, 18.5871, 18.6229,
    18.6588, 18.6948, 18.7308, 18.767, 18.8032, 18.8395, 18.8759,
    18.9123, 18.9489, 18.9855, 19.0222, 19.059, 19.0958, 19.1327,
    19.1697, 19.2067, 19.2439, 19.281, 19.3183, 19.3556, 19.393,
    19.4304, 19.4679, 19.5055, 19.5431, 19.5807, 19.6185, 19.6563,
    19.6941, 19.7321, 19.77, 19.8081, 19.8461, 19.8843, 19.9225,
    19.9607, 19.999, 20.0373, 20.0757, 20.1142, 20.1527, 20.1912,
    20.2298, 20.2684, 20.3071, 20.3458, 20.3846, 20.4233, 20.4622,
    20.501, 20.54, 20.5789, 20.6179, 20.6569, 20.6959, 20.735,
    20.7741, 20.8132, 20.8524, 20.8916, 20.9308, 20.97, 21.0093,
    21.0486, 21.0879, 21.1272, 21.1666, 21.2059, 21.2453, 21.2847,
    21.3242, 21.3636, 21.4031, 21.4426, 21.482, 21.5215, 21.5611,
    21.6006, 21.6401, 21.6797, 21.7193, 21.7588, 21.7984, 21.838,
    21.8776, 21.9172, 21.9568, 21.9964, 22.036, 22.0757, 22.1153,
    22.1549, 22.1945, 22.2341, 22.2738, 22.3134, 22.353, 7.2402,
    7.2627, 7.2852, 7.3076, 7.33, 7.3523, 7.3745, 7.3967, 7.4189,
    7.441, 7.463, 7.485, 7.5069, 7.5288, 7.5507, 7.5724, 7.5942,
    7.6158, 7.6375, 7.659, 7.6806, 7.702, 7.7234, 7.7448, 7.7661,
    7.7874, 7.8086, 7.8298, 7.8509, 7.872, 7.893, 7.914, 7.935,
    7.9559, 7.9768, 7.9976, 8.0184, 8.0392, 8.0599, 8.0806, 8.1012,
    8.1218, 8.1424, 8.163, 8.1835, 8.2039, 8.2244, 8.2448, 8.2651,
    8.2855, 8.3058, 8.3261, 8.3464, 8.3666, 8.3869, 8.4071, 8.4273,
    8.4474, 8.4676, 8.4877, 8.5078, 8.5278, 8.5479, 8.5679, 8.5879,
    8.6078, 8.6277, 8.6476, 8.6674, 8.6872, 8.707, 8.7267, 8.7464,
    8.7661, 8.7857, 8.8053, 8.8248, 8.8443, 8.8638, 8.8831, 8.9025,
    8.9217, 8.941, 8.9601, 8.9792, 8.9983, 9.0173, 9.0363, 9.0552,
    9.074, 9.0928, 9.1116, 9.1303, 9.149, 9.1676, 9.1862, 9.2048,
    9.2233, 9.2418, 9.2602, 9.2786, 9.297, 9.3154, 9.3337, 9.352,
    9.3703, 9.3886, 9.4069, 9.4252, 9.4435, 9.4617, 9.48, 9.4983,
    9.5166, 9.535, 9.5533, 9.5717, 9.5901, 9.6086, 9.6271, 9.6456,
    9.6642, 9.6828, 9.7015, 9.7202, 9.739, 9.7578, 9.7767, 9.7957,
    9.8147, 9.8338, 9.853, 9.8722, 9.8915, 9.9109, 9.9303, 9.9499,
    9.9695, 9.9892, 10.009, 10.0289, 10.0489, 10.069, 10.0891,
    10.1094, 10.1298, 10.1503, 10.1709, 10.1916, 10.2123, 10.2332,
    10.2542, 10.2753, 10.2965, 10.3178, 10.3393, 10.3608, 10.3824,
    10.4041, 10.4258, 10.4477, 10.4697, 10.4918, 10.514, 10.5363,
    10.5586, 10.5811, 10.6037, 10.6263, 10.6491, 10.6719, 10.6948,
    10.7178, 10.741, 10.7641, 10.7874, 10.8108, 10.8343, 10.8578,
    10.8814, 10.9051, 10.9289, 10.9527, 10.9767, 11.0007, 11.0248,
    11.0489, 11.0731, 11.0974, 11.1218, 11.1462, 11.1707, 11.1952,
    11.2198, 11.2444, 11.2691, 11.2939, 11.3187, 11.3435, 11.3684,
    11.3934, 11.4183, 11.4434, 11.4684, 11.4935, 11.5186, 11.5437,
    11.5689, 11.594, 11.6192, 11.6444, 11.6696, 11.6948, 11.7201,
    11.7453, 11.7705, 11.7957, 11.8209, 11.8461, 11.8713, 11.8965,
    11.9217, 11.9468, 11.972, 11.9971, 12.0223, 12.0474, 12.0725,
    12.0976, 12.1227, 12.1478, 12.1728, 12.1978, 12.2229, 12.2479,
    12.2729, 12.2978, 12.3228, 12.3477, 12.3727, 12.3976, 12.4225,
    12.4474, 12.4723, 12.4971, 12.522, 12.5468, 12.5717, 12.5965,
    12.6213, 12.6461, 12.6709, 12.6957, 12.7205, 12.7453, 12.77,
    12.7948, 12.8196, 12.8443, 12.8691, 12.8939, 12.9186, 12.9434,
    12.9681, 12.9929, 13.0177, 13.0424, 13.0672, 13.092, 13.1167,
    13.1415, 13.1663, 13.1911, 13.2158, 13.2406, 13.2654, 13.2902,
    13.3151, 13.3399, 13.3647, 13.3896, 13.4145, 13.4394, 13.4643,
    13.4892, 13.5142, 13.5391, 13.5641, 13.5892, 13.6142, 13.6393,
    13.6644, 13.6895, 13.7146, 13.7398, 13.765, 13.7902, 13.8155,
    13.8408, 13.8661, 13.8914, 13.9168, 13.9422, 13.9676, 13.9931,
    14.0186, 14.0441, 14.0697, 14.0953, 14.1209, 14.1466, 14.1724,
    14.1981, 14.2239, 14.2498, 14.2757, 14.3016, 14.3276, 14.3537,
    14.3798, 14.4059, 14.4321, 14.4584, 14.4848, 14.5112, 14.5376,
    14.5642, 14.5908, 14.6174, 14.6442, 14.671, 14.6979, 14.7248,
    14.7519, 14.779, 14.8062, 14.8334, 14.8608, 14.8882, 14.9157,
    14.9434, 14.9711, 14.9989, 15.0267, 15.0547, 15.0828, 15.1109,
    15.1392, 15.1676, 15.196, 15.2246, 15.2532, 15.2819, 15.3108,
    15.3397, 15.3687, 15.3979, 15.4271, 15.4564, 15.4858, 15.5154,
    15.545, 15.5747, 15.6046, 15.6345, 15.6646, 15.6947, 15.725,
    15.7553, 15.7858, 15.8164, 15.847, 15.8778, 15.9087, 15.9396,
    15.9707, 16.0019, 16.0332, 16.0645, 16.096, 16.1276, 16.1593,
    16.191, 16.2229, 16.2549, 16.287, 16.3191, 16.3514, 16.3837,
    16.4162, 16.4488, 16.4814, 16.5142, 16.547, 16.58, 16.6131,
    16.6462, 16.6795, 16.7129, 16.7464, 16.78, 16.8137, 16.8475,
    16.8814, 16.9154, 16.9496, 16.9838, 17.0182, 17.0527, 17.0873,
    17.122, 17.1569, 17.1918, 17.2269, 17.262, 17.2973, 17.3327,
    17.3683, 17.4039, 17.4397, 17.4755, 17.5115, 17.5476, 17.5839,
    17.6202, 17.6567, 17.6932, 17.7299, 17.7668, 17.8037, 17.8407,
    17.8779, 17.9152, 17.9526, 17.9901, 18.0277, 18.0654, 18.1033,
    18.1412, 18.1792, 18.2174, 18.2556, 18.294, 18.3324, 18.371,
    18.4096, 18.4484, 18.4872, 18.5262, 18.5652, 18.6043, 18.6436,
    18.6829, 18.7223, 18.7618, 18.8015, 18.8412, 18.8809, 18.9208,
    18.9608, 19.0009, 19.041, 19.0812, 19.1215, 19.1619, 19.2024,
    19.243, 19.2836, 19.3243, 19.3651, 19.406, 19.447, 19.488,
    19.5291, 19.5703, 19.6116, 19.6529, 19.6943, 19.7358, 19.7774,
    19.819, 19.8607, 19.9024, 19.9442, 19.9861, 20.028, 20.07,
    20.112, 20.1541, 20.1963, 20.2385, 20.2807, 20.323, 20.3653,
    20.4077, 20.4502, 20.4926, 20.5351, 20.5777, 20.6203, 20.6629,
    20.7056, 20.7483, 20.791, 20.8338, 20.8766, 20.9194, 20.9622,
    21.0051, 21.048, 21.0909, 21.1339, 21.1769, 21.2199, 21.2629,
    21.3059, 21.3489, 21.392, 21.4351, 21.4782, 21.5213, 21.5644,
    21.6075, 21.6507, 21.6938, 21.737, 21.7802, 21.8233, 21.8665,
    21.9097, 21.9529, 21.9961, 22.0393, 22.0825, 22.1258, 22.169,
    22.2122, 22.2554, 22.2986, 22.3419, 22.3851, 22.4283, 22.4715,
    22.5148, 22.558, 22.6012, 22.6444, 22.6877, 22.7309, 22.7741,
    22.8173), s = c(0.0956, 0.09597, 0.09634, 0.09672, 0.09709,
    0.09746, 0.09784, 0.09821, 0.09769, 0.09716, 0.09664, 0.09611,
    0.09559, 0.09507, 0.09454, 0.09416, 0.0938, 0.09347, 0.09315,
    0.09285, 0.09257, 0.0923, 0.09204, 0.0918, 0.09156, 0.09134,
    0.09112, 0.09092, 0.09072, 0.09053, 0.09035, 0.09017, 0.09,
    0.08984, 0.08968, 0.08953, 0.08938, 0.08924, 0.0891, 0.08897,
    0.08884, 0.08871, 0.08859, 0.08847, 0.08835, 0.08824, 0.08813,
    0.08802, 0.08792, 0.08782, 0.08772, 0.08762, 0.08753, 0.08743,
    0.08734, 0.08725, 0.08717, 0.08708, 0.087, 0.08692, 0.08684,
    0.08676, 0.08669, 0.08661, 0.08654, 0.08646, 0.08639, 0.08632,
    0.08626, 0.08619, 0.08612, 0.08606, 0.08599, 0.08593, 0.08587,
    0.08581, 0.08575, 0.08569, 0.08564, 0.08558, 0.08552, 0.08547,
    0.08541, 0.08536, 0.08531, 0.08526, 0.08521, 0.08516, 0.08511,
    0.08506, 0.08501, 0.08496, 0.08492, 0.08487, 0.08483, 0.08478,
    0.08474, 0.0847, 0.08465, 0.08461, 0.08457, 0.08453, 0.08449,
    0.08445, 0.08441, 0.08437, 0.08433, 0.08429, 0.08426, 0.08422,
    0.08418, 0.08415, 0.08411, 0.08408, 0.08404, 0.08401, 0.08397,
    0.08394, 0.08391, 0.08387, 0.08384, 0.08381, 0.08378, 0.08375,
    0.08371, 0.08368, 0.08365, 0.08362, 0.08359, 0.08356, 0.08354,
    0.08351, 0.08348, 0.08345, 0.08342, 0.0834, 0.08337, 0.08334,
    0.08332, 0.08329, 0.08326, 0.08324, 0.08321, 0.08319, 0.08316,
    0.08314, 0.08311, 0.08309, 0.08306, 0.08304, 0.08302, 0.08299,
    0.08297, 0.08295, 0.08292, 0.0829, 0.08288, 0.08285, 0.08283,
    0.08281, 0.08279, 0.08277, 0.08275, 0.08272, 0.0827, 0.08268,
    0.08266, 0.08264, 0.08262, 0.0826, 0.08258, 0.08256, 0.08254,
    0.08252, 0.0825, 0.08248, 0.08246, 0.08244, 0.08242, 0.08241,
    0.08239, 0.08237, 0.08235, 0.08233, 0.08231, 0.0823, 0.08228,
    0.08226, 0.08224, 0.08222, 0.08221, 0.08219, 0.08217, 0.08216,
    0.08214, 0.08212, 0.0821, 0.08209, 0.08207, 0.08205, 0.08204,
    0.08202, 0.08201, 0.08199, 0.08197, 0.08196, 0.08194, 0.08193,
    0.08191, 0.08189, 0.08188, 0.08186, 0.08185, 0.08183, 0.08182,
    0.0818, 0.08179, 0.08177, 0.08176, 0.08174, 0.08173, 0.08171,
    0.0817, 0.08168, 0.08167, 0.08165, 0.08164, 0.08163, 0.08161,
    0.0816, 0.08158, 0.08157, 0.08155, 0.08154, 0.08153, 0.08151,
    0.0815, 0.08149, 0.08147, 0.08146, 0.08145, 0.08143, 0.08142,
    0.08141, 0.08139, 0.08138, 0.08137, 0.08135, 0.08134, 0.08133,
    0.08131, 0.0813, 0.08129, 0.08128, 0.08126, 0.08125, 0.08124,
    0.08122, 0.08121, 0.0812, 0.08119, 0.08117, 0.08116, 0.08115,
    0.08114, 0.08113, 0.08111, 0.0811, 0.08109, 0.08108, 0.08107,
    0.08105, 0.08104, 0.08103, 0.08102, 0.08101, 0.08099, 0.08098,
    0.08097, 0.08096, 0.08095, 0.08094, 0.08093, 0.08091, 0.0809,
    0.08089, 0.08088, 0.08087, 0.08086, 0.08085, 0.08084, 0.08082,
    0.08081, 0.0808, 0.08079, 0.08078, 0.08077, 0.08076, 0.08075,
    0.08074, 0.08073, 0.08071, 0.0807, 0.08069, 0.08068, 0.08067,
    0.08066, 0.08065, 0.08064, 0.08063, 0.08062, 0.08061, 0.0806,
    0.08059, 0.08058, 0.08057, 0.08056, 0.08055, 0.08054, 0.08053,
    0.08052, 0.08051, 0.0805, 0.08049, 0.08048, 0.08047, 0.08046,
    0.08045, 0.08044, 0.08043, 0.08042, 0.08041, 0.0804, 0.08039,
    0.08038, 0.08037, 0.08036, 0.08035, 0.08034, 0.08033, 0.08032,
    0.08031, 0.0803, 0.08029, 0.08028, 0.08027, 0.08026, 0.08025,
    0.08024, 0.08023, 0.08022, 0.08022, 0.08021, 0.0802, 0.08019,
    0.08018, 0.08017, 0.08016, 0.08015, 0.08014, 0.08013, 0.08012,
    0.08011, 0.08011, 0.0801, 0.08009, 0.08008, 0.08007, 0.08006,
    0.08005, 0.08004, 0.08003, 0.08003, 0.08002, 0.08001, 0.08,
    0.07999, 0.07998, 0.07997, 0.07996, 0.07996, 0.07995, 0.07994,
    0.07993, 0.07992, 0.07991, 0.0799, 0.0799, 0.07989, 0.07988,
    0.07987, 0.07986, 0.07985, 0.07984, 0.07984, 0.07983, 0.07982,
    0.07981, 0.0798, 0.0798, 0.07979, 0.07978, 0.07977, 0.07976,
    0.07975, 0.07975, 0.07974, 0.07973, 0.07972, 0.07971, 0.07971,
    0.0797, 0.07969, 0.07968, 0.07967, 0.07966, 0.07966, 0.07965,
    0.07964, 0.07963, 0.07963, 0.07962, 0.07961, 0.0796, 0.07959,
    0.07959, 0.07958, 0.07957, 0.07956, 0.07955, 0.07955, 0.07954,
    0.07953, 0.07952, 0.07952, 0.07951, 0.0795, 0.07949, 0.07949,
    0.07948, 0.07947, 0.07946, 0.07946, 0.07945, 0.07944, 0.07943,
    0.07943, 0.07942, 0.07941, 0.0794, 0.0794, 0.07939, 0.07938,
    0.07937, 0.07937, 0.07936, 0.07935, 0.07934, 0.07934, 0.07933,
    0.07932, 0.07931, 0.07931, 0.0793, 0.07929, 0.07929, 0.07928,
    0.07927, 0.07926, 0.07926, 0.07925, 0.07924, 0.07924, 0.07923,
    0.07922, 0.07921, 0.07921, 0.0792, 0.07919, 0.07919, 0.07918,
    0.07917, 0.07916, 0.07916, 0.07915, 0.07914, 0.07914, 0.07913,
    0.07912, 0.07912, 0.07911, 0.0791, 0.07909, 0.07909, 0.07908,
    0.07907, 0.07907, 0.07906, 0.07905, 0.07905, 0.07904, 0.07903,
    0.07903, 0.07902, 0.07901, 0.07901, 0.079, 0.07899, 0.07899,
    0.07898, 0.07897, 0.07897, 0.07896, 0.07895, 0.07895, 0.07894,
    0.07893, 0.07893, 0.07892, 0.07891, 0.07891, 0.0789, 0.07889,
    0.07889, 0.07888, 0.07887, 0.07887, 0.07886, 0.07885, 0.07885,
    0.07884, 0.07883, 0.07883, 0.07882, 0.07881, 0.07881, 0.0788,
    0.0788, 0.07879, 0.07878, 0.07878, 0.07877, 0.07876, 0.07876,
    0.07875, 0.07874, 0.07874, 0.07873, 0.07873, 0.07872, 0.07871,
    0.07871, 0.0787, 0.07869, 0.07869, 0.07868, 0.07867, 0.07867,
    0.07866, 0.07866, 0.07865, 0.07864, 0.07864, 0.07863, 0.07863,
    0.07862, 0.07861, 0.07861, 0.0786, 0.07859, 0.07859, 0.07858,
    0.07858, 0.07857, 0.07856, 0.07856, 0.07855, 0.07855, 0.07854,
    0.07853, 0.07853, 0.07852, 0.07852, 0.07851, 0.0785, 0.0785,
    0.07849, 0.07849, 0.07848, 0.07847, 0.07847, 0.07846, 0.07846,
    0.07845, 0.07844, 0.07844, 0.07843, 0.07843, 0.07842, 0.07841,
    0.07841, 0.0784, 0.0784, 0.07839, 0.07838, 0.07838, 0.07837,
    0.07837, 0.07836, 0.07836, 0.07835, 0.07834, 0.07834, 0.07833,
    0.07833, 0.07832, 0.07832, 0.07831, 0.0783, 0.0783, 0.07829,
    0.07829, 0.07828, 0.07827, 0.07827, 0.07826, 0.07826, 0.07825,
    0.07825, 0.07824, 0.07824, 0.07823, 0.07822, 0.07822, 0.07821,
    0.07821, 0.0782, 0.0782, 0.07819, 0.07818, 0.07818, 0.07817,
    0.07817, 0.07816, 0.07816, 0.07815, 0.07815, 0.07814, 0.07813,
    0.07813, 0.07812, 0.07812, 0.07811, 0.07811, 0.0781, 0.0781,
    0.07809, 0.07809, 0.07808, 0.07807, 0.07807, 0.07806, 0.07806,
    0.07805, 0.07805, 0.07804, 0.07804, 0.07803, 0.07803, 0.07802,
    0.07802, 0.07801, 0.078, 0.078, 0.07799, 0.07799, 0.07798,
    0.07798, 0.07797, 0.07797, 0.07796, 0.07796, 0.07795, 0.07795,
    0.07794, 0.07794, 0.07793, 0.07792, 0.07792, 0.07791, 0.07791,
    0.0779, 0.0779, 0.07789, 0.07789, 0.07788, 0.07788, 0.07787,
    0.07787, 0.07786, 0.07786, 0.07785, 0.07785, 0.07784, 0.07784,
    0.07783, 0.07783, 0.07782, 0.07782, 0.07781, 0.07781, 0.0778,
    0.0778, 0.07779, 0.07779, 0.07778, 0.07778, 0.07777, 0.07777,
    0.07776, 0.07776, 0.07775, 0.07775, 0.07774, 0.07774, 0.07773,
    0.07773, 0.07772, 0.07772, 0.07771, 0.07771, 0.07785, 0.07785,
    0.07785, 0.07785, 0.07786, 0.07786, 0.07786, 0.07786, 0.07787,
    0.07787, 0.07787, 0.07787, 0.07787, 0.07788, 0.07788, 0.07788,
    0.07788, 0.07789, 0.07789, 0.07789, 0.07789, 0.07789, 0.0779,
    0.0779, 0.0779, 0.0779, 0.07791, 0.07791, 0.07791, 0.07791,
    0.07792, 0.07792, 0.07792, 0.07792, 0.07793, 0.07793, 0.07793,
    0.07793, 0.07794, 0.07794, 0.07794, 0.07794, 0.07795, 0.07795,
    0.07795, 0.07795, 0.07796, 0.07796, 0.07796, 0.07796, 0.07797,
    0.07797, 0.07797, 0.07798, 0.07798, 0.07798, 0.07798, 0.07799,
    0.07799, 0.07799, 0.07799, 0.078, 0.078, 0.078, 0.07801,
    0.07801, 0.07801, 0.07801, 0.07802, 0.07802, 0.07802, 0.07803,
    0.07803, 0.07803, 0.07803, 0.07804, 0.07804, 0.07804, 0.07805,
    0.07805, 0.07805, 0.07805, 0.07806, 0.07806, 0.07806, 0.07807,
    0.07807, 0.07807, 0.07808, 0.07808, 0.07808, 0.07809, 0.07809,
    0.07809, 0.07809, 0.0781, 0.0781, 0.0781, 0.07811, 0.07811,
    0.07811, 0.07812, 0.07812, 0.07812, 0.07813, 0.07813, 0.07813,
    0.07814, 0.07814, 0.07814, 0.07815, 0.07815, 0.07815, 0.07816,
    0.07816, 0.07816, 0.07817, 0.07817, 0.07817, 0.07818, 0.07818,
    0.07818, 0.07819, 0.07819, 0.07819, 0.0782, 0.0782, 0.0782,
    0.07821, 0.07821, 0.07821, 0.07822, 0.07822, 0.07822, 0.07823,
    0.07823, 0.07824, 0.07824, 0.07824, 0.07825, 0.07825, 0.07825,
    0.07826, 0.07826, 0.07826, 0.07827, 0.07827, 0.07828, 0.07828,
    0.07828, 0.07829, 0.07829, 0.07829, 0.0783, 0.0783, 0.07831,
    0.07831, 0.07831, 0.07832, 0.07832, 0.07832, 0.07833, 0.07833,
    0.07834, 0.07834, 0.07834, 0.07835, 0.07835, 0.07835, 0.07836,
    0.07836, 0.07837, 0.07837, 0.07837, 0.07838, 0.07838, 0.07839,
    0.07839, 0.07839, 0.0784, 0.0784, 0.07841, 0.07841, 0.07841,
    0.07842, 0.07842, 0.07843, 0.07843, 0.07843, 0.07844, 0.07844,
    0.07845, 0.07845, 0.07845, 0.07846, 0.07846, 0.07847, 0.07847,
    0.07848, 0.07848, 0.07848, 0.07849, 0.07849, 0.0785, 0.0785,
    0.0785, 0.07851, 0.07851, 0.07852, 0.07852, 0.07853, 0.07853,
    0.07853, 0.07854, 0.07854, 0.07855, 0.07855, 0.07856, 0.07856,
    0.07857, 0.07857, 0.07857, 0.07858, 0.07858, 0.07859, 0.07859,
    0.0786, 0.0786, 0.07861, 0.07861, 0.07861, 0.07862, 0.07862,
    0.07863, 0.07863, 0.07864, 0.07864, 0.07865, 0.07865, 0.07865,
    0.07866, 0.07866, 0.07867, 0.07867, 0.07868, 0.07868, 0.07869,
    0.07869, 0.0787, 0.0787, 0.07871, 0.07871, 0.07872, 0.07872,
    0.07872, 0.07873, 0.07873, 0.07874, 0.07874, 0.07875, 0.07875,
    0.07876, 0.07876, 0.07877, 0.07877, 0.07878, 0.07878, 0.07879,
    0.07879, 0.0788, 0.0788, 0.07881, 0.07881, 0.07882, 0.07882,
    0.07883, 0.07883, 0.07884, 0.07884, 0.07885, 0.07885, 0.07886,
    0.07886, 0.07887, 0.07887, 0.07888, 0.07888, 0.07889, 0.07889,
    0.0789, 0.0789, 0.07891, 0.07891, 0.07892, 0.07892, 0.07893,
    0.07893, 0.07894, 0.07894, 0.07895, 0.07895, 0.07896, 0.07896,
    0.07897, 0.07897, 0.07898, 0.07898, 0.07899, 0.07899, 0.079,
    0.079, 0.07901, 0.07901, 0.07902, 0.07903, 0.07903, 0.07904,
    0.07904, 0.07905, 0.07905, 0.07906, 0.07906, 0.07907, 0.07907,
    0.07908, 0.07908, 0.07909, 0.0791, 0.0791, 0.07911, 0.07911,
    0.07912, 0.07912, 0.07913, 0.07913, 0.07914, 0.07915, 0.07915,
    0.07916, 0.07916, 0.07917, 0.07917, 0.07918, 0.07918, 0.07919,
    0.0792, 0.0792, 0.07921, 0.07921, 0.07922, 0.07922, 0.07923,
    0.07924, 0.07924, 0.07925, 0.07925, 0.07926, 0.07926, 0.07927,
    0.07928, 0.07928, 0.07929, 0.07929, 0.0793, 0.07931, 0.07931,
    0.07932, 0.07932, 0.07933, 0.07934, 0.07934, 0.07935, 0.07935,
    0.07936, 0.07936, 0.07937, 0.07938, 0.07938, 0.07939, 0.0794,
    0.0794, 0.07941, 0.07941, 0.07942, 0.07943, 0.07943, 0.07944,
    0.07944, 0.07945, 0.07946, 0.07946, 0.07947, 0.07948, 0.07948,
    0.07949, 0.07949, 0.0795, 0.07951, 0.07951, 0.07952, 0.07953,
    0.07953, 0.07954, 0.07954, 0.07955, 0.07956, 0.07956, 0.07957,
    0.07958, 0.07958, 0.07959, 0.0796, 0.0796, 0.07961, 0.07962,
    0.07962, 0.07963, 0.07964, 0.07964, 0.07965, 0.07966, 0.07966,
    0.07967, 0.07967, 0.07968, 0.07969, 0.07969, 0.0797, 0.07971,
    0.07972, 0.07972, 0.07973, 0.07974, 0.07974, 0.07975, 0.07976,
    0.07976, 0.07977, 0.07978, 0.07978, 0.07979, 0.0798, 0.0798,
    0.07981, 0.07982, 0.07982, 0.07983, 0.07984, 0.07985, 0.07985,
    0.07986, 0.07987, 0.07987, 0.07988, 0.07989, 0.07989, 0.0799,
    0.07991, 0.07992, 0.07992, 0.07993, 0.07994, 0.07994, 0.07995,
    0.07996, 0.07997, 0.07997, 0.07998, 0.07999, 0.07999, 0.08,
    0.08001, 0.08002, 0.08002, 0.08003, 0.08004, 0.08005, 0.08005,
    0.08006, 0.08007, 0.08008, 0.08008, 0.08009, 0.0801, 0.08011,
    0.08011, 0.08012, 0.08013, 0.08014, 0.08014, 0.08015, 0.08016,
    0.08017, 0.08017, 0.08018, 0.08019, 0.0802, 0.0802, 0.08021,
    0.08022, 0.08023, 0.08023, 0.08024, 0.08025, 0.08026, 0.08027,
    0.08027, 0.08028, 0.08029, 0.0803, 0.08031, 0.08031, 0.08032,
    0.08033, 0.08034, 0.08034, 0.08035, 0.08036, 0.08037, 0.08038,
    0.08038, 0.08039, 0.0804, 0.08041, 0.08042, 0.08042, 0.08043,
    0.08044, 0.08045, 0.08046, 0.08046, 0.08047, 0.08048, 0.08049,
    0.0805, 0.08051, 0.08051, 0.08052, 0.08053, 0.08054, 0.08055,
    0.08056, 0.08056, 0.08057, 0.08058, 0.08059, 0.0806, 0.08061,
    0.08061, 0.08062, 0.08063, 0.08064, 0.08065, 0.08066, 0.08066,
    0.08067, 0.08068, 0.08069, 0.0807, 0.08071, 0.08072, 0.08072,
    0.08073, 0.08074, 0.08075, 0.08076, 0.08077, 0.08078, 0.08078,
    0.08079, 0.0808, 0.08081, 0.08082, 0.08083, 0.08084, 0.08085,
    0.08085, 0.08086, 0.08087, 0.08088, 0.08089, 0.0809, 0.08091,
    0.08092, 0.08093, 0.08093, 0.08094, 0.08095, 0.08096, 0.08097,
    0.08098, 0.08099, 0.081, 0.08101, 0.08102, 0.08102, 0.08103,
    0.08104, 0.08105, 0.08106, 0.08107, 0.08108, 0.08109, 0.0811,
    0.08111, 0.08112, 0.08113, 0.08113, 0.08114, 0.08115, 0.08116,
    0.08117, 0.08118, 0.08119, 0.0812, 0.08121, 0.08122, 0.08123,
    0.08124, 0.08125, 0.08126, 0.08127, 0.08128, 0.08128, 0.08129,
    0.0813, 0.08131, 0.08132, 0.08133, 0.08134, 0.08135, 0.08136,
    0.08137, 0.08138, 0.08139, 0.0814, 0.08141, 0.08142, 0.08143,
    0.08144, 0.08145, 0.08146, 0.08147, 0.08148, 0.08149, 0.0815,
    0.08151, 0.08152, 0.08153, 0.08154, 0.08155, 0.08156, 0.08157,
    0.08158, 0.08159, 0.0816, 0.08161, 0.08162, 0.08163, 0.08164,
    0.08165, 0.08166, 0.08167, 0.08168, 0.08169, 0.0817, 0.08171,
    0.08172, 0.08173, 0.08174, 0.08175, 0.08176, 0.08177, 0.08178,
    0.08179, 0.0818, 0.08181, 0.08182, 0.08183, 0.08184, 0.08185,
    0.08186, 0.08187, 0.08188, 0.08189, 0.0819, 0.08191, 0.08192,
    0.08193, 0.08194, 0.08195, 0.08196, 0.08197, 0.08198, 0.082,
    0.08201, 0.08202, 0.08203, 0.08204, 0.08205, 0.08206, 0.08207,
    0.08208, 0.08209, 0.0821, 0.08211, 0.08212, 0.08213, 0.08214,
    0.08215, 0.08216, 0.08218, 0.08219, 0.0822, 0.08221, 0.08222,
    0.08223, 0.08224, 0.08225, 0.08226, 0.08227, 0.08228, 0.08229,
    0.08231, 0.08232, 0.08233, 0.08234, 0.08235, 0.08236, 0.08237,
    0.08238, 0.08239, 0.0824, 0.08241, 0.08243, 0.08244, 0.08245,
    0.08246, 0.08247, 0.08248, 0.08249, 0.0825, 0.08251, 0.08253,
    0.08254, 0.08255, 0.08256, 0.08257, 0.08258, 0.08259, 0.0826,
    0.08262, 0.08263, 0.08264, 0.08265, 0.08266, 0.08267, 0.08268,
    0.08269, 0.08271, 0.08272, 0.08273, 0.08274, 0.08275, 0.08276,
    0.08277, 0.08279, 0.0828, 0.08281, 0.08282, 0.08283, 0.08284,
    0.08285, 0.08287, 0.08288, 0.08289, 0.0829, 0.08291, 0.08292,
    0.08293, 0.08295, 0.08296, 0.08297, 0.08298, 0.08299, 0.083,
    0.08302, 0.08303, 0.08304, 0.08305, 0.08306, 0.08307, 0.08309,
    0.0831, 0.08311, 0.08312, 0.08313, 0.08314, 0.08316, 0.08317,
    0.08318, 0.08319, 0.0832, 0.08322, 0.08323, 0.08324, 0.08325,
    0.08326, 0.08327, 0.08329, 0.0833, 0.08331, 0.08332, 0.08333,
    0.08335, 0.08336, 0.08337, 0.08338, 0.08339, 0.08341, 0.08342,
    0.08343, 0.08344, 0.08345, 0.08347, 0.08348, 0.08349, 0.0835,
    0.08351, 0.08353, 0.08354, 0.08355, 0.08356, 0.08357, 0.08359,
    0.0836, 0.08361, 0.08362, 0.08364, 0.08365, 0.08366, 0.08367,
    0.08368, 0.0837, 0.08371, 0.08372, 0.08373, 0.08375, 0.08376,
    0.08377, 0.08378, 0.08379, 0.08381, 0.08382, 0.08383, 0.08384,
    0.08386, 0.08387, 0.08388, 0.08389, 0.08391, 0.08392, 0.08393,
    0.08394, 0.08395, 0.08397, 0.08398, 0.08399, 0.084, 0.08402,
    0.08403, 0.08404, 0.08405, 0.08407, 0.08408, 0.08409, 0.0841,
    0.08412, 0.08413, 0.08414, 0.08415, 0.08417, 0.08418, 0.08419,
    0.0842, 0.08422, 0.08423, 0.08424, 0.08425, 0.08427, 0.08428,
    0.08429, 0.08431, 0.08432, 0.08433, 0.08434, 0.08436, 0.08437,
    0.08438, 0.08439, 0.08441, 0.08442, 0.08443, 0.08444, 0.08446,
    0.08447, 0.08448, 0.0845, 0.08451, 0.08452, 0.08453, 0.08455,
    0.08456, 0.08457, 0.08459, 0.0846, 0.08461, 0.08462, 0.08464,
    0.08465, 0.08466, 0.08468, 0.08469, 0.0847, 0.08471, 0.08473,
    0.08474, 0.08475, 0.08477, 0.08478, 0.08479, 0.0848, 0.08482,
    0.08483, 0.08484, 0.08486, 0.08487, 0.08488, 0.0849, 0.08491,
    0.08492, 0.08493, 0.08495, 0.08496, 0.08497, 0.08499, 0.085,
    0.08501, 0.08503, 0.08504, 0.08505, 0.08506, 0.08508, 0.08509,
    0.0851, 0.08512, 0.08513, 0.08514, 0.08516, 0.08517, 0.08518,
    0.0852, 0.08521, 0.08522, 0.08524, 0.08525, 0.08526, 0.08527,
    0.08529, 0.0853, 0.08531, 0.08533, 0.08534, 0.08535, 0.08537,
    0.08538, 0.08539, 0.08541, 0.08542, 0.08543, 0.08545, 0.08546,
    0.08547, 0.08549, 0.0855, 0.08551, 0.08553, 0.08554, 0.08555,
    0.08557, 0.08558, 0.08559, 0.08561, 0.08562, 0.08563, 0.08565,
    0.08566, 0.08567, 0.08569, 0.0857, 0.08571, 0.08573, 0.08574,
    0.08575, 0.08577, 0.08578, 0.08579, 0.08581, 0.08582, 0.08583,
    0.08585, 0.08586, 0.08587, 0.08589, 0.0859, 0.08591, 0.08593,
    0.08594, 0.08595, 0.08597, 0.08598, 0.08599, 0.08601, 0.08602,
    0.08603, 0.08605, 0.08606, 0.08608, 0.08609, 0.0861, 0.08612,
    0.08613, 0.08614, 0.08616, 0.08617, 0.08618, 0.0862, 0.08621,
    0.08622, 0.08624, 0.08625, 0.08626, 0.08628, 0.08629, 0.0863,
    0.08632, 0.08633, 0.08634, 0.08636, 0.08637, 0.08639, 0.0864,
    0.08641, 0.08643, 0.08644, 0.08645, 0.08647, 0.08648, 0.08649,
    0.08651, 0.08652, 0.08653, 0.08655, 0.08656, 0.08657, 0.08659,
    0.0866, 0.08662, 0.08663, 0.08664, 0.08666, 0.08667, 0.08668,
    0.0867, 0.08671, 0.08672, 0.08674, 0.08675, 0.08676, 0.08678,
    0.08679, 0.0868, 0.08682, 0.08683, 0.08685, 0.08686, 0.08687,
    0.08689, 0.0869, 0.08691, 0.08693, 0.08694, 0.08695, 0.08697,
    0.08698, 0.08699, 0.08701, 0.08702, 0.08704, 0.08705, 0.08706,
    0.08708, 0.08709, 0.0871, 0.08712, 0.08713, 0.08714, 0.08716,
    0.08717, 0.08718, 0.0872, 0.08721, 0.08722, 0.08724, 0.08725,
    0.08727, 0.08728, 0.08729, 0.08731, 0.08732, 0.08733, 0.08735,
    0.08736, 0.08737, 0.08739, 0.0874, 0.0839, 0.08414, 0.08439,
    0.08464, 0.0849, 0.08516, 0.08543, 0.0857, 0.08597, 0.08625,
    0.08653, 0.08682, 0.08711, 0.08741, 0.08771, 0.08802, 0.08833,
    0.08865, 0.08898, 0.08931, 0.08964, 0.08998, 0.09033, 0.09068,
    0.09103, 0.09139, 0.09176, 0.09213, 0.09251, 0.09289, 0.09327,
    0.09366, 0.09406, 0.09445, 0.09486, 0.09526, 0.09567, 0.09609,
    0.09651, 0.09693, 0.09735, 0.09778, 0.09821, 0.09864, 0.09907,
    0.09951, 0.09994, 0.10038, 0.10082, 0.10126, 0.1017, 0.10214,
    0.10259, 0.10303, 0.10347, 0.10391, 0.10435, 0.10478, 0.10522,
    0.10566, 0.10609, 0.10652, 0.10695, 0.10738, 0.1078, 0.10823,
    0.10865, 0.10906, 0.10948, 0.10989, 0.1103, 0.1107, 0.1111,
    0.1115, 0.11189, 0.11228, 0.11266, 0.11304, 0.11342, 0.11379,
    0.11415, 0.11451, 0.11487, 0.11522, 0.11556, 0.1159, 0.11623,
    0.11656, 0.11688, 0.1172, 0.11751, 0.11781, 0.11811, 0.11841,
    0.11869, 0.11898, 0.11925, 0.11952, 0.11979, 0.12005, 0.1203,
    0.12055, 0.12079, 0.12102, 0.12125, 0.12148, 0.1217, 0.12191,
    0.12212, 0.12233, 0.12253, 0.12272, 0.12291, 0.1231, 0.12328,
    0.12346, 0.12363, 0.1238, 0.12396, 0.12412, 0.12428, 0.12443,
    0.12458, 0.12473, 0.12487, 0.12501, 0.12514, 0.12528, 0.12541,
    0.12554, 0.12567, 0.12579, 0.12591, 0.12603, 0.12615, 0.12627,
    0.12638, 0.1265, 0.12661, 0.12672, 0.12683, 0.12694, 0.12704,
    0.12715, 0.12726, 0.12736, 0.12746, 0.12756, 0.12767, 0.12777,
    0.12787, 0.12797, 0.12807, 0.12816, 0.12826, 0.12836, 0.12845,
    0.12855, 0.12864, 0.12874, 0.12883, 0.12893, 0.12902, 0.12911,
    0.1292, 0.1293, 0.12939, 0.12948, 0.12948, 0.09272, 0.0936,
    0.09448, 0.09535, 0.09623, 0.09711, 0.09799, 0.09887, 0.09866,
    0.09845, 0.09824, 0.09804, 0.09783, 0.09762, 0.09741, 0.09726,
    0.09711, 0.09697, 0.09684, 0.09671, 0.09659, 0.09647, 0.09636,
    0.09625, 0.09615, 0.09605, 0.09595, 0.09586, 0.09577, 0.09568,
    0.09559, 0.09551, 0.09543, 0.09535, 0.09527, 0.0952, 0.09513,
    0.09506, 0.09499, 0.09492, 0.09485, 0.09479, 0.09472, 0.09466,
    0.0946, 0.09454, 0.09448, 0.09442, 0.09436, 0.09431, 0.09425,
    0.0942, 0.09415, 0.0941, 0.09404, 0.09399, 0.09394, 0.09389,
    0.09385, 0.0938, 0.09375, 0.09371, 0.09366, 0.09361, 0.09357,
    0.09353, 0.09348, 0.09344, 0.0934, 0.09336, 0.09332, 0.09328,
    0.09324, 0.0932, 0.09316, 0.09312, 0.09308, 0.09304, 0.093,
    0.09297, 0.09293, 0.09289, 0.09286, 0.09282, 0.09279, 0.09275,
    0.09272, 0.09268, 0.09265, 0.09262, 0.09258, 0.09255, 0.09252,
    0.09249, 0.09245, 0.09242, 0.09239, 0.09236, 0.09233, 0.0923,
    0.09227, 0.09224, 0.09221, 0.09218, 0.09215, 0.09212, 0.09209,
    0.09206, 0.09203, 0.09201, 0.09198, 0.09195, 0.09192, 0.09189,
    0.09187, 0.09184, 0.09181, 0.09179, 0.09176, 0.09173, 0.09171,
    0.09168, 0.09166, 0.09163, 0.09161, 0.09158, 0.09156, 0.09153,
    0.09151, 0.09148, 0.09146, 0.09143, 0.09141, 0.09139, 0.09136,
    0.09134, 0.09131, 0.09129, 0.09127, 0.09125, 0.09122, 0.0912,
    0.09118, 0.09116, 0.09113, 0.09111, 0.09109, 0.09107, 0.09104,
    0.09102, 0.091, 0.09098, 0.09096, 0.09094, 0.09092, 0.0909,
    0.09088, 0.09085, 0.09083, 0.09081, 0.09079, 0.09077, 0.09075,
    0.09073, 0.09071, 0.09069, 0.09067, 0.09065, 0.09063, 0.09061,
    0.09059, 0.09058, 0.09056, 0.09054, 0.09052, 0.0905, 0.09048,
    0.09046, 0.09044, 0.09043, 0.09041, 0.09039, 0.09037, 0.09035,
    0.09033, 0.09032, 0.0903, 0.09028, 0.09026, 0.09024, 0.09023,
    0.09021, 0.09019, 0.09017, 0.09016, 0.09014, 0.09012, 0.09011,
    0.09009, 0.09007, 0.09006, 0.09004, 0.09002, 0.09001, 0.08999,
    0.08997, 0.08996, 0.08994, 0.08992, 0.08991, 0.08989, 0.08988,
    0.08986, 0.08984, 0.08983, 0.08981, 0.0898, 0.08978, 0.08976,
    0.08975, 0.08973, 0.08972, 0.0897, 0.08969, 0.08967, 0.08966,
    0.08964, 0.08963, 0.08961, 0.0896, 0.08958, 0.08957, 0.08955,
    0.08954, 0.08952, 0.08951, 0.08949, 0.08948, 0.08947, 0.08945,
    0.08944, 0.08942, 0.08941, 0.08939, 0.08938, 0.08937, 0.08935,
    0.08934, 0.08932, 0.08931, 0.0893, 0.08928, 0.08927, 0.08926,
    0.08924, 0.08923, 0.08921, 0.0892, 0.08919, 0.08917, 0.08916,
    0.08915, 0.08913, 0.08912, 0.08911, 0.08909, 0.08908, 0.08907,
    0.08906, 0.08904, 0.08903, 0.08902, 0.089, 0.08899, 0.08898,
    0.08897, 0.08895, 0.08894, 0.08893, 0.08892, 0.0889, 0.08889,
    0.08888, 0.08887, 0.08885, 0.08884, 0.08883, 0.08882, 0.08881,
    0.08879, 0.08878, 0.08877, 0.08876, 0.08874, 0.08873, 0.08872,
    0.08871, 0.0887, 0.08869, 0.08867, 0.08866, 0.08865, 0.08864,
    0.08863, 0.08862, 0.0886, 0.08859, 0.08858, 0.08857, 0.08856,
    0.08855, 0.08854, 0.08852, 0.08851, 0.0885, 0.08849, 0.08848,
    0.08847, 0.08846, 0.08845, 0.08843, 0.08842, 0.08841, 0.0884,
    0.08839, 0.08838, 0.08837, 0.08836, 0.08835, 0.08834, 0.08833,
    0.08832, 0.0883, 0.08829, 0.08828, 0.08827, 0.08826, 0.08825,
    0.08824, 0.08823, 0.08822, 0.08821, 0.0882, 0.08819, 0.08818,
    0.08817, 0.08816, 0.08815, 0.08814, 0.08813, 0.08812, 0.08811,
    0.0881, 0.08809, 0.08808, 0.08807, 0.08806, 0.08805, 0.08804,
    0.08803, 0.08802, 0.08801, 0.088, 0.08799, 0.08798, 0.08797,
    0.08796, 0.08795, 0.08794, 0.08793, 0.08792, 0.08791, 0.0879,
    0.08789, 0.08788, 0.08787, 0.08786, 0.08785, 0.08784, 0.08783,
    0.08782, 0.08782, 0.08781, 0.0878, 0.08779, 0.08778, 0.08777,
    0.08776, 0.08775, 0.08774, 0.08773, 0.08772, 0.08771, 0.0877,
    0.08769, 0.08769, 0.08768, 0.08767, 0.08766, 0.08765, 0.08764,
    0.08763, 0.08762, 0.08761, 0.08761, 0.0876, 0.08759, 0.08758,
    0.08757, 0.08756, 0.08755, 0.08754, 0.08753, 0.08753, 0.08752,
    0.08751, 0.0875, 0.08749, 0.08748, 0.08747, 0.08747, 0.08746,
    0.08745, 0.08744, 0.08743, 0.08742, 0.08741, 0.08741, 0.0874,
    0.08739, 0.08738, 0.08737, 0.08736, 0.08736, 0.08735, 0.08734,
    0.08733, 0.08732, 0.08731, 0.08731, 0.0873, 0.08729, 0.08728,
    0.08727, 0.08727, 0.08726, 0.08725, 0.08724, 0.08723, 0.08722,
    0.08722, 0.08721, 0.0872, 0.08719, 0.08718, 0.08718, 0.08717,
    0.08716, 0.08715, 0.08714, 0.08714, 0.08713, 0.08712, 0.08711,
    0.08711, 0.0871, 0.08709, 0.08708, 0.08707, 0.08707, 0.08706,
    0.08705, 0.08704, 0.08704, 0.08703, 0.08702, 0.08701, 0.08701,
    0.087, 0.08699, 0.08698, 0.08698, 0.08697, 0.08696, 0.08695,
    0.08695, 0.08694, 0.08693, 0.08692, 0.08692, 0.08691, 0.0869,
    0.08689, 0.08689, 0.08688, 0.08687, 0.08686, 0.08686, 0.08685,
    0.08684, 0.08683, 0.08683, 0.08682, 0.08681, 0.08681, 0.0868,
    0.08679, 0.08678, 0.08678, 0.08677, 0.08676, 0.08676, 0.08675,
    0.08674, 0.08673, 0.08673, 0.08672, 0.08671, 0.08671, 0.0867,
    0.08669, 0.08668, 0.08668, 0.08667, 0.08666, 0.08666, 0.08665,
    0.08664, 0.08664, 0.08663, 0.08662, 0.08662, 0.08661, 0.0866,
    0.0866, 0.08659, 0.08658, 0.08657, 0.08657, 0.08656, 0.08655,
    0.08655, 0.08654, 0.08653, 0.08653, 0.08652, 0.08651, 0.08651,
    0.0865, 0.08649, 0.08649, 0.08648, 0.08647, 0.08647, 0.08646,
    0.08645, 0.08645, 0.08644, 0.08643, 0.08643, 0.08642, 0.08642,
    0.08641, 0.0864, 0.0864, 0.08639, 0.08638, 0.08638, 0.08637,
    0.08636, 0.08636, 0.08635, 0.08634, 0.08634, 0.08633, 0.08632,
    0.08632, 0.08631, 0.08631, 0.0863, 0.08629, 0.08629, 0.08628,
    0.08627, 0.08627, 0.08626, 0.08626, 0.08625, 0.08624, 0.08624,
    0.08623, 0.08622, 0.08622, 0.08621, 0.08621, 0.0862, 0.08619,
    0.08619, 0.08618, 0.08618, 0.08617, 0.08616, 0.08616, 0.08615,
    0.08614, 0.08614, 0.08613, 0.08613, 0.08612, 0.08611, 0.08611,
    0.0861, 0.0861, 0.08609, 0.08608, 0.08608, 0.08607, 0.08607,
    0.08606, 0.08605, 0.08605, 0.08604, 0.08604, 0.08603, 0.08603,
    0.08602, 0.08601, 0.08601, 0.086, 0.086, 0.08599, 0.08598,
    0.08598, 0.08597, 0.08597, 0.08596, 0.08596, 0.08595, 0.08594,
    0.08594, 0.08593, 0.08593, 0.08592, 0.08591, 0.08591, 0.0859,
    0.0859, 0.08589, 0.08589, 0.08588, 0.08587, 0.08587, 0.08586,
    0.08586, 0.08585, 0.08585, 0.08584, 0.08584, 0.08583, 0.08582,
    0.08582, 0.08581, 0.08581, 0.0858, 0.0858, 0.08579, 0.08579,
    0.08578, 0.08577, 0.08577, 0.08576, 0.08576, 0.08575, 0.08575,
    0.08574, 0.08574, 0.08573, 0.08573, 0.08572, 0.08571, 0.08571,
    0.0857, 0.0857, 0.08569, 0.08569, 0.08568, 0.08568, 0.08567,
    0.08567, 0.08566, 0.08565, 0.08565, 0.08564, 0.08564, 0.08563,
    0.08563, 0.08562, 0.08562, 0.08561, 0.08561, 0.0856, 0.0856,
    0.08559, 0.08559, 0.08558, 0.08558, 0.08557, 0.08556, 0.08556,
    0.08555, 0.08555, 0.08554, 0.08554, 0.08553, 0.08553, 0.08552,
    0.08552, 0.08551, 0.08551, 0.0855, 0.0855, 0.08549, 0.08549,
    0.08548, 0.08548, 0.08547, 0.08547, 0.08546, 0.08546, 0.08545,
    0.08545, 0.08454, 0.08454, 0.08454, 0.08454, 0.08454, 0.08454,
    0.08454, 0.08454, 0.08454, 0.08454, 0.08454, 0.08454, 0.08454,
    0.08454, 0.08453, 0.08453, 0.08453, 0.08453, 0.08453, 0.08453,
    0.08453, 0.08453, 0.08453, 0.08453, 0.08453, 0.08453, 0.08452,
    0.08452, 0.08452, 0.08452, 0.08452, 0.08452, 0.08452, 0.08452,
    0.08452, 0.08452, 0.08451, 0.08451, 0.08451, 0.08451, 0.08451,
    0.08451, 0.08451, 0.08451, 0.08451, 0.08451, 0.08451, 0.0845,
    0.0845, 0.0845, 0.0845, 0.0845, 0.0845, 0.0845, 0.0845, 0.0845,
    0.0845, 0.08449, 0.08449, 0.08449, 0.08449, 0.08449, 0.08449,
    0.08449, 0.08449, 0.08449, 0.08449, 0.08448, 0.08448, 0.08448,
    0.08448, 0.08448, 0.08448, 0.08448, 0.08448, 0.08448, 0.08448,
    0.08447, 0.08447, 0.08447, 0.08447, 0.08447, 0.08447, 0.08447,
    0.08447, 0.08447, 0.08447, 0.08447, 0.08447, 0.08446, 0.08446,
    0.08446, 0.08446, 0.08446, 0.08446, 0.08446, 0.08446, 0.08446,
    0.08446, 0.08446, 0.08446, 0.08445, 0.08445, 0.08445, 0.08445,
    0.08445, 0.08445, 0.08445, 0.08445, 0.08445, 0.08445, 0.08445,
    0.08445, 0.08445, 0.08445, 0.08444, 0.08444, 0.08444, 0.08444,
    0.08444, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444,
    0.08444, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444,
    0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443,
    0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443,
    0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443,
    0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443,
    0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443,
    0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443, 0.08443,
    0.08443, 0.08443, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444,
    0.08444, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444, 0.08444,
    0.08444, 0.08445, 0.08445, 0.08445, 0.08445, 0.08445, 0.08445,
    0.08445, 0.08445, 0.08445, 0.08446, 0.08446, 0.08446, 0.08446,
    0.08446, 0.08446, 0.08446, 0.08447, 0.08447, 0.08447, 0.08447,
    0.08447, 0.08447, 0.08448, 0.08448, 0.08448, 0.08448, 0.08448,
    0.08448, 0.08449, 0.08449, 0.08449, 0.08449, 0.0845, 0.0845,
    0.0845, 0.0845, 0.0845, 0.08451, 0.08451, 0.08451, 0.08451,
    0.08452, 0.08452, 0.08452, 0.08452, 0.08453, 0.08453, 0.08453,
    0.08454, 0.08454, 0.08454, 0.08455, 0.08455, 0.08455, 0.08455,
    0.08456, 0.08456, 0.08456, 0.08457, 0.08457, 0.08457, 0.08458,
    0.08458, 0.08459, 0.08459, 0.08459, 0.0846, 0.0846, 0.0846,
    0.08461, 0.08461, 0.08462, 0.08462, 0.08462, 0.08463, 0.08463,
    0.08464, 0.08464, 0.08465, 0.08465, 0.08465, 0.08466, 0.08466,
    0.08467, 0.08467, 0.08468, 0.08468, 0.08469, 0.08469, 0.0847,
    0.0847, 0.08471, 0.08471, 0.08472, 0.08472, 0.08473, 0.08473,
    0.08474, 0.08474, 0.08475, 0.08476, 0.08476, 0.08477, 0.08477,
    0.08478, 0.08478, 0.08479, 0.0848, 0.0848, 0.08481, 0.08482,
    0.08482, 0.08483, 0.08483, 0.08484, 0.08485, 0.08485, 0.08486,
    0.08487, 0.08487, 0.08488, 0.08489, 0.08489, 0.0849, 0.08491,
    0.08492, 0.08492, 0.08493, 0.08494, 0.08494, 0.08495, 0.08496,
    0.08497, 0.08497, 0.08498, 0.08499, 0.085, 0.08501, 0.08501,
    0.08502, 0.08503, 0.08504, 0.08505, 0.08505, 0.08506, 0.08507,
    0.08508, 0.08509, 0.0851, 0.0851, 0.08511, 0.08512, 0.08513,
    0.08514, 0.08515, 0.08516, 0.08517, 0.08517, 0.08518, 0.08519,
    0.0852, 0.08521, 0.08522, 0.08523, 0.08524, 0.08525, 0.08526,
    0.08527, 0.08528, 0.08529, 0.0853, 0.08531, 0.08532, 0.08533,
    0.08534, 0.08535, 0.08536, 0.08537, 0.08538, 0.08539, 0.0854,
    0.08541, 0.08542, 0.08543, 0.08544, 0.08545, 0.08547, 0.08548,
    0.08549, 0.0855, 0.08551, 0.08552, 0.08553, 0.08554, 0.08556,
    0.08557, 0.08558, 0.08559, 0.0856, 0.08561, 0.08563, 0.08564,
    0.08565, 0.08566, 0.08567, 0.08569, 0.0857, 0.08571, 0.08572,
    0.08574, 0.08575, 0.08576, 0.08577, 0.08579, 0.0858, 0.08581,
    0.08582, 0.08584, 0.08585, 0.08586, 0.08588, 0.08589, 0.0859,
    0.08592, 0.08593, 0.08594, 0.08596, 0.08597, 0.08598, 0.086,
    0.08601, 0.08602, 0.08604, 0.08605, 0.08606, 0.08608, 0.08609,
    0.08611, 0.08612, 0.08614, 0.08615, 0.08616, 0.08618, 0.08619,
    0.08621, 0.08622, 0.08624, 0.08625, 0.08627, 0.08628, 0.08629,
    0.08631, 0.08632, 0.08634, 0.08635, 0.08637, 0.08638, 0.0864,
    0.08641, 0.08643, 0.08645, 0.08646, 0.08648, 0.08649, 0.08651,
    0.08652, 0.08654, 0.08655, 0.08657, 0.08659, 0.0866, 0.08662,
    0.08663, 0.08665, 0.08666, 0.08668, 0.0867, 0.08671, 0.08673,
    0.08675, 0.08676, 0.08678, 0.08679, 0.08681, 0.08683, 0.08684,
    0.08686, 0.08688, 0.08689, 0.08691, 0.08693, 0.08694, 0.08696,
    0.08698, 0.08699, 0.08701, 0.08703, 0.08704, 0.08706, 0.08708,
    0.0871, 0.08711, 0.08713, 0.08715, 0.08716, 0.08718, 0.0872,
    0.08722, 0.08723, 0.08725, 0.08727, 0.08729, 0.0873, 0.08732,
    0.08734, 0.08736, 0.08737, 0.08739, 0.08741, 0.08743, 0.08745,
    0.08746, 0.08748, 0.0875, 0.08752, 0.08753, 0.08755, 0.08757,
    0.08759, 0.08761, 0.08763, 0.08764, 0.08766, 0.08768, 0.0877,
    0.08772, 0.08773, 0.08775, 0.08777, 0.08779, 0.08781, 0.08783,
    0.08785, 0.08786, 0.08788, 0.0879, 0.08792, 0.08794, 0.08796,
    0.08798, 0.08799, 0.08801, 0.08803, 0.08805, 0.08807, 0.08809,
    0.08811, 0.08813, 0.08814, 0.08816, 0.08818, 0.0882, 0.08822,
    0.08824, 0.08826, 0.08828, 0.0883, 0.08832, 0.08833, 0.08835,
    0.08837, 0.08839, 0.08841, 0.08843, 0.08845, 0.08847, 0.08849,
    0.08851, 0.08853, 0.08855, 0.08857, 0.08859, 0.0886, 0.08862,
    0.08864, 0.08866, 0.08868, 0.0887, 0.08872, 0.08874, 0.08876,
    0.08878, 0.0888, 0.08882, 0.08884, 0.08886, 0.08888, 0.0889,
    0.08892, 0.08894, 0.08896, 0.08898, 0.089, 0.08901, 0.08903,
    0.08905, 0.08907, 0.08909, 0.08911, 0.08913, 0.08915, 0.08917,
    0.08919, 0.08921, 0.08923, 0.08925, 0.08927, 0.08929, 0.08931,
    0.08933, 0.08935, 0.08937, 0.08939, 0.08941, 0.08943, 0.08945,
    0.08947, 0.08949, 0.08951, 0.08953, 0.08955, 0.08957, 0.08959,
    0.08961, 0.08963, 0.08964, 0.08966, 0.08968, 0.0897, 0.08972,
    0.08974, 0.08976, 0.08978, 0.0898, 0.08982, 0.08984, 0.08986,
    0.08988, 0.0899, 0.08992, 0.08994, 0.08996, 0.08998, 0.09,
    0.09002, 0.09004, 0.09006, 0.09008, 0.0901, 0.09012, 0.09013,
    0.09015, 0.09017, 0.09019, 0.09021, 0.09023, 0.09025, 0.09027,
    0.09029, 0.09031, 0.09033, 0.09035, 0.09037, 0.09039, 0.09041,
    0.09043, 0.09045, 0.09047, 0.09049, 0.0905, 0.09052, 0.09054,
    0.09056, 0.09058, 0.0906, 0.09062, 0.09064, 0.09066, 0.09068,
    0.0907, 0.09072, 0.09074, 0.09076, 0.09078, 0.0908, 0.09081,
    0.09083, 0.09085, 0.09087, 0.09089, 0.09091, 0.09093, 0.09095,
    0.09097, 0.09099, 0.09101, 0.09103, 0.09105, 0.09107, 0.09109,
    0.0911, 0.09112, 0.09114, 0.09116, 0.09118, 0.0912, 0.09122,
    0.09124, 0.09126, 0.09128, 0.0913, 0.09132, 0.09134, 0.09136,
    0.09138, 0.09139, 0.09141, 0.09143, 0.09145, 0.09147, 0.09149,
    0.09151, 0.09153, 0.09155, 0.09157, 0.09159, 0.09161, 0.09163,
    0.09165, 0.09167, 0.09168, 0.0917, 0.09172, 0.09174, 0.09176,
    0.09178, 0.0918, 0.09182, 0.09184, 0.09186, 0.09188, 0.0919,
    0.09192, 0.09194, 0.09196, 0.09198, 0.092, 0.09201, 0.09203,
    0.09205, 0.09207, 0.09209, 0.09211, 0.09213, 0.09215, 0.09217,
    0.09219, 0.09221, 0.09223, 0.09225, 0.09227, 0.09229, 0.09231,
    0.09232, 0.09234, 0.09236, 0.09238, 0.0924, 0.09242, 0.09244,
    0.09246, 0.09248, 0.0925, 0.09252, 0.09254, 0.09256, 0.09258,
    0.0926, 0.09262, 0.09263, 0.09265, 0.09267, 0.09269, 0.09271,
    0.09273, 0.09275, 0.09277, 0.09279, 0.09281, 0.09283, 0.09285,
    0.09287, 0.09289, 0.09291, 0.09292, 0.09294, 0.09296, 0.09298,
    0.093, 0.09302, 0.09304, 0.09306, 0.09308, 0.0931, 0.09312,
    0.09314, 0.09316, 0.09318, 0.0932, 0.09321, 0.09323, 0.09325,
    0.09327, 0.09329, 0.09331, 0.09333, 0.09335, 0.09337, 0.09339,
    0.09341, 0.09343, 0.09345, 0.09346, 0.09348, 0.0935, 0.09352,
    0.09354, 0.09356, 0.09358, 0.0936, 0.09362, 0.09364, 0.09366,
    0.09368, 0.09369, 0.09371, 0.09373, 0.09375, 0.09377, 0.09379,
    0.09381, 0.09383, 0.09385, 0.09387, 0.09388, 0.0939, 0.09392,
    0.09394, 0.09396, 0.09398, 0.094, 0.09402, 0.09404, 0.09406,
    0.09407, 0.09409, 0.09411, 0.09413, 0.09415, 0.09417, 0.09419,
    0.09421, 0.09422, 0.09424, 0.09426, 0.09428, 0.0943, 0.09432,
    0.09434, 0.09436, 0.09437, 0.09439, 0.09441, 0.09443, 0.09445,
    0.09447, 0.09449, 0.0945, 0.09452, 0.09454, 0.09456, 0.09458,
    0.0946, 0.09461, 0.09463, 0.09465, 0.09467, 0.09469, 0.09471,
    0.09472, 0.09474, 0.09476, 0.09478, 0.0948, 0.09481, 0.09483,
    0.09485, 0.09487, 0.09489, 0.09491, 0.09492, 0.09494, 0.09496,
    0.09498, 0.095, 0.09501, 0.09503, 0.09505, 0.09507, 0.09508,
    0.0951, 0.09512, 0.09514, 0.09516, 0.09517, 0.09519, 0.09521,
    0.09523, 0.09524, 0.09526, 0.09528, 0.0953, 0.09531, 0.09533,
    0.09535, 0.09537, 0.09538, 0.0954, 0.09542, 0.09544, 0.09545,
    0.09547, 0.09549, 0.0955, 0.09552, 0.09554, 0.09556, 0.09557,
    0.09559, 0.09561, 0.09562, 0.09564, 0.09566, 0.09567, 0.09569,
    0.09571, 0.09573, 0.09574, 0.09576, 0.09578, 0.09579, 0.09581,
    0.09583, 0.09584, 0.09586, 0.09588, 0.09589, 0.09591, 0.09593,
    0.09594, 0.09596, 0.09597, 0.09599, 0.09601, 0.09602, 0.09604,
    0.09606, 0.09607, 0.09609, 0.0961, 0.09612, 0.09614, 0.09615,
    0.09617, 0.09618, 0.0962, 0.09622, 0.09623, 0.09625, 0.09626,
    0.09628, 0.0963, 0.09631, 0.09633, 0.09634, 0.09636, 0.09637,
    0.09639, 0.09641, 0.09642, 0.09644, 0.09645, 0.09647, 0.09648,
    0.0965, 0.09651, 0.09653, 0.09654, 0.09656, 0.09657, 0.09659,
    0.0966, 0.09662, 0.09663, 0.09665, 0.09666, 0.09668, 0.09669,
    0.09671, 0.09672, 0.09674, 0.09675, 0.09677, 0.09678, 0.0968,
    0.09681, 0.09683, 0.09684, 0.09686, 0.09687, 0.09688, 0.0969,
    0.09691, 0.09693, 0.09694, 0.09696, 0.09697, 0.09699, 0.097,
    0.09701, 0.09703, 0.09704, 0.09706, 0.09707, 0.09708, 0.0971,
    0.09711, 0.09713, 0.09714, 0.09715, 0.09717, 0.09718, 0.0972,
    0.09721, 0.09722, 0.09724, 0.09725, 0.09726, 0.09728, 0.09729,
    0.0973, 0.09732, 0.09733, 0.09734, 0.09736, 0.09737, 0.09739,
    0.0974, 0.09741, 0.09743, 0.09744, 0.09745, 0.09746, 0.09748,
    0.09749, 0.0975, 0.09752, 0.09753, 0.09754, 0.09756, 0.09757,
    0.09758, 0.0976, 0.09761, 0.09762, 0.09763, 0.09765, 0.09766,
    0.09767, 0.09769, 0.0977, 0.09771, 0.09772, 0.09774, 0.09775,
    0.09776, 0.09777, 0.09779, 0.0978, 0.09781, 0.09782, 0.09784,
    0.09785, 0.09786, 0.09787, 0.09789, 0.0979, 0.09791, 0.09792,
    0.09794, 0.09795, 0.09796, 0.09797, 0.09799, 0.098, 0.09801,
    0.09802, 0.09803, 0.09805, 0.09806, 0.09807, 0.09808, 0.0981,
    0.09811, 0.09812, 0.09813, 0.09814, 0.09816, 0.09817, 0.09818,
    0.09819, 0.0982, 0.09822, 0.09823, 0.09824, 0.09825, 0.09692,
    0.09738, 0.09783, 0.09829, 0.09875, 0.0992, 0.09966, 0.10012,
    0.10058, 0.10104, 0.10149, 0.10195, 0.10241, 0.10287, 0.10333,
    0.10379, 0.10425, 0.10471, 0.10517, 0.10562, 0.10608, 0.10654,
    0.107, 0.10746, 0.10792, 0.10837, 0.10883, 0.10929, 0.10974,
    0.1102, 0.11065, 0.1111, 0.11156, 0.11201, 0.11246, 0.11291,
    0.11335, 0.1138, 0.11424, 0.11469, 0.11513, 0.11557, 0.11601,
    0.11644, 0.11688, 0.11731, 0.11774, 0.11816, 0.11859, 0.11901,
    0.11943, 0.11985, 0.12026, 0.12067, 0.12108, 0.12148, 0.12188,
    0.12228, 0.12268, 0.12307, 0.12346, 0.12384, 0.12422, 0.1246,
    0.12497, 0.12534, 0.12571, 0.12607, 0.12643, 0.12678, 0.12713,
    0.12748, 0.12782, 0.12816, 0.12849, 0.12882, 0.12914, 0.12946,
    0.12978, 0.13009, 0.1304, 0.1307, 0.13099, 0.13129, 0.13158,
    0.13186, 0.13214, 0.13241, 0.13268, 0.13295, 0.13321, 0.13347,
    0.13372, 0.13397, 0.13421, 0.13445, 0.13469, 0.13492, 0.13514,
    0.13537, 0.13559, 0.1358, 0.13601, 0.13622, 0.13642, 0.13662,
    0.13681, 0.137, 0.13719, 0.13738, 0.13756, 0.13774, 0.13791,
    0.13808, 0.13825, 0.13841, 0.13858, 0.13873, 0.13889, 0.13904,
    0.1392, 0.13934, 0.13949, 0.13963, 0.13977, 0.13991, 0.14005,
    0.14018, 0.14031, 0.14044, 0.14057, 0.1407, 0.14082, 0.14094,
    0.14106, 0.14118, 0.1413, 0.14142, 0.14153, 0.14164, 0.14176,
    0.14187, 0.14198, 0.14208, 0.14219, 0.1423, 0.1424, 0.1425,
    0.14261, 0.14271, 0.14281, 0.14291, 0.14301, 0.14311, 0.1432,
    0.1433, 0.1434, 0.14349, 0.14359, 0.14368, 0.14377, 0.14386,
    0.14396, 0.14405, 0.14414, 0.14423, 0.14432, 0.14441, 0.14441,
    0.03686, 0.03656, 0.03625, 0.03595, 0.03564, 0.03533, 0.03503,
    0.03472, 0.03441, 0.03411, 0.0338, 0.0335, 0.03319, 0.03288,
    0.03258, 0.03248, 0.03239, 0.0323, 0.03221, 0.03213, 0.03205,
    0.03197, 0.03189, 0.03182, 0.03175, 0.03168, 0.03161, 0.03154,
    0.03148, 0.03141, 0.03135, 0.03129, 0.03123, 0.03118, 0.03112,
    0.03107, 0.03101, 0.03096, 0.03091, 0.03086, 0.03081, 0.03076,
    0.03072, 0.03067, 0.03062, 0.03058, 0.03054, 0.03049, 0.03045,
    0.03041, 0.03037, 0.03033, 0.03029, 0.03025, 0.03021, 0.03018,
    0.03014, 0.0301, 0.03007, 0.03003, 0.03, 0.02997, 0.02993,
    0.0299, 0.02987, 0.02984, 0.02981, 0.02978, 0.02975, 0.02972,
    0.02969, 0.02966, 0.02963, 0.02961, 0.02958, 0.02955, 0.02953,
    0.0295, 0.02948, 0.02945, 0.02943, 0.0294, 0.02938, 0.02936,
    0.02933, 0.02931, 0.02929, 0.02927, 0.02925, 0.02922, 0.0292,
    0.02918, 0.02916, 0.02914, 0.02912, 0.0291, 0.02908, 0.02907,
    0.02905, 0.02903, 0.02901, 0.02899, 0.02898, 0.02896, 0.02894,
    0.02893, 0.02891, 0.02889, 0.02888, 0.02886, 0.02885, 0.02883,
    0.02882, 0.0288, 0.02879, 0.02877, 0.02876, 0.02875, 0.02873,
    0.02872, 0.02871, 0.02869, 0.02868, 0.02867, 0.02865, 0.02864,
    0.02863, 0.02862, 0.02861, 0.02859, 0.02858, 0.02857, 0.02856,
    0.02855, 0.02854, 0.02853, 0.02852, 0.02851, 0.0285, 0.02849,
    0.02848, 0.02847, 0.02846, 0.02845, 0.02844, 0.02843, 0.02842,
    0.02841, 0.0284, 0.02839, 0.02839, 0.02838, 0.02837, 0.02836,
    0.02835, 0.02835, 0.02834, 0.02833, 0.02832, 0.02832, 0.02831,
    0.0283, 0.02829, 0.02829, 0.02828, 0.02827, 0.02827, 0.02826,
    0.02825, 0.02825, 0.02824, 0.02823, 0.02823, 0.02822, 0.02822,
    0.02821, 0.0282, 0.0282, 0.02819, 0.02819, 0.02818, 0.02818,
    0.02817, 0.02817, 0.02816, 0.02816, 0.02815, 0.02815, 0.02814,
    0.02814, 0.02813, 0.02813, 0.02812, 0.02812, 0.02811, 0.02811,
    0.0281, 0.0281, 0.0281, 0.02809, 0.02809, 0.02808, 0.02808,
    0.02808, 0.02807, 0.02807, 0.02807, 0.02806, 0.02806, 0.02806,
    0.02805, 0.02805, 0.02805, 0.02804, 0.02804, 0.02804, 0.02803,
    0.02803, 0.02803, 0.02802, 0.02802, 0.02802, 0.02801, 0.02801,
    0.02801, 0.02801, 0.028, 0.028, 0.028, 0.028, 0.02799, 0.02799,
    0.02799, 0.02799, 0.02798, 0.02798, 0.02798, 0.02798, 0.02798,
    0.02797, 0.02797, 0.02797, 0.02797, 0.02797, 0.02796, 0.02796,
    0.02796, 0.02796, 0.02796, 0.02795, 0.02795, 0.02795, 0.02795,
    0.02795, 0.02795, 0.02794, 0.02794, 0.02794, 0.02794, 0.02794,
    0.02794, 0.02794, 0.02793, 0.02793, 0.02793, 0.02793, 0.02793,
    0.02793, 0.02793, 0.02793, 0.02792, 0.02792, 0.02792, 0.02792,
    0.02792, 0.02792, 0.02792, 0.02792, 0.02792, 0.02791, 0.02791,
    0.02791, 0.02791, 0.02791, 0.02791, 0.02791, 0.02791, 0.02791,
    0.02791, 0.02791, 0.02791, 0.0279, 0.0279, 0.0279, 0.0279,
    0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279,
    0.0279, 0.0279, 0.0279, 0.0279, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02788, 0.02788, 0.02788, 0.02788,
    0.02788, 0.02788, 0.02788, 0.02788, 0.02788, 0.02788, 0.02788,
    0.02788, 0.02788, 0.02788, 0.02788, 0.02788, 0.02788, 0.02788,
    0.02788, 0.02788, 0.02788, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789, 0.02789,
    0.02789, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279,
    0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279,
    0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279, 0.0279,
    0.0279, 0.02791, 0.02791, 0.02791, 0.02791, 0.02791, 0.02791,
    0.02791, 0.02791, 0.02791, 0.02791, 0.02791, 0.02791, 0.02791,
    0.02791, 0.02791, 0.02791, 0.02791, 0.02791, 0.02792, 0.02792,
    0.02792, 0.02792, 0.02792, 0.02792, 0.02792, 0.02792, 0.02792,
    0.02792, 0.02792, 0.02792, 0.02792, 0.02792, 0.02792, 0.02792,
    0.02793, 0.02793, 0.02793, 0.02793, 0.02793, 0.02793, 0.02793,
    0.02793, 0.02793, 0.02793, 0.02793, 0.02793, 0.02793, 0.02793,
    0.02794, 0.02794, 0.02794, 0.02794, 0.02794, 0.02794, 0.02794,
    0.02794, 0.02794, 0.02794, 0.02794, 0.02794, 0.02794, 0.02795,
    0.02795, 0.02795, 0.02795, 0.02795, 0.02795, 0.02795, 0.02795,
    0.02795, 0.02795, 0.02795, 0.02795, 0.02795, 0.02796, 0.02796,
    0.02796, 0.02796, 0.02796, 0.02796, 0.02796, 0.02796, 0.02796,
    0.02796, 0.02796, 0.02796, 0.02797, 0.02797, 0.02797, 0.02797,
    0.02797, 0.02797, 0.02797, 0.02797, 0.02797, 0.02797, 0.02797,
    0.02797, 0.02798, 0.02798, 0.02798, 0.02798, 0.02798, 0.02798,
    0.02798, 0.02798, 0.02798, 0.02798, 0.02798, 0.02799, 0.02799,
    0.02799, 0.02799, 0.02799, 0.02799, 0.02799, 0.02799, 0.02799,
    0.02799, 0.028, 0.028, 0.028, 0.028, 0.028, 0.028, 0.028,
    0.028, 0.028, 0.028, 0.028, 0.02801, 0.02801, 0.02801, 0.02801,
    0.02801, 0.02801, 0.02801, 0.02801, 0.02801, 0.02801, 0.02802,
    0.02802, 0.02802, 0.02802, 0.02802, 0.02802, 0.02802, 0.02802,
    0.02802, 0.02802, 0.02803, 0.02803, 0.02803, 0.02803, 0.02803,
    0.02803, 0.02803, 0.02803, 0.02803, 0.02804, 0.02804, 0.02804,
    0.02804, 0.02804, 0.02804, 0.02804, 0.02804, 0.02804, 0.02805,
    0.02805, 0.02805, 0.02805, 0.02805, 0.02805, 0.02805, 0.02805,
    0.02805, 0.02805, 0.02806, 0.02806, 0.02806, 0.02806, 0.02806,
    0.02806, 0.02806, 0.02806, 0.02806, 0.02807, 0.02807, 0.02807,
    0.02807, 0.02807, 0.02807, 0.02807, 0.02807, 0.02808, 0.02808,
    0.02808, 0.02808, 0.02808, 0.02808, 0.02808, 0.02808, 0.02808,
    0.02809, 0.02809, 0.02809, 0.02809, 0.02809, 0.02809, 0.02809,
    0.02809, 0.0281, 0.0281, 0.0281, 0.0281, 0.0281, 0.0281,
    0.0281, 0.0281, 0.0281, 0.02811, 0.02811, 0.02811, 0.02811,
    0.02811, 0.02811, 0.02811, 0.02811, 0.02812, 0.02812, 0.02812,
    0.02812, 0.02812, 0.02812, 0.02812, 0.02812, 0.02813, 0.02813,
    0.02813, 0.02813, 0.02813, 0.02813, 0.02813, 0.02813, 0.02814,
    0.02814, 0.02814, 0.02814, 0.02814, 0.02814, 0.02814, 0.02814,
    0.02815, 0.02815, 0.02815, 0.02815, 0.02815, 0.02815, 0.02815,
    0.02815, 0.02816, 0.02816, 0.02816, 0.02816, 0.02816, 0.02816,
    0.02816, 0.02816, 0.02817, 0.02817, 0.02817, 0.02817, 0.02817,
    0.02817, 0.02817, 0.02817, 0.02818, 0.02818, 0.02818, 0.02818,
    0.02818, 0.02818, 0.02818, 0.02819, 0.02819, 0.02819, 0.02819,
    0.02819, 0.02819, 0.02819, 0.02819, 0.0282, 0.0282, 0.0282,
    0.0282, 0.0282, 0.0282, 0.0282, 0.0282, 0.02821, 0.02821,
    0.02821, 0.02821, 0.02821, 0.02821, 0.02821, 0.02822, 0.02822,
    0.02822, 0.02822, 0.02822, 0.02822, 0.02822, 0.02823, 0.02823,
    0.02823, 0.02823, 0.02823, 0.02823, 0.02823, 0.02823, 0.02824,
    0.02824, 0.02824, 0.02824, 0.02824, 0.02824, 0.02824, 0.02825,
    0.02825, 0.02825, 0.02825, 0.02825, 0.02825, 0.02825, 0.02825,
    0.02826, 0.02826, 0.02826, 0.02826, 0.02826, 0.02826, 0.02826,
    0.02827, 0.02827, 0.02827, 0.02827, 0.02827, 0.02827, 0.02827,
    0.02828, 0.02828, 0.02828, 0.02828, 0.02828, 0.02828, 0.02828,
    0.02829, 0.02829, 0.02829, 0.02829, 0.02829, 0.02829, 0.02829,
    0.02829, 0.0283, 0.0283, 0.0283, 0.0283, 0.0283, 0.0283,
    0.0283, 0.02831, 0.02831, 0.02831, 0.02831, 0.02831, 0.02831,
    0.02831, 0.02832, 0.02832, 0.02832, 0.02832, 0.02832, 0.02832,
    0.02832, 0.02833, 0.02833, 0.02833, 0.02833, 0.02833, 0.02833,
    0.02833, 0.02834, 0.02834, 0.02834, 0.02834, 0.02834, 0.02834,
    0.02834, 0.02835, 0.02835, 0.02835, 0.02835, 0.02835, 0.02835,
    0.02835, 0.02835, 0.02836, 0.02836, 0.02836, 0.02836, 0.02836,
    0.02836, 0.02836, 0.02837, 0.02837, 0.02837, 0.02837, 0.02837,
    0.02837, 0.02837, 0.02838, 0.02838, 0.02838, 0.02838, 0.02838,
    0.02838, 0.02838, 0.02839, 0.02839, 0.02839, 0.02839, 0.02839,
    0.02839, 0.02839, 0.0284, 0.0284, 0.0284, 0.0284, 0.0284,
    0.0284, 0.0284, 0.02841, 0.02841, 0.02841, 0.02841, 0.02841,
    0.02841, 0.02841, 0.02842, 0.02842, 0.02842, 0.02842, 0.02842,
    0.02842, 0.02842, 0.02843, 0.02843, 0.02843, 0.02843, 0.02843,
    0.02843, 0.02843, 0.02843, 0.02844, 0.02844, 0.02844, 0.02844,
    0.02844, 0.02844, 0.02844, 0.02845, 0.02845, 0.02845, 0.02845,
    0.02845, 0.02845, 0.02845, 0.02846, 0.02846, 0.02846, 0.02846,
    0.02846, 0.02846, 0.02846, 0.02847, 0.02847, 0.02847, 0.02847,
    0.02847, 0.02847, 0.02847, 0.02848, 0.02848, 0.02848, 0.02848,
    0.02848, 0.02848, 0.02848, 0.02848, 0.02849, 0.02849, 0.02849,
    0.02849, 0.02849, 0.02849, 0.02849, 0.0285, 0.0285, 0.0285,
    0.0285, 0.0285, 0.0285, 0.0285, 0.02851, 0.02851, 0.02851,
    0.02851, 0.02851, 0.02851, 0.02851, 0.02852, 0.02852, 0.02852,
    0.02852, 0.02852, 0.02852, 0.02852, 0.02852, 0.02853, 0.02853,
    0.02853, 0.02853, 0.02853, 0.02853, 0.02853, 0.02854, 0.02854,
    0.02854, 0.02854, 0.02854, 0.02854, 0.02854, 0.02854, 0.02855,
    0.02855, 0.02855, 0.02855, 0.02855, 0.02855, 0.02855, 0.02856,
    0.02856, 0.02856, 0.02856, 0.02856, 0.02856, 0.02856, 0.02857,
    0.02857, 0.02857, 0.02857, 0.02857, 0.02857, 0.02857, 0.02857,
    0.02858, 0.02858, 0.02858, 0.02858, 0.02858, 0.02858, 0.02858,
    0.02859, 0.02859, 0.02859, 0.02859, 0.02859, 0.02859, 0.02859,
    0.02859, 0.0286, 0.0286, 0.0286, 0.0286, 0.0286, 0.0286,
    0.0286, 0.02861, 0.02861, 0.02861, 0.02861, 0.02861, 0.02861,
    0.02861, 0.02861, 0.02862, 0.02862, 0.02862, 0.02862, 0.02862,
    0.02862, 0.02862, 0.02862, 0.02863, 0.02863, 0.02863, 0.02863,
    0.02863, 0.02863, 0.02863, 0.02864, 0.02864, 0.02864, 0.02864,
    0.02864, 0.02864, 0.02864, 0.02864, 0.02865, 0.02865, 0.02865,
    0.02865, 0.02865, 0.02865, 0.02865, 0.02865, 0.02866, 0.02866,
    0.02866, 0.02866, 0.02866, 0.02866, 0.02866, 0.02867, 0.02867,
    0.02867, 0.02867, 0.02867, 0.02867, 0.02867, 0.02867, 0.02868,
    0.02868, 0.02868, 0.02868, 0.02868, 0.02868, 0.02868, 0.02868,
    0.02869, 0.02869, 0.02869, 0.02869, 0.02869, 0.02869, 0.02869,
    0.02869, 0.0287, 0.0287, 0.0287, 0.0287, 0.0287, 0.0287,
    0.0287, 0.0287, 0.02871, 0.02871, 0.02871, 0.02871, 0.02871,
    0.02871, 0.02871, 0.02871, 0.02872, 0.02872, 0.02872, 0.02872,
    0.02872, 0.02872, 0.02872, 0.02872, 0.02873, 0.02873, 0.02873,
    0.02873, 0.02873, 0.02873, 0.02873, 0.02873, 0.02874, 0.02874,
    0.02874, 0.02874, 0.02874, 0.02874, 0.02874, 0.02874, 0.02875,
    0.02875, 0.02875, 0.02875, 0.02875, 0.02875, 0.02875, 0.02875,
    0.02876, 0.02876, 0.02876, 0.02876, 0.02876, 0.02876, 0.02876,
    0.02876, 0.02877, 0.02877, 0.02877, 0.02877, 0.02877, 0.02877,
    0.02877, 0.02877, 0.02878, 0.02878, 0.02878, 0.02878, 0.02878,
    0.02878, 0.02878, 0.02878, 0.02878, 0.02879, 0.02879, 0.02879,
    0.02879, 0.02879, 0.02879, 0.02879, 0.02879, 0.0288, 0.0288,
    0.0288, 0.0288, 0.0288, 0.0288, 0.0288, 0.0288, 0.02881,
    0.02881, 0.02881, 0.02881, 0.02881, 0.02881, 0.02881, 0.02881,
    0.02882, 0.02882, 0.02882, 0.02882, 0.02882, 0.02882, 0.02882,
    0.02882, 0.02882, 0.02883, 0.02883, 0.02883, 0.02883, 0.02883,
    0.02883, 0.02883, 0.02883, 0.02884, 0.02884, 0.02884, 0.02884,
    0.02884, 0.02884, 0.02884, 0.02884, 0.02884, 0.02885, 0.02885,
    0.02885, 0.02885, 0.02885, 0.02885, 0.02885, 0.02885, 0.02886,
    0.02886, 0.02886, 0.02886, 0.02886, 0.02886, 0.02886, 0.02886,
    0.02886, 0.02887, 0.02887, 0.02887, 0.02887, 0.02887, 0.02887,
    0.02887, 0.02887, 0.02887, 0.02888, 0.02888, 0.02888, 0.02888,
    0.02888, 0.02888, 0.02888, 0.02888, 0.02889, 0.02889, 0.02889,
    0.02889, 0.02889, 0.02889, 0.02889, 0.02889, 0.02889, 0.0289,
    0.0289, 0.0289, 0.0289, 0.0289, 0.0289, 0.0289, 0.0289, 0.0289,
    0.02891, 0.02891, 0.02891, 0.02891, 0.02891, 0.02891, 0.02891,
    0.02891, 0.02891, 0.02892, 0.02892, 0.02892, 0.02892, 0.02892,
    0.02892, 0.02892, 0.02892, 0.02892, 0.02893, 0.02893, 0.02893,
    0.02893, 0.02893, 0.02893, 0.02893, 0.02893, 0.02893, 0.02894,
    0.02894, 0.02894, 0.02894, 0.02894, 0.02894, 0.02894, 0.02894,
    0.02894, 0.02895, 0.02895, 0.02895, 0.02895, 0.02895, 0.02895,
    0.02895, 0.02895, 0.02895, 0.02896, 0.02896, 0.02896, 0.02896,
    0.02896, 0.02896, 0.02896, 0.02896, 0.02896, 0.02897, 0.02897,
    0.02897, 0.02897, 0.02897, 0.02897, 0.02897, 0.02897, 0.02897,
    0.02898, 0.02898, 0.02898, 0.02898, 0.02898, 0.02898, 0.02898,
    0.02898, 0.02898, 0.02899, 0.02899, 0.02899, 0.02899, 0.02899,
    0.02899, 0.02899, 0.02899, 0.02899, 0.029, 0.029, 0.029,
    0.029, 0.029, 0.029, 0.029, 0.029, 0.029, 0.029, 0.02901,
    0.02901, 0.02901, 0.02901, 0.02901, 0.02901, 0.02901, 0.02901,
    0.02901, 0.02902, 0.02902, 0.02902, 0.02902, 0.02902, 0.02902,
    0.02902, 0.02902, 0.02902, 0.02903, 0.02903, 0.02903, 0.02903,
    0.02903, 0.02903, 0.02903, 0.02903, 0.02903, 0.02903, 0.02904,
    0.02904, 0.02904, 0.02904, 0.02904, 0.02904, 0.02904, 0.02904,
    0.02904, 0.02905, 0.02905, 0.02905, 0.02905, 0.02905, 0.02905,
    0.02905, 0.02905, 0.02905, 0.02905, 0.02906, 0.02906, 0.02906,
    0.02906, 0.02906, 0.02906, 0.02906, 0.02906, 0.02906, 0.02906,
    0.02907, 0.02907, 0.02907, 0.02907, 0.02907, 0.02907, 0.02907,
    0.02907, 0.02907, 0.02908, 0.02908, 0.02908, 0.02908, 0.02908,
    0.02908, 0.02908, 0.02908, 0.02908, 0.02908, 0.02909, 0.02909,
    0.02909, 0.02909, 0.02909, 0.02909, 0.02909, 0.02909, 0.02909,
    0.02909, 0.0291, 0.0291, 0.0291, 0.0291, 0.0291, 0.0291,
    0.0291, 0.0291, 0.0291, 0.0291, 0.02911, 0.02911, 0.02911,
    0.02911, 0.02911, 0.02911, 0.02911, 0.02911, 0.02911, 0.02912,
    0.02912, 0.02912, 0.02912, 0.02912, 0.02912, 0.02912, 0.02912,
    0.02912, 0.02912, 0.02913, 0.02913, 0.02913, 0.02913, 0.02913,
    0.02913, 0.02913, 0.02913, 0.02913, 0.02913, 0.02914, 0.02914,
    0.02914, 0.02914, 0.02914, 0.02914, 0.02914, 0.02914, 0.02914,
    0.02914, 0.02914, 0.02915, 0.02915, 0.02915, 0.02915, 0.02915,
    0.02915, 0.02915, 0.02915, 0.02915, 0.02915, 0.02916, 0.02916,
    0.02916, 0.02916, 0.02916, 0.02916, 0.02916, 0.02916, 0.02916,
    0.02916, 0.02917, 0.02917, 0.02917, 0.02917, 0.02917, 0.02917,
    0.02917, 0.02917, 0.02917, 0.02917, 0.02918, 0.02918, 0.02918,
    0.02918, 0.02918, 0.02918, 0.02918, 0.02918, 0.02918, 0.02918,
    0.02919, 0.02919, 0.02919, 0.02919, 0.02919, 0.02919, 0.02919,
    0.02919, 0.02919, 0.02919, 0.02919, 0.0292, 0.0292, 0.0292,
    0.0292, 0.0292, 0.0292, 0.0292, 0.0292, 0.0292, 0.0292, 0.02921,
    0.02921, 0.02921, 0.02921, 0.02921, 0.02921, 0.02921, 0.02921,
    0.02921, 0.02921, 0.02921, 0.02922, 0.02922, 0.02922, 0.02922,
    0.02922, 0.02922, 0.02922, 0.02922, 0.02922, 0.02922, 0.02923,
    0.02923, 0.02923, 0.02923, 0.02923, 0.02923, 0.02923, 0.02923,
    0.02923, 0.02923, 0.02923, 0.02924, 0.02924, 0.02924, 0.02924,
    0.02924, 0.02924, 0.02924, 0.02924, 0.02924, 0.02924, 0.02925,
    0.02925, 0.02925, 0.02925, 0.02925, 0.02925, 0.02925, 0.02925,
    0.02925, 0.02925, 0.02925, 0.02926, 0.02926, 0.02926, 0.02926,
    0.02926, 0.02926, 0.02926, 0.02926, 0.02926, 0.02926, 0.02926,
    0.02927, 0.02927, 0.02927, 0.02927, 0.02927, 0.02927, 0.02927,
    0.02927, 0.02927, 0.02927, 0.02927, 0.02928, 0.02928, 0.02928,
    0.02928, 0.02928, 0.02928, 0.02928, 0.02928, 0.02928, 0.02928,
    0.02929, 0.02929, 0.02929, 0.02929, 0.02929, 0.02929, 0.02929,
    0.02929, 0.02929, 0.02929, 0.02929, 0.0293, 0.0293, 0.0293,
    0.0293, 0.0293, 0.0293, 0.0293, 0.0293, 0.0293, 0.0293, 0.0293,
    0.02931, 0.02931, 0.02931, 0.02931, 0.02931, 0.02931, 0.02931,
    0.02931, 0.02931, 0.02931, 0.02931, 0.02932, 0.02932, 0.02932,
    0.02932, 0.02932, 0.02932, 0.02932, 0.02932, 0.02932, 0.02932,
    0.02932, 0.02933, 0.02933, 0.02933, 0.02933, 0.02933, 0.02933,
    0.02933, 0.02933, 0.02933, 0.02933, 0.02933, 0.02933, 0.02934,
    0.02934, 0.02934, 0.02934, 0.02934, 0.02934, 0.02934, 0.02934,
    0.02934, 0.02934, 0.02934, 0.02935, 0.02935, 0.02935, 0.02935,
    0.02935, 0.02935, 0.02935, 0.02935, 0.02935, 0.02935, 0.02935,
    0.02936, 0.02936, 0.02936, 0.02936, 0.02936, 0.02936, 0.02936,
    0.02936, 0.02936, 0.02936, 0.02936, 0.02937, 0.02937, 0.02937,
    0.02937, 0.02937, 0.02937, 0.02937, 0.02937, 0.02937, 0.02937,
    0.02937, 0.02937, 0.02938, 0.02938, 0.02938, 0.02938, 0.02938,
    0.02938, 0.02938, 0.02938, 0.02938, 0.02938, 0.02938, 0.02939,
    0.02939, 0.02939, 0.02939, 0.02939, 0.02939, 0.02939, 0.02939,
    0.02939, 0.02939, 0.02939, 0.0294, 0.0294, 0.0294, 0.0294,
    0.0294, 0.0294, 0.0294, 0.0294, 0.0294, 0.0294, 0.0294, 0.0294,
    0.02941, 0.02941, 0.02941, 0.02941, 0.02941, 0.02941, 0.02941,
    0.02941, 0.02941, 0.02941, 0.02941, 0.02941, 0.02942, 0.02942,
    0.02942, 0.02942, 0.02942, 0.02942, 0.02942, 0.02942, 0.02942,
    0.02942, 0.02942, 0.02943, 0.02943, 0.02943, 0.02943, 0.02943,
    0.02943, 0.02943, 0.02943, 0.02943, 0.02943, 0.02943, 0.02943,
    0.02944, 0.02944, 0.02944, 0.02944, 0.02944, 0.02944, 0.02944,
    0.02944, 0.02944, 0.02944, 0.02944, 0.02944, 0.02945, 0.02945,
    0.02945, 0.02945, 0.02945, 0.02945, 0.02945, 0.02945, 0.02945,
    0.02945, 0.02945, 0.02945, 0.02946, 0.02946, 0.02946, 0.02946,
    0.02946, 0.02946, 0.02946, 0.02946, 0.02946, 0.02946, 0.02946,
    0.02947, 0.02947, 0.02947, 0.02947, 0.02947, 0.02947, 0.02947,
    0.02947, 0.02947, 0.02947, 0.02947, 0.02947, 0.02948, 0.02948,
    0.02948, 0.02948, 0.02948, 0.02948, 0.02948, 0.03496, 0.03479,
    0.03461, 0.03444, 0.03426, 0.03409, 0.03391, 0.03374, 0.03356,
    0.03339, 0.03321, 0.03304, 0.03286, 0.03269, 0.03251, 0.03248,
    0.03245, 0.03242, 0.03239, 0.03236, 0.03233, 0.03231, 0.03228,
    0.03226, 0.03223, 0.03221, 0.03219, 0.03217, 0.03215, 0.03213,
    0.03211, 0.03209, 0.03207, 0.03206, 0.03204, 0.03202, 0.032,
    0.03199, 0.03197, 0.03196, 0.03194, 0.03193, 0.03191, 0.0319,
    0.03188, 0.03187, 0.03186, 0.03184, 0.03183, 0.03182, 0.0318,
    0.03179, 0.03178, 0.03177, 0.03176, 0.03174, 0.03173, 0.03172,
    0.03171, 0.0317, 0.03169, 0.03168, 0.03167, 0.03166, 0.03164,
    0.03163, 0.03162, 0.03161, 0.0316, 0.03159, 0.03158, 0.03158,
    0.03157, 0.03156, 0.03155, 0.03154, 0.03153, 0.03152, 0.03151,
    0.0315, 0.03149, 0.03149, 0.03148, 0.03147, 0.03146, 0.03145,
    0.03144, 0.03144, 0.03143, 0.03142, 0.03141, 0.0314, 0.0314,
    0.03139, 0.03138, 0.03137, 0.03137, 0.03136, 0.03135, 0.03134,
    0.03134, 0.03133, 0.03132, 0.03131, 0.03131, 0.0313, 0.03129,
    0.03129, 0.03128, 0.03127, 0.03127, 0.03126, 0.03125, 0.03125,
    0.03124, 0.03123, 0.03123, 0.03122, 0.03121, 0.03121, 0.0312,
    0.0312, 0.03119, 0.03118, 0.03118, 0.03117, 0.03117, 0.03116,
    0.03115, 0.03115, 0.03114, 0.03114, 0.03113, 0.03112, 0.03112,
    0.03111, 0.03111, 0.0311, 0.0311, 0.03109, 0.03108, 0.03108,
    0.03107, 0.03107, 0.03106, 0.03106, 0.03105, 0.03105, 0.03104,
    0.03104, 0.03103, 0.03103, 0.03102, 0.03102, 0.03101, 0.03101,
    0.031, 0.03099, 0.03099, 0.03098, 0.03098, 0.03098, 0.03097,
    0.03097, 0.03096, 0.03096, 0.03095, 0.03095, 0.03094, 0.03094,
    0.03093, 0.03093, 0.03092, 0.03092, 0.03091, 0.03091, 0.0309,
    0.0309, 0.03089, 0.03089, 0.03089, 0.03088, 0.03088, 0.03087,
    0.03087, 0.03086, 0.03086, 0.03085, 0.03085, 0.03085, 0.03084,
    0.03084, 0.03083, 0.03083, 0.03082, 0.03082, 0.03082, 0.03081,
    0.03081, 0.0308, 0.0308, 0.03079, 0.03079, 0.03079, 0.03078,
    0.03078, 0.03077, 0.03077, 0.03077, 0.03076, 0.03076, 0.03075,
    0.03075, 0.03075, 0.03074, 0.03074, 0.03073, 0.03073, 0.03073,
    0.03072, 0.03072, 0.03072, 0.03071, 0.03071, 0.0307, 0.0307,
    0.0307, 0.03069, 0.03069, 0.03069, 0.03068, 0.03068, 0.03067,
    0.03067, 0.03067, 0.03066, 0.03066, 0.03066, 0.03065, 0.03065,
    0.03065, 0.03064, 0.03064, 0.03063, 0.03063, 0.03063, 0.03062,
    0.03062, 0.03062, 0.03061, 0.03061, 0.03061, 0.0306, 0.0306,
    0.0306, 0.03059, 0.03059, 0.03059, 0.03058, 0.03058, 0.03058,
    0.03057, 0.03057, 0.03057, 0.03056, 0.03056, 0.03056, 0.03055,
    0.03055, 0.03055, 0.03054, 0.03054, 0.03054, 0.03053, 0.03053,
    0.03053, 0.03052, 0.03052, 0.03052, 0.03051, 0.03051, 0.03051,
    0.0305, 0.0305, 0.0305, 0.03049, 0.03049, 0.03049, 0.03049,
    0.03048, 0.03048, 0.03048, 0.03047, 0.03047, 0.03047, 0.03046,
    0.03046, 0.03046, 0.03045, 0.03045, 0.03045, 0.03045, 0.03044,
    0.03044, 0.03044, 0.03043, 0.03043, 0.03043, 0.03043, 0.03042,
    0.03042, 0.03042, 0.03041, 0.03041, 0.03041, 0.0304, 0.0304,
    0.0304, 0.0304, 0.03039, 0.03039, 0.03039, 0.03038, 0.03038,
    0.03038, 0.03038, 0.03037, 0.03037, 0.03037, 0.03037, 0.03036,
    0.03036, 0.03036, 0.03035, 0.03035, 0.03035, 0.03035, 0.03034,
    0.03034, 0.03034, 0.03034, 0.03033, 0.03033, 0.03033, 0.03032,
    0.03032, 0.03032, 0.03032, 0.03031, 0.03031, 0.03031, 0.03031,
    0.0303, 0.0303, 0.0303, 0.0303, 0.03029, 0.03029, 0.03029,
    0.03028, 0.03028, 0.03028, 0.03028, 0.03027, 0.03027, 0.03027,
    0.03027, 0.03026, 0.03026, 0.03026, 0.03026, 0.03025, 0.03025,
    0.03025, 0.03025, 0.03024, 0.03024, 0.03024, 0.03024, 0.03023,
    0.03023, 0.03023, 0.03023, 0.03022, 0.03022, 0.03022, 0.03022,
    0.03021, 0.03021, 0.03021, 0.03021, 0.0302, 0.0302, 0.0302,
    0.0302, 0.03019, 0.03019, 0.03019, 0.03019, 0.03019, 0.03018,
    0.03018, 0.03018, 0.03018, 0.03017, 0.03017, 0.03017, 0.03017,
    0.03016, 0.03016, 0.03016, 0.03016, 0.03015, 0.03015, 0.03015,
    0.03015, 0.03015, 0.03014, 0.03014, 0.03014, 0.03014, 0.03013,
    0.03013, 0.03013, 0.03013, 0.03013, 0.03012, 0.03012, 0.03012,
    0.03012, 0.03011, 0.03011, 0.03011, 0.03011, 0.0301, 0.0301,
    0.0301, 0.0301, 0.0301, 0.03009, 0.03009, 0.03009, 0.03009,
    0.03008, 0.03008, 0.03008, 0.03008, 0.03008, 0.03007, 0.03007,
    0.03007, 0.03007, 0.03007, 0.03006, 0.03006, 0.03006, 0.03006,
    0.03005, 0.03005, 0.03005, 0.03005, 0.03005, 0.03004, 0.03004,
    0.03004, 0.03004, 0.03004, 0.03003, 0.03003, 0.03003, 0.03003,
    0.03003, 0.03002, 0.03002, 0.03002, 0.03002, 0.03001, 0.03001,
    0.03001, 0.03001, 0.03001, 0.03, 0.03, 0.03, 0.03, 0.03,
    0.02999, 0.02999, 0.02999, 0.02999, 0.02999, 0.02998, 0.02998,
    0.02998, 0.02998, 0.02998, 0.02997, 0.02997, 0.02997, 0.02997,
    0.02997, 0.02996, 0.02996, 0.02996, 0.02996, 0.02996, 0.02995,
    0.02995, 0.02995, 0.02995, 0.02995, 0.02994, 0.02994, 0.02994,
    0.02994, 0.02994, 0.02993, 0.02993, 0.02993, 0.02993, 0.02993,
    0.02992, 0.02992, 0.02992, 0.02992, 0.02992, 0.02992, 0.02991,
    0.02991, 0.02991, 0.02991, 0.02991, 0.0299, 0.0299, 0.0299,
    0.0299, 0.0299, 0.02989, 0.02989, 0.02989, 0.02989, 0.02989,
    0.02989, 0.02988, 0.02988, 0.02988, 0.02988, 0.02988, 0.02987,
    0.02987, 0.02987, 0.02987, 0.02987, 0.02986, 0.02986, 0.02986,
    0.02986, 0.02986, 0.02986, 0.02985, 0.02985, 0.02985, 0.02985,
    0.02985, 0.02984, 0.02984, 0.02984, 0.02984, 0.02984, 0.02984,
    0.02983, 0.02983, 0.02983, 0.02983, 0.02983, 0.02983, 0.02982,
    0.02982, 0.02982, 0.02982, 0.02982, 0.02981, 0.02981, 0.02981,
    0.02981, 0.02981, 0.02981, 0.0298, 0.0298, 0.0298, 0.0298,
    0.0298, 0.0298, 0.02979, 0.02979, 0.02979, 0.02979, 0.02979,
    0.02978, 0.02978, 0.02978, 0.02978, 0.02978, 0.02978, 0.02977,
    0.02977, 0.02977, 0.02977, 0.02977, 0.02977, 0.02976, 0.02976,
    0.02976, 0.02976, 0.02976, 0.02976, 0.02975, 0.02975, 0.02975,
    0.02975, 0.02975, 0.02975, 0.02974, 0.02974, 0.02974, 0.02974,
    0.02974, 0.02974, 0.02973, 0.02973, 0.02973, 0.02973, 0.02973,
    0.02973, 0.02972, 0.02972, 0.02972, 0.02972, 0.02972, 0.02972,
    0.02971, 0.02971, 0.02971, 0.02971, 0.02971, 0.02971, 0.0297,
    0.0297, 0.0297, 0.0297, 0.0297, 0.0297, 0.0297, 0.02969,
    0.02969, 0.02969, 0.02969, 0.02969, 0.02969, 0.02968, 0.02968,
    0.02968, 0.02968, 0.02968, 0.02968, 0.02967, 0.02967, 0.02967,
    0.02967, 0.02967, 0.02967, 0.02966, 0.02966, 0.02966, 0.02966,
    0.02966, 0.02966, 0.02966, 0.02965, 0.02965, 0.02965, 0.02965,
    0.02965, 0.02965, 0.02964, 0.02964, 0.02964, 0.02964, 0.02964,
    0.02964, 0.02964, 0.02963, 0.02963, 0.02963, 0.02963, 0.02963,
    0.02963, 0.02962, 0.02962, 0.02962, 0.02962, 0.02962, 0.02962,
    0.02962, 0.02961, 0.02961, 0.02961, 0.02961, 0.02961, 0.02961,
    0.02961, 0.0296, 0.0296, 0.0296, 0.0296, 0.0296, 0.0296,
    0.02959, 0.02959, 0.02959, 0.02959, 0.02959, 0.02959, 0.02959,
    0.02958, 0.02958, 0.02958, 0.02958, 0.02958, 0.02958, 0.02958,
    0.02957, 0.02957, 0.02957, 0.02957, 0.02957, 0.02957, 0.02957,
    0.02956, 0.02956, 0.02956, 0.02956, 0.02956, 0.02956, 0.02955,
    0.02955, 0.02955, 0.02955, 0.02955, 0.02955, 0.02955, 0.02954,
    0.02954, 0.02954, 0.02954, 0.02954, 0.02954, 0.02954, 0.02953,
    0.02953, 0.02953, 0.02953, 0.02953, 0.02953, 0.02953, 0.02952,
    0.02952, 0.02952, 0.02952, 0.02952, 0.02952, 0.02952, 0.02952,
    0.02951, 0.02951, 0.02951, 0.02951, 0.02951, 0.02951, 0.02951,
    0.0295, 0.0295, 0.0295, 0.0295, 0.0295, 0.0295, 0.0295, 0.02949,
    0.02949, 0.02949, 0.02949, 0.02949, 0.02949, 0.02949, 0.02948,
    0.02948, 0.02948, 0.02948, 0.02948, 0.02948, 0.02948, 0.02947,
    0.02947, 0.02947, 0.02947, 0.02947, 0.02947, 0.02947, 0.02947,
    0.02946, 0.02946, 0.02946, 0.02946, 0.02946, 0.02946, 0.02946,
    0.02945, 0.02945, 0.02945, 0.02945, 0.02945, 0.02945, 0.02945,
    0.02945, 0.02944, 0.02944, 0.02944, 0.02944, 0.02944, 0.02944,
    0.02944, 0.02943, 0.02943, 0.02943, 0.02943, 0.02943, 0.02943,
    0.02943, 0.02943, 0.02942, 0.02942, 0.02942, 0.02942, 0.02942,
    0.02942, 0.02942, 0.02941, 0.02941, 0.02941, 0.02941, 0.02941,
    0.02941, 0.02941, 0.02941, 0.0294, 0.0294, 0.0294, 0.0294,
    0.0294, 0.0294, 0.0294, 0.0294, 0.02939, 0.02939, 0.02939,
    0.02939, 0.02939, 0.02939, 0.02939, 0.02939, 0.02938, 0.02938,
    0.02938, 0.02938, 0.02938, 0.02938, 0.02938, 0.02938, 0.02937,
    0.02937, 0.02937, 0.02937, 0.02937, 0.02937, 0.02937, 0.02937,
    0.02936, 0.02936, 0.02936, 0.02936, 0.02936, 0.02936, 0.02936,
    0.02935, 0.02935, 0.02935, 0.02935, 0.02935, 0.02935, 0.02935,
    0.02935, 0.02935, 0.02934, 0.02934, 0.02934, 0.02934, 0.02934,
    0.02934, 0.02934, 0.02934, 0.02933, 0.02933, 0.02933, 0.02933,
    0.02933, 0.02933, 0.02933, 0.02933, 0.02932, 0.02932, 0.02932,
    0.02932, 0.02932, 0.02932, 0.02932, 0.02932, 0.02931, 0.02931,
    0.02931, 0.02931, 0.02931, 0.02931, 0.02931, 0.02931, 0.0293,
    0.0293, 0.0293, 0.0293, 0.0293, 0.0293, 0.0293, 0.0293, 0.0293,
    0.02929, 0.02929, 0.02929, 0.02929, 0.02929, 0.02929, 0.02929,
    0.02929, 0.02928, 0.02928, 0.02928, 0.02928, 0.02928, 0.02928,
    0.02928, 0.02928, 0.02927, 0.02927, 0.02927, 0.02927, 0.02927,
    0.02927, 0.02927, 0.02927, 0.02927, 0.02926, 0.02926, 0.02926,
    0.02926, 0.02926, 0.02926, 0.02926, 0.02926, 0.02925, 0.02925,
    0.02925, 0.02925, 0.02925, 0.02925, 0.02925, 0.02925, 0.02925,
    0.02924, 0.02924, 0.02924, 0.02924, 0.02924, 0.02924, 0.02924,
    0.02924, 0.02924, 0.02923, 0.02923, 0.02923, 0.02923, 0.02923,
    0.02923, 0.02923, 0.02923, 0.02923, 0.02922, 0.02922, 0.02922,
    0.02922, 0.02922, 0.02922, 0.02922, 0.02922, 0.02921, 0.02921,
    0.02921, 0.02921, 0.02921, 0.02921, 0.02921, 0.02921, 0.02921,
    0.0292, 0.0292, 0.0292, 0.0292, 0.0292, 0.0292, 0.0292, 0.0292,
    0.0292, 0.02919, 0.02919, 0.02919, 0.02919, 0.02919, 0.02919,
    0.02919, 0.02919, 0.02919, 0.02918, 0.02918, 0.02918, 0.02918,
    0.02918, 0.02918, 0.02918, 0.02918, 0.02918, 0.02917, 0.02917,
    0.02917, 0.02917, 0.02917, 0.02917, 0.02917, 0.02917, 0.02917,
    0.02916, 0.02916, 0.02916, 0.02916, 0.02916, 0.02916, 0.02916,
    0.02916, 0.02916, 0.02916, 0.02915, 0.02915, 0.02915, 0.02915,
    0.02915, 0.02915, 0.02915, 0.02915, 0.02915, 0.02914, 0.02914,
    0.02914, 0.02914, 0.02914, 0.02914, 0.02914, 0.02914, 0.02914,
    0.02913, 0.02913, 0.02913, 0.02913, 0.02913, 0.02913, 0.02913,
    0.02913, 0.02913, 0.02912, 0.02912, 0.02912, 0.02912, 0.02912,
    0.02912, 0.02912, 0.02912, 0.02912, 0.02912, 0.02911, 0.02911,
    0.02911, 0.02911, 0.02911, 0.02911, 0.02911, 0.02911, 0.02911,
    0.0291, 0.0291, 0.0291, 0.0291, 0.0291, 0.0291, 0.0291, 0.0291,
    0.0291, 0.0291, 0.02909, 0.02909, 0.02909, 0.02909, 0.02909,
    0.02909, 0.02909, 0.02909, 0.02909, 0.02909, 0.02908, 0.02908,
    0.02908, 0.02908, 0.02908, 0.02908, 0.02908, 0.02908, 0.02908,
    0.02907, 0.02907, 0.02907, 0.02907, 0.02907, 0.02907, 0.02907,
    0.02907, 0.02907, 0.02907, 0.02906, 0.02906, 0.02906, 0.02906,
    0.02906, 0.02906, 0.02906, 0.02906, 0.02906, 0.02906, 0.02905,
    0.02905, 0.02905, 0.02905, 0.02905, 0.02905, 0.02905, 0.02905,
    0.02905, 0.02905, 0.02904, 0.02904, 0.02904, 0.02904, 0.02904,
    0.02904, 0.02904, 0.02904, 0.02904, 0.02904, 0.02903, 0.02903,
    0.02903, 0.02903, 0.02903, 0.02903, 0.02903, 0.02903, 0.02903,
    0.02903, 0.02902, 0.02902, 0.02902, 0.02902, 0.02902, 0.02902,
    0.02902, 0.02902, 0.02902, 0.02902, 0.02901, 0.02901, 0.02901,
    0.02901, 0.02901, 0.02901, 0.02901, 0.02901, 0.02901, 0.02901,
    0.029, 0.029, 0.029, 0.029, 0.029, 0.029, 0.029, 0.029, 0.029,
    0.029, 0.02899, 0.02899, 0.02899, 0.02899, 0.02899, 0.02899,
    0.02899, 0.02899, 0.02899, 0.02899, 0.02899, 0.02898, 0.02898,
    0.02898, 0.02898, 0.02898, 0.02898, 0.02898, 0.02898, 0.02898,
    0.02898, 0.02897, 0.02897, 0.02897, 0.02897, 0.02897, 0.02897,
    0.02897, 0.02897, 0.02897, 0.02897, 0.02897, 0.02896, 0.02896,
    0.02896, 0.02896, 0.02896, 0.02896, 0.02896, 0.02896, 0.02896,
    0.02896, 0.02895, 0.02895, 0.02895, 0.02895, 0.02895, 0.02895,
    0.02895, 0.02895, 0.02895, 0.02895, 0.02895, 0.02894, 0.02894,
    0.02894, 0.02894, 0.02894, 0.02894, 0.02894, 0.02894, 0.02894,
    0.02894, 0.02893, 0.02893, 0.02893, 0.02893, 0.02893, 0.02893,
    0.02893, 0.02893, 0.02893, 0.02893, 0.02893, 0.02892, 0.02892,
    0.02892, 0.02892, 0.02892, 0.02892, 0.02892, 0.02892, 0.02892,
    0.02892, 0.02892, 0.02891, 0.02891, 0.02891, 0.02891, 0.02891,
    0.02891, 0.02891, 0.02891, 0.02891, 0.02891, 0.02891, 0.0289,
    0.0289, 0.0289, 0.0289, 0.0289, 0.0289, 0.0289, 0.0289, 0.0289,
    0.0289, 0.0289, 0.02889, 0.02889, 0.02889, 0.02889, 0.02889,
    0.02889, 0.02889, 0.02889, 0.02889, 0.02889, 0.02889, 0.02888,
    0.02888, 0.02888, 0.02888, 0.02888, 0.02888, 0.02888, 0.02888,
    0.02888, 0.02888, 0.02888, 0.02887, 0.02887, 0.02887, 0.02887,
    0.02887, 0.02887, 0.02887, 0.02887, 0.02887, 0.02887, 0.02887,
    0.02886, 0.02886, 0.02886, 0.02886, 0.02886, 0.02886, 0.02886,
    0.02886, 0.02886, 0.02886, 0.02886, 0.02885, 0.02885, 0.02885,
    0.02885, 0.02885, 0.02885, 0.02885, 0.02885, 0.02885, 0.02885,
    0.02885, 0.02885, 0.02884, 0.02884, 0.02884, 0.02884, 0.02884,
    0.02884, 0.02884, 0.02884, 0.02884, 0.02884, 0.02884, 0.02883,
    0.02883, 0.02883, 0.02883, 0.02883, 0.02883, 0.02883, 0.02883,
    0.02883, 0.02883, 0.02883, 0.02883, 0.02882, 0.02882, 0.02882,
    0.02882, 0.02882, 0.02882, 0.02882, 0.02882, 0.02882, 0.02882,
    0.02882, 0.02881, 0.02881, 0.02881, 0.02881, 0.02881, 0.02881,
    0.02881, 0.02881, 0.02881, 0.02881, 0.02881, 0.02881, 0.0288,
    0.0288, 0.0288, 0.0288, 0.0288, 0.0288, 0.0288, 0.0288, 0.0288,
    0.0288, 0.0288, 0.0288, 0.02879, 0.02879, 0.02879, 0.02879,
    0.02879, 0.02879, 0.02879, 0.02879, 0.02879, 0.02879, 0.02879,
    0.02878, 0.02878, 0.02878, 0.02878, 0.02878, 0.02878, 0.02878,
    0.02878, 0.02878, 0.02878, 0.02878, 0.02878, 0.02877, 0.02877,
    0.02877, 0.02877, 0.02877, 0.02877, 0.02877, 0.02877, 0.02877,
    0.02877, 0.02877, 0.02877, 0.02876, 0.02876, 0.02876, 0.02876,
    0.02876, 0.02876, 0.02876, 0.02876, 0.02876, 0.02876, 0.02876,
    0.02876, 0.02875, 0.02875, 0.02875, 0.02875, 0.02875, 0.02875,
    0.02875, 0.02875, 0.02875, 0.02875, 0.02875, 0.02875, 0.02874,
    0.02874, 0.02874, 0.02874, 0.02874, 0.02874, 0.02874, 0.02874,
    0.02874, 0.02874, 0.02874, 0.02874, 0.02873, 0.02873, 0.02873,
    0.02873, 0.02873, 0.02873, 0.02873, 0.02873, 0.02873, 0.02873,
    0.02873, 0.02873, 0.02873, 0.02872, 0.02872, 0.02872, 0.02872,
    0.02872, 0.02872, 0.02872, 0.02872, 0.02872, 0.02872, 0.02872,
    0.02872, 0.02871, 0.02871, 0.02871, 0.02871, 0.02871, 0.02871,
    0.02871, 0.02871, 0.02871, 0.02871, 0.02871, 0.02871, 0.0287,
    0.0287, 0.0287, 0.0287, 0.0287, 0.0287, 0.0287, 0.0287, 0.0287,
    0.0287, 0.0287, 0.0287, 0.0287, 0.02869, 0.02869, 0.02869,
    0.02869, 0.02869, 0.02869, 0.02869, 0.02869, 0.02869, 0.02869,
    0.02869, 0.02869, 0.02868, 0.02868, 0.02868, 0.02868, 0.02868,
    0.02868, 0.02868, 0.02868, 0.02868, 0.02868, 0.02868, 0.02868,
    0.02868, 0.02867, 0.02867, 0.02867, 0.02867, 0.02867, 0.02867,
    0.02867, 0.02867, 0.02867, 0.02867, 0.02867, 0.02867, 0.02867,
    0.02866, 0.02866, 0.02866, 0.02866, 0.02866, 0.02866, 0.02866,
    0.02866, 0.02866, 0.02866, 0.02866, 0.02866, 0.02866, 0.02865,
    0.02865, 0.02865, 0.02865, 0.02865, 0.02865, 0.02865, 0.02865,
    0.02865, 0.02865, 0.02865, 0.02865, 0.02865, 0.02864, 0.02864,
    0.02864, 0.02864, 0.02864, 0.02864, 0.02864, 0.02864, 0.02864,
    0.02864, 0.02864, 0.02864, 0.02864, 0.02863, 0.02863, 0.02863,
    0.02863, 0.02863, 0.02863, 0.02863, 0.02863, 0.02863, 0.02863,
    0.02863, 0.02863, 0.02863, 0.02862, 0.02862, 0.02862, 0.02862,
    0.02862, 0.02862, 0.02862, 0.02862, 0.02862, 0.02862, 0.02862,
    0.02862, 0.02862, 0.02861, 0.02861, 0.02861, 0.02861, 0.02861,
    0.02861, 0.02861, 0.02861, 0.02861, 0.02861, 0.02861, 0.02861,
    0.02861, 0.0286, 0.0286, 0.0286, 0.0286, 0.0286, 0.0286,
    0.0286, 0.0286, 0.0286, 0.0286, 0.0286, 0.0286, 0.0286, 0.02859,
    0.02859, 0.02859, 0.02859, 0.02859, 0.02859, 0.02859, 0.02859,
    0.02859, 0.02859, 0.02859, 0.02859, 0.02859, 0.02859, 0.02858,
    0.02858, 0.02858, 0.02858, 0.02858, 0.02858, 0.02858, 0.02858,
    0.02858, 0.02858, 0.02858, 0.02858, 0.02858, 0.02857, 0.02857,
    0.02857, 0.02857, 0.02857, 0.02857, 0.02857, 0.02857, 0.02857,
    0.02857, 0.02857, 0.02857, 0.02857, 0.02857, 0.02856, 0.02856,
    0.02856, 0.02856, 0.02856, 0.02856, 0.02856, 0.02856, 0.02856,
    0.02856, 0.02856, 0.02856, 0.02856, 0.02855, 0.02855, 0.02855,
    0.02855, 0.02855, 0.02855, 0.02855, 0.02855, 0.02855, 0.02855,
    0.02855, 0.02855, 0.02855, 0.02855, 0.02854, 0.02854, 0.02854,
    0.02854, 0.02854, 0.02854, 0.02854, 0.02854, 0.02854, 0.02854,
    0.02854, 0.02854, 0.02854, 0.02854, 0.02853, 0.02853, 0.02853,
    0.02853, 0.02853, 0.02853, 0.02853, 0.02853, 0.02853, 0.02853,
    0.02853, 0.02853, 0.02853, 0.02853, 0.02852, 0.02852, 0.02852,
    0.02852, 0.02852, 0.02852, 0.02852, 0.02852, 0.02852, 0.02852,
    0.02852, 0.02852, 0.02852, 0.02852, 0.02851, 0.02851, 0.02851,
    0.02851, 0.02851, 0.02851, 0.02851, 0.02851, 0.02851, 0.02851,
    0.02851, 0.02851, 0.02851, 0.02851, 0.0285, 0.0285, 0.0285,
    0.0285, 0.0285, 0.0285, 0.0285, 0.0285, 0.0285, 0.0285, 0.0285,
    0.0285, 0.0285, 0.0285, 0.02849, 0.02849, 0.02849, 0.02849,
    0.02849, 0.02849, 0.02849, 0.02849, 0.02849, 0.02849, 0.02849,
    0.02849, 0.02849, 0.02849, 0.02848, 0.02848, 0.02848, 0.02848,
    0.02848, 0.02848, 0.02848, 0.02848, 0.02848, 0.02848, 0.02848,
    0.02848, 0.02848, 0.03508, 0.03509, 0.0351, 0.03511, 0.03513,
    0.03514, 0.03515, 0.03516, 0.03517, 0.03518, 0.03519, 0.03521,
    0.03522, 0.03523, 0.03524, 0.03525, 0.03526, 0.03527, 0.03528,
    0.0353, 0.03531, 0.03532, 0.03533, 0.03534, 0.03535, 0.03536,
    0.03538, 0.03539, 0.0354, 0.03541, 0.03542, 0.03543, 0.03544,
    0.03545, 0.03547, 0.03548, 0.03549, 0.0355, 0.03551, 0.03552,
    0.03553, 0.03555, 0.03556, 0.03557, 0.03558, 0.03559, 0.0356,
    0.03561, 0.03562, 0.03564, 0.03565, 0.03566, 0.03567, 0.03568,
    0.03569, 0.0357, 0.03571, 0.03572, 0.03574, 0.03575, 0.03576,
    0.03577, 0.03578, 0.03579, 0.0358, 0.03581, 0.03582, 0.03584,
    0.03585, 0.03586, 0.03587, 0.03588, 0.03589, 0.0359, 0.03591,
    0.03592, 0.03593, 0.03595, 0.03596, 0.03597, 0.03598, 0.03599,
    0.036, 0.03601, 0.03602, 0.03603, 0.03604, 0.03605, 0.03607,
    0.03608, 0.03609, 0.0361, 0.03611, 0.03612, 0.03613, 0.03614,
    0.03615, 0.03616, 0.03617, 0.03618, 0.0362, 0.03621, 0.03622,
    0.03623, 0.03624, 0.03625, 0.03626, 0.03627, 0.03628, 0.03629,
    0.0363, 0.03631, 0.03632, 0.03633, 0.03634, 0.03636, 0.03637,
    0.03638, 0.03639, 0.0364, 0.03641, 0.03642, 0.03643, 0.03644,
    0.03645, 0.03646, 0.03647, 0.03648, 0.03649, 0.0365, 0.03651,
    0.03652, 0.03653, 0.03654, 0.03655, 0.03656, 0.03657, 0.03659,
    0.0366, 0.03661, 0.03662, 0.03663, 0.03664, 0.03665, 0.03666,
    0.03667, 0.03668, 0.03669, 0.0367, 0.03671, 0.03672, 0.03673,
    0.03674, 0.03675, 0.03676, 0.03677, 0.03678, 0.03679, 0.0368,
    0.03681, 0.03682, 0.03683, 0.03684, 0.03685, 0.03686, 0.03687,
    0.03688, 0.03689, 0.0369, 0.03691, 0.03692, 0.03693, 0.03694,
    0.03695, 0.03696, 0.03697, 0.03698, 0.03699, 0.037, 0.03701,
    0.03702, 0.03703, 0.03704, 0.03705, 0.03706, 0.03707, 0.03708,
    0.03709, 0.0371, 0.03711, 0.03711, 0.03712, 0.03713, 0.03714,
    0.03715, 0.03716, 0.03717, 0.03718, 0.03719, 0.0372, 0.03721,
    0.03722, 0.03723, 0.03724, 0.03725, 0.03726, 0.03727, 0.03728,
    0.03729, 0.0373, 0.0373, 0.03731, 0.03732, 0.03733, 0.03734,
    0.03735, 0.03736, 0.03737, 0.03738, 0.03739, 0.0374, 0.03741,
    0.03742, 0.03743, 0.03743, 0.03744, 0.03745, 0.03746, 0.03747,
    0.03748, 0.03749, 0.0375, 0.03751, 0.03752, 0.03753, 0.03753,
    0.03754, 0.03755, 0.03756, 0.03757, 0.03758, 0.03759, 0.0376,
    0.03761, 0.03762, 0.03762, 0.03763, 0.03764, 0.03765, 0.03766,
    0.03767, 0.03768, 0.03769, 0.03769, 0.0377, 0.03771, 0.03772,
    0.03773, 0.03774, 0.03775, 0.03776, 0.03776, 0.03777, 0.03778,
    0.03779, 0.0378, 0.03781, 0.03782, 0.03782, 0.03783, 0.03784,
    0.03785, 0.03786, 0.03787, 0.03788, 0.03788, 0.03789, 0.0379,
    0.03791, 0.03792, 0.03793, 0.03793, 0.03794, 0.03795, 0.03796,
    0.03797, 0.03798, 0.03798, 0.03799, 0.038, 0.03801, 0.03802,
    0.03802, 0.03803, 0.03804, 0.03805, 0.03806, 0.03807, 0.03807,
    0.03808, 0.03809, 0.0381, 0.03811, 0.03811, 0.03812, 0.03813,
    0.03814, 0.03815, 0.03815, 0.03816, 0.03817, 0.03818, 0.03819,
    0.03819, 0.0382, 0.03821, 0.03822, 0.03822, 0.03823, 0.03824,
    0.03825, 0.03826, 0.03826, 0.03827, 0.03828, 0.03829, 0.03829,
    0.0383, 0.03831, 0.03832, 0.03833, 0.03833, 0.03834, 0.03835,
    0.03836, 0.03836, 0.03837, 0.03838, 0.03839, 0.03839, 0.0384,
    0.03841, 0.03842, 0.03842, 0.03843, 0.03844, 0.03845, 0.03845,
    0.03846, 0.03847, 0.03848, 0.03848, 0.03849, 0.0385, 0.0385,
    0.03851, 0.03852, 0.03853, 0.03853, 0.03854, 0.03855, 0.03856,
    0.03856, 0.03857, 0.03858, 0.03858, 0.03859, 0.0386, 0.03861,
    0.03861, 0.03862, 0.03863, 0.03863, 0.03864, 0.03865, 0.03866,
    0.03866, 0.03867, 0.03868, 0.03868, 0.03869, 0.0387, 0.0387,
    0.03871, 0.03872, 0.03873, 0.03873, 0.03874, 0.03875, 0.03875,
    0.03876, 0.03877, 0.03877, 0.03878, 0.03879, 0.03879, 0.0388,
    0.03881, 0.03881, 0.03882, 0.03883, 0.03883, 0.03884, 0.03885,
    0.03885, 0.03886, 0.03887, 0.03887, 0.03888, 0.03889, 0.03889,
    0.0389, 0.03891, 0.03891, 0.03892, 0.03893, 0.03893, 0.03894,
    0.03895, 0.03895, 0.03896, 0.03897, 0.03897, 0.03898, 0.03899,
    0.03899, 0.039, 0.03901, 0.03901, 0.03902, 0.03902, 0.03903,
    0.03904, 0.03904, 0.03905, 0.03906, 0.03906, 0.03907, 0.03908,
    0.03908, 0.03909, 0.03909, 0.0391, 0.03911, 0.03911, 0.03912,
    0.03913, 0.03913, 0.03914, 0.03914, 0.03915, 0.03916, 0.03916,
    0.03917, 0.03917, 0.03918, 0.03919, 0.03919, 0.0392, 0.0392,
    0.03921, 0.03922, 0.03922, 0.03923, 0.03924, 0.03924, 0.03925,
    0.03925, 0.03926, 0.03927, 0.03927, 0.03928, 0.03928, 0.03929,
    0.03929, 0.0393, 0.03931, 0.03931, 0.03932, 0.03932, 0.03933,
    0.03934, 0.03934, 0.03935, 0.03935, 0.03936, 0.03937, 0.03937,
    0.03938, 0.03938, 0.03939, 0.03939, 0.0394, 0.03941, 0.03941,
    0.03942, 0.03942, 0.03943, 0.03943, 0.03944, 0.03945, 0.03945,
    0.03946, 0.03946, 0.03947, 0.03947, 0.03948, 0.03949, 0.03949,
    0.0395, 0.0395, 0.03951, 0.03951, 0.03952, 0.03952, 0.03953,
    0.03954, 0.03954, 0.03955, 0.03955, 0.03956, 0.03956, 0.03957,
    0.03957, 0.03958, 0.03958, 0.03959, 0.0396, 0.0396, 0.03961,
    0.03961, 0.03962, 0.03962, 0.03963, 0.03963, 0.03964, 0.03964,
    0.03965, 0.03966, 0.03966, 0.03967, 0.03967, 0.03968, 0.03968,
    0.03969, 0.03969, 0.0397, 0.0397, 0.03971, 0.03971, 0.03972,
    0.03972, 0.03973, 0.03973, 0.03974, 0.03975, 0.03975, 0.03976,
    0.03976, 0.03977, 0.03977, 0.03978, 0.03978, 0.03979, 0.03979,
    0.0398, 0.0398, 0.03981, 0.03981, 0.03982, 0.03982, 0.03983,
    0.03983, 0.03984, 0.03984, 0.03985, 0.03985, 0.03986, 0.03986,
    0.03987, 0.03987, 0.03988, 0.03988, 0.03989, 0.0399, 0.0399,
    0.03991, 0.03991, 0.03992, 0.03992, 0.03993, 0.03993, 0.03994,
    0.03994, 0.03995, 0.03995, 0.03996, 0.03996, 0.03997, 0.03997,
    0.03998, 0.03998, 0.03999, 0.03999, 0.04, 0.04, 0.04001,
    0.04001, 0.04002, 0.04002, 0.04003, 0.04003, 0.04004, 0.04004,
    0.04004, 0.04005, 0.04005, 0.04006, 0.04006, 0.04007, 0.04007,
    0.04008, 0.04008, 0.04009, 0.04009, 0.0401, 0.0401, 0.04011,
    0.04011, 0.04012, 0.04012, 0.04013, 0.04013, 0.04014, 0.04014,
    0.04015, 0.04015, 0.04016, 0.04016, 0.04017, 0.04017, 0.04018,
    0.04018, 0.04019, 0.04019, 0.0402, 0.0402, 0.0402, 0.04021,
    0.04021, 0.04022, 0.04022, 0.04023, 0.04023, 0.04024, 0.04024,
    0.04025, 0.04025, 0.04026, 0.04026, 0.04027, 0.04027, 0.04028,
    0.04028, 0.04029, 0.04029, 0.0403, 0.0403, 0.0403, 0.04031,
    0.04031, 0.04032, 0.04032, 0.04033, 0.04033, 0.04034, 0.04034,
    0.04035, 0.04035, 0.04036, 0.04036, 0.04037, 0.04037, 0.04037,
    0.04038, 0.04038, 0.04039, 0.04039, 0.0404, 0.0404, 0.04041,
    0.04041, 0.04042, 0.04042, 0.04043, 0.04043, 0.04044, 0.04044,
    0.04044, 0.04045, 0.04045, 0.04046, 0.04046, 0.04047, 0.04047,
    0.04048, 0.04048, 0.04049, 0.04049, 0.0405, 0.0405, 0.0405,
    0.04051, 0.04051, 0.04052, 0.04052, 0.04053, 0.04053, 0.04054,
    0.04054, 0.04055, 0.04055, 0.04055, 0.04056, 0.04056, 0.04057,
    0.04057, 0.04058, 0.04058, 0.04059, 0.04059, 0.0406, 0.0406,
    0.0406, 0.04061, 0.04061, 0.04062, 0.04062, 0.04063, 0.04063,
    0.04064, 0.04064, 0.04065, 0.04065, 0.04065, 0.04066, 0.04066,
    0.04067, 0.04067, 0.04068, 0.04068, 0.04069, 0.04069, 0.04069,
    0.0407, 0.0407, 0.04071, 0.04071, 0.04072, 0.04072, 0.04073,
    0.04073, 0.04073, 0.04074, 0.04074, 0.04075, 0.04075, 0.04076,
    0.04076, 0.04077, 0.04077, 0.04078, 0.04078, 0.04078, 0.04079,
    0.04079, 0.0408, 0.0408, 0.04081, 0.04081, 0.04082, 0.04082,
    0.04082, 0.04083, 0.04083, 0.04084, 0.04084, 0.04085, 0.04085,
    0.04086, 0.04086, 0.04086, 0.04087, 0.04087, 0.04088, 0.04088,
    0.04089, 0.04089, 0.04089, 0.0409, 0.0409, 0.04091, 0.04091,
    0.04092, 0.04092, 0.04093, 0.04093, 0.04093, 0.04094, 0.04094,
    0.04095, 0.04095, 0.04096, 0.04096, 0.04097, 0.04097, 0.04097,
    0.04098, 0.04098, 0.04099, 0.04099, 0.041, 0.041, 0.041,
    0.04101, 0.04101, 0.04102, 0.04102, 0.04103, 0.04103, 0.04104,
    0.04104, 0.04104, 0.04105, 0.04105, 0.04106, 0.04106, 0.04107,
    0.04107, 0.04107, 0.04108, 0.04108, 0.04109, 0.04109, 0.0411,
    0.0411, 0.04111, 0.04111, 0.04111, 0.04112, 0.04112, 0.04113,
    0.04113, 0.04114, 0.04114, 0.04114, 0.04115, 0.04115, 0.04116,
    0.04116, 0.04117, 0.04117, 0.04117, 0.04118, 0.04118, 0.04119,
    0.04119, 0.0412, 0.0412, 0.0412, 0.04121, 0.04121, 0.04122,
    0.04122, 0.04123, 0.04123, 0.04123, 0.04124, 0.04124, 0.04125,
    0.04125, 0.04126, 0.04126, 0.04127, 0.04127, 0.04127, 0.04128,
    0.04128, 0.04129, 0.04129, 0.0413, 0.0413, 0.0413, 0.04131,
    0.04131, 0.04132, 0.04132, 0.04132, 0.04133, 0.04133, 0.04134,
    0.04134, 0.04135, 0.04135, 0.04135, 0.04136, 0.04136, 0.04137,
    0.04137, 0.04138, 0.04138, 0.04138, 0.04139, 0.04139, 0.0414,
    0.0414, 0.04141, 0.04141, 0.04141, 0.04142, 0.04142, 0.04143,
    0.04143, 0.04144, 0.04144, 0.04144, 0.04145, 0.04145, 0.04146,
    0.04146, 0.04147, 0.04147, 0.04147, 0.04148, 0.04148, 0.04149,
    0.04149, 0.04149, 0.0415, 0.0415, 0.04151, 0.04151, 0.04152,
    0.04152, 0.04152, 0.04153, 0.04153, 0.04154, 0.04154, 0.04154,
    0.04155, 0.04155, 0.04156, 0.04156, 0.04157, 0.04157, 0.04157,
    0.04158, 0.04158, 0.04159, 0.04159, 0.0416, 0.0416, 0.0416,
    0.04161, 0.04161, 0.04162, 0.04162, 0.04162, 0.04163, 0.04163,
    0.04164, 0.04164, 0.04165, 0.04165, 0.04165, 0.04166, 0.04166,
    0.04167, 0.04167, 0.04167, 0.04168, 0.04168, 0.04169, 0.04169,
    0.04169, 0.0417, 0.0417, 0.04171, 0.04171, 0.04172, 0.04172,
    0.04172, 0.04173, 0.04173, 0.04174, 0.04174, 0.04174, 0.04175,
    0.04175, 0.04176, 0.04176, 0.04176, 0.04177, 0.04177, 0.04178,
    0.04178, 0.04179, 0.04179, 0.04179, 0.0418, 0.0418, 0.04181,
    0.04181, 0.04181, 0.04182, 0.04182, 0.04183, 0.04183, 0.04183,
    0.04184, 0.04184, 0.04185, 0.04185, 0.04185, 0.04186, 0.04186,
    0.04187, 0.04187, 0.04188, 0.04188, 0.04188, 0.04189, 0.04189,
    0.0419, 0.0419, 0.0419, 0.04191, 0.04191, 0.04192, 0.04192,
    0.04192, 0.04193, 0.04193, 0.04194, 0.04194, 0.04194, 0.04195,
    0.04195, 0.04196, 0.04196, 0.04196, 0.04197, 0.04197, 0.04198,
    0.04198, 0.04198, 0.04199, 0.04199, 0.042, 0.042, 0.042,
    0.04201, 0.04201, 0.04202, 0.04202, 0.04202, 0.04203, 0.04203,
    0.04204, 0.04204, 0.04204, 0.04205, 0.04205, 0.04206, 0.04206,
    0.04206, 0.04207, 0.04207, 0.04208, 0.04208, 0.04208, 0.04209,
    0.04209, 0.0421, 0.0421, 0.0421, 0.04211, 0.04211, 0.04212,
    0.04212, 0.04212, 0.04213, 0.04213, 0.04214, 0.04214, 0.04214,
    0.04215, 0.04215, 0.04216, 0.04216, 0.04216, 0.04217, 0.04217,
    0.04218, 0.04218, 0.04218, 0.04219, 0.04219, 0.0422, 0.0422,
    0.0422, 0.04221, 0.04221, 0.04222, 0.04222, 0.04222, 0.04223,
    0.04223, 0.04223, 0.04224, 0.04224, 0.04225, 0.04225, 0.04225,
    0.04226, 0.04164, 0.04172, 0.0418, 0.04187, 0.04195, 0.04203,
    0.04211, 0.04218, 0.04226, 0.04234, 0.04241, 0.04249, 0.04257,
    0.04264, 0.04272, 0.0428, 0.04287, 0.04295, 0.04303, 0.04311,
    0.04318, 0.04326, 0.04334, 0.04342, 0.0435, 0.04358, 0.04366,
    0.04374, 0.04382, 0.0439, 0.04398, 0.04406, 0.04414, 0.04422,
    0.0443, 0.04438, 0.04446, 0.04454, 0.04462, 0.0447, 0.04478,
    0.04487, 0.04495, 0.04503, 0.04511, 0.04519, 0.04527, 0.04535,
    0.04543, 0.04551, 0.04559, 0.04566, 0.04574, 0.04582, 0.04589,
    0.04597, 0.04604, 0.04612, 0.04619, 0.04626, 0.04633, 0.0464,
    0.04647, 0.04654, 0.04661, 0.04667, 0.04674, 0.0468, 0.04686,
    0.04692, 0.04698, 0.04703, 0.04709, 0.04714, 0.04719, 0.04723,
    0.04728, 0.04732, 0.04736, 0.0474, 0.04744, 0.04747, 0.0475,
    0.04753, 0.04755, 0.04758, 0.04759, 0.04761, 0.04762, 0.04763,
    0.04763, 0.04764, 0.04763, 0.04763, 0.04762, 0.0476, 0.04758,
    0.04756, 0.04754, 0.04751, 0.04747, 0.04744, 0.0474, 0.04735,
    0.0473, 0.04725, 0.0472, 0.04714, 0.04707, 0.04701, 0.04694,
    0.04687, 0.04679, 0.04671, 0.04663, 0.04655, 0.04646, 0.04637,
    0.04628, 0.04619, 0.04609, 0.04599, 0.04589, 0.04579, 0.04569,
    0.04559, 0.04548, 0.04538, 0.04527, 0.04516, 0.04506, 0.04495,
    0.04484, 0.04473, 0.04462, 0.04451, 0.0444, 0.04429, 0.04418,
    0.04407, 0.04396, 0.04385, 0.04375, 0.04364, 0.04353, 0.04343,
    0.04332, 0.04322, 0.04311, 0.04301, 0.04291, 0.04281, 0.04271,
    0.04261, 0.04251, 0.04241, 0.04232, 0.04222, 0.04213, 0.04204,
    0.04195, 0.04185, 0.04177, 0.04168, 0.04159, 0.0415, 0.04142,
    0.04134, 0.04134, 0.03764, 0.03765, 0.03766, 0.03767, 0.03767,
    0.03768, 0.03769, 0.0377, 0.0377, 0.03771, 0.03772, 0.03772,
    0.03773, 0.03774, 0.03775, 0.03775, 0.03776, 0.03777, 0.03778,
    0.03778, 0.03779, 0.0378, 0.0378, 0.03781, 0.03782, 0.03783,
    0.03783, 0.03784, 0.03785, 0.03786, 0.03786, 0.03787, 0.03788,
    0.03788, 0.03789, 0.0379, 0.03791, 0.03791, 0.03792, 0.03793,
    0.03794, 0.03794, 0.03795, 0.03796, 0.03796, 0.03797, 0.03798,
    0.03799, 0.03799, 0.038, 0.03801, 0.03801, 0.03802, 0.03803,
    0.03804, 0.03804, 0.03805, 0.03806, 0.03806, 0.03807, 0.03808,
    0.03809, 0.03809, 0.0381, 0.03811, 0.03812, 0.03812, 0.03813,
    0.03814, 0.03814, 0.03815, 0.03816, 0.03817, 0.03817, 0.03818,
    0.03819, 0.03819, 0.0382, 0.03821, 0.03821, 0.03822, 0.03823,
    0.03824, 0.03824, 0.03825, 0.03826, 0.03826, 0.03827, 0.03828,
    0.03829, 0.03829, 0.0383, 0.03831, 0.03831, 0.03832, 0.03833,
    0.03834, 0.03834, 0.03835, 0.03836, 0.03836, 0.03837, 0.03838,
    0.03838, 0.03839, 0.0384, 0.03841, 0.03841, 0.03842, 0.03843,
    0.03843, 0.03844, 0.03845, 0.03845, 0.03846, 0.03847, 0.03848,
    0.03848, 0.03849, 0.0385, 0.0385, 0.03851, 0.03852, 0.03852,
    0.03853, 0.03854, 0.03855, 0.03855, 0.03856, 0.03857, 0.03857,
    0.03858, 0.03859, 0.03859, 0.0386, 0.03861, 0.03861, 0.03862,
    0.03863, 0.03864, 0.03864, 0.03865, 0.03866, 0.03866, 0.03867,
    0.03868, 0.03868, 0.03869, 0.0387, 0.0387, 0.03871, 0.03872,
    0.03872, 0.03873, 0.03874, 0.03874, 0.03875, 0.03876, 0.03877,
    0.03877, 0.03878, 0.03879, 0.03879, 0.0388, 0.03881, 0.03881,
    0.03882, 0.03883, 0.03883, 0.03884, 0.03885, 0.03885, 0.03886,
    0.03887, 0.03887, 0.03888, 0.03889, 0.03889, 0.0389, 0.03891,
    0.03891, 0.03892, 0.03893, 0.03893, 0.03894, 0.03895, 0.03895,
    0.03896, 0.03897, 0.03897, 0.03898, 0.03899, 0.03899, 0.039,
    0.03901, 0.03901, 0.03902, 0.03903, 0.03903, 0.03904, 0.03905,
    0.03905, 0.03906, 0.03907, 0.03907, 0.03908, 0.03909, 0.03909,
    0.0391, 0.03911, 0.03911, 0.03912, 0.03913, 0.03913, 0.03914,
    0.03915, 0.03915, 0.03916, 0.03917, 0.03917, 0.03918, 0.03918,
    0.03919, 0.0392, 0.0392, 0.03921, 0.03922, 0.03922, 0.03923,
    0.03924, 0.03924, 0.03925, 0.03926, 0.03926, 0.03927, 0.03928,
    0.03928, 0.03929, 0.03929, 0.0393, 0.03931, 0.03931, 0.03932,
    0.03933, 0.03933, 0.03934, 0.03935, 0.03935, 0.03936, 0.03936,
    0.03937, 0.03938, 0.03938, 0.03939, 0.0394, 0.0394, 0.03941,
    0.03942, 0.03942, 0.03943, 0.03943, 0.03944, 0.03945, 0.03945,
    0.03946, 0.03947, 0.03947, 0.03948, 0.03948, 0.03949, 0.0395,
    0.0395, 0.03951, 0.03952, 0.03952, 0.03953, 0.03953, 0.03954,
    0.03955, 0.03955, 0.03956, 0.03957, 0.03957, 0.03958, 0.03958,
    0.03959, 0.0396, 0.0396, 0.03961, 0.03961, 0.03962, 0.03963,
    0.03963, 0.03964, 0.03964, 0.03965, 0.03966, 0.03966, 0.03967,
    0.03968, 0.03968, 0.03969, 0.03969, 0.0397, 0.03971, 0.03971,
    0.03972, 0.03972, 0.03973, 0.03974, 0.03974, 0.03975, 0.03975,
    0.03976, 0.03977, 0.03977, 0.03978, 0.03978, 0.03979, 0.0398,
    0.0398, 0.03981, 0.03981, 0.03982, 0.03983, 0.03983, 0.03984,
    0.03984, 0.03985, 0.03986, 0.03986, 0.03987, 0.03987, 0.03988,
    0.03989, 0.03989, 0.0399, 0.0399, 0.03991, 0.03991, 0.03992,
    0.03993, 0.03993, 0.03994, 0.03994, 0.03995, 0.03996, 0.03996,
    0.03997, 0.03997, 0.03998, 0.03999, 0.03999, 0.04, 0.04,
    0.04001, 0.04001, 0.04002, 0.04003, 0.04003, 0.04004, 0.04004,
    0.04005, 0.04005, 0.04006, 0.04007, 0.04007, 0.04008, 0.04008,
    0.04009, 0.04009, 0.0401, 0.04011, 0.04011, 0.04012, 0.04012,
    0.04013, 0.04013, 0.04014, 0.04015, 0.04015, 0.04016, 0.04016,
    0.04017, 0.04017, 0.04018, 0.04019, 0.04019, 0.0402, 0.0402,
    0.04021, 0.04021, 0.04022, 0.04023, 0.04023, 0.04024, 0.04024,
    0.04025, 0.04025, 0.04026, 0.04026, 0.04027, 0.04028, 0.04028,
    0.04029, 0.04029, 0.0403, 0.0403, 0.04031, 0.04032, 0.04032,
    0.04033, 0.04033, 0.04034, 0.04034, 0.04035, 0.04035, 0.04036,
    0.04036, 0.04037, 0.04038, 0.04038, 0.04039, 0.04039, 0.0404,
    0.0404, 0.04041, 0.04041, 0.04042, 0.04043, 0.04043, 0.04044,
    0.04044, 0.04045, 0.04045, 0.04046, 0.04046, 0.04047, 0.04047,
    0.04048, 0.04049, 0.04049, 0.0405, 0.0405, 0.04051, 0.04051,
    0.04052, 0.04052, 0.04053, 0.04053, 0.04054, 0.04054, 0.04055,
    0.04056, 0.04056, 0.04057, 0.04057, 0.04058, 0.04058, 0.04059,
    0.04059, 0.0406, 0.0406, 0.04061, 0.04061, 0.04062, 0.04063,
    0.04063, 0.04064, 0.04064, 0.04065, 0.04065, 0.04066, 0.04066,
    0.04067, 0.04067, 0.04068, 0.04068, 0.04069, 0.04069, 0.0407,
    0.0407, 0.04071, 0.04072, 0.04072, 0.04073, 0.04073, 0.04074,
    0.04074, 0.04075, 0.04075, 0.04076, 0.04076, 0.04077, 0.04077,
    0.04078, 0.04078, 0.04079, 0.04079, 0.0408, 0.0408, 0.04081,
    0.04081, 0.04082, 0.04082, 0.04083, 0.04084, 0.04084, 0.04085,
    0.04085, 0.04086, 0.04086, 0.04087, 0.04087, 0.04088, 0.04088,
    0.04089, 0.04089, 0.0409, 0.0409, 0.04091, 0.04091, 0.04092,
    0.04092, 0.04093, 0.04093, 0.04094, 0.04094, 0.04095, 0.04095,
    0.04096, 0.04096, 0.04097, 0.04097, 0.04098, 0.04098, 0.04099,
    0.04099, 0.041, 0.041, 0.04101, 0.04101, 0.04102, 0.04103,
    0.04103, 0.04104, 0.04104, 0.04105, 0.04105, 0.04106, 0.04106,
    0.04107, 0.04107, 0.04108, 0.04108, 0.04109, 0.04109, 0.0411,
    0.0411, 0.04111, 0.04111, 0.04112, 0.04112, 0.04113, 0.04113,
    0.04114, 0.04114, 0.04115, 0.04115, 0.04116, 0.04116, 0.04117,
    0.04117, 0.04118, 0.04118, 0.04119, 0.04119, 0.0412, 0.0412,
    0.04121, 0.04121, 0.04122, 0.04122, 0.04123, 0.04123, 0.04124,
    0.04124, 0.04125, 0.04125, 0.04126, 0.04126, 0.04126, 0.04127,
    0.04127, 0.04128, 0.04128, 0.04129, 0.04129, 0.0413, 0.0413,
    0.04131, 0.04131, 0.04132, 0.04132, 0.04133, 0.04133, 0.04134,
    0.04134, 0.04135, 0.04135, 0.04136, 0.04136, 0.04137, 0.04137,
    0.04138, 0.04138, 0.04139, 0.04139, 0.0414, 0.0414, 0.04141,
    0.04141, 0.04142, 0.04142, 0.04143, 0.04143, 0.04144, 0.04144,
    0.04145, 0.04145, 0.04146, 0.04146, 0.04146, 0.04147, 0.04147,
    0.04148, 0.04148, 0.04149, 0.04149, 0.0415, 0.0415, 0.04151,
    0.04151, 0.04152, 0.04152, 0.04153, 0.04153, 0.04154, 0.04154,
    0.04155, 0.04155, 0.04156, 0.04156, 0.04157, 0.04157, 0.04158,
    0.04158, 0.04158, 0.04159, 0.04159, 0.0416, 0.0416, 0.04161,
    0.04161, 0.04162, 0.04162, 0.04163, 0.04163, 0.04164, 0.04164,
    0.04165, 0.04165, 0.04166, 0.04166, 0.04167, 0.04167, 0.04167,
    0.04168, 0.04168, 0.04169, 0.04169, 0.0417, 0.0417, 0.04171,
    0.04171, 0.04172, 0.04172, 0.04173, 0.04173, 0.04174, 0.04174,
    0.04175, 0.04175, 0.04175, 0.04176, 0.04176, 0.04177, 0.04177,
    0.04178, 0.04178, 0.04179, 0.04179, 0.0418, 0.0418, 0.04181,
    0.04181, 0.04181, 0.04182, 0.04182, 0.04183, 0.04183, 0.04184,
    0.04184, 0.04185, 0.04185, 0.04186, 0.04186, 0.04187, 0.04187,
    0.04187, 0.04188, 0.04188, 0.04189, 0.04189, 0.0419, 0.0419,
    0.04191, 0.04191, 0.04192, 0.04192, 0.04193, 0.04193, 0.04193,
    0.04194, 0.04194, 0.04195, 0.04195, 0.04196, 0.04196, 0.04197,
    0.04197, 0.04198, 0.04198, 0.04198, 0.04199, 0.04199, 0.042,
    0.042, 0.04201, 0.04201, 0.04202, 0.04202, 0.04203, 0.04203,
    0.04203, 0.04204, 0.04204, 0.04205, 0.04205, 0.04206, 0.04206,
    0.04207, 0.04207, 0.04208, 0.04208, 0.04208, 0.04209, 0.04209,
    0.0421, 0.0421, 0.04211, 0.04211, 0.04212, 0.04212, 0.04212,
    0.04213, 0.04213, 0.04214, 0.04214, 0.04215, 0.04215, 0.04216,
    0.04216, 0.04216, 0.04217, 0.04217, 0.04218, 0.04218, 0.04219,
    0.04219, 0.0422, 0.0422, 0.0422, 0.04221, 0.04221, 0.04222,
    0.04222, 0.04223, 0.04223, 0.04224, 0.04224, 0.04224, 0.04225,
    0.04225, 0.04226, 0.04226, 0.04227, 0.04227, 0.04227, 0.04228,
    0.04228, 0.04229, 0.04229, 0.0423, 0.0423, 0.04231, 0.04231,
    0.04231, 0.04232, 0.04232, 0.04233, 0.04233, 0.04234, 0.04234,
    0.04234, 0.04235, 0.04235, 0.04236, 0.04236, 0.04237, 0.04237,
    0.04238, 0.04238, 0.04238, 0.04239, 0.04239, 0.0424, 0.0424,
    0.04241, 0.04241, 0.04241, 0.04242, 0.04242, 0.04243, 0.04243,
    0.04244, 0.04244, 0.04244, 0.04245, 0.04245, 0.04246, 0.04246,
    0.04247, 0.04247, 0.04247, 0.04248, 0.04248, 0.04249, 0.04249,
    0.0425, 0.0425, 0.0425, 0.04251, 0.04251, 0.04252, 0.04252,
    0.04253, 0.04253, 0.04253, 0.04254, 0.04254, 0.04255, 0.04255,
    0.04256, 0.04256, 0.04256, 0.04257, 0.04257, 0.04258, 0.04258,
    0.04259, 0.04259, 0.04259, 0.0426, 0.0426, 0.04261, 0.04261,
    0.04262, 0.04262, 0.04262, 0.04263, 0.04263, 0.04264, 0.04264,
    0.04264, 0.04265, 0.04265, 0.04266, 0.04266, 0.04267, 0.04267,
    0.04267, 0.04268, 0.04268, 0.04269, 0.04269, 0.0427, 0.0427,
    0.0427, 0.04271, 0.04271, 0.04272, 0.04272, 0.04272, 0.04273,
    0.04273, 0.04274, 0.04274, 0.04275, 0.04275, 0.04275, 0.04276,
    0.04276, 0.04277, 0.04277, 0.04277, 0.04278, 0.04278, 0.04279,
    0.04279, 0.0428, 0.0428, 0.0428, 0.04281, 0.04281, 0.04282,
    0.04282, 0.04282, 0.04283, 0.04283, 0.04284, 0.04284, 0.04285,
    0.04285, 0.04285, 0.04286, 0.04286, 0.04287, 0.04287, 0.04287,
    0.04288, 0.04288, 0.04289, 0.04289, 0.04289, 0.0429, 0.0429,
    0.04291, 0.04291, 0.04292, 0.04292, 0.04292, 0.04293, 0.04293,
    0.04294, 0.04294, 0.04294, 0.04295, 0.04295, 0.04296, 0.04296,
    0.04296, 0.04297, 0.04297, 0.04298, 0.04298, 0.04299, 0.04299,
    0.04299, 0.043, 0.043, 0.04301, 0.04301, 0.04301, 0.04302,
    0.04302, 0.04303, 0.04303, 0.04303, 0.04304, 0.04304, 0.04305,
    0.04305, 0.04305, 0.04306, 0.04306, 0.04307, 0.04307, 0.04308,
    0.04308, 0.04308, 0.04309, 0.04309, 0.0431, 0.0431, 0.0431,
    0.04311, 0.04311, 0.04312, 0.04312, 0.04312, 0.04313, 0.04313,
    0.04314, 0.04314, 0.04314, 0.04315, 0.04315, 0.04316, 0.04316,
    0.04316, 0.04317, 0.04317, 0.04318, 0.04318, 0.04318, 0.04319,
    0.04319, 0.0432, 0.0432, 0.04321, 0.04321, 0.04321, 0.04322,
    0.04322, 0.04323, 0.04323, 0.04323, 0.04324, 0.04324, 0.04325,
    0.04325, 0.04325, 0.04326, 0.04326, 0.04327, 0.04327, 0.04327,
    0.04328, 0.04328, 0.04329, 0.04329, 0.04329, 0.0433, 0.0433,
    0.04331, 0.04331, 0.04331, 0.04332, 0.04332, 0.04333, 0.04333,
    0.04333, 0.04334, 0.04334, 0.04335, 0.04335, 0.04335, 0.04336,
    0.04336, 0.04337, 0.04337, 0.04337, 0.04338, 0.04338, 0.04339,
    0.04339, 0.04339, 0.0434, 0.0434, 0.04341, 0.04341, 0.04341,
    0.04342, 0.04342, 0.04343, 0.04343, 0.04343, 0.04344, 0.04344,
    0.04345, 0.04345, 0.04345, 0.04346, 0.04346, 0.04346, 0.04347,
    0.04347, 0.04348, 0.04348, 0.04348, 0.04349, 0.04349, 0.0435,
    0.0435, 0.0435, 0.04351, 0.04351, 0.04352, 0.04352, 0.04352,
    0.04353, 0.04353, 0.04354, 0.04354, 0.04354, 0.04355, 0.04355,
    0.04356, 0.04356, 0.04356, 0.04357, 0.04357, 0.04358, 0.04358,
    0.04358, 0.04355, 0.04364, 0.04373, 0.04382, 0.0439, 0.04399,
    0.04407, 0.04415, 0.04423, 0.04431, 0.04439, 0.04447, 0.04454,
    0.04461, 0.04469, 0.04475, 0.04482, 0.04489, 0.04495, 0.04502,
    0.04508, 0.04514, 0.0452, 0.04525, 0.04531, 0.04536, 0.04542,
    0.04547, 0.04551, 0.04556, 0.04561, 0.04565, 0.04569, 0.04573,
    0.04577, 0.04581, 0.04585, 0.04588, 0.04591, 0.04594, 0.04597,
    0.046, 0.04602, 0.04604, 0.04607, 0.04608, 0.0461, 0.04612,
    0.04613, 0.04614, 0.04615, 0.04616, 0.04616, 0.04617, 0.04617,
    0.04616, 0.04616, 0.04616, 0.04615, 0.04614, 0.04612, 0.04611,
    0.04609, 0.04607, 0.04605, 0.04603, 0.046, 0.04597, 0.04594,
    0.04591, 0.04588, 0.04584, 0.0458, 0.04576, 0.04571, 0.04567,
    0.04562, 0.04557, 0.04552, 0.04546, 0.04541, 0.04535, 0.04529,
    0.04523, 0.04516, 0.0451, 0.04503, 0.04497, 0.0449, 0.04483,
    0.04476, 0.04468, 0.04461, 0.04454, 0.04446, 0.04439, 0.04431,
    0.04423, 0.04415, 0.04408, 0.044, 0.04392, 0.04384, 0.04376,
    0.04369, 0.04361, 0.04353, 0.04345, 0.04337, 0.0433, 0.04322,
    0.04314, 0.04307, 0.04299, 0.04292, 0.04284, 0.04277, 0.0427,
    0.04263, 0.04255, 0.04248, 0.04241, 0.04235, 0.04228, 0.04221,
    0.04214, 0.04208, 0.04201, 0.04195, 0.04189, 0.04182, 0.04176,
    0.0417, 0.04164, 0.04158, 0.04152, 0.04147, 0.04141, 0.04136,
    0.0413, 0.04125, 0.04119, 0.04114, 0.04109, 0.04104, 0.04099,
    0.04094, 0.04089, 0.04084, 0.0408, 0.04075, 0.04071, 0.04066,
    0.04062, 0.04058, 0.04053, 0.04049, 0.04045, 0.04041, 0.04037,
    0.04034, 0.0403, 0.04026, 0.04023, 0.04019, 0.04016, 0.04012,
    0.04009, 0.04009, 0.03795, 0.03785, 0.03775, 0.03764, 0.03754,
    0.03744, 0.03734, 0.03723, 0.03713, 0.03703, 0.03693, 0.03682,
    0.03672, 0.03662, 0.03652, 0.03645, 0.03639, 0.03633, 0.03627,
    0.03621, 0.03615, 0.03609, 0.03603, 0.03597, 0.03592, 0.03586,
    0.03581, 0.03575, 0.0357, 0.03565, 0.03559, 0.03554, 0.03549,
    0.03544, 0.03539, 0.03534, 0.03529, 0.03524, 0.0352, 0.03515,
    0.0351, 0.03506, 0.03501, 0.03496, 0.03492, 0.03488, 0.03483,
    0.03479, 0.03475, 0.0347, 0.03466, 0.03462, 0.03458, 0.03454,
    0.0345, 0.03446, 0.03442, 0.03438, 0.03434, 0.03431, 0.03427,
    0.03423, 0.0342, 0.03416, 0.03412, 0.03409, 0.03405, 0.03402,
    0.03398, 0.03395, 0.03392, 0.03388, 0.03385, 0.03382, 0.03379,
    0.03375, 0.03372, 0.03369, 0.03366, 0.03363, 0.0336, 0.03357,
    0.03354, 0.03351, 0.03348, 0.03345, 0.03342, 0.0334, 0.03337,
    0.03334, 0.03331, 0.03329, 0.03326, 0.03323, 0.03321, 0.03318,
    0.03316, 0.03313, 0.03311, 0.03308, 0.03306, 0.03303, 0.03301,
    0.03298, 0.03296, 0.03294, 0.03291, 0.03289, 0.03287, 0.03284,
    0.03282, 0.0328, 0.03278, 0.03276, 0.03273, 0.03271, 0.03269,
    0.03267, 0.03265, 0.03263, 0.03261, 0.03259, 0.03257, 0.03255,
    0.03253, 0.03251, 0.03249, 0.03247, 0.03245, 0.03243, 0.03241,
    0.03239, 0.03238, 0.03236, 0.03234, 0.03232, 0.0323, 0.03229,
    0.03227, 0.03225, 0.03223, 0.03222, 0.0322, 0.03218, 0.03217,
    0.03215, 0.03214, 0.03212, 0.0321, 0.03209, 0.03207, 0.03206,
    0.03204, 0.03203, 0.03201, 0.032, 0.03198, 0.03197, 0.03196,
    0.03194, 0.03193, 0.03191, 0.0319, 0.03189, 0.03187, 0.03186,
    0.03185, 0.03183, 0.03182, 0.03181, 0.0318, 0.03179, 0.03177,
    0.03176, 0.03175, 0.03174, 0.03173, 0.03171, 0.0317, 0.03169,
    0.03168, 0.03167, 0.03166, 0.03165, 0.03164, 0.03163, 0.03162,
    0.03161, 0.0316, 0.03159, 0.03158, 0.03157, 0.03156, 0.03155,
    0.03154, 0.03153, 0.03152, 0.03152, 0.03151, 0.0315, 0.03149,
    0.03148, 0.03147, 0.03147, 0.03146, 0.03145, 0.03144, 0.03144,
    0.03143, 0.03142, 0.03141, 0.03141, 0.0314, 0.03139, 0.03139,
    0.03138, 0.03137, 0.03137, 0.03136, 0.03136, 0.03135, 0.03134,
    0.03134, 0.03133, 0.03133, 0.03132, 0.03132, 0.03131, 0.03131,
    0.0313, 0.0313, 0.03129, 0.03129, 0.03128, 0.03128, 0.03127,
    0.03127, 0.03126, 0.03126, 0.03126, 0.03125, 0.03125, 0.03125,
    0.03124, 0.03124, 0.03123, 0.03123, 0.03123, 0.03122, 0.03122,
    0.03122, 0.03122, 0.03121, 0.03121, 0.03121, 0.03121, 0.0312,
    0.0312, 0.0312, 0.0312, 0.03119, 0.03119, 0.03119, 0.03119,
    0.03119, 0.03118, 0.03118, 0.03118, 0.03118, 0.03118, 0.03118,
    0.03118, 0.03118, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117,
    0.03117, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117,
    0.03117, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117,
    0.03117, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117, 0.03117,
    0.03118, 0.03118, 0.03118, 0.03118, 0.03118, 0.03118, 0.03118,
    0.03118, 0.03119, 0.03119, 0.03119, 0.03119, 0.03119, 0.03119,
    0.0312, 0.0312, 0.0312, 0.0312, 0.0312, 0.03121, 0.03121,
    0.03121, 0.03121, 0.03122, 0.03122, 0.03122, 0.03122, 0.03123,
    0.03123, 0.03123, 0.03124, 0.03124, 0.03124, 0.03124, 0.03125,
    0.03125, 0.03125, 0.03126, 0.03126, 0.03126, 0.03127, 0.03127,
    0.03127, 0.03128, 0.03128, 0.03128, 0.03129, 0.03129, 0.0313,
    0.0313, 0.0313, 0.03131, 0.03131, 0.03132, 0.03132, 0.03132,
    0.03133, 0.03133, 0.03134, 0.03134, 0.03135, 0.03135, 0.03136,
    0.03136, 0.03136, 0.03137, 0.03137, 0.03138, 0.03138, 0.03139,
    0.03139, 0.0314, 0.0314, 0.03141, 0.03141, 0.03142, 0.03142,
    0.03143, 0.03143, 0.03144, 0.03144, 0.03145, 0.03146, 0.03146,
    0.03147, 0.03147, 0.03148, 0.03148, 0.03149, 0.03149, 0.0315,
    0.03151, 0.03151, 0.03152, 0.03152, 0.03153, 0.03154, 0.03154,
    0.03155, 0.03155, 0.03156, 0.03157, 0.03157, 0.03158, 0.03159,
    0.03159, 0.0316, 0.0316, 0.03161, 0.03162, 0.03162, 0.03163,
    0.03164, 0.03164, 0.03165, 0.03166, 0.03166, 0.03167, 0.03168,
    0.03168, 0.03169, 0.0317, 0.0317, 0.03171, 0.03172, 0.03172,
    0.03173, 0.03174, 0.03175, 0.03175, 0.03176, 0.03177, 0.03177,
    0.03178, 0.03179, 0.0318, 0.0318, 0.03181, 0.03182, 0.03183,
    0.03183, 0.03184, 0.03185, 0.03186, 0.03186, 0.03187, 0.03188,
    0.03189, 0.03189, 0.0319, 0.03191, 0.03192, 0.03192, 0.03193,
    0.03194, 0.03195, 0.03196, 0.03196, 0.03197, 0.03198, 0.03199,
    0.032, 0.032, 0.03201, 0.03202, 0.03203, 0.03204, 0.03204,
    0.03205, 0.03206, 0.03207, 0.03208, 0.03209, 0.03209, 0.0321,
    0.03211, 0.03212, 0.03213, 0.03214, 0.03214, 0.03215, 0.03216,
    0.03217, 0.03218, 0.03219, 0.0322, 0.0322, 0.03221, 0.03222,
    0.03223, 0.03224, 0.03225, 0.03226, 0.03226, 0.03227, 0.03228,
    0.03229, 0.0323, 0.03231, 0.03232, 0.03233, 0.03234, 0.03234,
    0.03235, 0.03236, 0.03237, 0.03238, 0.03239, 0.0324, 0.03241,
    0.03242, 0.03243, 0.03244, 0.03245, 0.03245, 0.03246, 0.03247,
    0.03248, 0.03249, 0.0325, 0.03251, 0.03252, 0.03253, 0.03254,
    0.03255, 0.03256, 0.03257, 0.03258, 0.03259, 0.0326, 0.03261,
    0.03261, 0.03262, 0.03263, 0.03264, 0.03265, 0.03266, 0.03267,
    0.03268, 0.03269, 0.0327, 0.03271, 0.03272, 0.03273, 0.03274,
    0.03275, 0.03276, 0.03277, 0.03278, 0.03279, 0.0328, 0.03281,
    0.03282, 0.03283, 0.03284, 0.03285, 0.03286, 0.03287, 0.03288,
    0.03289, 0.0329, 0.03291, 0.03292, 0.03293, 0.03294, 0.03295,
    0.03296, 0.03297, 0.03298, 0.03299, 0.033, 0.03301, 0.03302,
    0.03303, 0.03304, 0.03305, 0.03306, 0.03308, 0.03309, 0.0331,
    0.03311, 0.03312, 0.03313, 0.03314, 0.03315, 0.03316, 0.03317,
    0.03318, 0.03319, 0.0332, 0.03321, 0.03322, 0.03323, 0.03324,
    0.03325, 0.03326, 0.03327, 0.03329, 0.0333, 0.03331, 0.03332,
    0.03333, 0.03334, 0.03335, 0.03336, 0.03337, 0.03338, 0.03339,
    0.0334, 0.03341, 0.03342, 0.03344, 0.03345, 0.03346, 0.03347,
    0.03348, 0.03349, 0.0335, 0.03351, 0.03352, 0.03353, 0.03354,
    0.03356, 0.03357, 0.03358, 0.03359, 0.0336, 0.03361, 0.03362,
    0.03363, 0.03364, 0.03365, 0.03367, 0.03368, 0.03369, 0.0337,
    0.03371, 0.03372, 0.03373, 0.03374, 0.03375, 0.03377, 0.03378,
    0.03379, 0.0338, 0.03381, 0.03382, 0.03383, 0.03384, 0.03385,
    0.03387, 0.03388, 0.03389, 0.0339, 0.03391, 0.03392, 0.03393,
    0.03394, 0.03396, 0.03397, 0.03398, 0.03399, 0.034, 0.03401,
    0.03402, 0.03404, 0.03405, 0.03406, 0.03407, 0.03408, 0.03409,
    0.0341, 0.03411, 0.03413, 0.03414, 0.03415, 0.03416, 0.03417,
    0.03418, 0.03419, 0.03421, 0.03422, 0.03423, 0.03424, 0.03425,
    0.03426, 0.03427, 0.03429, 0.0343, 0.03431, 0.03432, 0.03433,
    0.03434, 0.03435, 0.03437, 0.03438, 0.03439, 0.0344, 0.03441,
    0.03442, 0.03443, 0.03445, 0.03446, 0.03447, 0.03448, 0.03449,
    0.0345, 0.03451, 0.03453, 0.03454, 0.03455, 0.03456, 0.03457,
    0.03458, 0.03459, 0.03461, 0.03462, 0.03463, 0.03464, 0.03465,
    0.03466, 0.03467, 0.03469, 0.0347, 0.03471, 0.03472, 0.03473,
    0.03474, 0.03475, 0.03477, 0.03478, 0.03479, 0.0379, 0.03783,
    0.03776, 0.0377, 0.03763, 0.03756, 0.03749, 0.03742, 0.03735,
    0.03728, 0.03722, 0.03715, 0.03708, 0.03701, 0.03694, 0.0369,
    0.03687, 0.03683, 0.0368, 0.03676, 0.03673, 0.03669, 0.03666,
    0.03663, 0.0366, 0.03656, 0.03653, 0.0365, 0.03647, 0.03644,
    0.03641, 0.03638, 0.03636, 0.03633, 0.0363, 0.03627, 0.03625,
    0.03622, 0.03619, 0.03617, 0.03614, 0.03612, 0.03609, 0.03607,
    0.03604, 0.03602, 0.036, 0.03597, 0.03595, 0.03593, 0.03591,
    0.03588, 0.03586, 0.03584, 0.03582, 0.0358, 0.03578, 0.03576,
    0.03574, 0.03572, 0.0357, 0.03568, 0.03566, 0.03564, 0.03562,
    0.03561, 0.03559, 0.03557, 0.03555, 0.03553, 0.03552, 0.0355,
    0.03548, 0.03547, 0.03545, 0.03543, 0.03542, 0.0354, 0.03539,
    0.03537, 0.03536, 0.03534, 0.03533, 0.03531, 0.0353, 0.03528,
    0.03527, 0.03526, 0.03524, 0.03523, 0.03521, 0.0352, 0.03519,
    0.03517, 0.03516, 0.03515, 0.03514, 0.03512, 0.03511, 0.0351,
    0.03509, 0.03508, 0.03506, 0.03505, 0.03504, 0.03503, 0.03502,
    0.03501, 0.035, 0.03499, 0.03497, 0.03496, 0.03495, 0.03494,
    0.03493, 0.03492, 0.03491, 0.0349, 0.03489, 0.03488, 0.03487,
    0.03487, 0.03486, 0.03485, 0.03484, 0.03483, 0.03482, 0.03481,
    0.0348, 0.03479, 0.03479, 0.03478, 0.03477, 0.03476, 0.03475,
    0.03475, 0.03474, 0.03473, 0.03472, 0.03471, 0.03471, 0.0347,
    0.03469, 0.03469, 0.03468, 0.03467, 0.03467, 0.03466, 0.03465,
    0.03465, 0.03464, 0.03463, 0.03463, 0.03462, 0.03461, 0.03461,
    0.0346, 0.0346, 0.03459, 0.03459, 0.03458, 0.03457, 0.03457,
    0.03456, 0.03456, 0.03455, 0.03455, 0.03454, 0.03454, 0.03453,
    0.03453, 0.03453, 0.03452, 0.03452, 0.03451, 0.03451, 0.0345,
    0.0345, 0.0345, 0.03449, 0.03449, 0.03449, 0.03448, 0.03448,
    0.03447, 0.03447, 0.03447, 0.03447, 0.03446, 0.03446, 0.03446,
    0.03445, 0.03445, 0.03445, 0.03444, 0.03444, 0.03444, 0.03444,
    0.03444, 0.03443, 0.03443, 0.03443, 0.03443, 0.03442, 0.03442,
    0.03442, 0.03442, 0.03442, 0.03442, 0.03441, 0.03441, 0.03441,
    0.03441, 0.03441, 0.03441, 0.03441, 0.03441, 0.0344, 0.0344,
    0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344,
    0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344,
    0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344,
    0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344, 0.0344,
    0.03441, 0.03441, 0.03441, 0.03441, 0.03441, 0.03441, 0.03441,
    0.03441, 0.03441, 0.03442, 0.03442, 0.03442, 0.03442, 0.03442,
    0.03442, 0.03443, 0.03443, 0.03443, 0.03443, 0.03443, 0.03444,
    0.03444, 0.03444, 0.03444, 0.03444, 0.03445, 0.03445, 0.03445,
    0.03445, 0.03445, 0.03446, 0.03446, 0.03446, 0.03446, 0.03447,
    0.03447, 0.03447, 0.03448, 0.03448, 0.03448, 0.03448, 0.03449,
    0.03449, 0.03449, 0.0345, 0.0345, 0.0345, 0.0345, 0.03451,
    0.03451, 0.03451, 0.03452, 0.03452, 0.03452, 0.03453, 0.03453,
    0.03453, 0.03454, 0.03454, 0.03454, 0.03455, 0.03455, 0.03456,
    0.03456, 0.03456, 0.03457, 0.03457, 0.03457, 0.03458, 0.03458,
    0.03459, 0.03459, 0.03459, 0.0346, 0.0346, 0.03461, 0.03461,
    0.03461, 0.03462, 0.03462, 0.03463, 0.03463, 0.03464, 0.03464,
    0.03464, 0.03465, 0.03465, 0.03466, 0.03466, 0.03467, 0.03467,
    0.03468, 0.03468, 0.03469, 0.03469, 0.03469, 0.0347, 0.0347,
    0.03471, 0.03471, 0.03472, 0.03472, 0.03473, 0.03473, 0.03474,
    0.03474, 0.03475, 0.03475, 0.03476, 0.03476, 0.03477, 0.03477,
    0.03478, 0.03478, 0.03479, 0.03479, 0.0348, 0.0348, 0.03481,
    0.03482, 0.03482, 0.03483, 0.03483, 0.03484, 0.03484, 0.03485,
    0.03485, 0.03486, 0.03486, 0.03487, 0.03488, 0.03488, 0.03489,
    0.03489, 0.0349, 0.0349, 0.03491, 0.03491, 0.03492, 0.03493,
    0.03493, 0.03494, 0.03494, 0.03495, 0.03495, 0.03496, 0.03497,
    0.03497, 0.03498, 0.03498, 0.03499, 0.035, 0.035, 0.03501,
    0.03501, 0.03502, 0.03503, 0.03503, 0.03504, 0.03504, 0.03505,
    0.03506, 0.03506, 0.03507, 0.03507, 0.03508, 0.03509, 0.03509,
    0.0351, 0.03511, 0.03511, 0.03512, 0.03512, 0.03513, 0.03514,
    0.03514, 0.03515, 0.03516, 0.03516, 0.03517, 0.03518, 0.03518,
    0.03519, 0.03519, 0.0352, 0.03521, 0.03521, 0.03522, 0.03523,
    0.03523, 0.03524, 0.03525, 0.03525, 0.03526, 0.03527, 0.03527,
    0.03528, 0.03529, 0.03529, 0.0353, 0.0353, 0.03531, 0.03532,
    0.03532, 0.03533, 0.03534, 0.03534, 0.03535, 0.03536, 0.03536,
    0.03537, 0.03538, 0.03538, 0.03539, 0.0354, 0.0354, 0.03541,
    0.03542, 0.03543, 0.03543, 0.03544, 0.03545, 0.03545, 0.03546,
    0.03547, 0.03547, 0.03548, 0.03549, 0.03549, 0.0355, 0.03551,
    0.03551, 0.03552, 0.03553, 0.03553, 0.03554, 0.03555, 0.03556,
    0.03556, 0.03557, 0.03558, 0.03558, 0.03559, 0.0356, 0.0356,
    0.03561, 0.03562, 0.03562, 0.03563, 0.03564, 0.03565, 0.03565,
    0.03566, 0.03567, 0.03567, 0.03568, 0.03569, 0.03569, 0.0357,
    0.03571, 0.03572, 0.03572, 0.03573, 0.03574, 0.03574, 0.03575,
    0.03576, 0.03577, 0.03577, 0.03578, 0.03579, 0.03579, 0.0358,
    0.03581, 0.03582, 0.03582, 0.03583, 0.03584, 0.03584, 0.03585,
    0.03586, 0.03587, 0.03587, 0.03588, 0.03589, 0.03589, 0.0359,
    0.03591, 0.03592, 0.03592, 0.03593, 0.03594, 0.03594, 0.03595,
    0.03596, 0.03597, 0.03597, 0.03598, 0.03599, 0.036, 0.036,
    0.03601, 0.03602, 0.03602, 0.03603, 0.03604, 0.03605, 0.03605,
    0.03606, 0.03607, 0.03608, 0.03608, 0.03609, 0.0361, 0.03611,
    0.03611, 0.03612, 0.03613, 0.03613, 0.03614, 0.03615, 0.03616,
    0.03616, 0.03617, 0.03618, 0.03619, 0.03619, 0.0362, 0.03621,
    0.03622, 0.03622, 0.03623, 0.03624, 0.03624, 0.03625, 0.03626,
    0.03627, 0.03627, 0.03628, 0.03629, 0.0363, 0.0363, 0.03631,
    0.03632, 0.03633, 0.03633, 0.03634, 0.03635, 0.03636, 0.03636,
    0.03637, 0.03638, 0.03639, 0.03639, 0.0364, 0.03641, 0.03642,
    0.03642, 0.03643, 0.03644, 0.03645, 0.03645, 0.03646, 0.03647,
    0.03648, 0.03648, 0.03649, 0.0365, 0.0365, 0.03651, 0.03652,
    0.03653, 0.03653, 0.03654, 0.03655, 0.03656, 0.03656, 0.03657,
    0.03658, 0.03659, 0.03659, 0.0366, 0.03661, 0.03662, 0.03662,
    0.03663, 0.03664, 0.03665, 0.03665, 0.03666, 0.03667, 0.03668,
    0.03668, 0.03669, 0.0367, 0.03671, 0.03671, 0.03672, 0.03673,
    0.03674, 0.03674, 0.03675, 0.03676, 0.03677, 0.03677, 0.03678,
    0.03679, 0.0368, 0.0368, 0.03681, 0.03682, 0.03683, 0.03683,
    0.03684, 0.03685, 0.03686, 0.03686, 0.03687, 0.03688, 0.03689,
    0.03689, 0.0369, 0.03691, 0.03692, 0.03692, 0.03693, 0.03694,
    0.03695, 0.03695, 0.03696, 0.03697, 0.03698, 0.03698, 0.03699,
    0.037, 0.03701, 0.03701, 0.03702, 0.03703, 0.03704, 0.03704,
    0.03705, 0.03706, 0.03706, 0.03707, 0.03708, 0.03709, 0.03709,
    0.0371, 0.03711, 0.03712, 0.03712, 0.03713, 0.03714, 0.03715,
    0.03715, 0.03716, 0.03717, 0.03718, 0.03718, 0.03719, 0.0372,
    0.03721, 0.03721, 0.03722, 0.03723, 0.03724, 0.03724, 0.03725,
    0.03726, 0.03727, 0.03727, 0.03728, 0.03729, 0.03729, 0.0373,
    0.03731, 0.03732, 0.03732, 0.03733, 0.07474, 0.07476, 0.07478,
    0.0748, 0.07481, 0.07483, 0.07485, 0.07486, 0.07488, 0.0749,
    0.07491, 0.07493, 0.07494, 0.07496, 0.07498, 0.07499, 0.07501,
    0.07502, 0.07504, 0.07505, 0.07507, 0.07509, 0.0751, 0.07512,
    0.07513, 0.07515, 0.07516, 0.07518, 0.07519, 0.07521, 0.07522,
    0.07524, 0.07525, 0.07527, 0.07528, 0.0753, 0.07531, 0.07532,
    0.07534, 0.07535, 0.07537, 0.07538, 0.0754, 0.07541, 0.07542,
    0.07544, 0.07545, 0.07547, 0.07548, 0.07549, 0.07551, 0.07552,
    0.07553, 0.07555, 0.07556, 0.07557, 0.07559, 0.0756, 0.07561,
    0.07563, 0.07564, 0.07565, 0.07567, 0.07568, 0.07569, 0.0757,
    0.07572, 0.07573, 0.07574, 0.07575, 0.07577, 0.07578, 0.07579,
    0.0758, 0.07581, 0.07583, 0.07584, 0.07585, 0.07586, 0.07587,
    0.07588, 0.07589, 0.07591, 0.07592, 0.07593, 0.07594, 0.07595,
    0.07596, 0.07597, 0.07598, 0.07599, 0.076, 0.07601, 0.07603,
    0.07604, 0.07605, 0.07606, 0.07607, 0.07608, 0.07609, 0.0761,
    0.07611, 0.07612, 0.07613, 0.07613, 0.07614, 0.07615, 0.07616,
    0.07617, 0.07618, 0.07619, 0.0762, 0.07621, 0.07622, 0.07623,
    0.07623, 0.07624, 0.07625, 0.07626, 0.07627, 0.07628, 0.07628,
    0.07629, 0.0763, 0.07631, 0.07632, 0.07632, 0.07633, 0.07634,
    0.07635, 0.07635, 0.07636, 0.07637, 0.07638, 0.07638, 0.07639,
    0.0764, 0.0764, 0.07641, 0.07642, 0.07642, 0.07643, 0.07644,
    0.07644, 0.07645, 0.07646, 0.07646, 0.07647, 0.07647, 0.07648,
    0.07649, 0.07649, 0.0765, 0.0765, 0.07651, 0.07652, 0.07652,
    0.07653, 0.07653, 0.07654, 0.07654, 0.07655, 0.07655, 0.07656,
    0.07656, 0.07657, 0.07657, 0.07658, 0.07658, 0.07659, 0.07659,
    0.0766, 0.0766, 0.07661, 0.07661, 0.07662, 0.07662, 0.07663,
    0.07663, 0.07663, 0.07664, 0.07664, 0.07665, 0.07665, 0.07666,
    0.07666, 0.07666, 0.07667, 0.07667, 0.07667, 0.07668, 0.07668,
    0.07669, 0.07669, 0.07669, 0.0767, 0.0767, 0.0767, 0.07671,
    0.07671, 0.07671, 0.07672, 0.07672, 0.07672, 0.07673, 0.07673,
    0.07673, 0.07674, 0.07674, 0.07674, 0.07675, 0.07675, 0.07675,
    0.07675, 0.07676, 0.07676, 0.07676, 0.07677, 0.07677, 0.07677,
    0.07677, 0.07678, 0.07678, 0.07678, 0.07679, 0.07679, 0.07679,
    0.07679, 0.0768, 0.0768, 0.0768, 0.0768, 0.07681, 0.07681,
    0.07681, 0.07681, 0.07681, 0.07682, 0.07682, 0.07682, 0.07682,
    0.07683, 0.07683, 0.07683, 0.07683, 0.07683, 0.07684, 0.07684,
    0.07684, 0.07684, 0.07685, 0.07685, 0.07685, 0.07685, 0.07685,
    0.07686, 0.07686, 0.07686, 0.07686, 0.07686, 0.07687, 0.07687,
    0.07687, 0.07687, 0.07687, 0.07687, 0.07688, 0.07688, 0.07688,
    0.07688, 0.07688, 0.07689, 0.07689, 0.07689, 0.07689, 0.07689,
    0.07689, 0.0769, 0.0769, 0.0769, 0.0769, 0.0769, 0.07691,
    0.07691, 0.07691, 0.07691, 0.07691, 0.07691, 0.07692, 0.07692,
    0.07692, 0.07692, 0.07692, 0.07692, 0.07693, 0.07693, 0.07693,
    0.07693, 0.07693, 0.07693, 0.07693, 0.07694, 0.07694, 0.07694,
    0.07694, 0.07694, 0.07694, 0.07695, 0.07695, 0.07695, 0.07695,
    0.07695, 0.07695, 0.07695, 0.07696, 0.07696, 0.07696, 0.07696,
    0.07696, 0.07696, 0.07697, 0.07697, 0.07697, 0.07697, 0.07697,
    0.07697, 0.07697, 0.07698, 0.07698, 0.07698, 0.07698, 0.07698,
    0.07698, 0.07698, 0.07699, 0.07699, 0.07699, 0.07699, 0.07699,
    0.07699, 0.07699, 0.077, 0.077, 0.077, 0.077, 0.077, 0.077,
    0.077, 0.07701, 0.07701, 0.07701, 0.07701, 0.07701, 0.07701,
    0.07701, 0.07701, 0.07702, 0.07702, 0.07702, 0.07702, 0.07702,
    0.07702, 0.07702, 0.07703, 0.07703, 0.07703, 0.07703, 0.07703,
    0.07703, 0.07703, 0.07703, 0.07704, 0.07704, 0.07704, 0.07704,
    0.07704, 0.07704, 0.07704, 0.07704, 0.07705, 0.07705, 0.07705,
    0.07705, 0.07705, 0.07705, 0.07705, 0.07705, 0.07706, 0.07706,
    0.07706, 0.07706, 0.07706, 0.07706, 0.07706, 0.07706, 0.07707,
    0.07707, 0.07707, 0.07707, 0.07707, 0.07707, 0.07707, 0.07707,
    0.07707, 0.07708, 0.07708, 0.07708, 0.07708, 0.07708, 0.07708,
    0.07708, 0.07708, 0.07708, 0.07709, 0.07709, 0.07709, 0.07709,
    0.07709, 0.07709, 0.07709, 0.07709, 0.07709, 0.0771, 0.0771,
    0.0771, 0.0771, 0.0771, 0.0771, 0.0771, 0.0771, 0.0771, 0.07711,
    0.07711, 0.07711, 0.07711, 0.07711, 0.07711, 0.07711, 0.07711,
    0.07711, 0.07711, 0.07712, 0.07712, 0.07712, 0.07712, 0.07712,
    0.07712, 0.07712, 0.07712, 0.07712, 0.07713, 0.07713, 0.07713,
    0.07713, 0.07713, 0.07713, 0.07713, 0.07713, 0.07713, 0.07714,
    0.07714, 0.07714, 0.07714, 0.07714, 0.07714, 0.07714, 0.07714,
    0.07714, 0.07714, 0.07715, 0.07715, 0.07715, 0.07715, 0.07715,
    0.07715, 0.07715, 0.07715, 0.07716, 0.07716, 0.07716, 0.07716,
    0.07716, 0.07716, 0.07716, 0.07716, 0.07716, 0.07717, 0.07717,
    0.07717, 0.07717, 0.07717, 0.07717, 0.07717, 0.07717, 0.07718,
    0.07718, 0.07718, 0.07718, 0.07718, 0.07718, 0.07718, 0.07718,
    0.07718, 0.07719, 0.07719, 0.07719, 0.07719, 0.07719, 0.07719,
    0.07719, 0.0772, 0.0772, 0.0772, 0.0772, 0.0772, 0.0772,
    0.0772, 0.0772, 0.07721, 0.07721, 0.07721, 0.07721, 0.07721,
    0.07721, 0.07721, 0.07722, 0.07722, 0.07722, 0.07722, 0.07722,
    0.07722, 0.07722, 0.07723, 0.07723, 0.07723, 0.07723, 0.07723,
    0.07723, 0.07724, 0.07724, 0.07724, 0.07724, 0.07724, 0.07724,
    0.07725, 0.07725, 0.07725, 0.07725, 0.07725, 0.07725, 0.07726,
    0.07726, 0.07726, 0.07726, 0.07726, 0.07726, 0.07727, 0.07727,
    0.07727, 0.07727, 0.07727, 0.07727, 0.07728, 0.07728, 0.07728,
    0.07728, 0.07728, 0.07729, 0.07729, 0.07729, 0.07729, 0.07729,
    0.07729, 0.0773, 0.0773, 0.0773, 0.0773, 0.0773, 0.07731,
    0.07731, 0.07731, 0.07731, 0.07731, 0.07732, 0.07732, 0.07732,
    0.07732, 0.07733, 0.07733, 0.07733, 0.07733, 0.07733, 0.07734,
    0.07734, 0.07734, 0.07734, 0.07734, 0.07735, 0.07735, 0.07735,
    0.07735, 0.07736, 0.07736, 0.07736, 0.07736, 0.07737, 0.07737,
    0.07737, 0.07737, 0.07738, 0.07738, 0.07738, 0.07738, 0.07739,
    0.07739, 0.07739, 0.07739, 0.0774, 0.0774, 0.0774, 0.0774,
    0.07741, 0.07741, 0.07741, 0.07741, 0.07742, 0.07742, 0.07742,
    0.07742, 0.07743, 0.07743, 0.07743, 0.07744, 0.07744, 0.07744,
    0.07744, 0.07745, 0.07745, 0.07745, 0.07746, 0.07746, 0.07746,
    0.07746, 0.07747, 0.07747, 0.07747, 0.07748, 0.07748, 0.07748,
    0.07749, 0.07749, 0.07749, 0.07749, 0.0775, 0.0775, 0.0775,
    0.07751, 0.07751, 0.07751, 0.07752, 0.07752, 0.07752, 0.07753,
    0.07753, 0.07753, 0.07754, 0.07754, 0.07754, 0.07755, 0.07755,
    0.07755, 0.07756, 0.07756, 0.07756, 0.07757, 0.07757, 0.07758,
    0.07758, 0.07758, 0.07759, 0.07759, 0.07759, 0.0776, 0.0776,
    0.0776, 0.07761, 0.07761, 0.07762, 0.07762, 0.07762, 0.07763,
    0.07763, 0.07763, 0.07764, 0.07764, 0.07765, 0.07765, 0.07765,
    0.07766, 0.07766, 0.07767, 0.07767, 0.07767, 0.07768, 0.07768,
    0.07769, 0.07769, 0.07769, 0.0777, 0.0777, 0.07771, 0.07771,
    0.07771, 0.07772, 0.07772, 0.07773, 0.07773, 0.07774, 0.07774,
    0.07774, 0.07775, 0.07775, 0.07776, 0.07776, 0.07777, 0.07777,
    0.07778, 0.07778, 0.07778, 0.07779, 0.07779, 0.0778, 0.0778,
    0.07781, 0.07781, 0.07782, 0.07782, 0.07782, 0.07783, 0.07783,
    0.07784, 0.07784, 0.07785, 0.07785, 0.07786, 0.07786, 0.07787,
    0.07787, 0.07788, 0.07788, 0.07789, 0.07789, 0.0779, 0.0779,
    0.0779, 0.07791, 0.07791, 0.07792, 0.07792, 0.07793, 0.07793,
    0.07794, 0.07794, 0.07795, 0.07795, 0.07796, 0.07796, 0.07797,
    0.07797, 0.07798, 0.07798, 0.07799, 0.078, 0.078, 0.07801,
    0.07801, 0.07802, 0.07802, 0.07803, 0.07803, 0.07804, 0.07804,
    0.07805, 0.07805, 0.07806, 0.07806, 0.07807, 0.07807, 0.07808,
    0.07808, 0.07809, 0.0781, 0.0781, 0.07811, 0.07811, 0.07812,
    0.07812, 0.07813, 0.07813, 0.07814, 0.07815, 0.07815, 0.07816,
    0.07816, 0.07817, 0.07817, 0.07818, 0.07818, 0.07819, 0.0782,
    0.0782, 0.07821, 0.07821, 0.07822, 0.07823, 0.07823, 0.07824,
    0.07824, 0.07825, 0.07825, 0.07826, 0.07827, 0.07827, 0.07828,
    0.07828, 0.07829, 0.0783, 0.0783, 0.07831, 0.07831, 0.07832,
    0.07833, 0.07833, 0.07834, 0.07834, 0.07835, 0.07836, 0.07836,
    0.07837, 0.07837, 0.07838, 0.07839, 0.07839, 0.0784, 0.07841,
    0.07841, 0.07842, 0.07842, 0.07843, 0.07844, 0.07844, 0.07845,
    0.07846, 0.07846, 0.07847, 0.07848, 0.07848, 0.07849, 0.07849,
    0.0785, 0.07851, 0.07851, 0.07852, 0.07853, 0.07853, 0.07854,
    0.07855, 0.07855, 0.07856, 0.07857, 0.07857, 0.07858, 0.07859,
    0.07859, 0.0786, 0.07861, 0.07861, 0.07862, 0.07863, 0.07863,
    0.07864, 0.07865, 0.07865, 0.07866, 0.07867, 0.07867, 0.07868,
    0.07869, 0.07869, 0.0787, 0.07871, 0.07871, 0.07872, 0.07873,
    0.07873, 0.07874, 0.07875, 0.07876, 0.07876, 0.07877, 0.07878,
    0.07878, 0.07879, 0.0788, 0.0788, 0.07881, 0.07882, 0.07883,
    0.07883, 0.07884, 0.07885, 0.07885, 0.07886, 0.07887, 0.07888,
    0.07888, 0.07889, 0.0789, 0.0789, 0.07891, 0.07892, 0.07893,
    0.07893, 0.07894, 0.07895, 0.07895, 0.07896, 0.07897, 0.07898,
    0.07898, 0.07899, 0.079, 0.07901, 0.07901, 0.07902, 0.07903,
    0.07904, 0.07904, 0.07905, 0.07906, 0.07906, 0.07907, 0.07908,
    0.07909, 0.07909, 0.0791, 0.07911, 0.07912, 0.07912, 0.07913,
    0.07914, 0.07915, 0.07915, 0.07916, 0.07917, 0.07918, 0.07918,
    0.07919, 0.0792, 0.07921, 0.07922, 0.07922, 0.07923, 0.07924,
    0.07925, 0.07925, 0.07926, 0.07927, 0.07928, 0.07928, 0.07929,
    0.0793, 0.07931, 0.07932, 0.07932, 0.07933, 0.07934, 0.07935,
    0.07935, 0.07936, 0.07937, 0.07938, 0.07939, 0.07939, 0.0794,
    0.07941, 0.07942, 0.07942, 0.07943, 0.07944, 0.07945, 0.07946,
    0.07946, 0.07947, 0.07948, 0.07949, 0.0795, 0.0795, 0.07951,
    0.07952, 0.07953, 0.07953, 0.07954, 0.07955, 0.07956, 0.07957,
    0.07957, 0.07958, 0.07959, 0.0796, 0.07961, 0.07961, 0.07962,
    0.07963, 0.07964, 0.07965, 0.07966, 0.07966, 0.07967, 0.07968,
    0.07969, 0.0797, 0.0797, 0.07971, 0.07972, 0.07973, 0.07974,
    0.07974, 0.07975, 0.07976, 0.07977, 0.07978, 0.07979, 0.07979,
    0.0798, 0.07981, 0.07982, 0.07983, 0.07983, 0.07984, 0.07985,
    0.07986, 0.07987, 0.07988, 0.07988, 0.07989, 0.0799, 0.07991,
    0.07992, 0.07992, 0.07993, 0.07994, 0.07995, 0.07996, 0.07997,
    0.07997, 0.07998, 0.07999, 0.08, 0.08001, 0.08002, 0.08002,
    0.08003, 0.08004, 0.08005, 0.08006, 0.08007, 0.08007, 0.08008,
    0.08009, 0.0801, 0.08011, 0.08012, 0.08013, 0.08013, 0.08014,
    0.08015, 0.08016, 0.08017, 0.08018, 0.08018, 0.08019, 0.0802,
    0.08021, 0.08022, 0.08023, 0.08023, 0.08024, 0.08025, 0.08026,
    0.08027, 0.08028, 0.08029, 0.08029, 0.0803, 0.08031, 0.08032,
    0.08033, 0.08034, 0.08035, 0.08035, 0.08036, 0.08037, 0.08038,
    0.08039, 0.0804, 0.08041, 0.08041, 0.08042, 0.08043, 0.08044,
    0.08045, 0.08046, 0.08047, 0.08047, 0.08048, 0.08049, 0.0805,
    0.08051, 0.08052, 0.08053, 0.08053, 0.08054, 0.08055, 0.08056,
    0.08057, 0.08058, 0.08059, 0.08059, 0.0806, 0.08061, 0.08062,
    0.08063, 0.08064, 0.08065, 0.08066, 0.08066, 0.08067, 0.08068,
    0.08069, 0.0807, 0.08071, 0.08072, 0.08073, 0.08073, 0.08074,
    0.08075, 0.08076, 0.08077, 0.08078, 0.08079, 0.0808, 0.0808,
    0.08081, 0.08082, 0.08083, 0.08084, 0.08085, 0.08086, 0.08087,
    0.08087, 0.08088, 0.08089, 0.0809, 0.08091, 0.08092, 0.08093,
    0.08094, 0.08094, 0.08095, 0.08096, 0.08097, 0.08098, 0.08099,
    0.081, 0.08101, 0.08102, 0.08102, 0.08103, 0.08104, 0.08105,
    0.08106, 0.08107, 0.08108, 0.08109, 0.0811, 0.0811, 0.08111,
    0.08112, 0.08113, 0.08114, 0.08115, 0.08116, 0.08117, 0.08118,
    0.08118, 0.08119, 0.0812, 0.08121, 0.08122, 0.08123, 0.08124,
    0.08125, 0.08126, 0.08126, 0.08127, 0.08128, 0.08129, 0.0813,
    0.08131, 0.08132, 0.08133, 0.08134, 0.08134, 0.08135, 0.08136,
    0.08137, 0.08138, 0.08139, 0.0814, 0.08141, 0.08142, 0.08143,
    0.08143, 0.08144, 0.08145, 0.08146, 0.08147, 0.08148, 0.08149,
    0.0815, 0.08151, 0.08152, 0.08152, 0.08153, 0.08154, 0.08155,
    0.08156, 0.08157, 0.08158, 0.08159, 0.0816, 0.08161, 0.08162,
    0.08162, 0.08163, 0.08164, 0.08165, 0.08166, 0.08167, 0.08168,
    0.08169, 0.0817, 0.08171, 0.08171, 0.08172, 0.08173, 0.08174,
    0.08175, 0.08176, 0.08177, 0.08178, 0.08179, 0.0818, 0.08181,
    0.08181, 0.08182, 0.08183, 0.08184, 0.08185, 0.08186, 0.08187,
    0.08188, 0.08189, 0.0819, 0.08191, 0.08192, 0.08192, 0.08193,
    0.08194, 0.08195, 0.08196, 0.08197, 0.08198, 0.08199, 0.082,
    0.08201, 0.08202, 0.08203, 0.08203, 0.08204, 0.08205, 0.08206,
    0.08207, 0.08208, 0.08209, 0.0821, 0.08211, 0.08212, 0.08213,
    0.08214, 0.08214, 0.08215, 0.08216, 0.08217, 0.08218, 0.08219,
    0.0822, 0.08221, 0.08222, 0.08223, 0.08224, 0.08225, 0.08225,
    0.08226, 0.08227, 0.08228, 0.08229, 0.0823, 0.08231, 0.08232,
    0.08233, 0.08234, 0.08235, 0.08236, 0.08237, 0.08237, 0.08238,
    0.08239, 0.0824, 0.08241, 0.08242, 0.08243, 0.08244, 0.08245,
    0.08246, 0.08247, 0.08248, 0.08249, 0.0825, 0.0825, 0.08251,
    0.08252, 0.08253, 0.08254, 0.08255, 0.08256, 0.08257, 0.08258,
    0.08259, 0.0826, 0.08261, 0.08262, 0.08262, 0.08263, 0.08264,
    0.08265, 0.08266, 0.08267, 0.08268, 0.08269, 0.0827, 0.08271,
    0.08272, 0.08273, 0.08274, 0.08275, 0.08275, 0.08276, 0.08277,
    0.08278, 0.08279, 0.0828, 0.08281, 0.08282, 0.08283, 0.08284,
    0.08285, 0.08286, 0.08287, 0.08288, 0.08289, 0.08289, 0.0829,
    0.08291, 0.08292, 0.08293, 0.08294, 0.08295, 0.08296, 0.08297,
    0.08298, 0.08299, 0.083, 0.08301, 0.08302, 0.08303, 0.08303,
    0.08304, 0.08305, 0.08306, 0.08307, 0.08308, 0.08309, 0.0831,
    0.08311, 0.08312, 0.08313, 0.08314, 0.08315, 0.08316, 0.08317,
    0.08317, 0.08318, 0.08319, 0.0832, 0.08321, 0.08322, 0.08323,
    0.08324, 0.08325, 0.08326, 0.08327, 0.08328, 0.08329, 0.0833,
    0.08331, 0.08331, 0.08332, 0.08333, 0.08334, 0.08335, 0.08336,
    0.08337, 0.08338, 0.08339, 0.0834, 0.08341, 0.08342, 0.08343,
    0.08344, 0.08345, 0.08346, 0.08346, 0.08347, 0.08348, 0.08349,
    0.0835, 0.08351, 0.08352, 0.08353, 0.08354, 0.08355, 0.08356,
    0.08357, 0.08358, 0.08359, 0.0836, 0.08361, 0.08362, 0.08362,
    0.08363, 0.08364, 0.08365, 0.08366, 0.08367, 0.08368, 0.08369,
    0.0837, 0.08371, 0.08372, 0.08373, 0.08374, 0.08375, 0.08376,
    0.08377, 0.08378, 0.08378, 0.08379, 0.0838, 0.08381, 0.08382,
    0.08383, 0.08384, 0.08385, 0.08386, 0.08387, 0.08388, 0.08389,
    0.0839, 0.08391, 0.08392, 0.08393, 0.08394, 0.08394, 0.08395,
    0.08396, 0.08397, 0.08398, 0.08399, 0.084, 0.08401, 0.08402,
    0.08403, 0.08404, 0.08405, 0.08406, 0.08407, 0.08408, 0.08409,
    0.0841, 0.08411, 0.08411, 0.08412, 0.08413, 0.08414, 0.08415,
    0.08416, 0.08417, 0.08418, 0.08419, 0.0842, 0.08421, 0.08422,
    0.08423, 0.08424, 0.08425, 0.08426, 0.08427, 0.08428, 0.08428,
    0.08429, 0.0843, 0.08431, 0.08432, 0.08433, 0.08434, 0.08435,
    0.08436, 0.08437, 0.08438, 0.08439, 0.0844, 0.08441, 0.08442,
    0.08443, 0.08444, 0.08445, 0.08446, 0.08446, 0.08447, 0.08448,
    0.08449, 0.0845, 0.08451, 0.08452, 0.08453, 0.08454, 0.08455,
    0.08456, 0.08457, 0.08458, 0.08459, 0.0846, 0.08461, 0.08462,
    0.08463, 0.08464, 0.08464, 0.08465, 0.08466, 0.08467, 0.08468,
    0.08469, 0.0847, 0.08471, 0.08472, 0.08473, 0.08474, 0.08475,
    0.08476, 0.08477, 0.08478, 0.08479, 0.0848, 0.08481, 0.08482,
    0.08483, 0.08484, 0.08484, 0.08485, 0.08486, 0.08487, 0.08488,
    0.08489, 0.0849, 0.08491, 0.08492, 0.08493, 0.08494, 0.08495,
    0.08496, 0.08497, 0.08498, 0.08499, 0.085, 0.08501, 0.08502,
    0.08503, 0.08504, 0.08504, 0.08505, 0.08506, 0.08507, 0.08508,
    0.08509, 0.0851, 0.08511, 0.08512, 0.08513, 0.08514, 0.08515,
    0.08516, 0.08517, 0.08518, 0.08519, 0.0852, 0.08521, 0.08522,
    0.08523, 0.08524, 0.08524, 0.08525, 0.08526, 0.08527, 0.08528,
    0.08529, 0.0853, 0.08531, 0.08532, 0.08533, 0.08534, 0.08535,
    0.08536, 0.08537, 0.08538, 0.08539, 0.0854, 0.08541, 0.08542,
    0.08543, 0.08544, 0.08545, 0.08546, 0.08546, 0.08547, 0.08548,
    0.08549, 0.0855, 0.08551, 0.08552, 0.08553, 0.08554, 0.08555,
    0.08556, 0.08557, 0.08558, 0.08559, 0.0856, 0.08561, 0.08562,
    0.08563, 0.08564, 0.08565, 0.08566, 0.08567, 0.08567, 0.08568,
    0.08569, 0.0857, 0.08571, 0.08572, 0.08573, 0.08574, 0.08575,
    0.08576, 0.08577, 0.08578, 0.08579, 0.0858, 0.08581, 0.08582,
    0.08583, 0.08584, 0.08585, 0.08586, 0.08587, 0.08588, 0.08589,
    0.08589, 0.0859, 0.08591, 0.08592, 0.08593, 0.08594, 0.08595,
    0.08596, 0.08597, 0.08598, 0.08599, 0.086, 0.08601, 0.08602,
    0.08603, 0.08604, 0.08605, 0.08606, 0.08607, 0.08608, 0.08609,
    0.0861, 0.0861, 0.08611, 0.08612, 0.08613, 0.08614, 0.08615,
    0.08616, 0.08617, 0.08618, 0.08619, 0.0862, 0.08621, 0.08622,
    0.08623, 0.0867, 0.08624, 0.08625, 0.08626, 0.08627, 0.08628,
    0.08629, 0.0863, 0.08631, 0.08631, 0.08632, 0.08633, 0.08634,
    0.08635, 0.08636, 0.08637, 0.08638, 0.08639, 0.0864, 0.08641,
    0.08642, 0.08643, 0.08644, 0.08645, 0.08646, 0.08647, 0.08648,
    0.08649, 0.0865, 0.08651, 0.08651, 0.08699, 0.08652, 0.08728,
    0.08758, 0.08789, 0.08819, 0.08851, 0.08882, 0.08915, 0.08948,
    0.08981, 0.09015, 0.09049, 0.09084, 0.0912, 0.09156, 0.09193,
    0.09231, 0.09269, 0.09308, 0.09347, 0.09388, 0.09428, 0.0947,
    0.09512, 0.09555, 0.09598, 0.09642, 0.09687, 0.09732, 0.09778,
    0.09824, 0.09871, 0.09918, 0.09966, 0.10014, 0.10063, 0.10112,
    0.10162, 0.10211, 0.10262, 0.10312, 0.10363, 0.10414, 0.10465,
    0.10516, 0.10568, 0.10619, 0.10671, 0.10722, 0.10774, 0.10825,
    0.10877, 0.10928, 0.10979, 0.11029, 0.1108, 0.1113, 0.11179,
    0.11228, 0.11277, 0.11325, 0.11372, 0.11419, 0.11465, 0.1151,
    0.11554, 0.11597, 0.1164, 0.11681, 0.11721, 0.11761, 0.11798,
    0.11835, 0.1187, 0.11904, 0.11937, 0.11967, 0.11997, 0.12024,
    0.1205, 0.12075, 0.12097, 0.12118, 0.12137, 0.12154, 0.12169,
    0.12183, 0.12194, 0.12204, 0.12212, 0.12218, 0.12221, 0.12223,
    0.12223, 0.12221, 0.12217, 0.12211, 0.12204, 0.12194, 0.12183,
    0.1217, 0.12155, 0.12138, 0.1212, 0.12101, 0.12079, 0.12057,
    0.12032, 0.12007, 0.1198, 0.11952, 0.11922, 0.11892, 0.1186,
    0.11828, 0.11795, 0.11761, 0.11726, 0.11691, 0.11655, 0.11619,
    0.11583, 0.11546, 0.1151, 0.11473, 0.11436, 0.11399, 0.11362,
    0.11326, 0.1129, 0.11254, 0.11219, 0.11184, 0.1115, 0.11116,
    0.11083, 0.11051, 0.1102, 0.1099, 0.1096, 0.10932, 0.10904,
    0.10878, 0.10852, 0.10827, 0.10803, 0.1078, 0.10758, 0.10737,
    0.10716, 0.10697, 0.10679, 0.10661, 0.10645, 0.10629, 0.10614,
    0.106, 0.10587, 0.10575, 0.10563, 0.10552, 0.10542, 0.10533,
    0.10524, 0.10516, 0.10508, 0.10501, 0.10495, 0.08262, 0.08264,
    0.08265, 0.08266, 0.08267, 0.08269, 0.0827, 0.08271, 0.08273,
    0.08274, 0.08275, 0.08276, 0.08277, 0.08279, 0.0828, 0.08281,
    0.08282, 0.08283, 0.08284, 0.08286, 0.08287, 0.08288, 0.08289,
    0.0829, 0.08291, 0.08292, 0.08293, 0.08294, 0.08296, 0.08297,
    0.08298, 0.08299, 0.083, 0.08301, 0.08302, 0.08303, 0.08304,
    0.08305, 0.08306, 0.08307, 0.08308, 0.08308, 0.08309, 0.0831,
    0.08311, 0.08312, 0.08313, 0.08314, 0.08315, 0.08316, 0.08316,
    0.08317, 0.08318, 0.08319, 0.0832, 0.08321, 0.08321, 0.08322,
    0.08323, 0.08324, 0.08324, 0.08325, 0.08326, 0.08327, 0.08327,
    0.08328, 0.08329, 0.08329, 0.0833, 0.08331, 0.08331, 0.08332,
    0.08333, 0.08333, 0.08334, 0.08335, 0.08335, 0.08336, 0.08336,
    0.08337, 0.08337, 0.08338, 0.08339, 0.08339, 0.0834, 0.0834,
    0.08341, 0.08341, 0.08342, 0.08342, 0.08343, 0.08343, 0.08343,
    0.08344, 0.08344, 0.08345, 0.08345, 0.08345, 0.08346, 0.08346,
    0.08347, 0.08347, 0.08347, 0.08348, 0.08348, 0.08348, 0.08348,
    0.08349, 0.08349, 0.08349, 0.08349, 0.0835, 0.0835, 0.0835,
    0.0835, 0.08351, 0.08351, 0.08351, 0.08351, 0.08351, 0.08351,
    0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352,
    0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352,
    0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352,
    0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08352, 0.08351,
    0.08351, 0.08351, 0.08351, 0.08351, 0.08351, 0.0835, 0.0835,
    0.0835, 0.0835, 0.0835, 0.08349, 0.08349, 0.08349, 0.08349,
    0.08348, 0.08348, 0.08348, 0.08348, 0.08347, 0.08347, 0.08347,
    0.08346, 0.08346, 0.08346, 0.08345, 0.08345, 0.08345, 0.08344,
    0.08344, 0.08344, 0.08343, 0.08343, 0.08342, 0.08342, 0.08342,
    0.08341, 0.08341, 0.0834, 0.0834, 0.08339, 0.08339, 0.08338,
    0.08338, 0.08337, 0.08337, 0.08336, 0.08336, 0.08335, 0.08335,
    0.08334, 0.08334, 0.08333, 0.08333, 0.08332, 0.08332, 0.08331,
    0.08331, 0.0833, 0.08329, 0.08329, 0.08328, 0.08328, 0.08327,
    0.08326, 0.08326, 0.08325, 0.08325, 0.08324, 0.08323, 0.08323,
    0.08322, 0.08321, 0.08321, 0.0832, 0.08319, 0.08319, 0.08318,
    0.08317, 0.08317, 0.08316, 0.08315, 0.08315, 0.08314, 0.08313,
    0.08313, 0.08312, 0.08311, 0.0831, 0.0831, 0.08309, 0.08308,
    0.08307, 0.08307, 0.08306, 0.08305, 0.08304, 0.08304, 0.08303,
    0.08302, 0.08301, 0.08301, 0.083, 0.08299, 0.08298, 0.08297,
    0.08297, 0.08296, 0.08295, 0.08294, 0.08293, 0.08293, 0.08292,
    0.08291, 0.0829, 0.08289, 0.08289, 0.08288, 0.08287, 0.08286,
    0.08285, 0.08284, 0.08284, 0.08283, 0.08282, 0.08281, 0.0828,
    0.08279, 0.08279, 0.08278, 0.08277, 0.08276, 0.08275, 0.08274,
    0.08274, 0.08273, 0.08272, 0.08271, 0.0827, 0.08269, 0.08268,
    0.08267, 0.08267, 0.08266, 0.08265, 0.08264, 0.08263, 0.08262,
    0.08261, 0.08261, 0.0826, 0.08259, 0.08258, 0.08257, 0.08256,
    0.08255, 0.08254, 0.08254, 0.08253, 0.08252, 0.08251, 0.0825,
    0.08249, 0.08248, 0.08247, 0.08247, 0.08246, 0.08245, 0.08244,
    0.08243, 0.08242, 0.08241, 0.0824, 0.0824, 0.08239, 0.08238,
    0.08237, 0.08236, 0.08235, 0.08234, 0.08233, 0.08233, 0.08232,
    0.08231, 0.0823, 0.08229, 0.08228, 0.08227, 0.08227, 0.08226,
    0.08225, 0.08224, 0.08223, 0.08222, 0.08222, 0.08221, 0.0822,
    0.08219, 0.08218, 0.08217, 0.08217, 0.08216, 0.08215, 0.08214,
    0.08213, 0.08212, 0.08212, 0.08211, 0.0821, 0.08209, 0.08208,
    0.08208, 0.08207, 0.08206, 0.08205, 0.08204, 0.08204, 0.08203,
    0.08202, 0.08201, 0.082, 0.082, 0.08199, 0.08198, 0.08197,
    0.08196, 0.08196, 0.08195, 0.08194, 0.08193, 0.08193, 0.08192,
    0.08191, 0.0819, 0.0819, 0.08189, 0.08188, 0.08187, 0.08187,
    0.08186, 0.08185, 0.08184, 0.08184, 0.08183, 0.08182, 0.08182,
    0.08181, 0.0818, 0.08179, 0.08179, 0.08178, 0.08177, 0.08177,
    0.08176, 0.08175, 0.08175, 0.08174, 0.08173, 0.08173, 0.08172,
    0.08171, 0.08171, 0.0817, 0.08169, 0.08169, 0.08168, 0.08167,
    0.08167, 0.08166, 0.08165, 0.08165, 0.08164, 0.08164, 0.08163,
    0.08162, 0.08162, 0.08161, 0.08161, 0.0816, 0.08159, 0.08159,
    0.08158, 0.08158, 0.08157, 0.08156, 0.08156, 0.08155, 0.08155,
    0.08154, 0.08154, 0.08153, 0.08153, 0.08152, 0.08151, 0.08151,
    0.0815, 0.0815, 0.08149, 0.08149, 0.08148, 0.08148, 0.08147,
    0.08147, 0.08146, 0.08146, 0.08145, 0.08145, 0.08144, 0.08144,
    0.08143, 0.08143, 0.08142, 0.08142, 0.08142, 0.08141, 0.08141,
    0.0814, 0.0814, 0.08139, 0.08139, 0.08138, 0.08138, 0.08138,
    0.08137, 0.08137, 0.08136, 0.08136, 0.08136, 0.08135, 0.08135,
    0.08134, 0.08134, 0.08134, 0.08133, 0.08133, 0.08133, 0.08132,
    0.08132, 0.08132, 0.08131, 0.08131, 0.08131, 0.0813, 0.0813,
    0.0813, 0.08129, 0.08129, 0.08129, 0.08128, 0.08128, 0.08128,
    0.08127, 0.08127, 0.08127, 0.08127, 0.08126, 0.08126, 0.08126,
    0.08125, 0.08125, 0.08125, 0.08125, 0.08124, 0.08124, 0.08124,
    0.08124, 0.08124, 0.08123, 0.08123, 0.08123, 0.08123, 0.08122,
    0.08122, 0.08122, 0.08122, 0.08122, 0.08121, 0.08121, 0.08121,
    0.08121, 0.08121, 0.08121, 0.0812, 0.0812, 0.0812, 0.0812,
    0.0812, 0.0812, 0.0812, 0.08119, 0.08119, 0.08119, 0.08119,
    0.08119, 0.08119, 0.08119, 0.08119, 0.08119, 0.08119, 0.08118,
    0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118,
    0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118,
    0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118,
    0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118,
    0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118,
    0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118, 0.08118,
    0.08119, 0.08119, 0.08119, 0.08119, 0.08119, 0.08119, 0.08119,
    0.08119, 0.08119, 0.08119, 0.0812, 0.0812, 0.0812, 0.0812,
    0.0812, 0.0812, 0.0812, 0.0812, 0.08121, 0.08121, 0.08121,
    0.08121, 0.08121, 0.08121, 0.08122, 0.08122, 0.08122, 0.08122,
    0.08122, 0.08122, 0.08123, 0.08123, 0.08123, 0.08123, 0.08123,
    0.08124, 0.08124, 0.08124, 0.08124, 0.08124, 0.08125, 0.08125,
    0.08125, 0.08125, 0.08126, 0.08126, 0.08126, 0.08126, 0.08127,
    0.08127, 0.08127, 0.08127, 0.08128, 0.08128, 0.08128, 0.08128,
    0.08129, 0.08129, 0.08129, 0.08129, 0.0813, 0.0813, 0.0813,
    0.08131, 0.08131, 0.08131, 0.08131, 0.08132, 0.08132, 0.08132,
    0.08133, 0.08133, 0.08133, 0.08134, 0.08134, 0.08134, 0.08135,
    0.08135, 0.08135, 0.08136, 0.08136, 0.08136, 0.08137, 0.08137,
    0.08137, 0.08138, 0.08138, 0.08138, 0.08139, 0.08139, 0.08139,
    0.0814, 0.0814, 0.0814, 0.08141, 0.08141, 0.08142, 0.08142,
    0.08142, 0.08143, 0.08143, 0.08144, 0.08144, 0.08144, 0.08145,
    0.08145, 0.08146, 0.08146, 0.08146, 0.08147, 0.08147, 0.08148,
    0.08148, 0.08149, 0.08149, 0.08149, 0.0815, 0.0815, 0.08151,
    0.08151, 0.08152, 0.08152, 0.08152, 0.08153, 0.08153, 0.08154,
    0.08154, 0.08155, 0.08155, 0.08156, 0.08156, 0.08157, 0.08157,
    0.08158, 0.08158, 0.08159, 0.08159, 0.0816, 0.0816, 0.08161,
    0.08161, 0.08162, 0.08162, 0.08163, 0.08163, 0.08164, 0.08164,
    0.08165, 0.08165, 0.08166, 0.08166, 0.08167, 0.08167, 0.08168,
    0.08168, 0.08169, 0.08169, 0.0817, 0.0817, 0.08171, 0.08172,
    0.08172, 0.08173, 0.08173, 0.08174, 0.08174, 0.08175, 0.08175,
    0.08176, 0.08177, 0.08177, 0.08178, 0.08178, 0.08179, 0.08179,
    0.0818, 0.08181, 0.08181, 0.08182, 0.08182, 0.08183, 0.08184,
    0.08184, 0.08185, 0.08185, 0.08186, 0.08187, 0.08187, 0.08188,
    0.08188, 0.08189, 0.0819, 0.0819, 0.08191, 0.08192, 0.08192,
    0.08193, 0.08193, 0.08194, 0.08195, 0.08195, 0.08196, 0.08197,
    0.08197, 0.08198, 0.08199, 0.08199, 0.082, 0.08201, 0.08201,
    0.08202, 0.08203, 0.08203, 0.08204, 0.08205, 0.08205, 0.08206,
    0.08207, 0.08207, 0.08208, 0.08209, 0.08209, 0.0821, 0.08211,
    0.08211, 0.08212, 0.08213, 0.08214, 0.08214, 0.08215, 0.08216,
    0.08216, 0.08217, 0.08218, 0.08219, 0.08219, 0.0822, 0.08221,
    0.08221, 0.08222, 0.08223, 0.08224, 0.08224, 0.08225, 0.08226,
    0.08227, 0.08227, 0.08228, 0.08229, 0.0823, 0.0823, 0.08231,
    0.08232, 0.08233, 0.08233, 0.08234, 0.08235, 0.08236, 0.08237,
    0.08237, 0.08238, 0.08239, 0.0824, 0.0824, 0.08241, 0.08242,
    0.08243, 0.08244, 0.08244, 0.08245, 0.08246, 0.08247, 0.08248,
    0.08248, 0.08249, 0.0825, 0.08251, 0.08252, 0.08253, 0.08253,
    0.08254, 0.08255, 0.08256, 0.08257, 0.08257, 0.08258, 0.08259,
    0.0826, 0.08261, 0.08262, 0.08262, 0.08263, 0.08264, 0.08265,
    0.08266, 0.08267, 0.08268, 0.08268, 0.08269, 0.0827, 0.08271,
    0.08272, 0.08273, 0.08274, 0.08275, 0.08275, 0.08276, 0.08277,
    0.08278, 0.08279, 0.0828, 0.08281, 0.08282, 0.08282, 0.08283,
    0.08284, 0.08285, 0.08286, 0.08287, 0.08288, 0.08289, 0.0829,
    0.08291, 0.08291, 0.08292, 0.08293, 0.08294, 0.08295, 0.08296,
    0.08297, 0.08298, 0.08299, 0.083, 0.08301, 0.08302, 0.08303,
    0.08303, 0.08304, 0.08305, 0.08306, 0.08307, 0.08308, 0.08309,
    0.0831, 0.08311, 0.08312, 0.08313, 0.08314, 0.08315, 0.08316,
    0.08317, 0.08318, 0.08319, 0.0832, 0.08321, 0.08322, 0.08323,
    0.08324, 0.08325, 0.08325, 0.08326, 0.08327, 0.08328, 0.08329,
    0.0833, 0.08331, 0.08332, 0.08333, 0.08334, 0.08335, 0.08336,
    0.08337, 0.08338, 0.08339, 0.0834, 0.08341, 0.08342, 0.08343,
    0.08344, 0.08345, 0.08346, 0.08347, 0.08348, 0.08349, 0.08351,
    0.08352, 0.08353, 0.08354, 0.08355, 0.08356, 0.08357, 0.08358,
    0.08359, 0.0836, 0.08361, 0.08362, 0.08363, 0.08364, 0.08365,
    0.08366, 0.08367, 0.08368, 0.08369, 0.0837, 0.08371, 0.08372,
    0.08373, 0.08375, 0.08376, 0.08377, 0.08378, 0.08379, 0.0838,
    0.08381, 0.08382, 0.08383, 0.08384, 0.08385, 0.08386, 0.08387,
    0.08388, 0.0839, 0.08391, 0.08392, 0.08393, 0.08394, 0.08395,
    0.08396, 0.08397, 0.08398, 0.08399, 0.08401, 0.08402, 0.08403,
    0.08404, 0.08405, 0.08406, 0.08407, 0.08408, 0.08409, 0.0841,
    0.08412, 0.08413, 0.08414, 0.08415, 0.08416, 0.08417, 0.08418,
    0.08419, 0.08421, 0.08422, 0.08423, 0.08424, 0.08425, 0.08426,
    0.08427, 0.08429, 0.0843, 0.08431, 0.08432, 0.08433, 0.08434,
    0.08435, 0.08437, 0.08438, 0.08439, 0.0844, 0.08441, 0.08442,
    0.08443, 0.08445, 0.08446, 0.08447, 0.08448, 0.08449, 0.0845,
    0.08452, 0.08453, 0.08454, 0.08455, 0.08456, 0.08457, 0.08459,
    0.0846, 0.08461, 0.08462, 0.08463, 0.08465, 0.08466, 0.08467,
    0.08468, 0.08469, 0.08471, 0.08472, 0.08473, 0.08474, 0.08475,
    0.08476, 0.08478, 0.08479, 0.0848, 0.08481, 0.08482, 0.08484,
    0.08485, 0.08486, 0.08487, 0.08489, 0.0849, 0.08491, 0.08492,
    0.08493, 0.08495, 0.08496, 0.08497, 0.08498, 0.08499, 0.08501,
    0.08502, 0.08503, 0.08504, 0.08506, 0.08507, 0.08508, 0.08509,
    0.0851, 0.08512, 0.08513, 0.08514, 0.08515, 0.08517, 0.08518,
    0.08519, 0.0852, 0.08522, 0.08523, 0.08524, 0.08525, 0.08527,
    0.08528, 0.08529, 0.0853, 0.08532, 0.08533, 0.08534, 0.08535,
    0.08537, 0.08538, 0.08539, 0.0854, 0.08542, 0.08543, 0.08544,
    0.08545, 0.08547, 0.08548, 0.08549, 0.0855, 0.08552, 0.08553,
    0.08554, 0.08555, 0.08557, 0.08558, 0.08559, 0.08561, 0.08562,
    0.08563, 0.08564, 0.08566, 0.08567, 0.08568, 0.08569, 0.08571,
    0.08572, 0.08573, 0.08575, 0.08576, 0.08577, 0.08578, 0.0858,
    0.08581, 0.08582, 0.08584, 0.08585, 0.08586, 0.08587, 0.08589,
    0.0859, 0.08591, 0.08593, 0.08594, 0.08595, 0.08596, 0.08598,
    0.08599, 0.086, 0.08602, 0.08603, 0.08604, 0.08606, 0.08607,
    0.08608, 0.08609, 0.08611, 0.08612, 0.08613, 0.08615, 0.08616,
    0.08617, 0.08619, 0.0862, 0.08621, 0.08623, 0.08624, 0.08625,
    0.08627, 0.08628, 0.08629, 0.0863, 0.08632, 0.08633, 0.08634,
    0.08636, 0.08637, 0.08638, 0.0864, 0.08641, 0.08642, 0.08644,
    0.08645, 0.08646, 0.08648, 0.08649, 0.0865, 0.08652, 0.08653,
    0.08654, 0.08656, 0.08657, 0.08658, 0.0866, 0.08661, 0.08662,
    0.08664, 0.08665, 0.08666, 0.08668, 0.08669, 0.0867, 0.08672,
    0.08673, 0.08674, 0.08676, 0.08677, 0.08678, 0.0868, 0.08681,
    0.08682, 0.08684, 0.08685, 0.08686, 0.08688, 0.08689, 0.0869,
    0.08692, 0.08693, 0.08694, 0.08696, 0.08697, 0.08698, 0.087,
    0.08701, 0.08702, 0.08704, 0.08705, 0.08706, 0.08708, 0.08709,
    0.0871, 0.08712, 0.08713, 0.08714, 0.08716, 0.08717, 0.08718,
    0.0872, 0.08721, 0.08723, 0.08724, 0.08725, 0.08727, 0.08728,
    0.08729, 0.08731, 0.08732, 0.08733, 0.08735, 0.08736, 0.08737,
    0.08739, 0.0874, 0.08741, 0.08743, 0.08744, 0.08746, 0.08747,
    0.08748, 0.0875, 0.08751, 0.08752, 0.08754, 0.08755, 0.08756,
    0.08758, 0.08759, 0.0876, 0.08762, 0.08763, 0.08765, 0.08766,
    0.08767, 0.08769, 0.0877, 0.08771, 0.08773, 0.08774, 0.08775,
    0.08777, 0.08778, 0.0878, 0.08781, 0.08782, 0.08784, 0.08785,
    0.08786, 0.08788, 0.08789, 0.0879, 0.08792, 0.08793, 0.08795,
    0.08796, 0.08797, 0.08799, 0.088, 0.08801, 0.08803, 0.08804,
    0.08805, 0.08807, 0.08808, 0.0881, 0.08811, 0.08812, 0.08814,
    0.08815, 0.08816, 0.08818, 0.08819, 0.08821, 0.08822, 0.08823,
    0.08825, 0.08826, 0.08827, 0.08829, 0.0883, 0.08832, 0.08833,
    0.08834, 0.08836, 0.08837, 0.08838, 0.0884, 0.08841, 0.08842,
    0.08844, 0.08845, 0.08847, 0.08848, 0.08849, 0.08851, 0.08852,
    0.08853, 0.08855, 0.08856, 0.08858, 0.08859, 0.0886, 0.08862,
    0.08863, 0.08864, 0.08866, 0.08867, 0.08869, 0.0887, 0.08871,
    0.08873, 0.08874, 0.08875, 0.08877, 0.08878, 0.0888, 0.08881,
    0.08882, 0.08884, 0.08885, 0.08886, 0.08888, 0.08889, 0.08891,
    0.08892, 0.08893, 0.08895, 0.08896, 0.08897, 0.08899, 0.089,
    0.08902, 0.08903, 0.08904, 0.08906, 0.08907, 0.08909, 0.0891,
    0.08911, 0.08913, 0.08914, 0.08915, 0.08917, 0.08918, 0.0892,
    0.08921, 0.08922, 0.08924, 0.08925, 0.08926, 0.08928, 0.08929,
    0.08931, 0.08932, 0.08933, 0.08935, 0.08936, 0.08937, 0.08939,
    0.0894, 0.08942, 0.08943, 0.08944, 0.08946, 0.08947, 0.08948,
    0.0895, 0.08951, 0.08953, 0.08954, 0.08955, 0.08957, 0.08958,
    0.08959, 0.08961, 0.08962, 0.08964, 0.08965, 0.08966, 0.08968,
    0.08969, 0.08971, 0.08972, 0.08973, 0.08975, 0.08976, 0.08977,
    0.08979, 0.0898, 0.08982, 0.08983, 0.08984, 0.08986, 0.08987,
    0.08988, 0.0899, 0.08991, 0.08993, 0.08994, 0.08995, 0.08997,
    0.08998, 0.08999, 0.09001, 0.09002, 0.09004, 0.09005, 0.09006,
    0.09008, 0.09009, 0.0901, 0.09012, 0.09013, 0.09015, 0.09016,
    0.09017, 0.09019, 0.0902, 0.09021, 0.09023, 0.09024, 0.09026,
    0.09027, 0.09028, 0.0903, 0.09031, 0.09032, 0.09034, 0.09035,
    0.09036, 0.09038, 0.09039, 0.09041, 0.09042, 0.09043, 0.09045,
    0.09046, 0.09047, 0.09049, 0.0905, 0.09052, 0.09053, 0.09054,
    0.09056, 0.09057, 0.09058, 0.0906, 0.09061, 0.09062, 0.09064,
    0.09065, 0.09067, 0.09068, 0.09069, 0.09071, 0.09072, 0.09073,
    0.09075, 0.09076, 0.09077, 0.09079, 0.0908, 0.09082, 0.09083,
    0.09084, 0.09086, 0.09087, 0.09088, 0.0909, 0.09091, 0.09092,
    0.09094, 0.09095, 0.09097, 0.09098, 0.09099, 0.09101, 0.09102,
    0.09103, 0.09105, 0.09106, 0.09107, 0.09109, 0.0911, 0.09111,
    0.09113, 0.09114, 0.09115, 0.09117, 0.09118, 0.0912, 0.09121,
    0.09122, 0.09124, 0.09125, 0.09126, 0.09128, 0.09129, 0.0913,
    0.09132, 0.09133, 0.09134, 0.09136, 0.09137, 0.09138, 0.0914,
    0.09141, 0.09143, 0.09144, 0.09145, 0.09147, 0.09148, 0.09149,
    0.09151, 0.09152, 0.09153, 0.09155, 0.09156, 0.09157, 0.09159,
    0.0916, 0.09161, 0.09163, 0.09164, 0.09165, 0.09167, 0.09168,
    0.09169, 0.09171, 0.09172, 0.09173, 0.09175, 0.09176, 0.09177,
    0.09179, 0.0918, 0.09181, 0.09183, 0.09184, 0.09185, 0.09187,
    0.09188, 0.09189, 0.09191, 0.09192, 0.09194, 0.09195, 0.09196,
    0.09198, 0.09199, 0.092, 0.09202, 0.09203, 0.09204, 0.09206,
    0.09207, 0.09208, 0.09209, 0.09211, 0.09212, 0.09213, 0.09215,
    0.09216, 0.09217, 0.09219, 0.0922, 0.09221, 0.09223, 0.09224,
    0.09225, 0.09227, 0.09228, 0.09229, 0.09231, 0.09232, 0.09233,
    0.09235, 0.09236, 0.09237, 0.09239, 0.0924, 0.09241, 0.09243,
    0.09244, 0.09245, 0.09247, 0.09248, 0.09249, 0.09251, 0.09252,
    0.09253, 0.09254, 0.09256, 0.09257, 0.09258, 0.0926, 0.09261,
    0.09262, 0.09264, 0.09265, 0.09266, 0.09268, 0.09269, 0.0927,
    0.09272, 0.09273, 0.09274, 0.09276, 0.09277, 0.09278, 0.09279,
    0.09281, 0.09282, 0.09283, 0.09285, 0.09286, 0.09287, 0.09289,
    0.0929, 0.09291, 0.09293, 0.09294, 0.09295, 0.09296, 0.09298,
    0.09299, 0.093, 0.09302, 0.09303, 0.09304, 0.09306, 0.09307,
    0.09308, 0.09309, 0.09311, 0.09312, 0.09313, 0.09315, 0.09316,
    0.09317, 0.09319, 0.0932, 0.09321, 0.09322, 0.09324, 0.09325,
    0.09326, 0.09328, 0.09329, 0.0933, 0.09332, 0.09333, 0.09334,
    0.09335, 0.09337, 0.09338, 0.09339, 0.09338, 0.09341, 0.09342,
    0.09343, 0.09344, 0.09346, 0.09347, 0.09348, 0.0935, 0.09351,
    0.09352, 0.09353, 0.09355, 0.09356, 0.09357, 0.09359, 0.0936,
    0.09361, 0.09362, 0.09364, 0.09365, 0.09366, 0.09368, 0.09369,
    0.0937, 0.09371, 0.09373, 0.09374, 0.09375, 0.09377, 0.09378,
    0.0938, 0.09379, 0.09423, 0.09467, 0.09512, 0.09557, 0.09603,
    0.09649, 0.09696, 0.09744, 0.09793, 0.09842, 0.09892, 0.09943,
    0.09995, 0.10047, 0.101, 0.10154, 0.10208, 0.10263, 0.10319,
    0.10375, 0.10433, 0.1049, 0.10549, 0.10608, 0.10667, 0.10727,
    0.10788, 0.10848, 0.10909, 0.10971, 0.11033, 0.11094, 0.11157,
    0.11219, 0.11281, 0.11343, 0.11405, 0.11467, 0.11529, 0.1159,
    0.11651, 0.11712, 0.11772, 0.11831, 0.1189, 0.11948, 0.12006,
    0.12062, 0.12117, 0.12171, 0.12224, 0.12276, 0.12327, 0.12376,
    0.12424, 0.12471, 0.12515, 0.12559, 0.12601, 0.12641, 0.12679,
    0.12716, 0.12751, 0.12783, 0.12814, 0.12843, 0.1287, 0.12895,
    0.12918, 0.12939, 0.12958, 0.12976, 0.12991, 0.13004, 0.13016,
    0.13025, 0.13032, 0.13038, 0.13041, 0.13043, 0.13043, 0.13041,
    0.13037, 0.13032, 0.13025, 0.13017, 0.13008, 0.12997, 0.12985,
    0.12971, 0.12957, 0.12941, 0.12925, 0.12907, 0.12889, 0.1287,
    0.1285, 0.1283, 0.12809, 0.12787, 0.12766, 0.12744, 0.12721,
    0.12699, 0.12676, 0.12653, 0.1263, 0.12608, 0.12585, 0.12563,
    0.12541, 0.12519, 0.12498, 0.12476, 0.12456, 0.12436, 0.12416,
    0.12397, 0.12378, 0.1236, 0.12343, 0.12326, 0.12311, 0.12296,
    0.12281, 0.12268, 0.12255, 0.12243, 0.12232, 0.12222, 0.12213,
    0.12204, 0.12196, 0.12189, 0.12183, 0.12177, 0.12173, 0.12169,
    0.12166, 0.12164, 0.12163, 0.12162, 0.12162, 0.12163, 0.12165,
    0.12167, 0.1217, 0.12174, 0.12178, 0.12183, 0.12189, 0.12195,
    0.12202, 0.1221, 0.12218, 0.12227, 0.12236, 0.12246, 0.12256,
    0.12267, 0.12278, 0.1229, 0.12302, 0.12315, 0.12328, 0.12342,
    0.12356, 0.17019, 0.17022, 0.17025, 0.17027, 0.1703, 0.17032,
    0.17035, 0.17038, 0.1704, 0.17043, 0.17045, 0.17048, 0.1705,
    0.17053, 0.17055, 0.17058, 0.17061, 0.17063, 0.17066, 0.17068,
    0.1707, 0.17073, 0.17075, 0.17078, 0.1708, 0.17083, 0.17085,
    0.17088, 0.1709, 0.17092, 0.17095, 0.17097, 0.171, 0.17102,
    0.17104, 0.17107, 0.17109, 0.17111, 0.17114, 0.17116, 0.17118,
    0.17121, 0.17123, 0.17125, 0.17128, 0.1713, 0.17132, 0.17135,
    0.17137, 0.17139, 0.17142, 0.17144, 0.17146, 0.17148, 0.17151,
    0.17153, 0.17155, 0.17157, 0.1716, 0.17162, 0.17164, 0.17166,
    0.17168, 0.17171, 0.17173, 0.17175, 0.17177, 0.17179, 0.17182,
    0.17184, 0.17186, 0.17188, 0.1719, 0.17192, 0.17195, 0.17197,
    0.17199, 0.17201, 0.17203, 0.17205, 0.17207, 0.1721, 0.17212,
    0.17214, 0.17216, 0.17218, 0.1722, 0.17222, 0.17224, 0.17226,
    0.17228, 0.17231, 0.17233, 0.17235, 0.17237, 0.17239, 0.17241,
    0.17243, 0.17245, 0.17247, 0.17249, 0.17251, 0.17253, 0.17255,
    0.17257, 0.17259, 0.17261, 0.17263, 0.17265, 0.17267, 0.17269,
    0.17271, 0.17273, 0.17275, 0.17277, 0.17279, 0.17281, 0.17283,
    0.17285, 0.17287, 0.17289, 0.17291, 0.17293, 0.17295, 0.17297,
    0.17299, 0.17301, 0.17303, 0.17305, 0.17307, 0.17309, 0.17311,
    0.17313, 0.17315, 0.17317, 0.17319, 0.1732, 0.17322, 0.17324,
    0.17326, 0.17328, 0.1733, 0.17332, 0.17334, 0.17336, 0.17338,
    0.1734, 0.17341, 0.17343, 0.17345, 0.17347, 0.17349, 0.17351,
    0.17353, 0.17355, 0.17356, 0.17358, 0.1736, 0.17362, 0.17364,
    0.17366, 0.17368, 0.1737, 0.17371, 0.17373, 0.17375, 0.17377,
    0.17379, 0.17381, 0.17382, 0.17384, 0.17386, 0.17388, 0.1739,
    0.17392, 0.17393, 0.17395, 0.17397, 0.17399, 0.17401, 0.17402,
    0.17404, 0.17406, 0.17408, 0.1741, 0.17411, 0.17413, 0.17415,
    0.17417, 0.17419, 0.1742, 0.17422, 0.17424, 0.17426, 0.17428,
    0.17429, 0.17431, 0.17433, 0.17435, 0.17436, 0.17438, 0.1744,
    0.17442, 0.17443, 0.17445, 0.17447, 0.17449, 0.17451, 0.17452,
    0.17454, 0.17456, 0.17457, 0.17459, 0.17461, 0.17463, 0.17464,
    0.17466, 0.17468, 0.1747, 0.17471, 0.17473, 0.17475, 0.17477,
    0.17478, 0.1748, 0.17482, 0.17483, 0.17485, 0.17487, 0.17489,
    0.1749, 0.17492, 0.17494, 0.17495, 0.17497, 0.17499, 0.175,
    0.17502, 0.17504, 0.17505, 0.17507, 0.17509, 0.17511, 0.17512,
    0.17514, 0.17516, 0.17517, 0.17519, 0.17521, 0.17522, 0.17524,
    0.17526, 0.17527, 0.17529, 0.17531, 0.17532, 0.17534, 0.17536,
    0.17537, 0.17539, 0.17541, 0.17542, 0.17544, 0.17546, 0.17547,
    0.17549, 0.1755, 0.17552, 0.17554, 0.17555, 0.17557, 0.17559,
    0.1756, 0.17562, 0.17564, 0.17565, 0.17567, 0.17568, 0.1757,
    0.17572, 0.17573, 0.17575, 0.17577, 0.17578, 0.1758, 0.17581,
    0.17583, 0.17585, 0.17586, 0.17588, 0.17589, 0.17591, 0.17593,
    0.17594, 0.17596, 0.17597, 0.17599, 0.17601, 0.17602, 0.17604,
    0.17605, 0.17607, 0.17609, 0.1761, 0.17612, 0.17613, 0.17615,
    0.17617, 0.17618, 0.1762, 0.17621, 0.17623, 0.17624, 0.17626,
    0.17628, 0.17629, 0.17631, 0.17632, 0.17634, 0.17635, 0.17637,
    0.17639, 0.1764, 0.17642, 0.17643, 0.17645, 0.17646, 0.17648,
    0.17649, 0.17651, 0.17653, 0.17654, 0.17656, 0.17657, 0.17659,
    0.1766, 0.17662, 0.17663, 0.17665, 0.17666, 0.17668, 0.17669,
    0.17671, 0.17673, 0.17674, 0.17676, 0.17677, 0.17679, 0.1768,
    0.17682, 0.17683, 0.17685, 0.17686, 0.17688, 0.17689, 0.17691,
    0.17692, 0.17694, 0.17695, 0.17697, 0.17698, 0.177, 0.17701,
    0.17703, 0.17705, 0.17706, 0.17708, 0.17709, 0.17711, 0.17712,
    0.17714, 0.17715, 0.17717, 0.17718, 0.1772, 0.17721, 0.17723,
    0.17724, 0.17726, 0.17727, 0.17729, 0.1773, 0.17731, 0.17733,
    0.17734, 0.17736, 0.17737, 0.17739, 0.1774, 0.17742, 0.17743,
    0.17745, 0.17746, 0.17748, 0.17749, 0.17751, 0.17752, 0.17754,
    0.17755, 0.17757, 0.17758, 0.1776, 0.17761, 0.17763, 0.17764,
    0.17765, 0.17767, 0.17768, 0.1777, 0.17771, 0.17773, 0.17774,
    0.17776, 0.17777, 0.17779, 0.1778, 0.17781, 0.17783, 0.17784,
    0.17786, 0.17787, 0.17789, 0.1779, 0.17792, 0.17793, 0.17795,
    0.17796, 0.17797, 0.17799, 0.178, 0.17802, 0.17803, 0.17805,
    0.17806, 0.17807, 0.17809, 0.1781, 0.17812, 0.17813, 0.17815,
    0.17816, 0.17817, 0.17819, 0.1782, 0.17822, 0.17823, 0.17825,
    0.17826, 0.17827, 0.17829, 0.1783, 0.17832, 0.17833, 0.17835,
    0.17836, 0.17837, 0.17839, 0.1784, 0.17842, 0.17843, 0.17844,
    0.17846, 0.17847, 0.17849, 0.1785, 0.17852, 0.17853, 0.17854,
    0.17856, 0.17857, 0.17859, 0.1786, 0.17861, 0.17863, 0.17864,
    0.17866, 0.17867, 0.17868, 0.1787, 0.17871, 0.17873, 0.17874,
    0.17875, 0.17877, 0.17878, 0.17879, 0.17881, 0.17882, 0.17884,
    0.17885, 0.17886, 0.17888, 0.17889, 0.17891, 0.17892, 0.17893,
    0.17895, 0.17896, 0.17897, 0.17899, 0.179, 0.17902, 0.17903,
    0.17904, 0.17906, 0.17907, 0.17908, 0.1791, 0.17911, 0.17913,
    0.17914, 0.17915, 0.17917, 0.17918, 0.17919, 0.17921, 0.17922,
    0.17924, 0.17925, 0.17926, 0.17928, 0.17929, 0.1793, 0.17932,
    0.17933, 0.17934, 0.17936, 0.17937, 0.17938, 0.1794, 0.17941,
    0.17943, 0.17944, 0.17945, 0.17947, 0.17948, 0.17949, 0.17951,
    0.17952, 0.17953, 0.17955, 0.17956, 0.17957, 0.17959, 0.1796,
    0.17961, 0.17963, 0.17964, 0.17965, 0.17967, 0.17968, 0.17969,
    0.17971, 0.17972, 0.17973, 0.17975, 0.17976, 0.17977, 0.17979,
    0.1798, 0.17981, 0.17983, 0.17984, 0.17985, 0.17987, 0.17988,
    0.17989, 0.17991, 0.17992, 0.17993, 0.17995, 0.17996, 0.17997,
    0.17999, 0.18, 0.18001, 0.18003, 0.18004, 0.18005, 0.18007,
    0.18008, 0.18009, 0.18011, 0.18012, 0.18013, 0.18015, 0.18016,
    0.18017, 0.18018, 0.1802, 0.18021, 0.18022, 0.18024, 0.18025,
    0.18026, 0.18028, 0.18029, 0.1803, 0.18032, 0.18033, 0.18034,
    0.18035, 0.18037, 0.18038, 0.18039, 0.18041, 0.18042, 0.18043,
    0.18045, 0.18046, 0.18047, 0.18048, 0.1805, 0.18051, 0.18052,
    0.18054, 0.18055, 0.18056, 0.18057, 0.18059, 0.1806, 0.18061,
    0.18063, 0.18064, 0.18065, 0.18067, 0.18068, 0.18069, 0.1807,
    0.18072, 0.18073, 0.18074, 0.18076, 0.18077, 0.18078, 0.18079,
    0.18081, 0.18082, 0.18083, 0.18084, 0.18086, 0.18087, 0.18088,
    0.1809, 0.18091, 0.18092, 0.18093, 0.18095, 0.18096, 0.18097,
    0.18099, 0.181, 0.18101, 0.18102, 0.18104, 0.18105, 0.18106,
    0.18107, 0.18109, 0.1811, 0.18111, 0.18112, 0.18114, 0.18115,
    0.18116, 0.18118, 0.18119, 0.1812, 0.18121, 0.18123, 0.18124,
    0.18125, 0.18126, 0.18128, 0.18129, 0.1813, 0.18131, 0.18133,
    0.18134, 0.18135, 0.18136, 0.18138, 0.18139, 0.1814, 0.18141,
    0.18143, 0.18144, 0.18145, 0.18146, 0.18148, 0.18149, 0.1815,
    0.18151, 0.18153, 0.18154, 0.18155, 0.18156, 0.18158, 0.18159,
    0.1816, 0.18161, 0.18163, 0.18164, 0.18165, 0.18166, 0.18168,
    0.18169, 0.1817, 0.18171, 0.18173, 0.18174, 0.18175, 0.18176,
    0.18178, 0.18179, 0.1818, 0.18181, 0.18182, 0.18184, 0.18185,
    0.18186, 0.18187, 0.18189, 0.1819, 0.18191, 0.18192, 0.18194,
    0.18195, 0.18196, 0.18197, 0.18198, 0.182, 0.18201, 0.18202,
    0.18203, 0.18205, 0.18206, 0.18207, 0.18208, 0.1821, 0.18211,
    0.18212, 0.18213, 0.18214, 0.18216, 0.18217, 0.18218, 0.18219,
    0.1822, 0.18222, 0.18223, 0.18224, 0.18225, 0.18227, 0.18228,
    0.18229, 0.1823, 0.18231, 0.18233, 0.18234, 0.18235, 0.18236,
    0.18238, 0.18239, 0.1824, 0.18241, 0.18242, 0.18244, 0.18245,
    0.18246, 0.18247, 0.18248, 0.1825, 0.18251, 0.18252, 0.18253,
    0.18254, 0.18256, 0.18257, 0.18258, 0.18259, 0.1826, 0.18262,
    0.18263, 0.18264, 0.18265, 0.18266, 0.18268, 0.18269, 0.1827,
    0.18271, 0.18272, 0.18274, 0.18275, 0.18276, 0.18277, 0.18278,
    0.1828, 0.18281, 0.18282, 0.18283, 0.18284, 0.18286, 0.18287,
    0.18288, 0.18289, 0.1829, 0.18292, 0.18293, 0.18294, 0.18295,
    0.18296, 0.18297, 0.18299, 0.183, 0.18301, 0.18302, 0.18303,
    0.18305, 0.18306, 0.18307, 0.18308, 0.18309, 0.1831, 0.18312,
    0.18313, 0.18314, 0.18315, 0.18316, 0.18318, 0.18319, 0.1832,
    0.18321, 0.18322, 0.18323, 0.18325, 0.18326, 0.18327, 0.18328,
    0.18329, 0.18331, 0.18332, 0.18333, 0.18334, 0.18335, 0.18336,
    0.18338, 0.18339, 0.1834, 0.18341, 0.18342, 0.18343, 0.18345,
    0.18346, 0.18347, 0.18348, 0.18349, 0.1835, 0.18352, 0.18353,
    0.18354, 0.18355, 0.18356, 0.18357, 0.18359, 0.1836, 0.18361,
    0.18362, 0.18363, 0.18364, 0.18366, 0.18367, 0.18368, 0.18369,
    0.1837, 0.18371, 0.18373, 0.18374, 0.18375, 0.18376, 0.18377,
    0.18378, 0.18379, 0.18381, 0.18382, 0.18383, 0.18384, 0.18385,
    0.18386, 0.18388, 0.18389, 0.1839, 0.18391, 0.18392, 0.18393,
    0.18394, 0.18396, 0.18397, 0.18398, 0.18399, 0.184, 0.18401,
    0.18403, 0.18404, 0.18405, 0.18406, 0.18407, 0.18408, 0.18409,
    0.18411, 0.18412, 0.18413, 0.18414, 0.18415, 0.18416, 0.18417,
    0.18419, 0.1842, 0.18421, 0.18422, 0.18423, 0.18424, 0.18425,
    0.18427, 0.18428, 0.18429, 0.1843, 0.18431, 0.18432, 0.18433,
    0.18435, 0.18436, 0.18437, 0.18438, 0.18439, 0.1844, 0.18441,
    0.18443, 0.18444, 0.18445, 0.18446, 0.18447, 0.18448, 0.18449,
    0.1845, 0.18452, 0.18453, 0.18454, 0.18455, 0.18456, 0.18457,
    0.18458, 0.18459, 0.18461, 0.18462, 0.18463, 0.18464, 0.18465,
    0.18466, 0.18467, 0.18469, 0.1847, 0.18471, 0.18472, 0.18473,
    0.18474, 0.18475, 0.18476, 0.18477, 0.18479, 0.1848, 0.18481,
    0.18482, 0.18483, 0.18484, 0.18485, 0.18486, 0.18488, 0.18489,
    0.1849, 0.18491, 0.18492, 0.18493, 0.18494, 0.18495, 0.18497,
    0.18498, 0.18499, 0.185, 0.18501, 0.18502, 0.18503, 0.18504,
    0.18505, 0.18507, 0.18508, 0.18509, 0.1851, 0.18511, 0.18512,
    0.18513, 0.18514, 0.18515, 0.18517, 0.18518, 0.18519, 0.1852,
    0.18521, 0.18522, 0.18523, 0.18524, 0.18525, 0.18527, 0.18528,
    0.18529, 0.1853, 0.18531, 0.18532, 0.18533, 0.18534, 0.18535,
    0.18537, 0.18538, 0.18539, 0.1854, 0.18541, 0.18542, 0.18543,
    0.18544, 0.18545, 0.18546, 0.18548, 0.18549, 0.1855, 0.18551,
    0.18552, 0.18553, 0.18554, 0.18555, 0.18556, 0.18557, 0.18559,
    0.1856, 0.18561, 0.18562, 0.18563, 0.18564, 0.18565, 0.18566,
    0.18567, 0.18568, 0.18569, 0.18571, 0.18572, 0.18573, 0.18574,
    0.18575, 0.18576, 0.18577, 0.18578, 0.18579, 0.1858, 0.18581,
    0.18583, 0.18584, 0.18585, 0.18586, 0.18587, 0.18588, 0.18589,
    0.1859, 0.18591, 0.18592, 0.18593, 0.18595, 0.18596, 0.18597,
    0.18598, 0.18599, 0.186, 0.18601, 0.18602, 0.18603, 0.18604,
    0.18605, 0.18606, 0.18608, 0.18609, 0.1861, 0.18611, 0.18612,
    0.18613, 0.18614, 0.18615, 0.18616, 0.18617, 0.18618, 0.18619,
    0.18621, 0.18622, 0.18623, 0.18624, 0.18625, 0.18626, 0.18627,
    0.18628, 0.18629, 0.1863, 0.18631, 0.18632, 0.18633, 0.18635,
    0.18636, 0.18637, 0.18638, 0.18639, 0.1864, 0.18641, 0.18642,
    0.18643, 0.18644, 0.18645, 0.18646, 0.18647, 0.18648, 0.1865,
    0.18651, 0.18652, 0.18653, 0.18654, 0.18655, 0.18656, 0.18657,
    0.18658, 0.18659, 0.1866, 0.18661, 0.18662, 0.18663, 0.18664,
    0.18666, 0.18667, 0.18668, 0.18669, 0.1867, 0.18671, 0.18672,
    0.18673, 0.18674, 0.18675, 0.18676, 0.18677, 0.18678, 0.18679,
    0.1868, 0.18682, 0.18683, 0.18684, 0.18685, 0.18686, 0.18687,
    0.18688, 0.18689, 0.1869, 0.18691, 0.18692, 0.18693, 0.18694,
    0.18695, 0.18696, 0.18697, 0.18698, 0.18699, 0.18701, 0.18702,
    0.18703, 0.18704, 0.18705, 0.18706, 0.18707, 0.18708, 0.18709,
    0.1871, 0.18711, 0.18712, 0.18713, 0.18714, 0.18715, 0.18716,
    0.18717, 0.18718, 0.1872, 0.18721, 0.18722, 0.18723, 0.18724,
    0.18725, 0.18726, 0.18727, 0.18728, 0.18729, 0.1873, 0.18731,
    0.18732, 0.18733, 0.18734, 0.18735, 0.18736, 0.18737, 0.18738,
    0.18739, 0.1874, 0.18742, 0.18743, 0.18744, 0.18745, 0.18746,
    0.18747, 0.18748, 0.18749, 0.1875, 0.18751, 0.18752, 0.18753,
    0.18754, 0.18755, 0.18756, 0.18757, 0.18758, 0.18759, 0.1876,
    0.18761, 0.18762, 0.18763, 0.18764, 0.18765, 0.18766, 0.18768,
    0.18769, 0.1877, 0.18771, 0.18772, 0.18773, 0.18774, 0.18775,
    0.18776, 0.18777, 0.18778, 0.18779, 0.1878, 0.18781, 0.18782,
    0.18783, 0.18784, 0.18785, 0.18786, 0.18787, 0.18788, 0.18789,
    0.1879, 0.18791, 0.18792, 0.18793, 0.18794, 0.18795, 0.18796,
    0.18798, 0.18799, 0.188, 0.18801, 0.18802, 0.18803, 0.18804,
    0.18805, 0.18806, 0.18807, 0.18808, 0.18809, 0.1881, 0.18811,
    0.18812, 0.18813, 0.18814, 0.18815, 0.18816, 0.18817, 0.18818,
    0.18819, 0.1882, 0.18821, 0.18822, 0.18823, 0.18824, 0.18825,
    0.18826, 0.18827, 0.18828, 0.18829, 0.1883, 0.18831, 0.18832,
    0.18833, 0.18834, 0.18835, 0.18836, 0.18837, 0.18838, 0.1884,
    0.18841, 0.18842, 0.18843, 0.18844, 0.18845, 0.18846, 0.18847,
    0.18848, 0.18849, 0.1885, 0.18851, 0.18852, 0.18853, 0.18854,
    0.18855, 0.18856, 0.18857, 0.18858, 0.18859, 0.1886, 0.18861,
    0.18862, 0.18863, 0.18864, 0.18865, 0.18866, 0.18867, 0.18868,
    0.18869, 0.1887, 0.18871, 0.18872, 0.18873, 0.18874, 0.18875,
    0.18876, 0.18877, 0.18878, 0.18879, 0.1888, 0.18881, 0.18882,
    0.18883, 0.18884, 0.18885, 0.18886, 0.18887, 0.18888, 0.18889,
    0.1889, 0.18891, 0.18892, 0.18893, 0.18894, 0.18895, 0.18896,
    0.18897, 0.18898, 0.18899, 0.189, 0.18901, 0.18902, 0.18903,
    0.18904, 0.18905, 0.18906, 0.18907, 0.18908, 0.18909, 0.1891,
    0.18911, 0.18912, 0.18913, 0.18914, 0.18915, 0.18916, 0.18917,
    0.18918, 0.18919, 0.1892, 0.18921, 0.18922, 0.18923, 0.18924,
    0.18925, 0.18926, 0.18927, 0.18928, 0.18929, 0.1893, 0.18931,
    0.18932, 0.18933, 0.18934, 0.18935, 0.18936, 0.18937, 0.18938,
    0.18939, 0.1894, 0.18941, 0.18942, 0.18943, 0.18944, 0.18945,
    0.18946, 0.18947, 0.18948, 0.18949, 0.1895, 0.18951, 0.18952,
    0.18953, 0.18954, 0.18955, 0.18956, 0.18957, 0.18958, 0.18959,
    0.1896, 0.18961, 0.18962, 0.18963, 0.18964, 0.18965, 0.18966,
    0.18967, 0.18968, 0.18969, 0.1897, 0.18971, 0.18972, 0.18973,
    0.18974, 0.18975, 0.18976, 0.18977, 0.18978, 0.18979, 0.1898,
    0.18981, 0.18982, 0.18983, 0.18984, 0.18985, 0.18986, 0.18987,
    0.18988, 0.18989, 0.1899, 0.18991, 0.18992, 0.18993, 0.18994,
    0.18995, 0.18996, 0.18997, 0.18998, 0.18998, 0.18999, 0.19,
    0.19001, 0.19002, 0.19003, 0.19004, 0.19005, 0.19006, 0.19007,
    0.19008, 0.19009, 0.1901, 0.19011, 0.19012, 0.19013, 0.19014,
    0.19015, 0.19016, 0.19017, 0.19018, 0.19019, 0.1902, 0.19021,
    0.19022, 0.19023, 0.19024, 0.19025, 0.19026, 0.19027, 0.19028,
    0.19029, 0.1903, 0.19031, 0.19032, 0.19033, 0.19034, 0.19035,
    0.19036, 0.19037, 0.19038, 0.19039, 0.1904, 0.19041, 0.19041,
    0.19042, 0.19043, 0.19044, 0.19045, 0.19046, 0.19047, 0.19048,
    0.19049, 0.1905, 0.19051, 0.19052, 0.19053, 0.19054, 0.19055,
    0.19056, 0.19057, 0.19058, 0.19059, 0.1906, 0.19061, 0.19062,
    0.19063, 0.19064, 0.19065, 0.19066, 0.19067, 0.19068, 0.19069,
    0.1907, 0.19071, 0.19072, 0.19072, 0.19073, 0.19074, 0.19075,
    0.19076, 0.19077, 0.19078, 0.19079, 0.1908, 0.19081, 0.19082,
    0.19083, 0.19084, 0.19085, 0.19086, 0.19087, 0.19088, 0.19089,
    0.1909, 0.19091, 0.19092, 0.19093, 0.19094, 0.19095, 0.19096,
    0.19097, 0.19098, 0.19098, 0.19099, 0.191, 0.19101, 0.19102,
    0.19103, 0.19104, 0.19105, 0.19106, 0.19107, 0.19108, 0.19109,
    0.1911, 0.19111, 0.19112, 0.19113, 0.19114, 0.19115, 0.19116,
    0.19117, 0.19118, 0.19119, 0.1912, 0.1912, 0.19121, 0.19122,
    0.19123, 0.19124, 0.19125, 0.19126, 0.19127, 0.19128, 0.19129,
    0.1913, 0.19131, 0.19132, 0.19133, 0.19134, 0.19135, 0.19136,
    0.19137, 0.19138, 0.19139, 0.1914, 0.1914, 0.19141, 0.19142,
    0.19143, 0.19144, 0.19145, 0.19146, 0.19147, 0.19148, 0.19149,
    0.1915, 0.19151, 0.19152, 0.19153, 0.19154, 0.19155, 0.19156,
    0.19157, 0.19158, 0.19159, 0.19159, 0.1916, 0.19161, 0.19162,
    0.19163, 0.19164, 0.19165, 0.19166, 0.19167, 0.19168, 0.19169,
    0.1917, 0.19171, 0.19172, 0.19173, 0.19174, 0.19175, 0.19176,
    0.19176, 0.19177, 0.19178, 0.19179, 0.1918, 0.19181, 0.19182,
    0.19183, 0.19184, 0.19185, 0.19186, 0.19187, 0.19188, 0.19189,
    0.1919, 0.19191, 0.19192, 0.19193, 0.19193, 0.19194, 0.19195,
    0.19196, 0.19197, 0.19198, 0.19199, 0.192, 0.19201, 0.19202,
    0.19203, 0.19204, 0.19205, 0.19206, 0.19207, 0.19208, 0.19208,
    0.19209, 0.1921, 0.19211, 0.19212, 0.19213, 0.19214, 0.19215,
    0.19216, 0.19217, 0.19218, 0.19219, 0.1922, 0.19221, 0.19222,
    0.19223, 0.19223, 0.19224, 0.19225, 0.19226, 0.19227, 0.19228,
    0.19229, 0.1923, 0.19231, 0.19232, 0.19233, 0.19234, 0.19235,
    0.19236, 0.19237, 0.19237, 0.19238, 0.19239, 0.1924, 0.19241,
    0.19242, 0.19243, 0.19244, 0.19245, 0.19246, 0.19247, 0.19248,
    0.19249, 0.1925, 0.1925, 0.19251, 0.19252, 0.19253, 0.19254,
    0.19255, 0.19256, 0.19257, 0.19258, 0.19259, 0.1926, 0.19261,
    0.19262, 0.19263, 0.19263, 0.19264, 0.19265, 0.19266, 0.19267,
    0.19268, 0.19269, 0.1927, 0.19271, 0.19272, 0.19273, 0.19274,
    0.19275, 0.19275, 0.19276, 0.19277, 0.19278, 0.19279, 0.1928,
    0.19281, 0.19282, 0.19283, 0.18428, 0.18428, 0.18428, 0.18428,
    0.18428, 0.18428, 0.18428, 0.18428, 0.18428, 0.18428, 0.18429,
    0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429,
    0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429,
    0.18429, 0.1843, 0.1843, 0.1843, 0.1843, 0.1843, 0.1843,
    0.1843, 0.1843, 0.1843, 0.1843, 0.1843, 0.1843, 0.1843, 0.18429,
    0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429,
    0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429, 0.18429,
    0.18429, 0.18429, 0.18429, 0.18429, 0.18428, 0.18428, 0.18428,
    0.18428, 0.18428, 0.18428, 0.18428, 0.18428, 0.18428, 0.18428,
    0.18428, 0.18428, 0.18427, 0.18427, 0.18427, 0.18427, 0.18427,
    0.18427, 0.18427, 0.18427, 0.18427, 0.18427, 0.18427, 0.18426,
    0.18426, 0.18426, 0.18426, 0.18426, 0.18426, 0.18426, 0.18426,
    0.18426, 0.18426, 0.18426, 0.18425, 0.18425, 0.18425, 0.18425,
    0.18425, 0.18425, 0.18425, 0.18425, 0.18425, 0.18425, 0.18424,
    0.18424, 0.18424, 0.18424, 0.18424, 0.18424, 0.18424, 0.18424,
    0.18423, 0.18423, 0.18423, 0.18423, 0.18423, 0.18423, 0.18423,
    0.18422, 0.18422, 0.18422, 0.18422, 0.18422, 0.18421, 0.18421,
    0.18421, 0.18421, 0.1842, 0.1842, 0.1842, 0.1842, 0.18419,
    0.18419, 0.18419, 0.18418, 0.18418, 0.18418, 0.18418, 0.18417,
    0.18417, 0.18417, 0.18416, 0.18416, 0.18416, 0.18415, 0.18415,
    0.18414, 0.18414, 0.18414, 0.18413, 0.18413, 0.18413, 0.18412,
    0.18412, 0.18411, 0.18411, 0.18411, 0.1841, 0.1841, 0.18409,
    0.18409, 0.18409, 0.18408, 0.18408, 0.18407, 0.18407, 0.18407,
    0.18406, 0.18406, 0.18405, 0.18405, 0.18404, 0.18404, 0.18404,
    0.18403, 0.18403, 0.18402, 0.18402, 0.18401, 0.18401, 0.184,
    0.184, 0.184, 0.18399, 0.18399, 0.18398, 0.18398, 0.18397,
    0.18397, 0.18397, 0.18396, 0.18396, 0.18395, 0.18395, 0.18395,
    0.18394, 0.18394, 0.18393, 0.18393, 0.18393, 0.18392, 0.18392,
    0.18391, 0.18391, 0.18391, 0.1839, 0.1839, 0.1839, 0.18389,
    0.18389, 0.18389, 0.18388, 0.18388, 0.18388, 0.18387, 0.18387,
    0.18387, 0.18386, 0.18386, 0.18386, 0.18386, 0.18385, 0.18385,
    0.18385, 0.18385, 0.18384, 0.18384, 0.18384, 0.18384, 0.18383,
    0.18383, 0.18383, 0.18383, 0.18383, 0.18382, 0.18382, 0.18382,
    0.18382, 0.18382, 0.18382, 0.18382, 0.18382, 0.18381, 0.18381,
    0.18381, 0.18381, 0.18381, 0.18381, 0.18381, 0.18381, 0.18381,
    0.18381, 0.18381, 0.18381, 0.18381, 0.18381, 0.18381, 0.18381,
    0.18381, 0.18381, 0.18381, 0.18381, 0.18381, 0.18381, 0.18381,
    0.18381, 0.18381, 0.18382, 0.18382, 0.18382, 0.18382, 0.18382,
    0.18382, 0.18383, 0.18383, 0.18383, 0.18383, 0.18383, 0.18384,
    0.18384, 0.18384, 0.18384, 0.18385, 0.18385, 0.18385, 0.18385,
    0.18386, 0.18386, 0.18386, 0.18387, 0.18387, 0.18387, 0.18388,
    0.18388, 0.18389, 0.18389, 0.18389, 0.1839, 0.1839, 0.18391,
    0.18391, 0.18392, 0.18392, 0.18393, 0.18393, 0.18394, 0.18394,
    0.18395, 0.18395, 0.18396, 0.18396, 0.18397, 0.18397, 0.18398,
    0.18399, 0.18399, 0.184, 0.184, 0.18401, 0.18402, 0.18402,
    0.18403, 0.18404, 0.18404, 0.18405, 0.18406, 0.18407, 0.18407,
    0.18408, 0.18409, 0.1841, 0.1841, 0.18411, 0.18412, 0.18413,
    0.18414, 0.18415, 0.18415, 0.18416, 0.18417, 0.18418, 0.18419,
    0.1842, 0.18421, 0.18422, 0.18423, 0.18424, 0.18425, 0.18426,
    0.18427, 0.18428, 0.18429, 0.1843, 0.18431, 0.18432, 0.18433,
    0.18434, 0.18435, 0.18436, 0.18437, 0.18438, 0.18439, 0.18441,
    0.18442, 0.18443, 0.18444, 0.18445, 0.18446, 0.18448, 0.18449,
    0.1845, 0.18451, 0.18452, 0.18454, 0.18455, 0.18456, 0.18458,
    0.18459, 0.1846, 0.18461, 0.18463, 0.18464, 0.18466, 0.18467,
    0.18468, 0.1847, 0.18471, 0.18472, 0.18474, 0.18475, 0.18477,
    0.18478, 0.1848, 0.18481, 0.18483, 0.18484, 0.18486, 0.18487,
    0.18489, 0.1849, 0.18492, 0.18493, 0.18495, 0.18496, 0.18498,
    0.185, 0.18501, 0.18503, 0.18504, 0.18506, 0.18508, 0.18509,
    0.18511, 0.18513, 0.18514, 0.18516, 0.18518, 0.18519, 0.18521,
    0.18523, 0.18525, 0.18526, 0.18528, 0.1853, 0.18532, 0.18534,
    0.18535, 0.18537, 0.18539, 0.18541, 0.18543, 0.18545, 0.18546,
    0.18548, 0.1855, 0.18552, 0.18554, 0.18556, 0.18558, 0.1856,
    0.18562, 0.18564, 0.18566, 0.18568, 0.18569, 0.18571, 0.18573,
    0.18575, 0.18577, 0.18579, 0.18582, 0.18584, 0.18586, 0.18588,
    0.1859, 0.18592, 0.18594, 0.18596, 0.18598, 0.186, 0.18602,
    0.18604, 0.18607, 0.18609, 0.18611, 0.18613, 0.18615, 0.18617,
    0.1862, 0.18622, 0.18624, 0.18626, 0.18628, 0.18631, 0.18633,
    0.18635, 0.18637, 0.1864, 0.18642, 0.18644, 0.18646, 0.18649,
    0.18651, 0.18653, 0.18656, 0.18658, 0.1866, 0.18663, 0.18665,
    0.18667, 0.1867, 0.18672, 0.18675, 0.18677, 0.18679, 0.18682,
    0.18684, 0.18687, 0.18689, 0.18691, 0.18694, 0.18696, 0.18699,
    0.18701, 0.18704, 0.18706, 0.18709, 0.18711, 0.18714, 0.18716,
    0.18719, 0.18721, 0.18724, 0.18726, 0.18729, 0.18731, 0.18734,
    0.18737, 0.18739, 0.18742, 0.18744, 0.18747, 0.1875, 0.18752,
    0.18755, 0.18757, 0.1876, 0.18763, 0.18765, 0.18768, 0.18771,
    0.18773, 0.18776, 0.18779, 0.18781, 0.18784, 0.18787, 0.1879,
    0.18792, 0.18795, 0.18798, 0.188, 0.18803, 0.18806, 0.18809,
    0.18812, 0.18814, 0.18817, 0.1882, 0.18823, 0.18825, 0.18828,
    0.18831, 0.18834, 0.18837, 0.1884, 0.18842, 0.18845, 0.18848,
    0.18851, 0.18854, 0.18857, 0.1886, 0.18863, 0.18865, 0.18868,
    0.18871, 0.18874, 0.18877, 0.1888, 0.18883, 0.18886, 0.18889,
    0.18892, 0.18895, 0.18898, 0.18901, 0.18904, 0.18907, 0.1891,
    0.18913, 0.18916, 0.18919, 0.18922, 0.18925, 0.18928, 0.18931,
    0.18934, 0.18937, 0.1894, 0.18943, 0.18946, 0.18949, 0.18952,
    0.18955, 0.18958, 0.18961, 0.18964, 0.18967, 0.18971, 0.18974,
    0.18977, 0.1898, 0.18983, 0.18986, 0.18989, 0.18992, 0.18996,
    0.18999, 0.19002, 0.19005, 0.19008, 0.19011, 0.19015, 0.19018,
    0.19021, 0.19024, 0.19027, 0.19031, 0.19034, 0.19037, 0.1904,
    0.19043, 0.19047, 0.1905, 0.19053, 0.19056, 0.1906, 0.19063,
    0.19066, 0.19069, 0.19073, 0.19076, 0.19079, 0.19083, 0.19086,
    0.19089, 0.19092, 0.19096, 0.19099, 0.19102, 0.19106, 0.19109,
    0.19112, 0.19116, 0.19119, 0.19122, 0.19126, 0.19129, 0.19133,
    0.19136, 0.19139, 0.19143, 0.19146, 0.19149, 0.19153, 0.19156,
    0.1916, 0.19163, 0.19166, 0.1917, 0.19173, 0.19177, 0.1918,
    0.19183, 0.19187, 0.1919, 0.19194, 0.19197, 0.19201, 0.19204,
    0.19208, 0.19211, 0.19215, 0.19218, 0.19222, 0.19225, 0.19228,
    0.19232, 0.19235, 0.19239, 0.19242, 0.19246, 0.19249, 0.19253,
    0.19257, 0.1926, 0.19264, 0.19267, 0.19271, 0.19274, 0.19278,
    0.19281, 0.19285, 0.19288, 0.19292, 0.19296, 0.19299, 0.19303,
    0.19306, 0.1931, 0.19313, 0.19317, 0.19321, 0.19324, 0.19328,
    0.19331, 0.19335, 0.19339, 0.19342, 0.19346, 0.19349, 0.19353,
    0.19357, 0.1936, 0.19364, 0.19368, 0.19371, 0.19375, 0.19379,
    0.19382, 0.19386, 0.1939, 0.19393, 0.19397, 0.19401, 0.19404,
    0.19408, 0.19412, 0.19415, 0.19419, 0.19423, 0.19426, 0.1943,
    0.19434, 0.19437, 0.19441, 0.19445, 0.19449, 0.19452, 0.19456,
    0.1946, 0.19464, 0.19467, 0.19471, 0.19475, 0.19479, 0.19482,
    0.19486, 0.1949, 0.19494, 0.19497, 0.19501, 0.19505, 0.19509,
    0.19512, 0.19516, 0.1952, 0.19524, 0.19528, 0.19531, 0.19535,
    0.19539, 0.19543, 0.19546, 0.1955, 0.19554, 0.19558, 0.19562,
    0.19566, 0.19569, 0.19573, 0.19577, 0.19581, 0.19585, 0.19589,
    0.19592, 0.19596, 0.196, 0.19604, 0.19608, 0.19612, 0.19615,
    0.19619, 0.19623, 0.19627, 0.19631, 0.19635, 0.19639, 0.19643,
    0.19646, 0.1965, 0.19654, 0.19658, 0.19662, 0.19666, 0.1967,
    0.19674, 0.19678, 0.19681, 0.19685, 0.19689, 0.19693, 0.19697,
    0.19701, 0.19705, 0.19709, 0.19713, 0.19717, 0.19721, 0.19725,
    0.19728, 0.19732, 0.19736, 0.1974, 0.19744, 0.19748, 0.19752,
    0.19756, 0.1976, 0.19764, 0.19768, 0.19772, 0.19776, 0.1978,
    0.19784, 0.19788, 0.19792, 0.19796, 0.198, 0.19804, 0.19808,
    0.19812, 0.19815, 0.19819, 0.19823, 0.19827, 0.19831, 0.19835,
    0.19839, 0.19843, 0.19847, 0.19851, 0.19855, 0.19859, 0.19863,
    0.19867, 0.19871, 0.19875, 0.19879, 0.19883, 0.19887, 0.19891,
    0.19895, 0.19899, 0.19904, 0.19908, 0.19912, 0.19916, 0.1992,
    0.19924, 0.19928, 0.19932, 0.19936, 0.1994, 0.19944, 0.19948,
    0.19952, 0.19956, 0.1996, 0.19964, 0.19968, 0.19972, 0.19976,
    0.1998, 0.19984, 0.19988, 0.19992, 0.19996, 0.2, 0.20004,
    0.20009, 0.20013, 0.20017, 0.20021, 0.20025, 0.20029, 0.20033,
    0.20037, 0.20041, 0.20045, 0.20049, 0.20053, 0.20057, 0.20061,
    0.20065, 0.2007, 0.20074, 0.20078, 0.20082, 0.20086, 0.2009,
    0.20094, 0.20098, 0.20102, 0.20106, 0.2011, 0.20114, 0.20119,
    0.20123, 0.20127, 0.20131, 0.20135, 0.20139, 0.20143, 0.20147,
    0.20151, 0.20155, 0.20159, 0.20164, 0.20168, 0.20172, 0.20176,
    0.2018, 0.20184, 0.20188, 0.20192, 0.20196, 0.202, 0.20205,
    0.20209, 0.20213, 0.20217, 0.20221, 0.20225, 0.20229, 0.20233,
    0.20237, 0.20242, 0.20246, 0.2025, 0.20254, 0.20258, 0.20262,
    0.20266, 0.2027, 0.20274, 0.20279, 0.20283, 0.20287, 0.20291,
    0.20295, 0.20299, 0.20303, 0.20307, 0.20312, 0.20316, 0.2032,
    0.20324, 0.20328, 0.20332, 0.20336, 0.2034, 0.20345, 0.20349,
    0.20353, 0.20357, 0.20361, 0.20365, 0.20369, 0.20373, 0.20378,
    0.20382, 0.20386, 0.2039, 0.20394, 0.20398, 0.20402, 0.20406,
    0.20411, 0.20415, 0.20419, 0.20423, 0.20427, 0.20431, 0.20435,
    0.2044, 0.20444, 0.20448, 0.20452, 0.20456, 0.2046, 0.20464,
    0.20469, 0.20473, 0.20477, 0.20481, 0.20485, 0.20489, 0.20493,
    0.20497, 0.20502, 0.20506, 0.2051, 0.20514, 0.20518, 0.20522,
    0.20526, 0.20531, 0.20535, 0.20539, 0.20543, 0.20547, 0.20551,
    0.20555, 0.2056, 0.20564, 0.20568, 0.20572, 0.20576, 0.2058,
    0.20584, 0.20589, 0.20593, 0.20597, 0.20601, 0.20605, 0.20609,
    0.20613, 0.20618, 0.20622, 0.20626, 0.2063, 0.20634, 0.20638,
    0.20642, 0.20647, 0.20651, 0.20655, 0.20659, 0.20663, 0.20667,
    0.20671, 0.20676, 0.2068, 0.20684, 0.20688, 0.20692, 0.20696,
    0.207, 0.20705, 0.20709, 0.20713, 0.20717, 0.20721, 0.20725,
    0.20729, 0.20734, 0.20738, 0.20742, 0.20746, 0.2075, 0.20754,
    0.20758, 0.20763, 0.20767, 0.20771, 0.20775, 0.20779, 0.20783,
    0.20787, 0.20791, 0.20796, 0.208, 0.20804, 0.20808, 0.20812,
    0.20816, 0.2082, 0.20825, 0.20829, 0.20833, 0.20837, 0.20841,
    0.20845, 0.20849, 0.20853, 0.20858, 0.20862, 0.20866, 0.2087,
    0.20874, 0.20878, 0.20882, 0.20887, 0.20891, 0.20895, 0.20899,
    0.20903, 0.20907, 0.20911, 0.20915, 0.2092, 0.20924, 0.20928,
    0.20932, 0.20936, 0.2094, 0.20944, 0.20948, 0.20953, 0.20957,
    0.20961, 0.20965, 0.20969, 0.20973, 0.20977, 0.20981, 0.20985,
    0.2099, 0.20994, 0.20998, 0.21002, 0.21006, 0.2101, 0.21014,
    0.21018, 0.21022, 0.21027, 0.21031, 0.21035, 0.21039, 0.21043,
    0.21047, 0.21051, 0.21055, 0.21059, 0.21063, 0.21068, 0.21072,
    0.21076, 0.2108, 0.21084, 0.21088, 0.21092, 0.21096, 0.211,
    0.21104, 0.21109, 0.21113, 0.21117, 0.21121, 0.21125, 0.21129,
    0.21133, 0.21137, 0.21141, 0.21145, 0.21149, 0.21154, 0.21158,
    0.21162, 0.21166, 0.2117, 0.21174, 0.21178, 0.21182, 0.21186,
    0.2119, 0.21194, 0.21198, 0.21202, 0.21206, 0.21211, 0.21215,
    0.21219, 0.21223, 0.21227, 0.21231, 0.21235, 0.21239, 0.21243,
    0.21247, 0.21251, 0.21255, 0.21259, 0.21263, 0.21267, 0.21271,
    0.21276, 0.2128, 0.21284, 0.21288, 0.21292, 0.21296, 0.213,
    0.21304, 0.21308, 0.21312, 0.21316, 0.2132, 0.21324, 0.21328,
    0.21332, 0.21336, 0.2134, 0.21344, 0.21348, 0.21352, 0.21356,
    0.2136, 0.21364, 0.21368, 0.21373, 0.21377, 0.21381, 0.21385,
    0.21389, 0.21393, 0.21397, 0.21401, 0.21405, 0.21409, 0.21413,
    0.21417, 0.21421, 0.21425, 0.21429, 0.21433, 0.21437, 0.21441,
    0.21445, 0.21449, 0.21453, 0.21457, 0.21461, 0.21465, 0.21469,
    0.21473, 0.21477, 0.21481, 0.21485, 0.21489, 0.21493, 0.21497,
    0.21501, 0.21505, 0.21509, 0.21513, 0.21517, 0.21521, 0.21525,
    0.21529, 0.21533, 0.21537, 0.21541, 0.21545, 0.21549, 0.21553,
    0.21557, 0.2156, 0.21564, 0.21568, 0.21572, 0.21576, 0.2158,
    0.21584, 0.21588, 0.21592, 0.21596, 0.216, 0.21604, 0.21608,
    0.21612, 0.21616, 0.2162, 0.21624, 0.21628, 0.21632, 0.21636,
    0.2164, 0.21644, 0.21648, 0.21651, 0.21655, 0.21659, 0.21663,
    0.21667, 0.21671, 0.21675, 0.21679, 0.21683, 0.21687, 0.21691,
    0.21695, 0.21699, 0.21703, 0.21707, 0.2171, 0.21714, 0.21718,
    0.21722, 0.21726, 0.2173, 0.21734, 0.21738, 0.21742, 0.21746,
    0.2175, 0.21753, 0.21757, 0.21761, 0.21765, 0.21769, 0.21773,
    0.21777, 0.21781, 0.21785, 0.21789, 0.21792, 0.21796, 0.218,
    0.21804, 0.21808, 0.21812, 0.21816, 0.2182, 0.21824, 0.21827,
    0.21831, 0.21835, 0.21839, 0.21843, 0.21847, 0.21851, 0.21855,
    0.21858, 0.21862, 0.21866, 0.2187, 0.21874, 0.21878, 0.21882,
    0.21885, 0.21889, 0.21893, 0.21897, 0.21901, 0.21905, 0.21909,
    0.21912, 0.21916, 0.2192, 0.21924, 0.21928, 0.21932, 0.21935,
    0.21939, 0.21943, 0.21947, 0.21951, 0.21955, 0.21959, 0.21962,
    0.21966, 0.2197, 0.21974, 0.21978, 0.21981, 0.21985, 0.21989,
    0.21993, 0.21997, 0.22001, 0.22004, 0.22008, 0.22012, 0.22016,
    0.2202, 0.22023, 0.22027, 0.22031, 0.22035, 0.22039, 0.22042,
    0.22046, 0.2205, 0.22054, 0.22058, 0.22061, 0.22065, 0.22069,
    0.22073, 0.22077, 0.2208, 0.22084, 0.22088, 0.22092, 0.22096,
    0.22099, 0.22103, 0.22107, 0.22111, 0.22114, 0.22118, 0.22122,
    0.22126, 0.22129, 0.22133, 0.22137, 0.22141, 0.22145, 0.22148,
    0.22152, 0.22156, 0.2216, 0.22163, 0.22167, 0.22171, 0.22175,
    0.22178, 0.22182, 0.22186, 0.2219, 0.22193, 0.22197, 0.22201,
    0.22204, 0.22208, 0.22212, 0.22216, 0.22219, 0.22223, 0.22227,
    0.22231, 0.22234, 0.22238, 0.22242, 0.22245, 0.22249, 0.22253,
    0.22257, 0.2226, 0.22264, 0.22268, 0.22271, 0.22275, 0.22279,
    0.22283, 0.22286, 0.2229, 0.22294, 0.22297, 0.22301, 0.22305,
    0.22308, 0.22312, 0.22316, 0.2232, 0.22323, 0.22327, 0.22331,
    0.22334, 0.22338, 0.22342, 0.22345, 0.22349, 0.22353, 0.22356,
    0.2236, 0.22364, 0.22367, 0.22371, 0.22375, 0.22378, 0.22382,
    0.22386, 0.22389, 0.22393, 0.22397, 0.224, 0.22404, 0.22407,
    0.22411, 0.22415, 0.22418, 0.22422, 0.22426, 0.22429, 0.22433,
    0.22437, 0.2244, 0.22444, 0.22448, 0.22451, 0.22455, 0.22458,
    0.22462, 0.22466, 0.22469, 0.22473, 0.22476, 0.2248, 0.22484,
    0.22487, 0.22491, 0.22495, 0.22498, 0.22502, 0.22505, 0.22509,
    0.22513, 0.22516, 0.2252, 0.22523, 0.22527, 0.22531, 0.22534,
    0.22538, 0.22541, 0.22545, 0.22548, 0.22552, 0.22556, 0.22559,
    0.22563, 0.22566, 0.2257, 0.22574, 0.22577, 0.22581, 0.22584,
    0.22588, 0.22591, 0.22595, 0.22598, 0.22602, 0.22606, 0.22609,
    0.22613, 0.22616, 0.2262, 0.22623, 0.22627, 0.2263, 0.22634,
    0.22638, 0.22641, 0.22645, 0.22648, 0.22652, 0.22655, 0.22659,
    0.22662, 0.22666, 0.22669, 0.22673, 0.22676, 0.2268, 0.22683,
    0.22687, 0.2269, 0.22694, 0.22697, 0.22701, 0.22704, 0.22708,
    0.22711, 0.22715, 0.22719, 0.22722, 0.22726, 0.22729, 0.22732,
    0.22736, 0.22739, 0.22743, 0.22746, 0.2275, 0.22753, 0.22757,
    0.2276, 0.22764, 0.22767, 0.22771, 0.22774, 0.22778, 0.22781,
    0.22785, 0.22788, 0.22792, 0.22795, 0.22799, 0.22802, 0.22805,
    0.22809, 0.22812, 0.22816, 0.22819, 0.22823, 0.22826, 0.2283,
    0.22833, 0.22837, 0.2284, 0.22843, 0.22847, 0.2285, 0.22854,
    0.22857, 0.22861, 0.22864, 0.22867, 0.22871, 0.22874, 0.22878,
    0.22881, 0.22885, 0.22888, 0.22891, 0.22895, 0.22898, 0.22902,
    0.22905, 0.22908, 0.22912, 0.22915, 0.22919, 0.22922, 0.22925,
    0.22929, 0.22932, 0.22936, 0.22939, 0.22942, 0.22946, 0.22949,
    0.22953, 0.22956, 0.22959, 0.22963, 0.22966, 0.2297, 0.22973,
    0.22976, 0.2298, 0.22983, 0.22986, 0.2299, 0.22993, 0.22996,
    0.23, 0.23003, 0.23007, 0.2301, 0.23013, 0.23017, 0.2302,
    0.23023, 0.23027, 0.2303, 0.23033, 0.23037, 0.2304, 0.23043,
    0.23047, 0.2305, 0.23053, 0.23057, 0.2306, 0.23063, 0.23067,
    0.2307, 0.23073, 0.23077, 0.2308, 0.23083, 0.23087, 0.2309,
    0.23093, 0.23097, 0.231, 0.23103, 0.23107, 0.2311, 0.23113,
    0.23116, 0.2312, 0.23123, 0.23126, 0.2313, 0.23133, 0.23136,
    0.2314, 0.23143, 0.23146, 0.23149, 0.23153, 0.23156, 0.23159,
    0.23163, 0.23166, 0.23169, 0.23172, 0.23176, 0.23179, 0.23182,
    0.23185, 0.23189, 0.23192, 0.23195, 0.23199, 0.23202, 0.23205,
    0.23208, 0.23212, 0.23215, 0.23218, 0.23221, 0.23225, 0.23228,
    0.23231, 0.23234, 0.23238, 0.23241, 0.23244, 0.23247, 0.23251,
    0.23254, 0.23257, 0.2326, 0.23264, 0.23267, 0.2327, 0.23273,
    0.23276, 0.2328, 0.23283, 0.23286, 0.23289, 0.23293, 0.23296,
    0.23299, 0.23302, 0.23305, 0.23309, 0.23312, 0.23315, 0.23318,
    0.23322, 0.23325, 0.23328, 0.23331, 0.23334, 0.23338, 0.23341,
    0.23344, 0.23347, 0.2335, 0.23354, 0.23357, 0.2336, 0.23363,
    0.23366, 0.23369, 0.23373, 0.23376, 0.16611, 0.16634, 0.16657,
    0.1668, 0.16703, 0.16725, 0.16748, 0.1677, 0.16792, 0.16814,
    0.16836, 0.16858, 0.16879, 0.16901, 0.16922, 0.16944, 0.16965,
    0.16986, 0.17007, 0.17027, 0.17048, 0.17069, 0.17089, 0.1711,
    0.1713, 0.1715, 0.1717, 0.1719, 0.1721, 0.1723, 0.1725, 0.17269,
    0.17289, 0.17308, 0.17328, 0.17347, 0.17366, 0.17385, 0.17405,
    0.17424, 0.17442, 0.17461, 0.1748, 0.17499, 0.17517, 0.17536,
    0.17554, 0.17573, 0.17591, 0.17609, 0.17627, 0.17645, 0.17663,
    0.17681, 0.17699, 0.17717, 0.17734, 0.17752, 0.17769, 0.17787,
    0.17804, 0.17821, 0.17838, 0.17855, 0.17872, 0.17889, 0.17906,
    0.17923, 0.17939, 0.17956, 0.17972, 0.17988, 0.18005, 0.18021,
    0.18037, 0.18053, 0.18069, 0.18085, 0.181, 0.18116, 0.18131,
    0.18147, 0.18162, 0.18177, 0.18192, 0.18207, 0.18222, 0.18237,
    0.18251, 0.18266, 0.1828, 0.18295, 0.18309, 0.18323, 0.18337,
    0.18351, 0.18365, 0.18378, 0.18392, 0.18405, 0.18419, 0.18432,
    0.18445, 0.18458, 0.18471, 0.18483, 0.18496, 0.18509, 0.18521,
    0.18533, 0.18546, 0.18558, 0.1857, 0.18582, 0.18593, 0.18605,
    0.18617, 0.18628, 0.1864, 0.18651, 0.18662, 0.18673, 0.18684,
    0.18695, 0.18705, 0.18716, 0.18726, 0.18737, 0.18747, 0.18757,
    0.18767, 0.18777, 0.18787, 0.18797, 0.18807, 0.18816, 0.18826,
    0.18835, 0.18844, 0.18853, 0.18863, 0.18871, 0.1888, 0.18889,
    0.18898, 0.18906, 0.18915, 0.18923, 0.18931, 0.1894, 0.18948,
    0.18956, 0.18964, 0.18972, 0.18979, 0.18987, 0.18994, 0.19002,
    0.19009, 0.19017, 0.19024, 0.19031, 0.19038, 0.19045, 0.19052,
    0.19058, 0.19065, 0.19072, 0.19078, 0.19085, 0.19091, 0.19097,
    0.19103, 0.1911, 0.19116, 0.19122, 0.19128, 0.19133, 0.19139,
    0.19145, 0.1915, 0.19156, 0.19161, 0.19167, 0.19172, 0.19177,
    0.19183, 0.19188, 0.19193, 0.19198, 0.19203, 0.19207, 0.19212,
    0.19217, 0.19222, 0.19226, 0.19231, 0.19235, 0.1924, 0.19244,
    0.19248, 0.19253, 0.19257, 0.19261, 0.19265, 0.19269, 0.19273,
    0.19277, 0.19281, 0.19284, 0.19288, 0.19292, 0.19296, 0.19299,
    0.19303, 0.19306, 0.1931, 0.19313, 0.19316, 0.1932, 0.19323,
    0.19326, 0.19329, 0.19332, 0.19336, 0.19339, 0.19342, 0.19345,
    0.19347, 0.1935, 0.19353, 0.19356, 0.19359, 0.19361, 0.19364,
    0.19367, 0.1937, 0.19372, 0.19375, 0.19377, 0.1938, 0.19382,
    0.19385, 0.19387, 0.1939, 0.19392, 0.19394, 0.19397, 0.19399,
    0.19401, 0.19403, 0.19406, 0.19408, 0.1941, 0.19412, 0.19414,
    0.19416, 0.19419, 0.19421, 0.19423, 0.19425, 0.19427, 0.19429,
    0.19431, 0.19433, 0.19435, 0.19437, 0.19439, 0.19441, 0.19443,
    0.19445, 0.19447, 0.19448, 0.1945, 0.19452, 0.19454, 0.19456,
    0.19458, 0.1946, 0.19461, 0.19463, 0.19465, 0.19467, 0.19469,
    0.19471, 0.19472, 0.19474, 0.19476, 0.19478, 0.19479, 0.19481,
    0.19483, 0.19485, 0.19486, 0.19488, 0.1949, 0.19492, 0.19493,
    0.19495, 0.19497, 0.19498, 0.195, 0.19502, 0.19504, 0.19505,
    0.19507, 0.19509, 0.1951, 0.19512, 0.19514, 0.19515, 0.19517,
    0.19519, 0.19521, 0.19522, 0.19524, 0.19526, 0.19527, 0.19529,
    0.19531, 0.19532, 0.19534, 0.19536, 0.19537, 0.19539, 0.19541,
    0.19542, 0.19544, 0.19546, 0.19547, 0.19549, 0.19551, 0.19553,
    0.19554, 0.19556, 0.19558, 0.19559, 0.19561, 0.19563, 0.19565,
    0.19566, 0.19568, 0.1957, 0.19571, 0.19573, 0.19575, 0.19577,
    0.19578, 0.1958, 0.19582, 0.19584, 0.19585, 0.19587, 0.19589,
    0.19591, 0.19593, 0.19594, 0.19596, 0.19598, 0.196, 0.19602,
    0.19603, 0.19605, 0.19607, 0.19609, 0.19611, 0.19612, 0.19614,
    0.19616, 0.19618, 0.1962, 0.19621, 0.19623, 0.19625, 0.19627,
    0.19629, 0.19631, 0.19632, 0.19634, 0.19636, 0.19638, 0.1964,
    0.19642, 0.19644, 0.19645, 0.19647, 0.19649, 0.19651, 0.19653,
    0.19655, 0.19657, 0.19659, 0.19661, 0.19662, 0.19664, 0.19666,
    0.19668, 0.1967, 0.19672, 0.19674, 0.19676, 0.19678, 0.1968,
    0.19682, 0.19684, 0.19686, 0.19688, 0.1969, 0.19691, 0.19693,
    0.19695, 0.19697, 0.19699, 0.19701, 0.19703, 0.19705, 0.19707,
    0.19709, 0.19711, 0.19713, 0.19715, 0.19717, 0.19719, 0.19721,
    0.19723, 0.19725, 0.19727, 0.1973, 0.19732, 0.19734, 0.19736,
    0.19738, 0.1974, 0.19742, 0.19744, 0.19746, 0.19748, 0.1975,
    0.19752, 0.19754, 0.19756, 0.19759, 0.19761, 0.19763, 0.19765,
    0.19767, 0.19769, 0.19771, 0.19773, 0.19776, 0.19778, 0.1978,
    0.19782, 0.19784, 0.19786, 0.19789, 0.19791, 0.19793, 0.19795,
    0.19797, 0.198, 0.19802, 0.19804, 0.19806, 0.19809, 0.19811,
    0.19813, 0.19815, 0.19818, 0.1982, 0.19822, 0.19824, 0.19827,
    0.19829, 0.19831, 0.19833, 0.19836, 0.19838, 0.1984, 0.19843,
    0.19845, 0.19847, 0.1985, 0.19852, 0.19854, 0.19857, 0.19859,
    0.19861, 0.19864, 0.19866, 0.19868, 0.19871, 0.19873, 0.19876,
    0.19878, 0.1988, 0.19883, 0.19885, 0.19888, 0.1989, 0.19893,
    0.19895, 0.19898, 0.199, 0.19902, 0.19905, 0.19907, 0.1991,
    0.19912, 0.19915, 0.19917, 0.1992, 0.19922, 0.19925, 0.19927,
    0.1993, 0.19933, 0.19935, 0.19938, 0.1994, 0.19943, 0.19945,
    0.19948, 0.19951, 0.19953, 0.19956, 0.19958, 0.19961, 0.19964,
    0.19966, 0.19969, 0.19972, 0.19974, 0.19977, 0.1998, 0.19982,
    0.19985, 0.19988, 0.1999, 0.19993, 0.19996, 0.19998, 0.20001,
    0.20004, 0.20007, 0.20009, 0.20012, 0.20015, 0.20017, 0.2002,
    0.20023, 0.20026, 0.20029, 0.20031, 0.20034, 0.20037, 0.2004,
    0.20043, 0.20045, 0.20048, 0.20051, 0.20054, 0.20057, 0.20059,
    0.20062, 0.20065, 0.20068, 0.20071, 0.20074, 0.20077, 0.20079,
    0.20082, 0.20085, 0.20088, 0.20091, 0.20094, 0.20097, 0.201,
    0.20103, 0.20106, 0.20109, 0.20112, 0.20114, 0.20117, 0.2012,
    0.20123, 0.20126, 0.20129, 0.20132, 0.20135, 0.20138, 0.20141,
    0.20144, 0.20147, 0.2015, 0.20153, 0.20156, 0.20159, 0.20162,
    0.20165, 0.20168, 0.20172, 0.20175, 0.20178, 0.20181, 0.20184,
    0.20187, 0.2019, 0.20193, 0.20196, 0.20199, 0.20202, 0.20205,
    0.20209, 0.20212, 0.20215, 0.20218, 0.20221, 0.20224, 0.20227,
    0.20231, 0.20234, 0.20237, 0.2024, 0.20243, 0.20246, 0.2025,
    0.20253, 0.20256, 0.20259, 0.20262, 0.20266, 0.20269, 0.20272,
    0.20275, 0.20278, 0.20282, 0.20285, 0.20288, 0.20291, 0.20295,
    0.20298, 0.20301, 0.20304, 0.20308, 0.20311, 0.20314, 0.20317,
    0.20321, 0.20324, 0.20327, 0.20331, 0.20334, 0.20337, 0.2034,
    0.20344, 0.20347, 0.2035, 0.20354, 0.20357, 0.2036, 0.20364,
    0.20367, 0.2037, 0.20374, 0.20377, 0.2038, 0.20384, 0.20387,
    0.2039, 0.20394, 0.20397, 0.204, 0.20404, 0.20407, 0.20411,
    0.20414, 0.20417, 0.20421, 0.20424, 0.20428, 0.20431, 0.20434,
    0.20438, 0.20441, 0.20445, 0.20448, 0.20451, 0.20455, 0.20458,
    0.20462, 0.20465, 0.20468, 0.20472, 0.20475, 0.20479, 0.20482,
    0.20486, 0.20489, 0.20492, 0.20496, 0.20499, 0.20503, 0.20506,
    0.2051, 0.20513, 0.20517, 0.2052, 0.20524, 0.20527, 0.2053,
    0.20534, 0.20537, 0.20541, 0.20544, 0.20548, 0.20551, 0.20555,
    0.20558, 0.20562, 0.20565, 0.20569, 0.20572, 0.20576, 0.20579,
    0.20583, 0.20586, 0.2059, 0.20593, 0.20597, 0.206, 0.20604,
    0.20607, 0.2061, 0.20614, 0.20617, 0.20621, 0.20624, 0.20628,
    0.20631, 0.20635, 0.20639, 0.20642, 0.20646, 0.20649, 0.20653,
    0.20656, 0.2066, 0.20663, 0.20667, 0.2067, 0.20674, 0.20677,
    0.20681, 0.20684, 0.20688, 0.20691, 0.20695, 0.20698, 0.20702,
    0.20705, 0.20709, 0.20712, 0.20716, 0.20719, 0.20723, 0.20727,
    0.2073, 0.20734, 0.20737, 0.20741, 0.20744, 0.20748, 0.20751,
    0.20755, 0.20758, 0.20762, 0.20766, 0.20769, 0.20773, 0.20776,
    0.2078, 0.20783, 0.20787, 0.20791, 0.20794, 0.20798, 0.20801,
    0.20805, 0.20808, 0.20812, 0.20816, 0.20819, 0.20823, 0.20826,
    0.2083, 0.20833, 0.20837, 0.20841, 0.20844, 0.20848, 0.20851,
    0.20855, 0.20859, 0.20862, 0.20866, 0.20869, 0.20873, 0.20877,
    0.2088, 0.20884, 0.20887, 0.20891, 0.20895, 0.20898, 0.20902,
    0.20905, 0.20909, 0.20913, 0.20916, 0.2092, 0.20924, 0.20927,
    0.20931, 0.20934, 0.20938, 0.20942, 0.20945, 0.20949, 0.20953,
    0.20956, 0.2096, 0.20964, 0.20967, 0.20971, 0.20975, 0.20978,
    0.20982, 0.20985, 0.20989, 0.20993, 0.20996, 0.21, 0.21004,
    0.21007, 0.21011, 0.21015, 0.21019, 0.21022, 0.21026, 0.2103,
    0.21033, 0.21037, 0.21041, 0.21044, 0.21048, 0.21052, 0.21055,
    0.21059, 0.21063, 0.21067, 0.2107, 0.21074, 0.21078, 0.21081,
    0.21085, 0.21089, 0.21093, 0.21096, 0.211, 0.21104, 0.21108,
    0.21111, 0.21115, 0.21119, 0.21123, 0.21126, 0.2113, 0.21134,
    0.21138, 0.21141, 0.21145, 0.21149, 0.21153, 0.21157, 0.2116,
    0.21164, 0.21168, 0.21172, 0.21175, 0.21179, 0.21183, 0.21187,
    0.21191, 0.21195, 0.21198, 0.21202, 0.21206, 0.2121, 0.21214,
    0.21217, 0.21221, 0.21225, 0.21229, 0.21233, 0.21237, 0.21241,
    0.21244, 0.21248, 0.21252, 0.21256, 0.2126, 0.21264, 0.21268,
    0.21272, 0.21275, 0.21279, 0.21283, 0.21287, 0.21291, 0.21295,
    0.21299, 0.21303, 0.21307, 0.21311, 0.21315, 0.21319, 0.21322,
    0.21326, 0.2133, 0.21334, 0.21338, 0.21342, 0.21346, 0.2135,
    0.21354, 0.21358, 0.21362, 0.21366, 0.2137, 0.21374, 0.21378,
    0.21382, 0.21386, 0.2139, 0.21394, 0.21398, 0.21402, 0.21406,
    0.2141, 0.21414, 0.21418, 0.21422, 0.21426, 0.2143, 0.21434,
    0.21438, 0.21442, 0.21446, 0.21451, 0.21455, 0.21459, 0.21463,
    0.21467, 0.21471, 0.21475, 0.21479, 0.21483, 0.21487, 0.21491,
    0.21495, 0.215, 0.21504, 0.21508, 0.21512, 0.21516, 0.2152,
    0.21524, 0.21529, 0.21533, 0.21537, 0.21541, 0.21545, 0.21549,
    0.21553, 0.21558, 0.21562, 0.21566, 0.2157, 0.21574, 0.21579,
    0.21583, 0.21587, 0.21591, 0.21595, 0.216, 0.21604, 0.21608,
    0.21612, 0.21617, 0.21621, 0.21625, 0.21629, 0.21634, 0.21638,
    0.21642, 0.21646, 0.21651, 0.21655, 0.21659, 0.21663, 0.21668,
    0.21672, 0.21676, 0.21681, 0.21685, 0.21689, 0.21694, 0.21698,
    0.21702, 0.21707, 0.21711, 0.21715, 0.2172, 0.21724, 0.21728,
    0.21733, 0.21737, 0.21741, 0.21746, 0.2175, 0.21754, 0.21759,
    0.21763, 0.21768, 0.21772, 0.21776, 0.21781, 0.21785, 0.2179,
    0.21794, 0.21798, 0.21803, 0.21807, 0.21812, 0.21816, 0.21821,
    0.21825, 0.2183, 0.21834, 0.21838, 0.21843, 0.21847, 0.21852,
    0.21856, 0.21861, 0.21865, 0.2187, 0.21874, 0.21879, 0.21883,
    0.21888, 0.21892, 0.21897, 0.21901, 0.21906, 0.21911, 0.21915,
    0.2192, 0.21924, 0.21929, 0.21933, 0.21938, 0.21942, 0.21947,
    0.21952, 0.21956, 0.21961, 0.21965, 0.2197, 0.21975, 0.21979,
    0.21984, 0.21988, 0.21993, 0.21998, 0.22002, 0.22007, 0.22012,
    0.22016, 0.22021, 0.22026, 0.2203, 0.22035, 0.2204, 0.22044,
    0.22049, 0.22054, 0.22058, 0.22063, 0.22068, 0.22072, 0.22077,
    0.22082, 0.22087, 0.22091, 0.22096, 0.22101, 0.22106, 0.2211,
    0.22115, 0.2212, 0.22125, 0.22129, 0.22134, 0.22139, 0.22144,
    0.22148, 0.22153, 0.22158, 0.22163, 0.22168, 0.22172, 0.22177,
    0.22182, 0.22187, 0.22192, 0.22197, 0.22201, 0.22206, 0.22211,
    0.22216, 0.22221, 0.22226, 0.2223, 0.22235, 0.2224, 0.22245,
    0.2225, 0.22255, 0.2226, 0.22265, 0.2227, 0.22274, 0.22279,
    0.22284, 0.22289, 0.22294, 0.22299, 0.22304, 0.22309, 0.22314,
    0.22319, 0.22324, 0.22329, 0.22334, 0.22339, 0.22344, 0.22349,
    0.22354, 0.22359, 0.22363, 0.22368, 0.22373, 0.22378, 0.22383,
    0.22388, 0.22393, 0.22399, 0.22404, 0.22409, 0.22414, 0.22419,
    0.22424, 0.22429, 0.22434, 0.22439, 0.22444, 0.22449, 0.22454,
    0.22459, 0.22464, 0.22469, 0.22474, 0.22479, 0.22484, 0.22489,
    0.22495, 0.225, 0.22505, 0.2251, 0.22515, 0.2252, 0.22525,
    0.2253, 0.22535, 0.22541, 0.22546, 0.22551, 0.22556, 0.22561,
    0.22566, 0.22571, 0.22576, 0.22582, 0.22587, 0.22592, 0.22597,
    0.22602, 0.22607, 0.22613, 0.22618, 0.22623, 0.22628, 0.22633,
    0.22639, 0.22644, 0.22649, 0.22654, 0.22659, 0.22665, 0.2267,
    0.22675, 0.2268, 0.22685, 0.22691, 0.22696, 0.22701, 0.22706,
    0.22712, 0.22717, 0.22722, 0.22727, 0.22733, 0.22738, 0.22743,
    0.22748, 0.22754, 0.22759, 0.22764, 0.22769, 0.22775, 0.2278,
    0.22785, 0.2279, 0.22796, 0.22801, 0.22806, 0.22812, 0.22817,
    0.22822, 0.22827, 0.22833, 0.22838, 0.22843, 0.22849, 0.22854,
    0.22859, 0.22865, 0.2287, 0.22875, 0.22881, 0.22886, 0.22891,
    0.22897, 0.22902, 0.22907, 0.22913, 0.22918, 0.22923, 0.22929,
    0.22934, 0.22939, 0.22945, 0.2295, 0.22955, 0.22961, 0.22966,
    0.22972, 0.22977, 0.22982, 0.22988, 0.22993, 0.22998, 0.23004,
    0.23009, 0.23015, 0.2302, 0.23025, 0.23031, 0.23036, 0.23042,
    0.23047, 0.23052, 0.23058, 0.23063, 0.23069, 0.23074, 0.23079,
    0.23085, 0.2309, 0.23096, 0.23101, 0.23106, 0.23112, 0.23117,
    0.23123, 0.23128, 0.23134, 0.23139, 0.23144, 0.2315, 0.23155,
    0.23161, 0.23166, 0.23172, 0.23177, 0.23182, 0.23188, 0.23193,
    0.23199, 0.23204, 0.2321, 0.23215, 0.23221, 0.23226, 0.23232,
    0.23237, 0.23242, 0.23248, 0.23253, 0.23259, 0.23264, 0.2327,
    0.23275, 0.23281, 0.23286, 0.23292, 0.23297, 0.23303, 0.23308,
    0.23314, 0.23319, 0.23325, 0.2333, 0.23336, 0.23341, 0.23347,
    0.23352, 0.23358, 0.23363, 0.23369, 0.23374, 0.2338, 0.23385,
    0.23391, 0.23396, 0.23402, 0.23407, 0.23413, 0.23418, 0.23424,
    0.23429, 0.23435, 0.2344, 0.23446, 0.23451, 0.23457, 0.23462,
    0.23468, 0.23473, 0.23479, 0.23484, 0.2349, 0.23495, 0.23501,
    0.23506, 0.23512, 0.23517, 0.23523, 0.23528, 0.23534, 0.2354,
    0.23545, 0.23551, 0.23556, 0.23562, 0.23567, 0.23573, 0.23578,
    0.23584, 0.23589, 0.23595, 0.236, 0.23606, 0.23612, 0.23617,
    0.23623, 0.23628, 0.23634, 0.23639, 0.23645, 0.2365, 0.23656,
    0.23661, 0.23667, 0.23673, 0.23678, 0.23684, 0.23689, 0.23695,
    0.237, 0.23706, 0.23711, 0.23717, 0.23723, 0.23728, 0.23734,
    0.23739, 0.23745, 0.2375, 0.23756, 0.23761, 0.23767, 0.23773,
    0.23778, 0.23784, 0.23789, 0.23795, 0.238, 0.23806, 0.23812,
    0.23817, 0.23823, 0.23828, 0.23834, 0.23839, 0.23845, 0.23851,
    0.23856, 0.23862, 0.23867, 0.23873, 0.23878, 0.23884, 0.2389,
    0.23895, 0.23901, 0.23906, 0.23912, 0.23918, 0.23923, 0.23929,
    0.23934, 0.2394, 0.23945, 0.23951, 0.23957, 0.23962, 0.23968,
    0.23973, 0.23979, 0.23985, 0.2399, 0.23996, 0.24001, 0.24007,
    0.24013, 0.24018, 0.24024, 0.24029, 0.24035, 0.24041, 0.24046,
    0.24052, 0.24057, 0.24063, 0.24068, 0.24074, 0.2408, 0.24085,
    0.24091, 0.24097, 0.24102, 0.24108, 0.24113, 0.24119, 0.24125,
    0.2413, 0.24136, 0.24141, 0.24147, 0.24153, 0.24158, 0.24164,
    0.24169, 0.24175, 0.24181, 0.24186, 0.24192, 0.24198, 0.24203,
    0.24209, 0.24214, 0.2422, 0.24226, 0.24231, 0.24237, 0.24242,
    0.24248, 0.24254, 0.24259, 0.24265, 0.24271, 0.24276, 0.24282,
    0.24287, 0.24293, 0.24299, 0.24304, 0.2431, 0.24316, 0.24321,
    0.24327, 0.24333, 0.24338, 0.24344, 0.24349, 0.24355, 0.24361,
    0.24366, 0.24372, 0.24378, 0.24383, 0.24389, 0.24395, 0.244,
    0.24406, 0.24411, 0.24417, 0.24423, 0.24428, 0.24434, 0.2444,
    0.24445, 0.24451, 0.24457, 0.24462, 0.24468, 0.24474, 0.24479,
    0.24485, 0.24491, 0.24496, 0.24502, 0.24507, 0.24513, 0.24519,
    0.24524, 0.2453, 0.24536, 0.24541, 0.24547, 0.24553, 0.24558,
    0.24564, 0.2457, 0.24575, 0.24581, 0.24587, 0.24592, 0.24598,
    0.24604, 0.24609, 0.24615, 0.24621, 0.24626, 0.24632, 0.24638,
    0.24643, 0.24649, 0.24655, 0.2466, 0.24666, 0.24672, 0.24677,
    0.24683, 0.24689, 0.24694, 0.247, 0.24706, 0.24711, 0.24717,
    0.24723, 0.24729, 0.24734, 0.2474, 0.24746, 0.24751, 0.24757,
    0.24763, 0.24768, 0.24774, 0.2478, 0.24785, 0.24791, 0.24797,
    0.24802, 0.24808, 0.24814, 0.24819, 0.24825, 0.24831, 0.24837,
    0.24842, 0.24848, 0.24854, 0.24859, 0.24865, 0.24871, 0.24876,
    0.24882, 0.24888, 0.24893, 0.24899, 0.24905, 0.2491, 0.24916,
    0.24922, 0.24928, 0.24933, 0.24939, 0.24945, 0.2495, 0.24956,
    0.24962, 0.24967, 0.24973, 0.24979, 0.24985, 0.2499, 0.24996,
    0.25002, 0.25007, 0.25013, 0.25019, 0.25024, 0.2503, 0.25036,
    0.25041, 0.25047, 0.25053, 0.25059, 0.25064, 0.2507, 0.25076,
    0.25081, 0.25087, 0.25093, 0.25098, 0.25104, 0.2511, 0.25116,
    0.25121, 0.25127, 0.25133, 0.25138, 0.25144, 0.2515, 0.25156,
    0.25161, 0.25167, 0.25173, 0.25178, 0.25184, 0.2519, 0.25195,
    0.25201, 0.25207, 0.25213, 0.25218, 0.25224, 0.2523, 0.25235,
    0.25241, 0.25247, 0.25252, 0.25258, 0.25264, 0.2527, 0.25275,
    0.25281, 0.25287, 0.25292, 0.25298, 0.25304, 0.25309, 0.25315,
    0.25321, 0.25326, 0.25332, 0.25338, 0.25344, 0.25349, 0.25355,
    0.25361, 0.25366, 0.25372, 0.25378, 0.25383, 0.25389, 0.25395,
    0.25401, 0.25406, 0.25412, 0.25418, 0.25423, 0.25429, 0.25435,
    0.2544, 0.25446, 0.25452, 0.25457, 0.25463, 0.25469, 0.25475,
    0.2548, 0.25486, 0.25492, 0.25497, 0.25503, 0.25509, 0.25514,
    0.2552, 0.25526, 0.25531, 0.25537, 0.25543, 0.25549, 0.25554,
    0.2556, 0.25566, 0.25571, 0.25577, 0.25583, 0.25588, 0.25594,
    0.256, 0.25605, 0.25611, 0.25617, 0.25622, 0.25628, 0.25634,
    0.25639, 0.25645, 0.25651, 0.25656, 0.25662, 0.25668, 0.25674,
    0.25679, 0.25685, 0.25691, 0.25696, 0.25702, 0.17525, 0.17555,
    0.17583, 0.17612, 0.1764, 0.17669, 0.17697, 0.17725, 0.17752,
    0.1778, 0.17807, 0.17834, 0.17861, 0.17888, 0.17914, 0.17941,
    0.17967, 0.17993, 0.18019, 0.18045, 0.1807, 0.18096, 0.18121,
    0.18146, 0.18172, 0.18196, 0.18221, 0.18246, 0.18271, 0.18295,
    0.18319, 0.18343, 0.18367, 0.18391, 0.18415, 0.18439, 0.18462,
    0.18486, 0.18509, 0.18532, 0.18555, 0.18578, 0.186, 0.18623,
    0.18645, 0.18667, 0.1869, 0.18712, 0.18733, 0.18755, 0.18776,
    0.18798, 0.18819, 0.1884, 0.18861, 0.18882, 0.18902, 0.18923,
    0.18943, 0.18963, 0.18983, 0.19003, 0.19023, 0.19042, 0.19062,
    0.19081, 0.191, 0.19119, 0.19138, 0.19157, 0.19175, 0.19194,
    0.19212, 0.1923, 0.19248, 0.19266, 0.19283, 0.19301, 0.19318,
    0.19335, 0.19352, 0.19369, 0.19386, 0.19403, 0.19419, 0.19435,
    0.19452, 0.19468, 0.19483, 0.19499, 0.19515, 0.1953, 0.19545,
    0.19561, 0.19576, 0.1959, 0.19605, 0.19619, 0.19634, 0.19648,
    0.19662, 0.19676, 0.1969, 0.19703, 0.19717, 0.1973, 0.19743,
    0.19756, 0.19769, 0.19782, 0.19794, 0.19807, 0.19819, 0.19831,
    0.19843, 0.19855, 0.19866, 0.19878, 0.19889, 0.199, 0.19911,
    0.19922, 0.19933, 0.19944, 0.19954, 0.19964, 0.19974, 0.19984,
    0.19994, 0.20004, 0.20013, 0.20023, 0.20032, 0.20041, 0.2005,
    0.20059, 0.20068, 0.20076, 0.20084, 0.20093, 0.20101, 0.20109,
    0.20117, 0.20124, 0.20132, 0.2014, 0.20147, 0.20154, 0.20161,
    0.20168, 0.20175, 0.20182, 0.20188, 0.20195, 0.20201, 0.20207,
    0.20213, 0.20219, 0.20225, 0.20231, 0.20237, 0.20242, 0.20248,
    0.20253, 0.20258, 0.20263, 0.20268, 0.20273, 0.20278, 0.20283,
    0.20287, 0.20292, 0.20296, 0.20301, 0.20305, 0.20309, 0.20313,
    0.20317, 0.20321, 0.20325, 0.20328, 0.20332, 0.20336, 0.20339,
    0.20342, 0.20346, 0.20349, 0.20352, 0.20355, 0.20358, 0.20361,
    0.20364, 0.20367, 0.2037, 0.20372, 0.20375, 0.20377, 0.2038,
    0.20382, 0.20385, 0.20387, 0.20389, 0.20391, 0.20394, 0.20396,
    0.20398, 0.204, 0.20402, 0.20403, 0.20405, 0.20407, 0.20409,
    0.2041, 0.20412, 0.20414, 0.20415, 0.20417, 0.20418, 0.20419,
    0.20421, 0.20422, 0.20423, 0.20425, 0.20426, 0.20427, 0.20428,
    0.20429, 0.2043, 0.20431, 0.20432, 0.20433, 0.20434, 0.20435,
    0.20436, 0.20436, 0.20437, 0.20438, 0.20439, 0.20439, 0.2044,
    0.20441, 0.20441, 0.20442, 0.20442, 0.20443, 0.20443, 0.20443,
    0.20444, 0.20444, 0.20444, 0.20445, 0.20445, 0.20445, 0.20445,
    0.20446, 0.20446, 0.20446, 0.20446, 0.20446, 0.20446, 0.20446,
    0.20446, 0.20446, 0.20446, 0.20446, 0.20446, 0.20446, 0.20446,
    0.20446, 0.20446, 0.20446, 0.20446, 0.20446, 0.20445, 0.20445,
    0.20445, 0.20445, 0.20444, 0.20444, 0.20444, 0.20444, 0.20443,
    0.20443, 0.20443, 0.20442, 0.20442, 0.20441, 0.20441, 0.20441,
    0.2044, 0.2044, 0.20439, 0.20439, 0.20438, 0.20438, 0.20437,
    0.20437, 0.20436, 0.20436, 0.20435, 0.20435, 0.20434, 0.20433,
    0.20433, 0.20432, 0.20432, 0.20431, 0.2043, 0.2043, 0.20429,
    0.20428, 0.20428, 0.20427, 0.20426, 0.20426, 0.20425, 0.20424,
    0.20424, 0.20423, 0.20422, 0.20421, 0.20421, 0.2042, 0.20419,
    0.20418, 0.20418, 0.20417, 0.20416, 0.20415, 0.20414, 0.20414,
    0.20413, 0.20412, 0.20411, 0.2041, 0.2041, 0.20409, 0.20408,
    0.20407, 0.20406, 0.20405, 0.20405, 0.20404, 0.20403, 0.20402,
    0.20401, 0.204, 0.204, 0.20399, 0.20398, 0.20397, 0.20396,
    0.20395, 0.20395, 0.20394, 0.20393, 0.20392, 0.20391, 0.2039,
    0.20389, 0.20389, 0.20388, 0.20387, 0.20386, 0.20385, 0.20385,
    0.20384, 0.20383, 0.20382, 0.20381, 0.20381, 0.2038, 0.20379,
    0.20378, 0.20378, 0.20377, 0.20376, 0.20375, 0.20375, 0.20374,
    0.20373, 0.20372, 0.20372, 0.20371, 0.2037, 0.2037, 0.20369,
    0.20368, 0.20368, 0.20367, 0.20366, 0.20366, 0.20365, 0.20365,
    0.20364, 0.20363, 0.20363, 0.20362, 0.20362, 0.20361, 0.2036,
    0.2036, 0.20359, 0.20359, 0.20358, 0.20358, 0.20357, 0.20357,
    0.20357, 0.20356, 0.20356, 0.20355, 0.20355, 0.20354, 0.20354,
    0.20354, 0.20353, 0.20353, 0.20353, 0.20352, 0.20352, 0.20352,
    0.20351, 0.20351, 0.20351, 0.20351, 0.2035, 0.2035, 0.2035,
    0.2035, 0.2035, 0.20349, 0.20349, 0.20349, 0.20349, 0.20349,
    0.20349, 0.20349, 0.20349, 0.20349, 0.20349, 0.20349, 0.20349,
    0.20349, 0.20349, 0.20349, 0.20349, 0.20349, 0.20349, 0.20349,
    0.20349, 0.20349, 0.20349, 0.20349, 0.2035, 0.2035, 0.2035,
    0.2035, 0.2035, 0.20351, 0.20351, 0.20351, 0.20351, 0.20352,
    0.20352, 0.20352, 0.20353, 0.20353, 0.20354, 0.20354, 0.20354,
    0.20355, 0.20355, 0.20356, 0.20356, 0.20357, 0.20357, 0.20358,
    0.20358, 0.20359, 0.20359, 0.2036, 0.2036, 0.20361, 0.20362,
    0.20362, 0.20363, 0.20364, 0.20364, 0.20365, 0.20366, 0.20367,
    0.20367, 0.20368, 0.20369, 0.2037, 0.20371, 0.20371, 0.20372,
    0.20373, 0.20374, 0.20375, 0.20376, 0.20377, 0.20378, 0.20379,
    0.2038, 0.20381, 0.20382, 0.20383, 0.20384, 0.20385, 0.20386,
    0.20387, 0.20388, 0.2039, 0.20391, 0.20392, 0.20393, 0.20394,
    0.20396, 0.20397, 0.20398, 0.20399, 0.20401, 0.20402, 0.20403,
    0.20405, 0.20406, 0.20408, 0.20409, 0.2041, 0.20412, 0.20413,
    0.20415, 0.20416, 0.20418, 0.20419, 0.20421, 0.20422, 0.20424,
    0.20426, 0.20427, 0.20429, 0.2043, 0.20432, 0.20434, 0.20435,
    0.20437, 0.20439, 0.20441, 0.20442, 0.20444, 0.20446, 0.20448,
    0.20449, 0.20451, 0.20453, 0.20455, 0.20457, 0.20459, 0.20461,
    0.20462, 0.20464, 0.20466, 0.20468, 0.2047, 0.20472, 0.20474,
    0.20476, 0.20478, 0.2048, 0.20482, 0.20484, 0.20487, 0.20489,
    0.20491, 0.20493, 0.20495, 0.20497, 0.20499, 0.20502, 0.20504,
    0.20506, 0.20508, 0.2051, 0.20513, 0.20515, 0.20517, 0.20519,
    0.20522, 0.20524, 0.20526, 0.20529, 0.20531, 0.20533, 0.20536,
    0.20538, 0.20541, 0.20543, 0.20546, 0.20548, 0.2055, 0.20553,
    0.20555, 0.20558, 0.2056, 0.20563, 0.20566, 0.20568, 0.20571,
    0.20573, 0.20576, 0.20578, 0.20581, 0.20584, 0.20586, 0.20589,
    0.20592, 0.20594, 0.20597, 0.206, 0.20603, 0.20605, 0.20608,
    0.20611, 0.20614, 0.20616, 0.20619, 0.20622, 0.20625, 0.20628,
    0.20631, 0.20633, 0.20636, 0.20639, 0.20642, 0.20645, 0.20648,
    0.20651, 0.20654, 0.20657, 0.2066, 0.20663, 0.20666, 0.20669,
    0.20672, 0.20675, 0.20678, 0.20681, 0.20684, 0.20687, 0.20691,
    0.20694, 0.20697, 0.207, 0.20703, 0.20706, 0.20709, 0.20713,
    0.20716, 0.20719, 0.20722, 0.20726, 0.20729, 0.20732, 0.20735,
    0.20739, 0.20742, 0.20745, 0.20749, 0.20752, 0.20755, 0.20759,
    0.20762, 0.20765, 0.20769, 0.20772, 0.20776, 0.20779, 0.20782,
    0.20786, 0.20789, 0.20793, 0.20796, 0.208, 0.20803, 0.20807,
    0.2081, 0.20814, 0.20817, 0.20821, 0.20825, 0.20828, 0.20832,
    0.20835, 0.20839, 0.20843, 0.20846, 0.2085, 0.20853, 0.20857,
    0.20861, 0.20865, 0.20868, 0.20872, 0.20876, 0.20879, 0.20883,
    0.20887, 0.20891, 0.20894, 0.20898, 0.20902, 0.20906, 0.2091,
    0.20913, 0.20917, 0.20921, 0.20925, 0.20929, 0.20933, 0.20936,
    0.2094, 0.20944, 0.20948, 0.20952, 0.20956, 0.2096, 0.20964,
    0.20968, 0.20972, 0.20976, 0.2098, 0.20984, 0.20988, 0.20992,
    0.20996, 0.21, 0.21004, 0.21008, 0.21012, 0.21016, 0.2102,
    0.21024, 0.21028, 0.21032, 0.21036, 0.2104, 0.21045, 0.21049,
    0.21053, 0.21057, 0.21061, 0.21065, 0.21069, 0.21074, 0.21078,
    0.21082, 0.21086, 0.2109, 0.21095, 0.21099, 0.21103, 0.21107,
    0.21112, 0.21116, 0.2112, 0.21124, 0.21129, 0.21133, 0.21137,
    0.21142, 0.21146, 0.2115, 0.21154, 0.21159, 0.21163, 0.21167,
    0.21172, 0.21176, 0.21181, 0.21185, 0.21189, 0.21194, 0.21198,
    0.21202, 0.21207, 0.21211, 0.21216, 0.2122, 0.21225, 0.21229,
    0.21233, 0.21238, 0.21242, 0.21247, 0.21251, 0.21256, 0.2126,
    0.21265, 0.21269, 0.21274, 0.21278, 0.21283, 0.21287, 0.21292,
    0.21296, 0.21301, 0.21306, 0.2131, 0.21315, 0.21319, 0.21324,
    0.21328, 0.21333, 0.21338, 0.21342, 0.21347, 0.21351, 0.21356,
    0.21361, 0.21365, 0.2137, 0.21374, 0.21379, 0.21384, 0.21388,
    0.21393, 0.21398, 0.21402, 0.21407, 0.21412, 0.21416, 0.21421,
    0.21426, 0.21431, 0.21435, 0.2144, 0.21445, 0.21449, 0.21454,
    0.21459, 0.21464, 0.21468, 0.21473, 0.21478, 0.21483, 0.21487,
    0.21492, 0.21497, 0.21502, 0.21507, 0.21511, 0.21516, 0.21521,
    0.21526, 0.21531, 0.21535, 0.2154, 0.21545, 0.2155, 0.21555,
    0.2156, 0.21564, 0.21569, 0.21574, 0.21579, 0.21584, 0.21589,
    0.21593, 0.21598, 0.21603, 0.21608, 0.21613, 0.21618, 0.21623,
    0.21628, 0.21633, 0.21637, 0.21642, 0.21647, 0.21652, 0.21657,
    0.21662, 0.21667, 0.21672, 0.21677, 0.21682, 0.21687, 0.21692,
    0.21697, 0.21702, 0.21707, 0.21712, 0.21717, 0.21722, 0.21726,
    0.21731, 0.21736, 0.21741, 0.21746, 0.21751, 0.21756, 0.21761,
    0.21766, 0.21771, 0.21776, 0.21782, 0.21787, 0.21792, 0.21797,
    0.21802, 0.21807, 0.21812, 0.21817, 0.21822, 0.21827, 0.21832,
    0.21837, 0.21842, 0.21847, 0.21852, 0.21857, 0.21862, 0.21867,
    0.21872, 0.21878, 0.21883, 0.21888, 0.21893, 0.21898, 0.21903,
    0.21908, 0.21913, 0.21918, 0.21924, 0.21929, 0.21934, 0.21939,
    0.21944, 0.21949, 0.21954, 0.21959, 0.21965, 0.2197, 0.21975,
    0.2198, 0.21985, 0.2199, 0.21996, 0.22001, 0.22006, 0.22011,
    0.22016, 0.22021, 0.22027, 0.22032, 0.22037, 0.22042, 0.22047,
    0.22053, 0.22058, 0.22063, 0.22068, 0.22073, 0.22079, 0.22084,
    0.22089, 0.22094, 0.22099, 0.22105, 0.2211, 0.22115, 0.2212,
    0.22126, 0.22131, 0.22136, 0.22141, 0.22146, 0.22152, 0.22157,
    0.22162, 0.22167, 0.22173, 0.22178, 0.22183, 0.22188, 0.22194,
    0.22199, 0.22204, 0.2221, 0.22215, 0.2222, 0.22225, 0.22231,
    0.22236, 0.22241, 0.22247, 0.22252, 0.22257, 0.22262, 0.22268,
    0.22273, 0.22278, 0.22284, 0.22289, 0.22294, 0.223, 0.22305,
    0.2231, 0.22315, 0.22321, 0.22326, 0.22331, 0.22337, 0.22342,
    0.22347, 0.22353, 0.22358, 0.22363, 0.22369, 0.22374, 0.22379,
    0.22385, 0.2239, 0.22395, 0.22401, 0.22406, 0.22411, 0.22417,
    0.22422, 0.22427, 0.22433, 0.22438, 0.22443, 0.22449, 0.22454,
    0.2246, 0.22465, 0.2247, 0.22476, 0.22481, 0.22486, 0.22492,
    0.22497, 0.22502, 0.22508, 0.22513, 0.22519, 0.22524, 0.22529,
    0.22535, 0.2254, 0.22545, 0.22551, 0.22556, 0.22562, 0.22567,
    0.22572, 0.22578, 0.22583, 0.22589, 0.22594, 0.22599, 0.22605,
    0.2261, 0.22615, 0.22621, 0.22626, 0.22632, 0.22637, 0.22642,
    0.22648, 0.22653, 0.22659, 0.22664, 0.22669, 0.22675, 0.2268,
    0.22686, 0.22691, 0.22696, 0.22702, 0.22707, 0.22713, 0.22718,
    0.22723, 0.22729, 0.22734, 0.2274, 0.22745, 0.2275, 0.22756,
    0.22761, 0.22767, 0.22772, 0.22777, 0.22783, 0.22788, 0.22794,
    0.22799, 0.22805, 0.2281, 0.22815, 0.22821, 0.22826, 0.22832,
    0.22837, 0.22842, 0.22848, 0.22853, 0.22859, 0.22864, 0.22869,
    0.22875, 0.2288, 0.22886, 0.22891, 0.22896, 0.22902, 0.22907,
    0.22913, 0.22918, 0.22923, 0.22929, 0.22934, 0.2294, 0.22945,
    0.2295, 0.22956, 0.22961, 0.22967, 0.22972, 0.22977, 0.22983,
    0.22988, 0.22994, 0.22999, 0.23004, 0.2301, 0.23015, 0.23021,
    0.23026, 0.23031, 0.23037, 0.23042, 0.23048, 0.23053, 0.23058,
    0.23064, 0.23069, 0.23074, 0.2308, 0.23085, 0.23091, 0.23096,
    0.23101, 0.23107, 0.23112, 0.23118, 0.23123, 0.23128, 0.23134,
    0.23139, 0.23144, 0.2315, 0.23155, 0.23161, 0.23166, 0.23171,
    0.23177, 0.23182, 0.23187, 0.23193, 0.23198, 0.23203, 0.23209,
    0.23214, 0.2322, 0.23225, 0.2323, 0.23236, 0.23241, 0.23246,
    0.23252, 0.23257, 0.23262, 0.23268, 0.23273, 0.23278, 0.23284,
    0.23289, 0.23294, 0.233, 0.23305, 0.23311, 0.23316, 0.23321,
    0.23327, 0.23332, 0.23337, 0.23343, 0.23348, 0.23353, 0.23358,
    0.23364, 0.23369, 0.23374, 0.2338, 0.23385, 0.2339, 0.23396,
    0.23401, 0.23406, 0.23412, 0.23417, 0.23422, 0.23428, 0.23433,
    0.23438, 0.23444, 0.23449, 0.23454, 0.23459, 0.23465, 0.2347,
    0.23475, 0.23481, 0.23486, 0.23491, 0.23496, 0.23502, 0.23507,
    0.23512, 0.23518, 0.23523, 0.23528, 0.23533, 0.23539, 0.23544,
    0.23549, 0.23555, 0.2356, 0.23565, 0.2357, 0.23576, 0.23581,
    0.23586, 0.23591, 0.23597, 0.23602, 0.23607, 0.23612, 0.23618,
    0.23623, 0.23628, 0.23633, 0.23639, 0.23644, 0.23649, 0.23654,
    0.2366, 0.23665, 0.2367, 0.23675, 0.23681, 0.23686, 0.23691,
    0.23696, 0.23701, 0.23707, 0.23712, 0.23717, 0.23722, 0.23728,
    0.23733, 0.23738, 0.23743, 0.23748, 0.23754, 0.23759, 0.23764,
    0.23769, 0.23774, 0.2378, 0.23785, 0.2379, 0.23795, 0.238,
    0.23806, 0.23811, 0.23816, 0.23821, 0.23826, 0.23832, 0.23837,
    0.23842, 0.23847, 0.23852, 0.23857, 0.23863, 0.23868, 0.23873,
    0.23878, 0.23883, 0.23888, 0.23894, 0.23899, 0.23904, 0.23909,
    0.23914, 0.23919, 0.23924, 0.2393, 0.23935, 0.2394, 0.23945,
    0.2395, 0.23955, 0.2396, 0.23966, 0.23971, 0.23976, 0.23981,
    0.23986, 0.23991, 0.23996, 0.24001, 0.24007, 0.24012, 0.24017,
    0.24022, 0.24027, 0.24032, 0.24037, 0.24042, 0.24047, 0.24052,
    0.24058, 0.24063, 0.24068, 0.24073, 0.24078, 0.24083, 0.24088,
    0.24093, 0.24098, 0.24103, 0.24108, 0.24114, 0.24119, 0.24124,
    0.24129, 0.24134, 0.24139, 0.24144, 0.24149, 0.24154, 0.24159,
    0.24164, 0.24169, 0.24174, 0.24179, 0.24184, 0.24189, 0.24194,
    0.24199, 0.24205, 0.2421, 0.24215, 0.2422, 0.24225, 0.2423,
    0.24235, 0.2424, 0.24245, 0.2425, 0.24255, 0.2426, 0.24265,
    0.2427, 0.24275, 0.2428, 0.24285, 0.2429, 0.24295, 0.243,
    0.24305, 0.2431, 0.24315, 0.2432, 0.24325, 0.2433, 0.24335,
    0.2434, 0.24345, 0.2435, 0.24355, 0.2436, 0.24365, 0.2437,
    0.24375, 0.2438, 0.24385, 0.24389, 0.24394, 0.24399, 0.24404,
    0.24409, 0.24414, 0.24419, 0.24424, 0.24429, 0.24434, 0.24439,
    0.24444, 0.24449, 0.24454, 0.24459, 0.24464, 0.24469, 0.24473,
    0.24478, 0.24483, 0.24488, 0.24493, 0.24498, 0.24503, 0.24508,
    0.24513, 0.24518, 0.24523, 0.24527, 0.24532, 0.24537, 0.24542,
    0.24547, 0.24552, 0.24557, 0.24562, 0.24567, 0.24571, 0.24576,
    0.24581, 0.24586, 0.24591, 0.24596, 0.24601, 0.24605, 0.2461,
    0.24615, 0.2462, 0.24625, 0.2463, 0.24635, 0.24639, 0.24644,
    0.24649, 0.24654, 0.24659, 0.24664, 0.24668, 0.24673, 0.24678,
    0.24683, 0.24688, 0.24692, 0.24697, 0.24702, 0.24707, 0.24712,
    0.24716, 0.24721, 0.24726, 0.24731, 0.24736, 0.2474, 0.24745,
    0.2475, 0.24755, 0.2476, 0.24764, 0.24769, 0.24774, 0.24779,
    0.24783, 0.24788, 0.24793, 0.24798, 0.24802, 0.24807, 0.24812,
    0.24817, 0.24821, 0.24826, 0.24831, 0.24836, 0.2484, 0.24845,
    0.2485, 0.24854, 0.24859, 0.24864, 0.24869, 0.24873, 0.24878,
    0.24883, 0.24887, 0.24892, 0.24897, 0.24902, 0.24906, 0.24911,
    0.24916, 0.2492, 0.24925, 0.2493, 0.24934, 0.24939, 0.24944,
    0.24948, 0.24953, 0.24958, 0.24962, 0.24967, 0.24972, 0.24976,
    0.24981, 0.24986, 0.2499, 0.24995, 0.25, 0.25004, 0.25009,
    0.25014, 0.25018, 0.25023, 0.25027, 0.25032, 0.25037, 0.25041,
    0.25046, 0.25051, 0.25055, 0.2506, 0.25064, 0.25069, 0.25074,
    0.25078, 0.25083, 0.25087, 0.25092, 0.25096, 0.25101, 0.25106,
    0.2511, 0.25115, 0.25119, 0.25124, 0.25129, 0.25133, 0.25138,
    0.25142, 0.25147, 0.25151, 0.25156, 0.2516, 0.25165, 0.25169,
    0.25174, 0.25179, 0.25183, 0.25188, 0.25192, 0.25197, 0.25201,
    0.25206, 0.2521, 0.25215, 0.25219, 0.25224, 0.25228, 0.25233,
    0.25237, 0.25242, 0.25246, 0.25251, 0.25255, 0.2526, 0.25264,
    0.25269, 0.25273, 0.25278, 0.25282, 0.25287, 0.25291, 0.25296,
    0.253, 0.25304, 0.25309, 0.25313, 0.25318, 0.25322, 0.25327,
    0.25331, 0.25336, 0.2534, 0.25345, 0.25349, 0.25353, 0.25358,
    0.25362, 0.25367, 0.25371, 0.25375, 0.2538, 0.25384, 0.25389,
    0.25393, 0.25398, 0.25402, 0.25406, 0.25411, 0.25415, 0.2542,
    0.25424, 0.25428, 0.25433, 0.25437, 0.25441, 0.25446, 0.2545,
    0.25455, 0.25459, 0.25463, 0.25468, 0.25472, 0.25476, 0.25481,
    0.25485, 0.25489, 0.25494, 0.25498, 0.25502, 0.25507, 0.25511,
    0.25515, 0.2552, 0.25524, 0.25528, 0.25533, 0.25537, 0.25541,
    0.25546, 0.2555, 0.25554, 0.25559, 0.25563, 0.25567, 0.25571,
    0.25576, 0.2558, 0.25584, 0.25589, 0.25593, 0.25597, 0.25601,
    0.25606, 0.2561, 0.25614, 0.25619, 0.25623, 0.25627, 0.25631,
    0.25636, 0.2564, 0.25644, 0.25648, 0.25653, 0.25657, 0.25661,
    0.25665, 0.2567, 0.25674, 0.25678, 0.25682, 0.25686, 0.25691,
    0.25695, 0.25699, 0.25703, 0.25708, 0.25712, 0.25716, 0.2572,
    0.25724, 0.25729, 0.25733, 0.25737, 0.25741, 0.25745, 0.25749,
    0.25754, 0.25758, 0.25762, 0.25766, 0.2577, 0.25775, 0.25779,
    0.25783, 0.25787, 0.25791, 0.25795, 0.258, 0.25804, 0.25808,
    0.25812, 0.25816, 0.2582, 0.25824, 0.25829, 0.25833, 0.25837,
    0.25841, 0.25845, 0.25849, 0.25853, 0.25858, 0.25862, 0.25866,
    0.2587, 0.25874, 0.25878, 0.25882, 0.25886, 0.2589, 0.25895,
    0.25899, 0.25903, 0.25907, 0.25911, 0.25915, 0.25919, 0.25923,
    0.25927, 0.25931, 0.25935, 0.2594, 0.25944, 0.25948, 0.25952,
    0.25956, 0.2596, 0.25964, 0.25968, 0.25972, 0.25976, 0.2598,
    0.25984, 0.25988, 0.25992, 0.25996, 0.26, 0.26004, 0.26008,
    0.14602, 0.14693, 0.14676, 0.14647, 0.14611, 0.14571, 0.14528,
    0.14483, 0.14436, 0.14388, 0.14339, 0.1429, 0.14241, 0.14192,
    0.14142, 0.14093, 0.14044, 0.13996, 0.13948, 0.139, 0.13853,
    0.13807, 0.13761, 0.13715, 0.1367, 0.13626, 0.13582, 0.13539,
    0.13497, 0.13455, 0.13413, 0.13372, 0.13332, 0.13292, 0.13253,
    0.13215, 0.13177, 0.13139, 0.13102, 0.13066, 0.1303, 0.12994,
    0.1296, 0.12925, 0.12891, 0.12858, 0.12825, 0.12792, 0.1276,
    0.12729, 0.12698, 0.12667, 0.12637, 0.12607, 0.12577, 0.12548,
    0.1252, 0.12491, 0.12463, 0.12436, 0.12409, 0.12382, 0.12356,
    0.1233, 0.12304, 0.12279, 0.12254, 0.12229, 0.12205, 0.12181,
    0.12157, 0.12134, 0.12111, 0.12088, 0.12066, 0.12044, 0.12022,
    0.12001, 0.1198, 0.11959, 0.11939, 0.11918, 0.11899, 0.11879,
    0.1186, 0.11841, 0.11822, 0.11803, 0.11785, 0.11767, 0.1175,
    0.11732, 0.11715, 0.11698, 0.11682, 0.11666, 0.11649, 0.11634,
    0.11618, 0.11603, 0.11588, 0.11573, 0.11558, 0.11544, 0.1153,
    0.11516, 0.11502, 0.11489, 0.11476, 0.11463, 0.1145, 0.11438,
    0.11425, 0.11413, 0.11401, 0.1139, 0.11378, 0.11367, 0.11356,
    0.11345, 0.11334, 0.11324, 0.11313, 0.11303, 0.11293, 0.11283,
    0.11274, 0.11265, 0.11255, 0.11246, 0.11237, 0.11229, 0.1122,
    0.11212, 0.11204, 0.11196, 0.11188, 0.1118, 0.11172, 0.11165,
    0.11158, 0.1115, 0.11143, 0.11137, 0.1113, 0.11123, 0.11117,
    0.11111, 0.11104, 0.11098, 0.11092, 0.11087, 0.11081, 0.11075,
    0.1107, 0.11065, 0.11059, 0.11054, 0.11049, 0.11044, 0.1104,
    0.11035, 0.11031, 0.11026, 0.11022, 0.11018, 0.11013, 0.11009,
    0.11005, 0.11002, 0.10998, 0.10994, 0.10991, 0.10987, 0.10984,
    0.1098, 0.10977, 0.10974, 0.10971, 0.10968, 0.10965, 0.10962,
    0.10959, 0.10957, 0.10954, 0.10951, 0.10949, 0.10946, 0.10944,
    0.10942, 0.1094, 0.10937, 0.10935, 0.10933, 0.10931, 0.10929,
    0.10927, 0.10925, 0.10924, 0.10922, 0.1092, 0.10919, 0.10917,
    0.10915, 0.10914, 0.10913, 0.10911, 0.1091, 0.10908, 0.10907,
    0.10906, 0.10905, 0.10903, 0.10902, 0.10901, 0.109, 0.10899,
    0.10898, 0.10897, 0.10896, 0.10895, 0.10894, 0.10894, 0.10893,
    0.10892, 0.10891, 0.10891, 0.1089, 0.10889, 0.10889, 0.10888,
    0.10887, 0.10887, 0.10886, 0.10886, 0.10885, 0.10885, 0.10884,
    0.10884, 0.10884, 0.10883, 0.10883, 0.10882, 0.10882, 0.10882,
    0.10882, 0.10881, 0.10881, 0.10881, 0.10881, 0.10881, 0.1088,
    0.1088, 0.1088, 0.1088, 0.1088, 0.1088, 0.1088, 0.1088, 0.1088,
    0.1088, 0.1088, 0.1088, 0.1088, 0.1088, 0.1088, 0.1088, 0.1088,
    0.1088, 0.1088, 0.1088, 0.1088, 0.10881, 0.10881, 0.10881,
    0.10881, 0.10881, 0.10882, 0.10882, 0.10882, 0.10882, 0.10882,
    0.10883, 0.10883, 0.10883, 0.10884, 0.10884, 0.10884, 0.10884,
    0.10885, 0.10885, 0.10885, 0.10886, 0.10886, 0.10887, 0.10887,
    0.10887, 0.10888, 0.10888, 0.10888, 0.10889, 0.10889, 0.1089,
    0.1089, 0.1089, 0.10891, 0.10891, 0.10892, 0.10892, 0.10893,
    0.10893, 0.10894, 0.10894, 0.10894, 0.10895, 0.10895, 0.10896,
    0.10896, 0.10897, 0.10897, 0.10898, 0.10898, 0.10899, 0.10899,
    0.109, 0.10901, 0.10901, 0.10902, 0.10902, 0.10903, 0.10903,
    0.10904, 0.10904, 0.10905, 0.10905, 0.10906, 0.10907, 0.10907,
    0.10908, 0.10908, 0.10909, 0.1091, 0.1091, 0.10911, 0.10911,
    0.10912, 0.10913, 0.10913, 0.10914, 0.10915, 0.10915, 0.10916,
    0.10916, 0.10917, 0.10918, 0.10918, 0.10919, 0.1092, 0.1092,
    0.10921, 0.10922, 0.10922, 0.10923, 0.10924, 0.10925, 0.10925,
    0.10926, 0.10927, 0.10927, 0.10928, 0.10929, 0.1093, 0.1093,
    0.10931, 0.10932, 0.10933, 0.10933, 0.10934, 0.10935, 0.10936,
    0.10936, 0.10937, 0.10938, 0.10939, 0.10939, 0.1094, 0.10941,
    0.10942, 0.10943, 0.10943, 0.10944, 0.10945, 0.10946, 0.10947,
    0.10948, 0.10948, 0.10949, 0.1095, 0.10951, 0.10952, 0.10953,
    0.10954, 0.10954, 0.10955, 0.10956, 0.10957, 0.10958, 0.10959,
    0.1096, 0.10961, 0.10961, 0.10962, 0.10963, 0.10964, 0.10965,
    0.10966, 0.10967, 0.10968, 0.10969, 0.1097, 0.10971, 0.10971,
    0.10972, 0.10973, 0.10974, 0.10975, 0.10976, 0.10977, 0.10978,
    0.10979, 0.1098, 0.10981, 0.10982, 0.10983, 0.10984, 0.10985,
    0.10986, 0.10987, 0.10988, 0.10989, 0.1099, 0.10991, 0.10992,
    0.10993, 0.10994, 0.10995, 0.10996, 0.10997, 0.10998, 0.10999,
    0.11, 0.11001, 0.11002, 0.11003, 0.11005, 0.11006, 0.11007,
    0.11008, 0.11009, 0.1101, 0.11011, 0.11012, 0.11013, 0.11014,
    0.11015, 0.11016, 0.11017, 0.11019, 0.1102, 0.11021, 0.11022,
    0.11023, 0.11024, 0.11025, 0.11026, 0.11027, 0.11029, 0.1103,
    0.11031, 0.11032, 0.11033, 0.11034, 0.11035, 0.11037, 0.11038,
    0.11039, 0.1104, 0.11041, 0.11042, 0.11044, 0.11045, 0.11046,
    0.11047, 0.11048, 0.1105, 0.11051, 0.11052, 0.11053, 0.11054,
    0.11056, 0.11057, 0.11058, 0.11059, 0.1106, 0.11062, 0.11063,
    0.11064, 0.11065, 0.11067, 0.11068, 0.11069, 0.1107, 0.11072,
    0.11073, 0.11074, 0.11075, 0.11077, 0.11078, 0.11079, 0.11081,
    0.11082, 0.11083, 0.11084, 0.11086, 0.11087, 0.11088, 0.1109,
    0.11091, 0.11092, 0.11094, 0.11095, 0.11096, 0.11098, 0.11099,
    0.111, 0.11102, 0.11103, 0.11104, 0.11106, 0.11107, 0.11108,
    0.1111, 0.11111, 0.11113, 0.11114, 0.11115, 0.11117, 0.11118,
    0.1112, 0.11121, 0.11122, 0.11124, 0.11125, 0.11127, 0.11128,
    0.11129, 0.11131, 0.11132, 0.11134, 0.11135, 0.11137, 0.11138,
    0.11139, 0.11141, 0.11142, 0.11144, 0.11145, 0.11147, 0.11148,
    0.1115, 0.11151, 0.11153, 0.11154, 0.11156, 0.11157, 0.11159,
    0.1116, 0.11162, 0.11163, 0.11165, 0.11166, 0.11168, 0.11169,
    0.11171, 0.11172, 0.11174, 0.11175, 0.11177, 0.11178, 0.1118,
    0.11182, 0.11183, 0.11185, 0.11186, 0.11188, 0.11189, 0.11191,
    0.11192, 0.11194, 0.11196, 0.11197, 0.11199, 0.112, 0.11202,
    0.11204, 0.11205, 0.11207, 0.11208, 0.1121, 0.11212, 0.11213,
    0.11215, 0.11216, 0.11218, 0.1122, 0.11221, 0.11223, 0.11224,
    0.11226, 0.11228, 0.11229, 0.11231, 0.11233, 0.11234, 0.11236,
    0.11238, 0.11239, 0.11241, 0.11243, 0.11244, 0.11246, 0.11248,
    0.11249, 0.11251, 0.11253, 0.11254, 0.11256, 0.11258, 0.11259,
    0.11261, 0.11263, 0.11265, 0.11266, 0.11268, 0.1127, 0.11271,
    0.11273, 0.11275, 0.11276, 0.11278, 0.1128, 0.11282, 0.11283,
    0.11285, 0.11287, 0.11289, 0.1129, 0.11292, 0.11294, 0.11296,
    0.11297, 0.11299, 0.11301, 0.11303, 0.11304, 0.11306, 0.11308,
    0.1131, 0.11311, 0.11313, 0.11315, 0.11317, 0.11318, 0.1132,
    0.11322, 0.11324, 0.11326, 0.11327, 0.11329, 0.11331, 0.11333,
    0.11335, 0.11336, 0.11338, 0.1134, 0.11342, 0.11344, 0.11345,
    0.11347, 0.11349, 0.11351, 0.11353, 0.11354, 0.11356, 0.11358,
    0.1136, 0.11362, 0.11364, 0.11365, 0.11367, 0.11369, 0.11371,
    0.11373, 0.11375, 0.11376, 0.11378, 0.1138, 0.11382, 0.11384,
    0.11386, 0.11388, 0.11389, 0.11391, 0.11393, 0.11395, 0.11397,
    0.11399, 0.11401, 0.11403, 0.11404, 0.11406, 0.11408, 0.1141,
    0.11412, 0.11414, 0.11416, 0.11418, 0.1142, 0.11421, 0.11423,
    0.11425, 0.11427, 0.11429, 0.11431, 0.11433, 0.11435, 0.11437,
    0.11439, 0.1144, 0.11442, 0.11444, 0.11446, 0.11448, 0.1145,
    0.11452, 0.11454, 0.11456, 0.11458, 0.1146, 0.11462, 0.11464,
    0.11465, 0.11467, 0.11469, 0.11471, 0.11473, 0.11475, 0.11477,
    0.11479, 0.11481, 0.11483, 0.11485, 0.11487, 0.11489, 0.11491,
    0.11493, 0.11495, 0.11497, 0.11498, 0.115, 0.11502, 0.11504,
    0.11506, 0.11508, 0.1151, 0.11512, 0.11514, 0.11516, 0.11518,
    0.1152, 0.11522, 0.11524, 0.11526, 0.11528, 0.1153, 0.11532,
    0.11534, 0.11536, 0.11538, 0.1154, 0.11542, 0.11544, 0.11545,
    0.11547, 0.11549, 0.11551, 0.11553, 0.11555, 0.11557, 0.11559,
    0.11561, 0.11563, 0.11565, 0.11567, 0.11569, 0.11571, 0.11573,
    0.11575, 0.11577, 0.11579, 0.11581, 0.11583, 0.11585, 0.11587,
    0.11589, 0.11591, 0.11593, 0.11595, 0.11597, 0.11599, 0.11601,
    0.11602, 0.11604, 0.11606, 0.11608, 0.1161, 0.11612, 0.11614,
    0.11616, 0.11618, 0.1162, 0.11622, 0.11624, 0.11626, 0.11628,
    0.1163, 0.11632, 0.11634, 0.11636, 0.11638, 0.1164, 0.11642,
    0.11644, 0.11646, 0.11647, 0.11649, 0.11651, 0.11653, 0.11655,
    0.11657, 0.11659, 0.11661, 0.11663, 0.11665, 0.11667, 0.11669,
    0.11671, 0.11673, 0.11675, 0.11677, 0.11679, 0.11681, 0.11683,
    0.11684, 0.11686, 0.11688, 0.1169, 0.11692, 0.11694, 0.11696,
    0.11698, 0.117, 0.11702, 0.11704, 0.11706, 0.11708, 0.1171,
    0.11712, 0.11713, 0.11715, 0.11717, 0.11719, 0.11721, 0.11723,
    0.11725, 0.11727, 0.11729, 0.11731, 0.11733, 0.11735, 0.11737,
    0.11739, 0.1174, 0.11742, 0.11744, 0.11746, 0.11748, 0.1175,
    0.11752, 0.11754, 0.11756, 0.11758, 0.1176, 0.11762, 0.11763,
    0.11765, 0.11767, 0.11769, 0.11771, 0.11773, 0.11775, 0.11777,
    0.11779, 0.11781, 0.11783, 0.11785, 0.11786, 0.11788, 0.1179,
    0.11792, 0.11794, 0.11796, 0.11798, 0.118, 0.11802, 0.11804,
    0.11805, 0.11807, 0.11809, 0.11811, 0.11813, 0.11815, 0.11817,
    0.11819, 0.11821, 0.11823, 0.11825, 0.11826, 0.11828, 0.1183,
    0.11832, 0.11834, 0.11836, 0.11838, 0.1184, 0.11842, 0.11843,
    0.11845, 0.11847, 0.11849, 0.11851, 0.11853, 0.11855, 0.11857,
    0.11859, 0.1186, 0.11862, 0.11864, 0.11866, 0.11868, 0.1187,
    0.11872, 0.11874, 0.11876, 0.11877, 0.11879, 0.11881, 0.11883,
    0.11885, 0.11887, 0.11889, 0.11891, 0.11892, 0.11894, 0.11896,
    0.11898, 0.119, 0.11902, 0.11904, 0.11906, 0.11907, 0.11909,
    0.11911, 0.11913, 0.11915, 0.11917, 0.11919, 0.1192, 0.11922,
    0.11924, 0.11926, 0.11928, 0.1193, 0.11932, 0.11933, 0.11935,
    0.11937, 0.11939, 0.11941, 0.11943, 0.11945, 0.11946, 0.11948,
    0.1195, 0.11952, 0.11954, 0.11956, 0.11957, 0.11959, 0.11961,
    0.11963, 0.11965, 0.11967, 0.11968, 0.1197, 0.11972, 0.11974,
    0.11976, 0.11978, 0.11979, 0.11981, 0.11983, 0.11985, 0.11987,
    0.11988, 0.1199, 0.11992, 0.11994, 0.11996, 0.11998, 0.11999,
    0.12001, 0.12003, 0.12005, 0.12007, 0.12008, 0.1201, 0.12012,
    0.12014, 0.12016, 0.12017, 0.12019, 0.12021, 0.12023, 0.12025,
    0.12026, 0.12028, 0.1203, 0.12032, 0.12033, 0.12035, 0.12037,
    0.12039, 0.12041, 0.12042, 0.12044, 0.12046, 0.12048, 0.1205,
    0.12051, 0.12053, 0.12055, 0.12057, 0.12058, 0.1206, 0.12062,
    0.12064, 0.12065, 0.12067, 0.12069, 0.12071, 0.12073, 0.12074,
    0.12076, 0.12078, 0.1208, 0.12081, 0.12083, 0.12085, 0.12087,
    0.12088, 0.1209, 0.12092, 0.12094, 0.12095, 0.12097, 0.12099,
    0.12101, 0.12102, 0.12104, 0.12106, 0.12108, 0.12109, 0.12111,
    0.12113, 0.12115, 0.12116, 0.12118, 0.1212, 0.12121, 0.12123,
    0.12125, 0.12127, 0.12128, 0.1213, 0.12132, 0.12134, 0.12135,
    0.12137, 0.12139, 0.12141, 0.12142, 0.12144, 0.12146, 0.12147,
    0.12149, 0.12151, 0.12153, 0.12154, 0.12156, 0.12158, 0.12159,
    0.12161, 0.12163, 0.12165, 0.12166, 0.12168, 0.1217, 0.12171,
    0.12173, 0.12175, 0.12177, 0.12178, 0.1218, 0.12182, 0.12183,
    0.12185, 0.12187, 0.12189, 0.1219, 0.12192, 0.12194, 0.12195,
    0.12197, 0.12199, 0.122, 0.12202, 0.12204, 0.12206, 0.12207,
    0.12209, 0.12211, 0.12212, 0.12214, 0.12216, 0.12217, 0.12219,
    0.12221, 0.12222, 0.12224, 0.12226, 0.12228, 0.12229, 0.12231,
    0.12233, 0.12234, 0.12236, 0.12238, 0.12239, 0.12241, 0.12243,
    0.12244, 0.12246, 0.12248, 0.12249, 0.12251, 0.12253, 0.12254,
    0.12256, 0.12258, 0.12259, 0.12261, 0.12263, 0.12265, 0.12266,
    0.12268, 0.1227, 0.12271, 0.12273, 0.12275, 0.12276, 0.12278,
    0.1228, 0.12281, 0.12283, 0.12285, 0.12286, 0.12288, 0.1229,
    0.12291, 0.12293, 0.12295, 0.12296, 0.12298, 0.123, 0.12301,
    0.12303, 0.12305, 0.12306, 0.12308, 0.1231, 0.12311, 0.12313,
    0.12315, 0.12316, 0.12318, 0.1232, 0.12321, 0.12323, 0.12325,
    0.12326, 0.12328, 0.1233, 0.12331, 0.12333, 0.12335, 0.12336,
    0.12338, 0.1234, 0.12342, 0.12343, 0.12345, 0.12347, 0.12348,
    0.1235, 0.12352, 0.12353, 0.12355, 0.12357, 0.12358, 0.1236,
    0.12362, 0.12363, 0.12365, 0.12367, 0.12368, 0.1237, 0.12372,
    0.12373, 0.12375, 0.12377, 0.12379, 0.1238, 0.12382, 0.12384,
    0.12385, 0.12387, 0.12389, 0.1239, 0.12392, 0.12394, 0.12395,
    0.12397, 0.12399, 0.12401, 0.12402, 0.12404, 0.12406, 0.12407,
    0.12409, 0.12411, 0.12412, 0.12414, 0.12416, 0.12418, 0.12419,
    0.12421, 0.12423, 0.12424, 0.12426, 0.12428, 0.1243, 0.12431,
    0.12433, 0.12435, 0.12436, 0.12438, 0.1244, 0.12442, 0.12443,
    0.12445, 0.12447, 0.12448, 0.1245, 0.12452, 0.12454, 0.12455,
    0.12457, 0.12459, 0.12461, 0.12462, 0.12464, 0.12466, 0.12467,
    0.12469, 0.12471, 0.12473, 0.12474, 0.12476, 0.12478, 0.1248,
    0.12481, 0.12483, 0.12485, 0.12487, 0.12488, 0.1249, 0.12492,
    0.12494, 0.12495, 0.12497, 0.12499, 0.12501, 0.12502, 0.12504,
    0.12506, 0.12508, 0.1251, 0.12511, 0.12513, 0.12515, 0.12517,
    0.12518, 0.1252, 0.12522, 0.12524, 0.12526, 0.12527, 0.12529,
    0.12531, 0.12533, 0.12534, 0.12536, 0.12538, 0.1254, 0.12542,
    0.12543, 0.12545, 0.12547, 0.12549, 0.12551, 0.12552, 0.12554,
    0.12556, 0.12558, 0.1256, 0.12561, 0.12563, 0.12565, 0.12567,
    0.12569, 0.1257, 0.12572, 0.12574, 0.12576, 0.12578, 0.1258,
    0.12581, 0.12583, 0.12585, 0.12587, 0.12589, 0.12591, 0.12592,
    0.12594, 0.12596, 0.12598, 0.126, 0.12602, 0.12603, 0.12605,
    0.12607, 0.12609, 0.12611, 0.12613, 0.12615, 0.12616, 0.12618,
    0.1262, 0.12622, 0.12624, 0.12626, 0.12627, 0.12629, 0.12631,
    0.12633, 0.12635, 0.12637, 0.12639, 0.12641, 0.12642, 0.12644,
    0.12646, 0.12648, 0.1265, 0.12652, 0.12654, 0.12656, 0.12657,
    0.12659, 0.12661, 0.12663, 0.12665, 0.12667, 0.12669, 0.12671,
    0.12673, 0.12674, 0.12676, 0.12678, 0.1268, 0.12682, 0.12684,
    0.12686, 0.12688, 0.1269, 0.12692, 0.12693, 0.12695, 0.12697,
    0.12699, 0.12701, 0.12703, 0.12705, 0.12707, 0.12709, 0.12711,
    0.12713, 0.12715, 0.12717, 0.12718, 0.1272, 0.12722, 0.12724,
    0.12726, 0.12728, 0.1273, 0.12732, 0.12734, 0.12736, 0.12738,
    0.1274, 0.12742, 0.12744, 0.12746, 0.12747, 0.12749, 0.12751,
    0.12753, 0.12755, 0.12757, 0.12759, 0.12761, 0.12763, 0.12765,
    0.12767, 0.12769, 0.12771, 0.12773, 0.12775, 0.12777, 0.12779,
    0.12781, 0.12783, 0.12785, 0.12787, 0.12789, 0.12791, 0.12793,
    0.12795, 0.12797, 0.12799, 0.12801, 0.12803, 0.12804, 0.12806,
    0.12808, 0.1281, 0.12812, 0.12814, 0.12816, 0.12818, 0.1282,
    0.12822, 0.12824, 0.12826, 0.12828, 0.1283, 0.12832, 0.12834,
    0.12836, 0.12838, 0.1284, 0.12842, 0.12844, 0.12846, 0.12848,
    0.1285, 0.12852, 0.12854, 0.12856, 0.12858, 0.1286, 0.12863,
    0.12865, 0.12867, 0.12869, 0.12871, 0.12873, 0.12875, 0.12877,
    0.12879, 0.12881, 0.12883, 0.12885, 0.12887, 0.12889, 0.12891,
    0.12893, 0.12895, 0.12897, 0.12899, 0.12901, 0.12903, 0.12905,
    0.12907, 0.12909, 0.12911, 0.12913, 0.12915, 0.12917, 0.12919,
    0.12921, 0.12923, 0.12925, 0.12928, 0.1293, 0.12932, 0.12934,
    0.12936, 0.12938, 0.1294, 0.12942, 0.12944, 0.12946, 0.12948,
    0.1295, 0.12952, 0.12954, 0.12956, 0.12958, 0.1296, 0.12962,
    0.12965, 0.12967, 0.12969, 0.12971, 0.12973, 0.12975, 0.12977,
    0.12979, 0.12981, 0.12983, 0.12985, 0.12987, 0.12989, 0.12991,
    0.12993, 0.12996, 0.12998, 0.13, 0.13002, 0.13004, 0.13006,
    0.13008, 0.1301, 0.13012, 0.13014, 0.13016, 0.13018, 0.1302,
    0.13023, 0.13025, 0.13027, 0.13029, 0.13031, 0.13033, 0.13035,
    0.13037, 0.13039, 0.13041, 0.13043, 0.13045, 0.13047, 0.1305,
    0.13052, 0.13054, 0.13056, 0.13058, 0.1306, 0.13062, 0.13064,
    0.13066, 0.13068, 0.1307, 0.13073, 0.13075, 0.13077, 0.13079,
    0.13081, 0.13083, 0.13085, 0.13087, 0.13089, 0.13091, 0.13093,
    0.13096, 0.13098, 0.131, 0.13102, 0.13104, 0.13106, 0.13108,
    0.1311, 0.13112, 0.13114, 0.13117, 0.13119, 0.13121, 0.13123,
    0.13125, 0.13127, 0.13129, 0.13131, 0.13133, 0.13135, 0.13137,
    0.1314, 0.13142, 0.13144, 0.13146, 0.13148, 0.1315, 0.13152,
    0.13154, 0.13156, 0.13159, 0.13161, 0.13163, 0.13165, 0.13167,
    0.13169, 0.13171, 0.13173, 0.13175, 0.13177, 0.1318, 0.13182,
    0.13184, 0.13186, 0.13188, 0.1319, 0.13192, 0.13194, 0.13196,
    0.13199, 0.13201, 0.13203, 0.13205, 0.13207, 0.13209, 0.13211,
    0.13213, 0.13215, 0.13218, 0.1322, 0.13222, 0.13224, 0.13226,
    0.13228, 0.1323, 0.13232, 0.13234, 0.13237, 0.13239, 0.13241,
    0.13243, 0.13245, 0.13247, 0.13249, 0.13251, 0.13253, 0.13256,
    0.13258, 0.1326, 0.13262, 0.13264, 0.13266, 0.13268, 0.1327,
    0.13272, 0.13275, 0.13277, 0.13279, 0.13281, 0.13283, 0.13285,
    0.13287, 0.13289, 0.13291, 0.13294, 0.13296, 0.13298, 0.133,
    0.13302, 0.13304, 0.13306, 0.13308, 0.1331, 0.13313, 0.13315,
    0.13317, 0.13319, 0.13321, 0.13323, 0.13325, 0.13327, 0.13329,
    0.13332, 0.13334, 0.13336, 0.13338, 0.1334, 0.13342, 0.13344,
    0.13346, 0.13348, 0.13351, 0.13353, 0.13355, 0.13357, 0.13359,
    0.13361, 0.13363, 0.13365, 0.13367, 0.1337, 0.13372, 0.13374,
    0.13376, 0.13378, 0.1338, 0.13382, 0.13384, 0.13386, 0.13389,
    0.13391, 0.13393, 0.13395, 0.13397, 0.13399, 0.13401, 0.13403,
    0.13405, 0.13408, 0.1341, 0.13412, 0.13414, 0.13416, 0.13418,
    0.1342, 0.13422, 0.13424, 0.13426, 0.13429, 0.13431, 0.13433,
    0.13435, 0.13437, 0.13439, 0.13441, 0.13443, 0.13445, 0.13448,
    0.1345, 0.13452, 0.13454, 0.13456, 0.13458, 0.1346, 0.13462,
    0.13464, 0.13466, 0.13469, 0.13471, 0.13473, 0.13475, 0.13477,
    0.13479, 0.13481, 0.13483, 0.13485, 0.13487, 0.1349, 0.13492,
    0.13494, 0.13496, 0.13498, 0.135, 0.13502, 0.13504, 0.13506,
    0.13508, 0.13511, 0.13513, 0.13515, 0.13517, 0.13519, 0.13521,
    0.13523, 0.13525, 0.13527, 0.13529, 0.13531, 0.13534, 0.13536,
    0.13538, 0.1354, 0.13542, 0.13544, 0.13546, 0.13548, 0.1355,
    0.13552, 0.13554, 0.13557, 0.13559, 0.13561, 0.13563, 0.13565,
    0.13567, 0.13569, 0.13571, 0.13573, 0.13575, 0.13577, 0.1358,
    0.12988, 0.13028, 0.13067, 0.13105, 0.13142, 0.13178, 0.13213,
    0.13246, 0.13279, 0.13311, 0.13342, 0.13372, 0.13402, 0.13432,
    0.13462, 0.13493, 0.13523, 0.13554, 0.13586, 0.13618, 0.13652,
    0.13686, 0.13722, 0.13759, 0.13797, 0.13838, 0.1388, 0.13923,
    0.13969, 0.14016, 0.14065, 0.14117, 0.1417, 0.14226, 0.14284,
    0.14344, 0.14407, 0.14472, 0.14539, 0.14608, 0.14679, 0.14752,
    0.14828, 0.14905, 0.14984, 0.15066, 0.15149, 0.15233, 0.15319,
    0.15406, 0.15493, 0.15581, 0.1567, 0.1576, 0.1585, 0.1594,
    0.16031, 0.16122, 0.16213, 0.16305, 0.16305, 0.14171, 0.14578,
    0.14637, 0.14657, 0.14658, 0.14646, 0.14626, 0.146, 0.14569,
    0.14534, 0.14498, 0.14459, 0.1442, 0.1438, 0.14339, 0.14299,
    0.14258, 0.14218, 0.14177, 0.14138, 0.14098, 0.1406, 0.14021,
    0.13984, 0.13947, 0.1391, 0.13875, 0.1384, 0.13805, 0.13771,
    0.13738, 0.13706, 0.13674, 0.13643, 0.13613, 0.13583, 0.13554,
    0.13526, 0.13498, 0.1347, 0.13444, 0.13418, 0.13392, 0.13367,
    0.13342, 0.13318, 0.13295, 0.13272, 0.1325, 0.13228, 0.13206,
    0.13185, 0.13165, 0.13145, 0.13125, 0.13106, 0.13087, 0.13068,
    0.1305, 0.13033, 0.13015, 0.12998, 0.12982, 0.12966, 0.1295,
    0.12934, 0.12919, 0.12904, 0.12889, 0.12875, 0.12861, 0.12847,
    0.12834, 0.12821, 0.12808, 0.12795, 0.12783, 0.1277, 0.12758,
    0.12747, 0.12735, 0.12724, 0.12713, 0.12702, 0.12691, 0.12681,
    0.12671, 0.1266, 0.12651, 0.12641, 0.12631, 0.12622, 0.12613,
    0.12604, 0.12595, 0.12586, 0.12577, 0.12569, 0.12561, 0.12553,
    0.12545, 0.12537, 0.12529, 0.12522, 0.12514, 0.12507, 0.125,
    0.12493, 0.12486, 0.12479, 0.12472, 0.12466, 0.12459, 0.12453,
    0.12447, 0.12441, 0.12435, 0.12429, 0.12423, 0.12417, 0.12412,
    0.12406, 0.12401, 0.12395, 0.1239, 0.12385, 0.1238, 0.12375,
    0.1237, 0.12365, 0.1236, 0.12355, 0.12351, 0.12346, 0.12342,
    0.12337, 0.12333, 0.12329, 0.12325, 0.12321, 0.12317, 0.12313,
    0.12309, 0.12305, 0.12301, 0.12298, 0.12294, 0.12291, 0.12287,
    0.12284, 0.12281, 0.12277, 0.12274, 0.12271, 0.12268, 0.12265,
    0.12262, 0.12259, 0.12256, 0.12254, 0.12251, 0.12248, 0.12246,
    0.12243, 0.12241, 0.12238, 0.12236, 0.12234, 0.12231, 0.12229,
    0.12227, 0.12225, 0.12223, 0.12221, 0.12219, 0.12217, 0.12215,
    0.12214, 0.12212, 0.1221, 0.12208, 0.12207, 0.12205, 0.12204,
    0.12202, 0.12201, 0.122, 0.12198, 0.12197, 0.12196, 0.12195,
    0.12194, 0.12192, 0.12191, 0.1219, 0.12189, 0.12188, 0.12188,
    0.12187, 0.12186, 0.12185, 0.12184, 0.12184, 0.12183, 0.12182,
    0.12182, 0.12181, 0.12181, 0.1218, 0.1218, 0.12179, 0.12179,
    0.12179, 0.12178, 0.12178, 0.12178, 0.12177, 0.12177, 0.12177,
    0.12177, 0.12177, 0.12177, 0.12177, 0.12176, 0.12176, 0.12176,
    0.12176, 0.12177, 0.12177, 0.12177, 0.12177, 0.12177, 0.12177,
    0.12177, 0.12178, 0.12178, 0.12178, 0.12178, 0.12179, 0.12179,
    0.12179, 0.1218, 0.1218, 0.1218, 0.12181, 0.12181, 0.12182,
    0.12182, 0.12182, 0.12183, 0.12183, 0.12184, 0.12185, 0.12185,
    0.12186, 0.12186, 0.12187, 0.12187, 0.12188, 0.12189, 0.12189,
    0.1219, 0.1219, 0.12191, 0.12192, 0.12192, 0.12193, 0.12194,
    0.12194, 0.12195, 0.12196, 0.12197, 0.12197, 0.12198, 0.12199,
    0.12199, 0.122, 0.12201, 0.12202, 0.12202, 0.12203, 0.12204,
    0.12205, 0.12206, 0.12206, 0.12207, 0.12208, 0.12209, 0.12209,
    0.1221, 0.12211, 0.12212, 0.12213, 0.12213, 0.12214, 0.12215,
    0.12216, 0.12217, 0.12218, 0.12218, 0.12219, 0.1222, 0.12221,
    0.12222, 0.12222, 0.12223, 0.12224, 0.12225, 0.12226, 0.12227,
    0.12227, 0.12228, 0.12229, 0.1223, 0.12231, 0.12231, 0.12232,
    0.12233, 0.12234, 0.12235, 0.12235, 0.12236, 0.12237, 0.12238,
    0.12239, 0.12239, 0.1224, 0.12241, 0.12242, 0.12243, 0.12243,
    0.12244, 0.12245, 0.12246, 0.12246, 0.12247, 0.12248, 0.12249,
    0.12249, 0.1225, 0.12251, 0.12252, 0.12252, 0.12253, 0.12254,
    0.12254, 0.12255, 0.12256, 0.12256, 0.12257, 0.12258, 0.12259,
    0.12259, 0.1226, 0.12261, 0.12261, 0.12262, 0.12262, 0.12263,
    0.12264, 0.12264, 0.12265, 0.12266, 0.12266, 0.12267, 0.12267,
    0.12268, 0.12269, 0.12269, 0.1227, 0.1227, 0.12271, 0.12272,
    0.12272, 0.12273, 0.12273, 0.12274, 0.12274, 0.12275, 0.12275,
    0.12276, 0.12276, 0.12277, 0.12277, 0.12278, 0.12278, 0.12279,
    0.12279, 0.1228, 0.1228, 0.12281, 0.12281, 0.12282, 0.12282,
    0.12282, 0.12283, 0.12283, 0.12284, 0.12284, 0.12285, 0.12285,
    0.12285, 0.12286, 0.12286, 0.12287, 0.12287, 0.12287, 0.12288,
    0.12288, 0.12288, 0.12289, 0.12289, 0.12289, 0.1229, 0.1229,
    0.1229, 0.12291, 0.12291, 0.12291, 0.12292, 0.12292, 0.12292,
    0.12292, 0.12293, 0.12293, 0.12293, 0.12294, 0.12294, 0.12294,
    0.12294, 0.12295, 0.12295, 0.12295, 0.12295, 0.12295, 0.12296,
    0.12296, 0.12296, 0.12296, 0.12296, 0.12297, 0.12297, 0.12297,
    0.12297, 0.12297, 0.12298, 0.12298, 0.12298, 0.12298, 0.12298,
    0.12298, 0.12299, 0.12299, 0.12299, 0.12299, 0.12299, 0.12299,
    0.12299, 0.123, 0.123, 0.123, 0.123, 0.123, 0.123, 0.123,
    0.123, 0.12301, 0.12301, 0.12301, 0.12301, 0.12301, 0.12301,
    0.12301, 0.12301, 0.12301, 0.12302, 0.12302, 0.12302, 0.12302,
    0.12302, 0.12302, 0.12302, 0.12302, 0.12302, 0.12302, 0.12303,
    0.12303, 0.12303, 0.12303, 0.12303, 0.12303, 0.12303, 0.12303,
    0.12303, 0.12303, 0.12303, 0.12304, 0.12304, 0.12304, 0.12304,
    0.12304, 0.12304, 0.12304, 0.12304, 0.12304, 0.12304, 0.12304,
    0.12305, 0.12305, 0.12305, 0.12305, 0.12305, 0.12305, 0.12305,
    0.12305, 0.12305, 0.12305, 0.12305, 0.12306, 0.12306, 0.12306,
    0.12306, 0.12306, 0.12306, 0.12306, 0.12306, 0.12306, 0.12307,
    0.12307, 0.12307, 0.12307, 0.12307, 0.12307, 0.12307, 0.12307,
    0.12308, 0.12308, 0.12308, 0.12308, 0.12308, 0.12308, 0.12308,
    0.12309, 0.12309, 0.12309, 0.12309, 0.12309, 0.12309, 0.12309,
    0.1231, 0.1231, 0.1231, 0.1231, 0.1231, 0.1231, 0.12311,
    0.12311, 0.12311, 0.12311, 0.12311, 0.12311, 0.12312, 0.12312,
    0.12312, 0.12312, 0.12312, 0.12313, 0.12313, 0.12313, 0.12313,
    0.12313, 0.12314, 0.12314, 0.12314, 0.12314, 0.12314, 0.12315,
    0.12315, 0.12315, 0.12315, 0.12316, 0.12316, 0.12316, 0.12316,
    0.12316, 0.12317, 0.12317, 0.12317, 0.12317, 0.12318, 0.12318,
    0.12318, 0.12319, 0.12319, 0.12319, 0.12319, 0.1232, 0.1232,
    0.1232, 0.1232, 0.12321, 0.12321, 0.12321, 0.12322, 0.12322,
    0.12322, 0.12323, 0.12323, 0.12323, 0.12324, 0.12324, 0.12324,
    0.12325, 0.12325, 0.12325, 0.12326, 0.12326, 0.12326, 0.12327,
    0.12327, 0.12327, 0.12328, 0.12328, 0.12328, 0.12329, 0.12329,
    0.1233, 0.1233, 0.1233, 0.12331, 0.12331, 0.12332, 0.12332,
    0.12332, 0.12333, 0.12333, 0.12334, 0.12334, 0.12335, 0.12335,
    0.12336, 0.12336, 0.12336, 0.12337, 0.12337, 0.12338, 0.12338,
    0.12339, 0.12339, 0.1234, 0.1234, 0.12341, 0.12341, 0.12342,
    0.12342, 0.12343, 0.12343, 0.12344, 0.12344, 0.12345, 0.12345,
    0.12346, 0.12346, 0.12347, 0.12347, 0.12348, 0.12348, 0.12349,
    0.1235, 0.1235, 0.12351, 0.12351, 0.12352, 0.12352, 0.12353,
    0.12353, 0.12354, 0.12355, 0.12355, 0.12356, 0.12356, 0.12357,
    0.12358, 0.12358, 0.12359, 0.12359, 0.1236, 0.12361, 0.12361,
    0.12362, 0.12362, 0.12363, 0.12364, 0.12364, 0.12365, 0.12366,
    0.12366, 0.12367, 0.12367, 0.12368, 0.12369, 0.12369, 0.1237,
    0.12371, 0.12371, 0.12372, 0.12373, 0.12373, 0.12374, 0.12375,
    0.12375, 0.12376, 0.12377, 0.12377, 0.12378, 0.12379, 0.12379,
    0.1238, 0.12381, 0.12382, 0.12382, 0.12383, 0.12384, 0.12384,
    0.12385, 0.12386, 0.12387, 0.12387, 0.12388, 0.12389, 0.12389,
    0.1239, 0.12391, 0.12392, 0.12392, 0.12393, 0.12394, 0.12395,
    0.12395, 0.12396, 0.12397, 0.12398, 0.12399, 0.12399, 0.124,
    0.12401, 0.12402, 0.12402, 0.12403, 0.12404, 0.12405, 0.12406,
    0.12406, 0.12407, 0.12408, 0.12409, 0.1241, 0.1241, 0.12411,
    0.12412, 0.12413, 0.12414, 0.12415, 0.12415, 0.12416, 0.12417,
    0.12418, 0.12419, 0.1242, 0.12421, 0.12421, 0.12422, 0.12423,
    0.12424, 0.12425, 0.12426, 0.12427, 0.12428, 0.12429, 0.12429,
    0.1243, 0.12431, 0.12432, 0.12433, 0.12434, 0.12435, 0.12436,
    0.12437, 0.12438, 0.12439, 0.1244, 0.12441, 0.12441, 0.12442,
    0.12443, 0.12444, 0.12445, 0.12446, 0.12447, 0.12448, 0.12449,
    0.1245, 0.12451, 0.12452, 0.12453, 0.12454, 0.12455, 0.12456,
    0.12457, 0.12458, 0.12459, 0.1246, 0.12461, 0.12462, 0.12463,
    0.12465, 0.12466, 0.12467, 0.12468, 0.12469, 0.1247, 0.12471,
    0.12472, 0.12473, 0.12474, 0.12475, 0.12476, 0.12477, 0.12479,
    0.1248, 0.12481, 0.12482, 0.12483, 0.12484, 0.12485, 0.12486,
    0.12487, 0.12489, 0.1249, 0.12491, 0.12492, 0.12493, 0.12494,
    0.12495, 0.12497, 0.12498, 0.12499, 0.125, 0.12501, 0.12503,
    0.12504, 0.12505, 0.12506, 0.12507, 0.12509, 0.1251, 0.12511,
    0.12512, 0.12513, 0.12515, 0.12516, 0.12517, 0.12518, 0.1252,
    0.12521, 0.12522, 0.12523, 0.12525, 0.12526, 0.12527, 0.12528,
    0.1253, 0.12531, 0.12532, 0.12533, 0.12535, 0.12536, 0.12537,
    0.12539, 0.1254, 0.12541, 0.12543, 0.12544, 0.12545, 0.12547,
    0.12548, 0.12549, 0.12551, 0.12552, 0.12553, 0.12555, 0.12556,
    0.12557, 0.12559, 0.1256, 0.12561, 0.12563, 0.12564, 0.12566,
    0.12567, 0.12568, 0.1257, 0.12571, 0.12573, 0.12574, 0.12575,
    0.12577, 0.12578, 0.1258, 0.12581, 0.12583, 0.12584, 0.12585,
    0.12587, 0.12588, 0.1259, 0.12591, 0.12593, 0.12594, 0.12596,
    0.12597, 0.12599, 0.126, 0.12602, 0.12603, 0.12605, 0.12606,
    0.12608, 0.12609, 0.12611, 0.12612, 0.12614, 0.12615, 0.12617,
    0.12618, 0.1262, 0.12621, 0.12623, 0.12625, 0.12626, 0.12628,
    0.12629, 0.12631, 0.12632, 0.12634, 0.12636, 0.12637, 0.12639,
    0.1264, 0.12642, 0.12644, 0.12645, 0.12647, 0.12648, 0.1265,
    0.12652, 0.12653, 0.12655, 0.12656, 0.12658, 0.1266, 0.12661,
    0.12663, 0.12665, 0.12666, 0.12668, 0.1267, 0.12671, 0.12673,
    0.12675, 0.12676, 0.12678, 0.1268, 0.12681, 0.12683, 0.12685,
    0.12687, 0.12688, 0.1269, 0.12692, 0.12693, 0.12695, 0.12697,
    0.12699, 0.127, 0.12702, 0.12704, 0.12706, 0.12707, 0.12709,
    0.12711, 0.12713, 0.12714, 0.12716, 0.12718, 0.1272, 0.12721,
    0.12723, 0.12725, 0.12727, 0.12729, 0.1273, 0.12732, 0.12734,
    0.12736, 0.12738, 0.12739, 0.12741, 0.12743, 0.12745, 0.12747,
    0.12749, 0.1275, 0.12752, 0.12754, 0.12756, 0.12758, 0.1276,
    0.12762, 0.12763, 0.12765, 0.12767, 0.12769, 0.12771, 0.12773,
    0.12775, 0.12777, 0.12779, 0.12781, 0.12782, 0.12784, 0.12786,
    0.12788, 0.1279, 0.12792, 0.12794, 0.12796, 0.12798, 0.128,
    0.12802, 0.12804, 0.12806, 0.12808, 0.1281, 0.12812, 0.12814,
    0.12816, 0.12818, 0.12819, 0.12821, 0.12823, 0.12825, 0.12827,
    0.12829, 0.12832, 0.12834, 0.12836, 0.12838, 0.1284, 0.12842,
    0.12844, 0.12846, 0.12848, 0.1285, 0.12852, 0.12854, 0.12856,
    0.12858, 0.1286, 0.12862, 0.12864, 0.12866, 0.12868, 0.12871,
    0.12873, 0.12875, 0.12877, 0.12879, 0.12881, 0.12883, 0.12885,
    0.12887, 0.1289, 0.12892, 0.12894, 0.12896, 0.12898, 0.129,
    0.12902, 0.12905, 0.12907, 0.12909, 0.12911, 0.12913, 0.12915,
    0.12918, 0.1292, 0.12922, 0.12924, 0.12926, 0.12929, 0.12931,
    0.12933, 0.12935, 0.12937, 0.1294, 0.12942, 0.12944, 0.12946,
    0.12948, 0.12951, 0.12953, 0.12955, 0.12957, 0.1296, 0.12962,
    0.12964, 0.12967, 0.12969, 0.12971, 0.12973, 0.12976, 0.12978,
    0.1298, 0.12982, 0.12985, 0.12987, 0.12989, 0.12992, 0.12994,
    0.12996, 0.12999, 0.13001, 0.13003, 0.13006, 0.13008, 0.1301,
    0.13013, 0.13015, 0.13017, 0.1302, 0.13022, 0.13024, 0.13027,
    0.13029, 0.13032, 0.13034, 0.13036, 0.13039, 0.13041, 0.13043,
    0.13046, 0.13048, 0.13051, 0.13053, 0.13055, 0.13058, 0.1306,
    0.13063, 0.13065, 0.13068, 0.1307, 0.13072, 0.13075, 0.13077,
    0.1308, 0.13082, 0.13085, 0.13087, 0.1309, 0.13092, 0.13095,
    0.13097, 0.13099, 0.13102, 0.13104, 0.13107, 0.13109, 0.13112,
    0.13114, 0.13117, 0.13119, 0.13122, 0.13124, 0.13127, 0.13129,
    0.13132, 0.13134, 0.13137, 0.1314, 0.13142, 0.13145, 0.13147,
    0.1315, 0.13152, 0.13155, 0.13157, 0.1316, 0.13162, 0.13165,
    0.13167, 0.1317, 0.13173, 0.13175, 0.13178, 0.1318, 0.13183,
    0.13185, 0.13188, 0.13191, 0.13193, 0.13196, 0.13198, 0.13201,
    0.13204, 0.13206, 0.13209, 0.13211, 0.13214, 0.13217, 0.13219,
    0.13222, 0.13225, 0.13227, 0.1323, 0.13232, 0.13235, 0.13238,
    0.1324, 0.13243, 0.13246, 0.13248, 0.13251, 0.13254, 0.13256,
    0.13259, 0.13262, 0.13264, 0.13267, 0.13269, 0.13272, 0.13275,
    0.13278, 0.1328, 0.13283, 0.13286, 0.13288, 0.13291, 0.13294,
    0.13296, 0.13299, 0.13302, 0.13304, 0.13307, 0.1331, 0.13312,
    0.13315, 0.13318, 0.13321, 0.13323, 0.13326, 0.13329, 0.13331,
    0.13334, 0.13337, 0.13339, 0.13342, 0.13345, 0.13348, 0.1335,
    0.13353, 0.13356, 0.13359, 0.13361, 0.13364, 0.13367, 0.13369,
    0.13372, 0.13375, 0.13378, 0.1338, 0.13383, 0.13386, 0.13389,
    0.13391, 0.13394, 0.13397, 0.134, 0.13402, 0.13405, 0.13408,
    0.13411, 0.13413, 0.13416, 0.13419, 0.13422, 0.13425, 0.13427,
    0.1343, 0.13433, 0.13436, 0.13438, 0.13441, 0.13444, 0.13447,
    0.13449, 0.13452, 0.13455, 0.13458, 0.13461, 0.13463, 0.13466,
    0.13469, 0.13472, 0.13474, 0.13477, 0.1348, 0.13483, 0.13486,
    0.13488, 0.13491, 0.13494, 0.13497, 0.135, 0.13502, 0.13505,
    0.13508, 0.13511, 0.13514, 0.13516, 0.13519, 0.13522, 0.13525,
    0.13527, 0.1353, 0.13533, 0.13536, 0.13539, 0.13541, 0.13544,
    0.13547, 0.1355, 0.13553, 0.13555, 0.13558, 0.13561, 0.13564,
    0.13567, 0.13569, 0.13572, 0.13575, 0.13578, 0.13581, 0.13584,
    0.13586, 0.13589, 0.13592, 0.13595, 0.13598, 0.136, 0.13603,
    0.13606, 0.13609, 0.13612, 0.13614, 0.13617, 0.1362, 0.13623,
    0.13626, 0.13628, 0.13631, 0.13634, 0.13637, 0.1364, 0.13642,
    0.13645, 0.13648, 0.13651, 0.13654, 0.13656, 0.13659, 0.13662,
    0.13665, 0.13668, 0.1367, 0.13673, 0.13676, 0.13679, 0.13682,
    0.13684, 0.13687, 0.1369, 0.13693, 0.13696, 0.13698, 0.13701,
    0.13704, 0.13707, 0.1371, 0.13712, 0.13715, 0.13718, 0.13721,
    0.13724, 0.13726, 0.13729, 0.13732, 0.13735, 0.13737, 0.1374,
    0.13743, 0.13746, 0.13749, 0.13751, 0.13754, 0.13757, 0.1376,
    0.13763, 0.13765, 0.13768, 0.13771, 0.13774, 0.13776, 0.13779,
    0.13782, 0.13785, 0.13788, 0.1379, 0.13793, 0.13796, 0.13799,
    0.13801, 0.13804, 0.13807, 0.1381, 0.13813, 0.13815, 0.13818,
    0.13821, 0.13824, 0.13826, 0.13829, 0.13832, 0.13835, 0.13838,
    0.1384, 0.13843, 0.13846, 0.13849, 0.13851, 0.13854, 0.13857,
    0.1386, 0.13862, 0.13865, 0.13868, 0.13871, 0.13873, 0.13876,
    0.13879, 0.13882, 0.13884, 0.13887, 0.1389, 0.13893, 0.13895,
    0.13898, 0.13901, 0.13904, 0.13907, 0.13909, 0.13912, 0.13915,
    0.13918, 0.1392, 0.13923, 0.13926, 0.13928, 0.13931, 0.13934,
    0.13937, 0.13939, 0.13942, 0.13945, 0.13948, 0.1395, 0.13953,
    0.13956, 0.13959, 0.13961, 0.13964, 0.13967, 0.1397, 0.13972,
    0.13975, 0.13978, 0.1398, 0.13983, 0.13986, 0.13989, 0.13991,
    0.13994, 0.13997, 0.14, 0.14002, 0.14005, 0.14008, 0.1401,
    0.14013, 0.14016, 0.14019, 0.14021, 0.14024, 0.14027, 0.14029,
    0.14032, 0.14035, 0.14038, 0.1404, 0.14043, 0.14046, 0.14048,
    0.14051, 0.14054, 0.14056, 0.14059, 0.14062, 0.14065, 0.14067,
    0.1407, 0.14073, 0.14075, 0.14078, 0.14081, 0.14083, 0.14086,
    0.14089, 0.14091, 0.14094, 0.14097, 0.141, 0.14102, 0.14105,
    0.14108, 0.1411, 0.14113, 0.14116, 0.14118, 0.14121, 0.14124,
    0.14126, 0.14129, 0.14132, 0.14134, 0.14137, 0.1414, 0.14142,
    0.14145, 0.14148, 0.1415, 0.14153, 0.14156, 0.14158, 0.14161,
    0.14164, 0.14166, 0.14169, 0.14172, 0.14174, 0.14177, 0.14179,
    0.14182, 0.14185, 0.14187, 0.1419, 0.14193, 0.14195, 0.14198,
    0.14201, 0.14203, 0.14206, 0.14209, 0.14211, 0.14214, 0.14216,
    0.14219, 0.14222, 0.14224, 0.14227, 0.1423, 0.14232, 0.14235,
    0.14237, 0.1424, 0.14243, 0.14245, 0.14248, 0.14251, 0.14253,
    0.14256, 0.14258, 0.14261, 0.14264, 0.14266, 0.14269, 0.14271,
    0.14274, 0.14277, 0.14279, 0.14282, 0.14284, 0.14287, 0.1429,
    0.14292, 0.14295, 0.14297, 0.143, 0.14303, 0.14305, 0.14308,
    0.1431, 0.14313, 0.14315, 0.14318, 0.14321, 0.14323, 0.14326,
    0.14328, 0.14331, 0.14334, 0.14336, 0.14339, 0.14341, 0.14344,
    0.14346, 0.14349, 0.14352, 0.14354, 0.14357, 0.14359, 0.14362,
    0.14364, 0.14367, 0.14369, 0.14372, 0.14375, 0.14377, 0.1438,
    0.14382, 0.14385, 0.14387, 0.1439, 0.14392, 0.14395, 0.14398,
    0.144, 0.14403, 0.14405, 0.14408, 0.1441, 0.14413, 0.14415,
    0.14418, 0.1442, 0.14423, 0.14426, 0.14428, 0.14431, 0.14433,
    0.14436, 0.14438, 0.14441, 0.14443, 0.14446, 0.14448, 0.14451,
    0.14453, 0.14456, 0.14458, 0.14461, 0.14463, 0.14466, 0.14468,
    0.14471, 0.14473, 0.14476, 0.14479, 0.14481, 0.14484, 0.14486,
    0.14489, 0.14491, 0.14494, 0.14496, 0.14499, 0.14501, 0.14504,
    0.14506, 0.14509, 0.14511, 0.14514, 0.14516, 0.14519, 0.14521,
    0.14524, 0.14526, 0.14529, 0.14531, 0.14534, 0.14536, 0.14539,
    0.14541, 0.14544, 0.14546, 0.14549, 0.14551, 0.14553, 0.14556,
    0.14558, 0.14561, 0.14563, 0.14566, 0.14568, 0.14571, 0.14573,
    0.14576, 0.14578, 0.14581, 0.14583, 0.14586, 0.14588, 0.14591,
    0.14593, 0.14596, 0.14598, 0.146, 0.14603, 0.14605, 0.14608,
    0.1461, 0.14613, 0.14615, 0.14618, 0.1462, 0.14623, 0.14625,
    0.14628, 0.1463, 0.14632, 0.14635, 0.14637, 0.1464, 0.14642,
    0.14645, 0.14647, 0.1465, 0.14652, 0.14654, 0.14657, 0.14659,
    0.14662, 0.14664, 0.14667, 0.14669, 0.14672, 0.14674, 0.14676,
    0.14679, 0.14681, 0.14684, 0.14686, 0.14689, 0.14691, 0.14693,
    0.14696, 0.14698, 0.14701, 0.14703, 0.14706, 0.14708, 0.1471,
    0.14713, 0.14715, 0.14718, 0.1472, 0.14722, 0.14725, 0.14727,
    0.1473, 0.14732, 0.14735, 0.14737, 0.14739, 0.14742, 0.14744,
    0.14747, 0.14749, 0.14751, 0.14754, 0.14756, 0.14759, 0.14761,
    0.14763, 0.14766, 0.14768, 0.14771, 0.14773, 0.14775, 0.14778,
    0.1478, 0.14783, 0.14785, 0.14787, 0.1479, 0.14792, 0.14794,
    0.14797, 0.14799, 0.14802, 0.14804, 0.14806, 0.14809, 0.14811,
    0.14814, 0.14816, 0.14818, 0.14821, 0.14823, 0.14825, 0.14828,
    0.1483, 0.14833, 0.14835, 0.14837, 0.1484, 0.14842, 0.14844,
    0.14847, 0.14849, 0.14852, 0.14854, 0.14856, 0.14859, 0.14861,
    0.14863, 0.14866, 0.14868, 0.14871, 0.14873, 0.14875, 0.14878,
    0.1488, 0.14882, 0.14885, 0.14887, 0.14889, 0.14892, 0.14295,
    0.1435, 0.14404, 0.14459, 0.14514, 0.14569, 0.14624, 0.14679,
    0.14735, 0.1479, 0.14845, 0.149, 0.14955, 0.1501, 0.15065,
    0.1512, 0.15175, 0.1523, 0.15284, 0.15339, 0.15393, 0.15448,
    0.15502, 0.15556, 0.1561, 0.15663, 0.15717, 0.1577, 0.15823,
    0.15876, 0.15928, 0.1598, 0.16032, 0.16084, 0.16135, 0.16186,
    0.16237, 0.16287, 0.16337, 0.16386, 0.16435, 0.16483, 0.16532,
    0.16579, 0.16626, 0.16673, 0.16719, 0.16764, 0.16809, 0.16854,
    0.16897, 0.16941, 0.16983, 0.17025, 0.17066, 0.17107, 0.17146,
    0.17186, 0.17224, 0.17262, 0.17262, 0.09182, 0.09176, 0.0917,
    0.09164, 0.09159, 0.09153, 0.09147, 0.09141, 0.09135, 0.09129,
    0.09124, 0.09118, 0.09112, 0.09106, 0.091, 0.09094, 0.09088,
    0.09083, 0.09077, 0.09071, 0.09065, 0.09059, 0.09053, 0.09047,
    0.09042, 0.09036, 0.0903, 0.09024, 0.09018, 0.09012, 0.09007,
    0.09001, 0.08995, 0.08989, 0.08983, 0.08977, 0.08972, 0.08966,
    0.0896, 0.08954, 0.08948, 0.08943, 0.08937, 0.08931, 0.08925,
    0.08919, 0.08913, 0.08908, 0.08902, 0.08896, 0.0889, 0.08884,
    0.08878, 0.08872, 0.08867, 0.08861, 0.08855, 0.08849, 0.08843,
    0.08837, 0.08831, 0.08825, 0.08819, 0.08813, 0.08807, 0.08801,
    0.08795, 0.08789, 0.08783, 0.08777, 0.08771, 0.08765, 0.08759,
    0.08753, 0.08747, 0.08741, 0.08735, 0.08729, 0.08723, 0.08717,
    0.08711, 0.08705, 0.08699, 0.08693, 0.08687, 0.08681, 0.08675,
    0.08669, 0.08663, 0.08657, 0.08651, 0.08645, 0.08639, 0.08633,
    0.08627, 0.08621, 0.08615, 0.0861, 0.08604, 0.08598, 0.08592,
    0.08586, 0.0858, 0.08575, 0.08569, 0.08563, 0.08558, 0.08552,
    0.08546, 0.08541, 0.08535, 0.08529, 0.08524, 0.08518, 0.08513,
    0.08507, 0.08502, 0.08497, 0.08491, 0.08486, 0.08481, 0.08475,
    0.0847, 0.08465, 0.0846, 0.08455, 0.08449, 0.08444, 0.08439,
    0.08434, 0.0843, 0.08425, 0.0842, 0.08415, 0.0841, 0.08406,
    0.08401, 0.08397, 0.08392, 0.08388, 0.08383, 0.08379, 0.08375,
    0.0837, 0.08366, 0.08362, 0.08358, 0.08354, 0.0835, 0.08346,
    0.08342, 0.08339, 0.08335, 0.08331, 0.08328, 0.08324, 0.08321,
    0.08317, 0.08314, 0.08311, 0.08308, 0.08304, 0.08301, 0.08298,
    0.08295, 0.08292, 0.0829, 0.08287, 0.08284, 0.08281, 0.08279,
    0.08276, 0.08273, 0.08271, 0.08268, 0.08266, 0.08264, 0.08261,
    0.08259, 0.08257, 0.08255, 0.08253, 0.08251, 0.08249, 0.08247,
    0.08245, 0.08243, 0.08241, 0.0824, 0.08238, 0.08236, 0.08235,
    0.08233, 0.08232, 0.0823, 0.08229, 0.08228, 0.08227, 0.08225,
    0.08224, 0.08223, 0.08222, 0.08221, 0.0822, 0.08219, 0.08218,
    0.08218, 0.08217, 0.08216, 0.08216, 0.08215, 0.08214, 0.08214,
    0.08214, 0.08213, 0.08213, 0.08213, 0.08212, 0.08212, 0.08212,
    0.08212, 0.08212, 0.08212, 0.08212, 0.08212, 0.08212, 0.08212,
    0.08213, 0.08213, 0.08213, 0.08214, 0.08214, 0.08214, 0.08215,
    0.08215, 0.08216, 0.08217, 0.08217, 0.08218, 0.08219, 0.08219,
    0.0822, 0.08221, 0.08222, 0.08223, 0.08224, 0.08225, 0.08226,
    0.08227, 0.08228, 0.08229, 0.0823, 0.08231, 0.08232, 0.08233,
    0.08235, 0.08236, 0.08237, 0.08238, 0.0824, 0.08241, 0.08242,
    0.08243, 0.08245, 0.08246, 0.08248, 0.08249, 0.0825, 0.08252,
    0.08253, 0.08254, 0.08256, 0.08257, 0.08259, 0.0826, 0.08262,
    0.08263, 0.08264, 0.08266, 0.08267, 0.08269, 0.0827, 0.08272,
    0.08273, 0.08274, 0.08276, 0.08277, 0.08278, 0.0828, 0.08281,
    0.08283, 0.08284, 0.08285, 0.08287, 0.08288, 0.08289, 0.0829,
    0.08292, 0.08293, 0.08294, 0.08295, 0.08297, 0.08298, 0.08299,
    0.083, 0.08301, 0.08302, 0.08303, 0.08305, 0.08306, 0.08307,
    0.08307, 0.08308, 0.08309, 0.0831, 0.08311, 0.08312, 0.08312,
    0.08313, 0.08314, 0.08314, 0.08315, 0.08315, 0.08316, 0.08316,
    0.08317, 0.08317, 0.08317, 0.08318, 0.08318, 0.08318, 0.08318,
    0.08318, 0.08318, 0.08318, 0.08318, 0.08317, 0.08317, 0.08317,
    0.08316, 0.08316, 0.08315, 0.08315, 0.08314, 0.08313, 0.08313,
    0.08312, 0.08311, 0.0831, 0.08309, 0.08308, 0.08307, 0.08305,
    0.08304, 0.08303, 0.08301, 0.083, 0.08298, 0.08297, 0.08295,
    0.08293, 0.08291, 0.0829, 0.08288, 0.08286, 0.08284, 0.08282,
    0.08279, 0.08277, 0.08275, 0.08273, 0.0827, 0.08268, 0.08265,
    0.08263, 0.0826, 0.08258, 0.08255, 0.08252, 0.08249, 0.08246,
    0.08244, 0.08241, 0.08238, 0.08235, 0.08231, 0.08228, 0.08225,
    0.08222, 0.08219, 0.08215, 0.08212, 0.08209, 0.08205, 0.08202,
    0.08198, 0.08195, 0.08191, 0.08188, 0.08184, 0.08181, 0.08177,
    0.08174, 0.0817, 0.08166, 0.08163, 0.08159, 0.08156, 0.08152,
    0.08148, 0.08145, 0.08141, 0.08138, 0.08134, 0.08131, 0.08128,
    0.08124, 0.08121, 0.08118, 0.08114, 0.08111, 0.08108, 0.08105,
    0.08102, 0.08099, 0.08096, 0.08093, 0.0809, 0.08087, 0.08084,
    0.08082, 0.08079, 0.08076, 0.08074, 0.08071, 0.08069, 0.08067,
    0.08064, 0.08062, 0.0806, 0.08058, 0.08056, 0.08054, 0.08052,
    0.0805, 0.08048, 0.08047, 0.08045, 0.08044, 0.08042, 0.08041,
    0.08039, 0.08038, 0.08037, 0.08035, 0.08034, 0.08033, 0.08032,
    0.08031, 0.0803, 0.0803, 0.08029, 0.08028, 0.08027, 0.08027,
    0.08026, 0.08026, 0.08025, 0.08025, 0.08025, 0.08025, 0.08025,
    0.08024, 0.08024, 0.08024, 0.08025, 0.08025, 0.08025, 0.08025,
    0.08026, 0.08026, 0.08027, 0.08027, 0.08028, 0.08028, 0.08029,
    0.0803, 0.08031, 0.08032, 0.08033, 0.08034, 0.08035, 0.08036,
    0.08037, 0.08038, 0.0804, 0.08041, 0.08043, 0.08044, 0.08046,
    0.08047, 0.08049, 0.08051, 0.08052, 0.08054, 0.08056, 0.08058,
    0.0806, 0.08062, 0.08064, 0.08067, 0.08069, 0.08071, 0.08073,
    0.08076, 0.08078, 0.08081, 0.08083, 0.08086, 0.08089, 0.08092,
    0.08094, 0.08097, 0.081, 0.08103, 0.08106, 0.08109, 0.08112,
    0.08116, 0.08119, 0.08122, 0.08125, 0.08129, 0.08132, 0.08136,
    0.08139, 0.08143, 0.08146, 0.0815, 0.08154, 0.08157, 0.08161,
    0.08165, 0.08169, 0.08173, 0.08177, 0.08181, 0.08185, 0.08189,
    0.08194, 0.08198, 0.08202, 0.08206, 0.08211, 0.08215, 0.0822,
    0.08224, 0.08229, 0.08233, 0.08238, 0.08243, 0.08247, 0.08252,
    0.08257, 0.08262, 0.08267, 0.08272, 0.08277, 0.08281, 0.08287,
    0.08292, 0.08297, 0.08302, 0.08307, 0.08312, 0.08317, 0.08322,
    0.08328, 0.08333, 0.08338, 0.08343, 0.08349, 0.08354, 0.08359,
    0.08365, 0.0837, 0.08376, 0.08381, 0.08386, 0.08392, 0.08397,
    0.08403, 0.08408, 0.08414, 0.08419, 0.08425, 0.08431, 0.08436,
    0.08442, 0.08447, 0.08453, 0.08458, 0.08464, 0.0847, 0.08475,
    0.08481, 0.08487, 0.08493, 0.08498, 0.08504, 0.0851, 0.08516,
    0.08521, 0.08527, 0.08533, 0.08539, 0.08545, 0.08551, 0.08557,
    0.08562, 0.08568, 0.08574, 0.0858, 0.08586, 0.08592, 0.08599,
    0.08605, 0.08611, 0.08617, 0.08623, 0.08629, 0.08635, 0.08641,
    0.08648, 0.08654, 0.0866, 0.08666, 0.08673, 0.08679, 0.08685,
    0.08691, 0.08698, 0.08704, 0.0871, 0.08717, 0.08723, 0.0873,
    0.08736, 0.08742, 0.08749, 0.08755, 0.09029, 0.0903, 0.0903,
    0.09031, 0.09032, 0.09033, 0.09033, 0.09034, 0.09035, 0.09036,
    0.09037, 0.09037, 0.09038, 0.09039, 0.0904, 0.0904, 0.09041,
    0.09042, 0.09043, 0.09044, 0.09044, 0.09045, 0.09046, 0.09047,
    0.09047, 0.09048, 0.09049, 0.0905, 0.0905, 0.09051, 0.09052,
    0.09053, 0.09054, 0.09054, 0.09055, 0.09056, 0.09057, 0.09057,
    0.09058, 0.09059, 0.0906, 0.09061, 0.09061, 0.09062, 0.09063,
    0.09064, 0.09065, 0.09065, 0.09066, 0.09067, 0.09068, 0.09069,
    0.09069, 0.0907, 0.09071, 0.09072, 0.09073, 0.09074, 0.09074,
    0.09075, 0.09076, 0.09077, 0.09078, 0.09079, 0.0908, 0.0908,
    0.09081, 0.09082, 0.09083, 0.09084, 0.09085, 0.09086, 0.09086,
    0.09087, 0.09088, 0.09089, 0.0909, 0.09091, 0.09092, 0.09093,
    0.09093, 0.09094, 0.09095, 0.09096, 0.09097, 0.09098, 0.09099,
    0.09099, 0.091, 0.09101, 0.09102, 0.09103, 0.09104, 0.09105,
    0.09105, 0.09106, 0.09107, 0.09108, 0.09109, 0.09109, 0.0911,
    0.09111, 0.09112, 0.09113, 0.09113, 0.09114, 0.09115, 0.09116,
    0.09116, 0.09117, 0.09118, 0.09119, 0.09119, 0.0912, 0.09121,
    0.09121, 0.09122, 0.09123, 0.09123, 0.09124, 0.09125, 0.09125,
    0.09126, 0.09126, 0.09127, 0.09128, 0.09128, 0.09129, 0.09129,
    0.0913, 0.0913, 0.09131, 0.09131, 0.09131, 0.09132, 0.09132,
    0.09133, 0.09133, 0.09133, 0.09134, 0.09134, 0.09134, 0.09135,
    0.09135, 0.09135, 0.09135, 0.09136, 0.09136, 0.09136, 0.09136,
    0.09136, 0.09136, 0.09137, 0.09137, 0.09137, 0.09137, 0.09137,
    0.09137, 0.09137, 0.09137, 0.09137, 0.09137, 0.09136, 0.09136,
    0.09136, 0.09136, 0.09136, 0.09136, 0.09135, 0.09135, 0.09135,
    0.09135, 0.09134, 0.09134, 0.09134, 0.09133, 0.09133, 0.09133,
    0.09132, 0.09132, 0.09131, 0.09131, 0.0913, 0.0913, 0.09129,
    0.09129, 0.09128, 0.09128, 0.09127, 0.09127, 0.09126, 0.09125,
    0.09125, 0.09124, 0.09123, 0.09123, 0.09122, 0.09121, 0.0912,
    0.0912, 0.09119, 0.09118, 0.09117, 0.09116, 0.09116, 0.09115,
    0.09114, 0.09113, 0.09112, 0.09111, 0.0911, 0.09109, 0.09109,
    0.09108, 0.09107, 0.09106, 0.09105, 0.09104, 0.09103, 0.09102,
    0.09101, 0.091, 0.09099, 0.09098, 0.09097, 0.09096, 0.09095,
    0.09094, 0.09093, 0.09091, 0.0909, 0.09089, 0.09088, 0.09087,
    0.09086, 0.09085, 0.09084, 0.09083, 0.09082, 0.0908, 0.09079,
    0.09078, 0.09077, 0.09076, 0.09075, 0.09074, 0.09072, 0.09071,
    0.0907, 0.09069, 0.09068, 0.09067, 0.09065, 0.09064, 0.09063,
    0.09062, 0.09061, 0.09059, 0.09058, 0.09057, 0.09056, 0.09055,
    0.09053, 0.09052, 0.09051, 0.0905, 0.09048, 0.09047, 0.09046,
    0.09045, 0.09043, 0.09042, 0.09041, 0.0904, 0.09039, 0.09037,
    0.09036, 0.09035, 0.09034, 0.09032, 0.09031, 0.0903, 0.09028,
    0.09027, 0.09026, 0.09025, 0.09023, 0.09022, 0.09021, 0.0902,
    0.09018, 0.09017, 0.09016, 0.09014, 0.09013, 0.09012, 0.09011,
    0.09009, 0.09008, 0.09007, 0.09005, 0.09004, 0.09003, 0.09001,
    0.09, 0.08999, 0.08997, 0.08996, 0.08995, 0.08993, 0.08992,
    0.08991, 0.08989, 0.08988, 0.08987, 0.08985, 0.08984, 0.08983,
    0.08981, 0.0898, 0.08979, 0.08977, 0.08976, 0.08975, 0.08973,
    0.08972, 0.08971, 0.08969, 0.08968, 0.08966, 0.08965, 0.08964,
    0.08963, 0.08961, 0.0896, 0.08959, 0.08957, 0.08956, 0.08955,
    0.08953, 0.08952, 0.08951, 0.0895, 0.08948, 0.08947, 0.08946,
    0.08945, 0.08943, 0.08942, 0.08941, 0.0894, 0.08939, 0.08937,
    0.08936, 0.08935, 0.08934, 0.08933, 0.08932, 0.0893, 0.08929,
    0.08928, 0.08927, 0.08926, 0.08925, 0.08924, 0.08923, 0.08922,
    0.08921, 0.0892, 0.08919, 0.08918, 0.08917, 0.08916, 0.08915,
    0.08915, 0.08914, 0.08913, 0.08912, 0.08911, 0.0891, 0.0891,
    0.08909, 0.08908, 0.08907, 0.08907, 0.08906, 0.08905, 0.08905,
    0.08904, 0.08903, 0.08903, 0.08902, 0.08902, 0.08901, 0.08901,
    0.089, 0.089, 0.08899, 0.08899, 0.08899, 0.08898, 0.08898,
    0.08897, 0.08897, 0.08897, 0.08897, 0.08896, 0.08896, 0.08896,
    0.08896, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895,
    0.08895, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895,
    0.08895, 0.08895, 0.08895, 0.08896, 0.08896, 0.08896, 0.08896,
    0.08896, 0.08897, 0.08897, 0.08897, 0.08898, 0.08898, 0.08898,
    0.08899, 0.08899, 0.089, 0.089, 0.08901, 0.08901, 0.08902,
    0.08902, 0.08903, 0.08903, 0.08904, 0.08904, 0.08905, 0.08906,
    0.08906, 0.08907, 0.08908, 0.08909, 0.08909, 0.0891, 0.08911,
    0.08912, 0.08912, 0.08913, 0.08914, 0.08915, 0.08916, 0.08917,
    0.08918, 0.08919, 0.0892, 0.08921, 0.08922, 0.08923, 0.08924,
    0.08925, 0.08926, 0.08927, 0.08928, 0.0893, 0.08931, 0.08932,
    0.08933, 0.08934, 0.08936, 0.08937, 0.08938, 0.0894, 0.08941,
    0.08942, 0.08944, 0.08945, 0.08947, 0.08948, 0.08949, 0.08951,
    0.08952, 0.08954, 0.08955, 0.08957, 0.08959, 0.0896, 0.08962,
    0.08963, 0.08965, 0.08967, 0.08968, 0.0897, 0.08972, 0.08974,
    0.08975, 0.08977, 0.08979, 0.08981, 0.08983, 0.08984, 0.08986,
    0.08988, 0.0899, 0.08992, 0.08994, 0.08996, 0.08998, 0.09,
    0.09002, 0.09004, 0.09006, 0.09008, 0.0901, 0.09012, 0.09015,
    0.09017, 0.09019, 0.09021, 0.09023, 0.09026, 0.09028, 0.0903,
    0.09033, 0.09035, 0.09037, 0.0904, 0.09042, 0.09044, 0.09047,
    0.09049, 0.09052, 0.09054, 0.09057, 0.09059, 0.09062, 0.09064,
    0.09067, 0.09069, 0.09072, 0.09075, 0.09077, 0.0908, 0.09083,
    0.09085, 0.09088, 0.09091, 0.09093, 0.09096, 0.09099, 0.09102,
    0.09105, 0.09107, 0.0911, 0.09113, 0.09116, 0.09119, 0.09122,
    0.09125, 0.09128, 0.09131, 0.09133, 0.09136, 0.09139, 0.09142,
    0.09146, 0.09149, 0.09152, 0.09155, 0.09158, 0.09161, 0.09164,
    0.09167, 0.0917, 0.09173, 0.09177, 0.0918, 0.09183, 0.09186,
    0.0919, 0.09193, 0.09196, 0.09199, 0.09203, 0.09206, 0.09209,
    0.09213, 0.09216, 0.09219, 0.09223, 0.09226, 0.09229, 0.09233,
    0.09236, 0.0924, 0.09243, 0.09247, 0.0925, 0.09254, 0.09257,
    0.09261, 0.09264, 0.09268, 0.09271, 0.09275, 0.09278, 0.09282,
    0.09286, 0.09289, 0.09293, 0.09296, 0.093, 0.09304, 0.09307,
    0.09311, 0.09315, 0.09318, 0.09322, 0.09326, 0.09329, 0.09333,
    0.09337, 0.09341, 0.09344, 0.09348, 0.09352, 0.09356, 0.09359,
    0.09363, 0.09367, 0.09371, 0.09375, 0.09378, 0.09382, 0.09386,
    0.0939, 0.09394, 0.09397, 0.09401, 0.08217, 0.08216, 0.08216,
    0.08215, 0.08214, 0.08214, 0.08214, 0.08213, 0.08213, 0.08213,
    0.08212, 0.08212, 0.08212, 0.08212, 0.08212, 0.08212, 0.08212,
    0.08212, 0.08212, 0.08212, 0.08213, 0.08213, 0.08213, 0.08214,
    0.08214, 0.08214, 0.08215, 0.08215, 0.08216, 0.08217, 0.08217,
    0.08218, 0.08219, 0.08219, 0.0822, 0.08221, 0.08222, 0.08223,
    0.08224, 0.08225, 0.08226, 0.08227, 0.08228, 0.08229, 0.0823,
    0.08231, 0.08232, 0.08233, 0.08235, 0.08236, 0.08237, 0.08238,
    0.0824, 0.08241, 0.08242, 0.08243, 0.08245, 0.08246, 0.08248,
    0.08249, 0.0825, 0.08252, 0.08253, 0.08254, 0.08256, 0.08257,
    0.08259, 0.0826, 0.08262, 0.08263, 0.08264, 0.08266, 0.08267,
    0.08269, 0.0827, 0.08272, 0.08273, 0.08274, 0.08276, 0.08277,
    0.08278, 0.0828, 0.08281, 0.08283, 0.08284, 0.08285, 0.08287,
    0.08288, 0.08289, 0.0829, 0.08292, 0.08293, 0.08294, 0.08295,
    0.08297, 0.08298, 0.08299, 0.083, 0.08301, 0.08302, 0.08303,
    0.08305, 0.08306, 0.08307, 0.08307, 0.08308, 0.08309, 0.0831,
    0.08311, 0.08312, 0.08312, 0.08313, 0.08314, 0.08314, 0.08315,
    0.08315, 0.08316, 0.08316, 0.08317, 0.08317, 0.08317, 0.08318,
    0.08318, 0.08318, 0.08318, 0.08318, 0.08318, 0.08318, 0.08318,
    0.08317, 0.08317, 0.08317, 0.08316, 0.08316, 0.08315, 0.08315,
    0.08314, 0.08313, 0.08313, 0.08312, 0.08311, 0.0831, 0.08309,
    0.08308, 0.08307, 0.08305, 0.08304, 0.08303, 0.08301, 0.083,
    0.08298, 0.08297, 0.08295, 0.08293, 0.08291, 0.0829, 0.08288,
    0.08286, 0.08284, 0.08282, 0.08279, 0.08277, 0.08275, 0.08273,
    0.0827, 0.08268, 0.08265, 0.08263, 0.0826, 0.08258, 0.08255,
    0.08252, 0.08249, 0.08246, 0.08244, 0.08241, 0.08238, 0.08235,
    0.08231, 0.08228, 0.08225, 0.08222, 0.08219, 0.08215, 0.08212,
    0.08209, 0.08205, 0.08202, 0.08198, 0.08195, 0.08191, 0.08188,
    0.08184, 0.08181, 0.08177, 0.08174, 0.0817, 0.08166, 0.08163,
    0.08159, 0.08156, 0.08152, 0.08148, 0.08145, 0.08141, 0.08138,
    0.08134, 0.08131, 0.08128, 0.08124, 0.08121, 0.08118, 0.08114,
    0.08111, 0.08108, 0.08105, 0.08102, 0.08099, 0.08096, 0.08093,
    0.0809, 0.08087, 0.08084, 0.08082, 0.08079, 0.08076, 0.08074,
    0.08071, 0.08069, 0.08067, 0.08064, 0.08062, 0.0806, 0.08058,
    0.08056, 0.08054, 0.08052, 0.0805, 0.08048, 0.08047, 0.08045,
    0.08044, 0.08042, 0.08041, 0.08039, 0.08038, 0.08037, 0.08035,
    0.08034, 0.08033, 0.08032, 0.08031, 0.0803, 0.0803, 0.08029,
    0.08028, 0.08027, 0.08027, 0.08026, 0.08026, 0.08025, 0.08025,
    0.08025, 0.08025, 0.08025, 0.08024, 0.08024, 0.08024, 0.08025,
    0.08025, 0.08025, 0.08025, 0.08026, 0.08026, 0.08027, 0.08027,
    0.08028, 0.08028, 0.08029, 0.0803, 0.08031, 0.08032, 0.08033,
    0.08034, 0.08035, 0.08036, 0.08037, 0.08038, 0.0804, 0.08041,
    0.08043, 0.08044, 0.08046, 0.08047, 0.08049, 0.08051, 0.08052,
    0.08054, 0.08056, 0.08058, 0.0806, 0.08062, 0.08064, 0.08067,
    0.08069, 0.08071, 0.08073, 0.08076, 0.08078, 0.08081, 0.08083,
    0.08086, 0.08089, 0.08092, 0.08094, 0.08097, 0.081, 0.08103,
    0.08106, 0.08109, 0.08112, 0.08116, 0.08119, 0.08122, 0.08125,
    0.08129, 0.08132, 0.08136, 0.08139, 0.08143, 0.08146, 0.0815,
    0.08154, 0.08157, 0.08161, 0.08165, 0.08169, 0.08173, 0.08177,
    0.08181, 0.08185, 0.08189, 0.08194, 0.08198, 0.08202, 0.08206,
    0.08211, 0.08215, 0.0822, 0.08224, 0.08229, 0.08233, 0.08238,
    0.08243, 0.08247, 0.08252, 0.08257, 0.08262, 0.08267, 0.08272,
    0.08277, 0.08281, 0.08287, 0.08292, 0.08297, 0.08302, 0.08307,
    0.08312, 0.08317, 0.08322, 0.08328, 0.08333, 0.08338, 0.08343,
    0.08349, 0.08354, 0.08359, 0.08365, 0.0837, 0.08376, 0.08381,
    0.08386, 0.08392, 0.08397, 0.08403, 0.08408, 0.08414, 0.08419,
    0.08425, 0.08431, 0.08436, 0.08442, 0.08447, 0.08453, 0.08458,
    0.08464, 0.0847, 0.08475, 0.08481, 0.08487, 0.08493, 0.08498,
    0.08504, 0.0851, 0.08516, 0.08521, 0.08527, 0.08533, 0.08539,
    0.08545, 0.08551, 0.08557, 0.08562, 0.08568, 0.08574, 0.0858,
    0.08586, 0.08592, 0.08599, 0.08605, 0.08611, 0.08617, 0.08623,
    0.08629, 0.08635, 0.08641, 0.08648, 0.08654, 0.0866, 0.08666,
    0.08673, 0.08679, 0.08685, 0.08691, 0.08698, 0.08704, 0.0871,
    0.08717, 0.08723, 0.0873, 0.08736, 0.08742, 0.08749, 0.08755,
    0.08762, 0.08768, 0.08774, 0.08781, 0.08787, 0.08794, 0.088,
    0.08806, 0.08813, 0.08819, 0.08826, 0.08832, 0.08838, 0.08845,
    0.08851, 0.08858, 0.08864, 0.08871, 0.08877, 0.08883, 0.0889,
    0.08896, 0.08903, 0.08909, 0.08915, 0.08922, 0.08928, 0.08934,
    0.08941, 0.08947, 0.08953, 0.0896, 0.08966, 0.08972, 0.08979,
    0.08985, 0.08991, 0.08997, 0.09004, 0.0901, 0.09016, 0.09022,
    0.09029, 0.09035, 0.09041, 0.09047, 0.09054, 0.0906, 0.09066,
    0.09072, 0.09079, 0.09085, 0.09091, 0.09097, 0.09103, 0.0911,
    0.09116, 0.09122, 0.09128, 0.09134, 0.0914, 0.09147, 0.09153,
    0.09159, 0.09165, 0.09171, 0.09177, 0.09183, 0.0919, 0.09196,
    0.09202, 0.09208, 0.09214, 0.0922, 0.09227, 0.09233, 0.09239,
    0.09245, 0.09251, 0.09257, 0.09263, 0.0927, 0.09276, 0.09282,
    0.09288, 0.09294, 0.093, 0.09307, 0.09313, 0.09319, 0.09325,
    0.09331, 0.09338, 0.09344, 0.0935, 0.09356, 0.09362, 0.09368,
    0.09375, 0.09381, 0.09387, 0.09393, 0.09399, 0.09406, 0.09412,
    0.09418, 0.09424, 0.09113, 0.09112, 0.09111, 0.0911, 0.09109,
    0.09109, 0.09108, 0.09107, 0.09106, 0.09105, 0.09104, 0.09103,
    0.09102, 0.09101, 0.091, 0.09099, 0.09098, 0.09097, 0.09096,
    0.09095, 0.09094, 0.09093, 0.09091, 0.0909, 0.09089, 0.09088,
    0.09087, 0.09086, 0.09085, 0.09084, 0.09083, 0.09082, 0.0908,
    0.09079, 0.09078, 0.09077, 0.09076, 0.09075, 0.09074, 0.09072,
    0.09071, 0.0907, 0.09069, 0.09068, 0.09067, 0.09065, 0.09064,
    0.09063, 0.09062, 0.09061, 0.09059, 0.09058, 0.09057, 0.09056,
    0.09055, 0.09053, 0.09052, 0.09051, 0.0905, 0.09048, 0.09047,
    0.09046, 0.09045, 0.09043, 0.09042, 0.09041, 0.0904, 0.09039,
    0.09037, 0.09036, 0.09035, 0.09034, 0.09032, 0.09031, 0.0903,
    0.09028, 0.09027, 0.09026, 0.09025, 0.09023, 0.09022, 0.09021,
    0.0902, 0.09018, 0.09017, 0.09016, 0.09014, 0.09013, 0.09012,
    0.09011, 0.09009, 0.09008, 0.09007, 0.09005, 0.09004, 0.09003,
    0.09001, 0.09, 0.08999, 0.08997, 0.08996, 0.08995, 0.08993,
    0.08992, 0.08991, 0.08989, 0.08988, 0.08987, 0.08985, 0.08984,
    0.08983, 0.08981, 0.0898, 0.08979, 0.08977, 0.08976, 0.08975,
    0.08973, 0.08972, 0.08971, 0.08969, 0.08968, 0.08966, 0.08965,
    0.08964, 0.08963, 0.08961, 0.0896, 0.08959, 0.08957, 0.08956,
    0.08955, 0.08953, 0.08952, 0.08951, 0.0895, 0.08948, 0.08947,
    0.08946, 0.08945, 0.08943, 0.08942, 0.08941, 0.0894, 0.08939,
    0.08937, 0.08936, 0.08935, 0.08934, 0.08933, 0.08932, 0.0893,
    0.08929, 0.08928, 0.08927, 0.08926, 0.08925, 0.08924, 0.08923,
    0.08922, 0.08921, 0.0892, 0.08919, 0.08918, 0.08917, 0.08916,
    0.08915, 0.08915, 0.08914, 0.08913, 0.08912, 0.08911, 0.0891,
    0.0891, 0.08909, 0.08908, 0.08907, 0.08907, 0.08906, 0.08905,
    0.08905, 0.08904, 0.08903, 0.08903, 0.08902, 0.08902, 0.08901,
    0.08901, 0.089, 0.089, 0.08899, 0.08899, 0.08899, 0.08898,
    0.08898, 0.08897, 0.08897, 0.08897, 0.08897, 0.08896, 0.08896,
    0.08896, 0.08896, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895,
    0.08895, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895, 0.08895,
    0.08895, 0.08895, 0.08895, 0.08895, 0.08896, 0.08896, 0.08896,
    0.08896, 0.08896, 0.08897, 0.08897, 0.08897, 0.08898, 0.08898,
    0.08898, 0.08899, 0.08899, 0.089, 0.089, 0.08901, 0.08901,
    0.08902, 0.08902, 0.08903, 0.08903, 0.08904, 0.08904, 0.08905,
    0.08906, 0.08906, 0.08907, 0.08908, 0.08909, 0.08909, 0.0891,
    0.08911, 0.08912, 0.08912, 0.08913, 0.08914, 0.08915, 0.08916,
    0.08917, 0.08918, 0.08919, 0.0892, 0.08921, 0.08922, 0.08923,
    0.08924, 0.08925, 0.08926, 0.08927, 0.08928, 0.0893, 0.08931,
    0.08932, 0.08933, 0.08934, 0.08936, 0.08937, 0.08938, 0.0894,
    0.08941, 0.08942, 0.08944, 0.08945, 0.08947, 0.08948, 0.08949,
    0.08951, 0.08952, 0.08954, 0.08955, 0.08957, 0.08959, 0.0896,
    0.08962, 0.08963, 0.08965, 0.08967, 0.08968, 0.0897, 0.08972,
    0.08974, 0.08975, 0.08977, 0.08979, 0.08981, 0.08983, 0.08984,
    0.08986, 0.08988, 0.0899, 0.08992, 0.08994, 0.08996, 0.08998,
    0.09, 0.09002, 0.09004, 0.09006, 0.09008, 0.0901, 0.09012,
    0.09015, 0.09017, 0.09019, 0.09021, 0.09023, 0.09026, 0.09028,
    0.0903, 0.09033, 0.09035, 0.09037, 0.0904, 0.09042, 0.09044,
    0.09047, 0.09049, 0.09052, 0.09054, 0.09057, 0.09059, 0.09062,
    0.09064, 0.09067, 0.09069, 0.09072, 0.09075, 0.09077, 0.0908,
    0.09083, 0.09085, 0.09088, 0.09091, 0.09093, 0.09096, 0.09099,
    0.09102, 0.09105, 0.09107, 0.0911, 0.09113, 0.09116, 0.09119,
    0.09122, 0.09125, 0.09128, 0.09131, 0.09133, 0.09136, 0.09139,
    0.09142, 0.09146, 0.09149, 0.09152, 0.09155, 0.09158, 0.09161,
    0.09164, 0.09167, 0.0917, 0.09173, 0.09177, 0.0918, 0.09183,
    0.09186, 0.0919, 0.09193, 0.09196, 0.09199, 0.09203, 0.09206,
    0.09209, 0.09213, 0.09216, 0.09219, 0.09223, 0.09226, 0.09229,
    0.09233, 0.09236, 0.0924, 0.09243, 0.09247, 0.0925, 0.09254,
    0.09257, 0.09261, 0.09264, 0.09268, 0.09271, 0.09275, 0.09278,
    0.09282, 0.09286, 0.09289, 0.09293, 0.09296, 0.093, 0.09304,
    0.09307, 0.09311, 0.09315, 0.09318, 0.09322, 0.09326, 0.09329,
    0.09333, 0.09337, 0.09341, 0.09344, 0.09348, 0.09352, 0.09356,
    0.09359, 0.09363, 0.09367, 0.09371, 0.09375, 0.09378, 0.09382,
    0.09386, 0.0939, 0.09394, 0.09397, 0.09401, 0.09405, 0.09409,
    0.09413, 0.09417, 0.09421, 0.09424, 0.09428, 0.09432, 0.09436,
    0.0944, 0.09444, 0.09448, 0.09452, 0.09456, 0.0946, 0.09464,
    0.09467, 0.09471, 0.09475, 0.09479, 0.09483, 0.09487, 0.09491,
    0.09495, 0.09499, 0.09503, 0.09507, 0.09511, 0.09515, 0.09519,
    0.09523, 0.09527, 0.09531, 0.09534, 0.09538, 0.09542, 0.09546,
    0.0955, 0.09554, 0.09558, 0.09562, 0.09566, 0.0957, 0.09574,
    0.09578, 0.09582, 0.09586, 0.0959, 0.09594, 0.09598, 0.09602,
    0.09606, 0.0961, 0.09614, 0.09618, 0.09622, 0.09626, 0.0963,
    0.09634, 0.09638, 0.09642, 0.09646, 0.0965, 0.09654, 0.09658,
    0.09662, 0.09666, 0.0967, 0.09674, 0.09678, 0.09682, 0.09686,
    0.09691, 0.09695, 0.09699, 0.09703, 0.09707, 0.09711, 0.09715,
    0.09719, 0.09723, 0.09727, 0.09731, 0.09735, 0.09739, 0.09743,
    0.09747, 0.09751, 0.09755, 0.09759, 0.09763, 0.09767, 0.09771,
    0.09775, 0.0978, 0.09784, 0.09788, 0.09792, 0.09796, 0.098,
    0.09804, 0.09808, 0.09812, 0.09816, 0.0982, 0.09824, 0.09828
    )), row.names = c(1L, 2L, 3L, 4L, 5L, 6L, 7L, 8L, 9L, 10L,
11L, 12L, 13L, 14L, 15L, 16L, 17L, 18L, 19L, 20L, 21L, 22L, 23L,
24L, 25L, 26L, 27L, 28L, 29L, 30L, 31L, 32L, 33L, 34L, 35L, 36L,
37L, 38L, 39L, 40L, 41L, 42L, 43L, 44L, 45L, 46L, 47L, 48L, 49L,
50L, 51L, 52L, 53L, 54L, 55L, 56L, 57L, 58L, 59L, 60L, 61L, 62L,
63L, 64L, 65L, 66L, 67L, 68L, 69L, 70L, 71L, 72L, 73L, 74L, 75L,
76L, 77L, 78L, 79L, 80L, 81L, 82L, 83L, 84L, 85L, 86L, 87L, 88L,
89L, 90L, 91L, 92L, 93L, 94L, 95L, 96L, 97L, 98L, 99L, 100L,
101L, 102L, 103L, 104L, 105L, 106L, 107L, 108L, 109L, 110L, 111L,
112L, 113L, 114L, 115L, 116L, 117L, 118L, 119L, 120L, 121L, 122L,
123L, 124L, 125L, 126L, 127L, 128L, 129L, 130L, 131L, 132L, 133L,
134L, 135L, 136L, 137L, 138L, 139L, 140L, 141L, 142L, 143L, 144L,
145L, 146L, 147L, 148L, 149L, 150L, 151L, 152L, 153L, 154L, 155L,
156L, 157L, 158L, 159L, 160L, 161L, 162L, 163L, 164L, 165L, 166L,
167L, 168L, 169L, 170L, 171L, 172L, 173L, 174L, 175L, 176L, 177L,
178L, 179L, 180L, 181L, 182L, 183L, 184L, 185L, 186L, 187L, 188L,
189L, 190L, 191L, 192L, 193L, 194L, 195L, 196L, 197L, 198L, 199L,
200L, 201L, 202L, 203L, 204L, 205L, 206L, 207L, 208L, 209L, 210L,
211L, 212L, 213L, 214L, 215L, 216L, 217L, 218L, 219L, 220L, 221L,
222L, 223L, 224L, 225L, 226L, 227L, 228L, 229L, 230L, 231L, 232L,
233L, 234L, 235L, 236L, 237L, 238L, 239L, 240L, 241L, 242L, 243L,
244L, 245L, 246L, 247L, 248L, 249L, 250L, 251L, 252L, 253L, 254L,
255L, 256L, 257L, 258L, 259L, 260L, 261L, 262L, 263L, 264L, 265L,
266L, 267L, 268L, 269L, 270L, 271L, 272L, 273L, 274L, 275L, 276L,
277L, 278L, 279L, 280L, 281L, 282L, 283L, 284L, 285L, 286L, 287L,
288L, 289L, 290L, 291L, 292L, 293L, 294L, 295L, 296L, 297L, 298L,
299L, 300L, 301L, 302L, 303L, 304L, 305L, 306L, 307L, 308L, 309L,
310L, 311L, 312L, 313L, 314L, 315L, 316L, 317L, 318L, 319L, 320L,
321L, 322L, 323L, 324L, 325L, 326L, 327L, 328L, 329L, 330L, 331L,
332L, 333L, 334L, 335L, 336L, 337L, 338L, 339L, 340L, 341L, 342L,
343L, 344L, 345L, 346L, 347L, 348L, 349L, 350L, 351L, 352L, 353L,
354L, 355L, 356L, 357L, 358L, 359L, 360L, 361L, 362L, 363L, 364L,
365L, 366L, 367L, 368L, 369L, 370L, 371L, 372L, 373L, 374L, 375L,
376L, 377L, 378L, 379L, 380L, 381L, 382L, 383L, 384L, 385L, 386L,
387L, 388L, 389L, 390L, 391L, 392L, 393L, 394L, 395L, 396L, 397L,
398L, 399L, 400L, 401L, 402L, 403L, 404L, 405L, 406L, 407L, 408L,
409L, 410L, 411L, 412L, 413L, 414L, 415L, 416L, 417L, 418L, 419L,
420L, 421L, 422L, 423L, 424L, 425L, 426L, 427L, 428L, 429L, 430L,
431L, 432L, 433L, 434L, 435L, 436L, 437L, 438L, 439L, 440L, 441L,
442L, 443L, 444L, 445L, 446L, 447L, 448L, 449L, 450L, 451L, 452L,
453L, 454L, 455L, 456L, 457L, 458L, 459L, 460L, 461L, 462L, 463L,
464L, 465L, 466L, 467L, 468L, 469L, 470L, 471L, 472L, 473L, 474L,
475L, 476L, 477L, 478L, 479L, 480L, 481L, 482L, 483L, 484L, 485L,
486L, 487L, 488L, 489L, 490L, 491L, 492L, 493L, 494L, 495L, 496L,
497L, 498L, 499L, 500L, 501L, 502L, 503L, 504L, 505L, 506L, 507L,
508L, 509L, 510L, 511L, 512L, 513L, 514L, 515L, 516L, 517L, 518L,
519L, 520L, 521L, 522L, 523L, 524L, 525L, 526L, 527L, 528L, 529L,
530L, 531L, 532L, 533L, 534L, 535L, 536L, 537L, 538L, 539L, 540L,
541L, 542L, 543L, 544L, 545L, 546L, 547L, 548L, 549L, 550L, 551L,
552L, 553L, 554L, 555L, 556L, 557L, 558L, 559L, 560L, 561L, 562L,
563L, 564L, 565L, 566L, 567L, 568L, 569L, 570L, 571L, 572L, 573L,
574L, 575L, 576L, 577L, 578L, 579L, 580L, 581L, 582L, 583L, 584L,
585L, 586L, 587L, 588L, 589L, 590L, 591L, 592L, 593L, 594L, 595L,
596L, 597L, 598L, 599L, 600L, 601L, 602L, 603L, 604L, 605L, 606L,
607L, 608L, 609L, 610L, 611L, 612L, 613L, 614L, 615L, 616L, 617L,
618L, 619L, 620L, 621L, 622L, 623L, 624L, 625L, 626L, 627L, 628L,
629L, 630L, 631L, 632L, 633L, 634L, 635L, 636L, 637L, 638L, 639L,
640L, 641L, 642L, 643L, 644L, 645L, 646L, 647L, 648L, 649L, 650L,
651L, 652L, 653L, 654L, 655L, 656L, 657L, 658L, 659L, 660L, 661L,
662L, 663L, 664L, 665L, 666L, 667L, 668L, 669L, 670L, 671L, 672L,
673L, 674L, 675L, 676L, 677L, 678L, 679L, 680L, 681L, 682L, 683L,
684L, 685L, 686L, 687L, 688L, 689L, 690L, 691L, 692L, 693L, 694L,
695L, 696L, 697L, 698L, 699L, 700L, 701L, 702L, 703L, 704L, 705L,
706L, 707L, 708L, 709L, 710L, 711L, 712L, 713L, 714L, 715L, 716L,
717L, 718L, 719L, 720L, 721L, 722L, 723L, 724L, 725L, 726L, 727L,
728L, 729L, 730L, 731L, 732L, 733L, 734L, 735L, 736L, 737L, 738L,
739L, 740L, 741L, 742L, 743L, 744L, 745L, 746L, 747L, 748L, 749L,
750L, 751L, 752L, 753L, 754L, 755L, 756L, 757L, 758L, 759L, 760L,
761L, 762L, 763L, 764L, 765L, 766L, 767L, 768L, 769L, 770L, 771L,
772L, 773L, 774L, 775L, 776L, 777L, 778L, 779L, 780L, 781L, 782L,
783L, 784L, 785L, 786L, 787L, 788L, 789L, 790L, 791L, 792L, 793L,
794L, 795L, 796L, 797L, 798L, 799L, 800L, 801L, 802L, 803L, 804L,
805L, 806L, 807L, 808L, 809L, 810L, 811L, 812L, 813L, 814L, 815L,
816L, 817L, 818L, 819L, 820L, 821L, 822L, 823L, 824L, 825L, 826L,
827L, 828L, 829L, 830L, 831L, 832L, 833L, 834L, 835L, 836L, 837L,
838L, 839L, 840L, 841L, 842L, 843L, 844L, 845L, 846L, 847L, 848L,
849L, 850L, 851L, 852L, 853L, 854L, 855L, 856L, 857L, 858L, 859L,
860L, 861L, 862L, 863L, 864L, 865L, 866L, 867L, 868L, 869L, 870L,
871L, 872L, 873L, 874L, 875L, 876L, 877L, 878L, 879L, 880L, 881L,
882L, 883L, 884L, 885L, 886L, 887L, 888L, 889L, 890L, 891L, 892L,
893L, 894L, 895L, 896L, 897L, 898L, 899L, 900L, 901L, 902L, 903L,
904L, 905L, 906L, 907L, 908L, 909L, 910L, 911L, 912L, 913L, 914L,
915L, 916L, 917L, 918L, 919L, 920L, 921L, 922L, 923L, 924L, 925L,
926L, 927L, 928L, 929L, 930L, 931L, 932L, 933L, 934L, 935L, 936L,
937L, 938L, 939L, 940L, 941L, 942L, 943L, 944L, 945L, 946L, 947L,
948L, 949L, 950L, 951L, 952L, 953L, 954L, 955L, 956L, 957L, 958L,
959L, 960L, 961L, 962L, 963L, 964L, 965L, 966L, 967L, 968L, 969L,
970L, 971L, 972L, 973L, 974L, 975L, 976L, 977L, 978L, 979L, 980L,
981L, 982L, 983L, 984L, 985L, 986L, 987L, 988L, 989L, 990L, 991L,
992L, 993L, 994L, 995L, 996L, 997L, 998L, 999L, 1000L, 1001L,
1002L, 1003L, 1004L, 1005L, 1006L, 1007L, 1008L, 1009L, 1010L,
1011L, 1012L, 1013L, 1014L, 1015L, 1016L, 1017L, 1018L, 1019L,
1020L, 1021L, 1022L, 1023L, 1024L, 1025L, 1026L, 1027L, 1028L,
1029L, 1030L, 1031L, 1032L, 1033L, 1034L, 1035L, 1036L, 1037L,
1038L, 1039L, 1040L, 1041L, 1042L, 1043L, 1044L, 1045L, 1046L,
1047L, 1048L, 1049L, 1050L, 1051L, 1052L, 1053L, 1054L, 1055L,
1056L, 1057L, 1058L, 1059L, 1060L, 1061L, 1062L, 1063L, 1064L,
1065L, 1066L, 1067L, 1068L, 1069L, 1070L, 1071L, 1072L, 1073L,
1074L, 1075L, 1076L, 1077L, 1078L, 1079L, 1080L, 1081L, 1082L,
1083L, 1084L, 1085L, 1086L, 1087L, 1088L, 1089L, 1090L, 1091L,
1092L, 1093L, 1094L, 1095L, 1096L, 1097L, 1098L, 1099L, 1100L,
1101L, 1102L, 1103L, 1104L, 1105L, 1106L, 1107L, 1108L, 1109L,
1110L, 1111L, 1112L, 1113L, 1114L, 1115L, 1116L, 1117L, 1118L,
1119L, 1120L, 1121L, 1122L, 1123L, 1124L, 1125L, 1126L, 1127L,
1128L, 1129L, 1130L, 1131L, 1132L, 1133L, 1134L, 1135L, 1136L,
1137L, 1138L, 1139L, 1140L, 1141L, 1142L, 1143L, 1144L, 1145L,
1146L, 1147L, 1148L, 1149L, 1150L, 1151L, 1152L, 1153L, 1154L,
1155L, 1156L, 1157L, 1158L, 1159L, 1160L, 1161L, 1162L, 1163L,
1164L, 1165L, 1166L, 1167L, 1168L, 1169L, 1170L, 1171L, 1172L,
1173L, 1174L, 1175L, 1176L, 1177L, 1178L, 1179L, 1180L, 1181L,
1182L, 1183L, 1184L, 1185L, 1186L, 1187L, 1188L, 1189L, 1190L,
1191L, 1192L, 1193L, 1194L, 1195L, 1196L, 1197L, 1198L, 1199L,
1200L, 1201L, 1202L, 1203L, 1204L, 1205L, 1206L, 1207L, 1208L,
1209L, 1210L, 1211L, 1212L, 1213L, 1214L, 1215L, 1216L, 1217L,
1218L, 1219L, 1220L, 1221L, 1222L, 1223L, 1224L, 1225L, 1226L,
1227L, 1228L, 1229L, 1230L, 1231L, 1232L, 1233L, 1234L, 1235L,
1236L, 1237L, 1238L, 1239L, 1240L, 1241L, 1242L, 1243L, 1244L,
1245L, 1246L, 1247L, 1248L, 1249L, 1250L, 1251L, 1252L, 1253L,
1254L, 1255L, 1256L, 1257L, 1258L, 1259L, 1260L, 1261L, 1262L,
1263L, 1264L, 1265L, 1266L, 1267L, 1268L, 1269L, 1270L, 1271L,
1272L, 1273L, 1274L, 1275L, 1276L, 1277L, 1278L, 1279L, 1280L,
1281L, 1282L, 1283L, 1284L, 1285L, 1286L, 1287L, 1288L, 1289L,
1290L, 1291L, 1292L, 1293L, 1294L, 1295L, 1296L, 1297L, 1298L,
1299L, 1300L, 1301L, 1302L, 1303L, 1304L, 1305L, 1306L, 1307L,
1308L, 1309L, 1310L, 1311L, 1312L, 1313L, 1314L, 1315L, 1316L,
1317L, 1318L, 1319L, 1320L, 1321L, 1322L, 1323L, 1324L, 1325L,
1326L, 1327L, 1328L, 1329L, 1330L, 1331L, 1332L, 1333L, 1334L,
1335L, 1336L, 1337L, 1338L, 1339L, 1340L, 1341L, 1342L, 1343L,
1344L, 1345L, 1346L, 1347L, 1348L, 1349L, 1350L, 1351L, 1352L,
1353L, 1354L, 1355L, 1356L, 1357L, 1358L, 1359L, 1360L, 1361L,
1362L, 1363L, 1364L, 1365L, 1366L, 1367L, 1368L, 1369L, 1370L,
1371L, 1372L, 1373L, 1374L, 1375L, 1376L, 1377L, 1378L, 1379L,
1380L, 1381L, 1382L, 1383L, 1384L, 1385L, 1386L, 1387L, 1388L,
1389L, 1390L, 1391L, 1392L, 1393L, 1394L, 1395L, 1396L, 1397L,
1398L, 1399L, 1400L, 1401L, 1402L, 1403L, 1404L, 1405L, 1406L,
1407L, 1408L, 1409L, 1410L, 1411L, 1412L, 1413L, 1414L, 1415L,
1416L, 1417L, 1418L, 1419L, 1420L, 1421L, 1422L, 1423L, 1424L,
1425L, 1426L, 1427L, 1428L, 1429L, 1430L, 1431L, 1432L, 1433L,
1434L, 1435L, 1436L, 1437L, 1438L, 1439L, 1440L, 1441L, 1442L,
1443L, 1444L, 1445L, 1446L, 1447L, 1448L, 1449L, 1450L, 1451L,
1452L, 1453L, 1454L, 1455L, 1456L, 1457L, 1458L, 1459L, 1460L,
1461L, 1462L, 1463L, 1464L, 1465L, 1466L, 1467L, 1468L, 1469L,
1470L, 1471L, 1472L, 1473L, 1474L, 1475L, 1476L, 1477L, 1478L,
1479L, 1480L, 1481L, 1482L, 1483L, 1484L, 1485L, 1486L, 1487L,
1488L, 1489L, 1490L, 1491L, 1492L, 1493L, 1494L, 1495L, 1496L,
1497L, 1498L, 1499L, 1500L, 1501L, 1502L, 1503L, 1504L, 1505L,
1506L, 1507L, 1508L, 1509L, 1510L, 1511L, 1512L, 1513L, 1514L,
1515L, 1516L, 1517L, 1518L, 1519L, 1520L, 1521L, 1522L, 1523L,
1524L, 1525L, 1526L, 1527L, 1528L, 1529L, 1530L, 1531L, 1532L,
1533L, 1534L, 1535L, 1536L, 1537L, 1538L, 1539L, 1540L, 1541L,
1542L, 1543L, 1544L, 1545L, 1546L, 1547L, 1548L, 1549L, 1550L,
1551L, 1552L, 1553L, 1554L, 1555L, 1556L, 1557L, 1558L, 1559L,
1560L, 1561L, 1562L, 1563L, 1564L, 1565L, 1566L, 1567L, 1568L,
1569L, 1570L, 1571L, 1572L, 1573L, 1574L, 1575L, 1576L, 1577L,
1578L, 1579L, 1580L, 1581L, 1582L, 1583L, 1584L, 1585L, 1586L,
1587L, 1588L, 1589L, 1590L, 1591L, 1592L, 1593L, 1594L, 1595L,
1596L, 1597L, 1598L, 1599L, 1600L, 1601L, 1602L, 1603L, 1604L,
1605L, 1606L, 1607L, 1608L, 1609L, 1610L, 1611L, 1612L, 1613L,
1614L, 1615L, 1616L, 1617L, 1618L, 1619L, 1620L, 1621L, 1622L,
1623L, 1624L, 1625L, 1626L, 1627L, 1628L, 1629L, 1630L, 1631L,
1632L, 1633L, 1634L, 1635L, 1636L, 1637L, 1638L, 1639L, 1640L,
1641L, 1642L, 1643L, 1644L, 1645L, 1646L, 1647L, 1648L, 1649L,
1650L, 1651L, 1652L, 1653L, 1654L, 1655L, 1656L, 1657L, 1658L,
1659L, 1660L, 1661L, 1662L, 1663L, 1664L, 1665L, 1666L, 1667L,
1668L, 1669L, 1670L, 1671L, 1672L, 1673L, 1674L, 1675L, 1676L,
1677L, 1678L, 1679L, 1680L, 1681L, 1682L, 1683L, 1684L, 1685L,
1686L, 1687L, 1688L, 1689L, 1690L, 1691L, 1692L, 1693L, 1694L,
1695L, 1696L, 1697L, 1698L, 1699L, 1700L, 1701L, 1702L, 1703L,
1704L, 1705L, 1706L, 1707L, 1708L, 1709L, 1710L, 1711L, 1712L,
1713L, 1714L, 1715L, 1716L, 1717L, 1718L, 1719L, 1720L, 1721L,
1722L, 1723L, 1724L, 1725L, 1726L, 1727L, 1728L, 1729L, 1730L,
1731L, 1732L, 1733L, 1734L, 1735L, 1736L, 1737L, 1738L, 1739L,
1740L, 1741L, 1742L, 1743L, 1744L, 1745L, 1746L, 1747L, 1748L,
1749L, 1750L, 1751L, 1752L, 1753L, 1754L, 1755L, 1756L, 1757L,
1758L, 1759L, 1760L, 1761L, 1762L, 1763L, 1764L, 1765L, 1766L,
1767L, 1768L, 1769L, 1770L, 1771L, 1772L, 1773L, 1774L, 1775L,
1776L, 1777L, 1778L, 1779L, 1780L, 1781L, 1782L, 1783L, 1784L,
1785L, 1786L, 1787L, 1788L, 1789L, 1790L, 1791L, 1792L, 1793L,
1794L, 1795L, 1796L, 1797L, 1798L, 1799L, 1800L, 1801L, 1802L,
1803L, 1804L, 1805L, 1806L, 1807L, 1808L, 1809L, 1810L, 1811L,
1812L, 1813L, 1814L, 1815L, 1816L, 1817L, 1818L, 1819L, 1820L,
1821L, 1822L, 1823L, 1824L, 1825L, 1826L, 1827L, 1828L, 1829L,
1830L, 1831L, 1832L, 1833L, 1834L, 1835L, 1836L, 1837L, 1838L,
1839L, 1840L, 1841L, 1842L, 1843L, 1844L, 1845L, 1846L, 1847L,
1848L, 1849L, 1850L, 1851L, 1852L, 1853L, 1854L, 1855L, 1856L,
1857L, 3715L, 3716L, 3717L, 3718L, 3719L, 3720L, 3721L, 3722L,
3723L, 3724L, 3725L, 3726L, 3727L, 3728L, 3729L, 3730L, 3731L,
3732L, 3733L, 3734L, 3735L, 3736L, 3737L, 3738L, 3739L, 3740L,
3741L, 3742L, 3743L, 3744L, 3745L, 3746L, 3747L, 3748L, 3749L,
3750L, 3751L, 3752L, 3753L, 3754L, 3755L, 3756L, 3757L, 3758L,
3759L, 3760L, 3761L, 3762L, 3763L, 3764L, 3765L, 3766L, 3767L,
3768L, 3769L, 3770L, 3771L, 3772L, 3773L, 3774L, 3775L, 3776L,
3777L, 3778L, 3779L, 3780L, 3781L, 3782L, 3783L, 3784L, 3785L,
3786L, 3787L, 3788L, 3789L, 3790L, 3791L, 3792L, 3793L, 3794L,
3795L, 3796L, 3797L, 3798L, 3799L, 3800L, 3801L, 3802L, 3803L,
3804L, 3805L, 3806L, 3807L, 3808L, 3809L, 3810L, 3811L, 3812L,
3813L, 3814L, 3815L, 3816L, 3817L, 3818L, 3819L, 3820L, 3821L,
3822L, 3823L, 3824L, 3825L, 3826L, 3827L, 3828L, 3829L, 3830L,
3831L, 3832L, 3833L, 3834L, 3835L, 3836L, 3837L, 3838L, 3839L,
3840L, 3841L, 3842L, 3843L, 3844L, 3845L, 3846L, 3847L, 3848L,
3849L, 3850L, 3851L, 3852L, 3853L, 3854L, 3855L, 3856L, 3857L,
3858L, 3859L, 3860L, 3861L, 3862L, 3863L, 3864L, 3865L, 3866L,
3867L, 3868L, 3869L, 3870L, 3871L, 3872L, 3873L, 3874L, 3875L,
3876L, 3877L, 3878L, 3879L, 3880L, 3881L, 3882L, 3883L, 1858L,
1859L, 1860L, 1861L, 1862L, 1863L, 1864L, 1865L, 1866L, 1867L,
1868L, 1869L, 1870L, 1871L, 1872L, 1873L, 1874L, 1875L, 1876L,
1877L, 1878L, 1879L, 1880L, 1881L, 1882L, 1883L, 1884L, 1885L,
1886L, 1887L, 1888L, 1889L, 1890L, 1891L, 1892L, 1893L, 1894L,
1895L, 1896L, 1897L, 1898L, 1899L, 1900L, 1901L, 1902L, 1903L,
1904L, 1905L, 1906L, 1907L, 1908L, 1909L, 1910L, 1911L, 1912L,
1913L, 1914L, 1915L, 1916L, 1917L, 1918L, 1919L, 1920L, 1921L,
1922L, 1923L, 1924L, 1925L, 1926L, 1927L, 1928L, 1929L, 1930L,
1931L, 1932L, 1933L, 1934L, 1935L, 1936L, 1937L, 1938L, 1939L,
1940L, 1941L, 1942L, 1943L, 1944L, 1945L, 1946L, 1947L, 1948L,
1949L, 1950L, 1951L, 1952L, 1953L, 1954L, 1955L, 1956L, 1957L,
1958L, 1959L, 1960L, 1961L, 1962L, 1963L, 1964L, 1965L, 1966L,
1967L, 1968L, 1969L, 1970L, 1971L, 1972L, 1973L, 1974L, 1975L,
1976L, 1977L, 1978L, 1979L, 1980L, 1981L, 1982L, 1983L, 1984L,
1985L, 1986L, 1987L, 1988L, 1989L, 1990L, 1991L, 1992L, 1993L,
1994L, 1995L, 1996L, 1997L, 1998L, 1999L, 2000L, 2001L, 2002L,
2003L, 2004L, 2005L, 2006L, 2007L, 2008L, 2009L, 2010L, 2011L,
2012L, 2013L, 2014L, 2015L, 2016L, 2017L, 2018L, 2019L, 2020L,
2021L, 2022L, 2023L, 2024L, 2025L, 2026L, 2027L, 2028L, 2029L,
2030L, 2031L, 2032L, 2033L, 2034L, 2035L, 2036L, 2037L, 2038L,
2039L, 2040L, 2041L, 2042L, 2043L, 2044L, 2045L, 2046L, 2047L,
2048L, 2049L, 2050L, 2051L, 2052L, 2053L, 2054L, 2055L, 2056L,
2057L, 2058L, 2059L, 2060L, 2061L, 2062L, 2063L, 2064L, 2065L,
2066L, 2067L, 2068L, 2069L, 2070L, 2071L, 2072L, 2073L, 2074L,
2075L, 2076L, 2077L, 2078L, 2079L, 2080L, 2081L, 2082L, 2083L,
2084L, 2085L, 2086L, 2087L, 2088L, 2089L, 2090L, 2091L, 2092L,
2093L, 2094L, 2095L, 2096L, 2097L, 2098L, 2099L, 2100L, 2101L,
2102L, 2103L, 2104L, 2105L, 2106L, 2107L, 2108L, 2109L, 2110L,
2111L, 2112L, 2113L, 2114L, 2115L, 2116L, 2117L, 2118L, 2119L,
2120L, 2121L, 2122L, 2123L, 2124L, 2125L, 2126L, 2127L, 2128L,
2129L, 2130L, 2131L, 2132L, 2133L, 2134L, 2135L, 2136L, 2137L,
2138L, 2139L, 2140L, 2141L, 2142L, 2143L, 2144L, 2145L, 2146L,
2147L, 2148L, 2149L, 2150L, 2151L, 2152L, 2153L, 2154L, 2155L,
2156L, 2157L, 2158L, 2159L, 2160L, 2161L, 2162L, 2163L, 2164L,
2165L, 2166L, 2167L, 2168L, 2169L, 2170L, 2171L, 2172L, 2173L,
2174L, 2175L, 2176L, 2177L, 2178L, 2179L, 2180L, 2181L, 2182L,
2183L, 2184L, 2185L, 2186L, 2187L, 2188L, 2189L, 2190L, 2191L,
2192L, 2193L, 2194L, 2195L, 2196L, 2197L, 2198L, 2199L, 2200L,
2201L, 2202L, 2203L, 2204L, 2205L, 2206L, 2207L, 2208L, 2209L,
2210L, 2211L, 2212L, 2213L, 2214L, 2215L, 2216L, 2217L, 2218L,
2219L, 2220L, 2221L, 2222L, 2223L, 2224L, 2225L, 2226L, 2227L,
2228L, 2229L, 2230L, 2231L, 2232L, 2233L, 2234L, 2235L, 2236L,
2237L, 2238L, 2239L, 2240L, 2241L, 2242L, 2243L, 2244L, 2245L,
2246L, 2247L, 2248L, 2249L, 2250L, 2251L, 2252L, 2253L, 2254L,
2255L, 2256L, 2257L, 2258L, 2259L, 2260L, 2261L, 2262L, 2263L,
2264L, 2265L, 2266L, 2267L, 2268L, 2269L, 2270L, 2271L, 2272L,
2273L, 2274L, 2275L, 2276L, 2277L, 2278L, 2279L, 2280L, 2281L,
2282L, 2283L, 2284L, 2285L, 2286L, 2287L, 2288L, 2289L, 2290L,
2291L, 2292L, 2293L, 2294L, 2295L, 2296L, 2297L, 2298L, 2299L,
2300L, 2301L, 2302L, 2303L, 2304L, 2305L, 2306L, 2307L, 2308L,
2309L, 2310L, 2311L, 2312L, 2313L, 2314L, 2315L, 2316L, 2317L,
2318L, 2319L, 2320L, 2321L, 2322L, 2323L, 2324L, 2325L, 2326L,
2327L, 2328L, 2329L, 2330L, 2331L, 2332L, 2333L, 2334L, 2335L,
2336L, 2337L, 2338L, 2339L, 2340L, 2341L, 2342L, 2343L, 2344L,
2345L, 2346L, 2347L, 2348L, 2349L, 2350L, 2351L, 2352L, 2353L,
2354L, 2355L, 2356L, 2357L, 2358L, 2359L, 2360L, 2361L, 2362L,
2363L, 2364L, 2365L, 2366L, 2367L, 2368L, 2369L, 2370L, 2371L,
2372L, 2373L, 2374L, 2375L, 2376L, 2377L, 2378L, 2379L, 2380L,
2381L, 2382L, 2383L, 2384L, 2385L, 2386L, 2387L, 2388L, 2389L,
2390L, 2391L, 2392L, 2393L, 2394L, 2395L, 2396L, 2397L, 2398L,
2399L, 2400L, 2401L, 2402L, 2403L, 2404L, 2405L, 2406L, 2407L,
2408L, 2409L, 2410L, 2411L, 2412L, 2413L, 2414L, 2415L, 2416L,
2417L, 2418L, 2419L, 2420L, 2421L, 2422L, 2423L, 2424L, 2425L,
2426L, 2427L, 2428L, 2429L, 2430L, 2431L, 2432L, 2433L, 2434L,
2435L, 2436L, 2437L, 2438L, 2439L, 2440L, 2441L, 2442L, 2443L,
2444L, 2445L, 2446L, 2447L, 2448L, 2449L, 2450L, 2451L, 2452L,
2453L, 2454L, 2455L, 2456L, 2457L, 2458L, 2459L, 2460L, 2461L,
2462L, 2463L, 2464L, 2465L, 2466L, 2467L, 2468L, 2469L, 2470L,
2471L, 2472L, 2473L, 2474L, 2475L, 2476L, 2477L, 2478L, 2479L,
2480L, 2481L, 2482L, 2483L, 2484L, 2485L, 2486L, 2487L, 2488L,
2489L, 2490L, 2491L, 2492L, 2493L, 2494L, 2495L, 2496L, 2497L,
2498L, 2499L, 2500L, 2501L, 2502L, 2503L, 2504L, 2505L, 2506L,
2507L, 2508L, 2509L, 2510L, 2511L, 2512L, 2513L, 2514L, 2515L,
2516L, 2517L, 2518L, 2519L, 2520L, 2521L, 2522L, 2523L, 2524L,
2525L, 2526L, 2527L, 2528L, 2529L, 2530L, 2531L, 2532L, 2533L,
2534L, 2535L, 2536L, 2537L, 2538L, 2539L, 2540L, 2541L, 2542L,
2543L, 2544L, 2545L, 2546L, 2547L, 2548L, 2549L, 2550L, 2551L,
2552L, 2553L, 2554L, 2555L, 2556L, 2557L, 2558L, 2559L, 2560L,
2561L, 2562L, 2563L, 2564L, 2565L, 2566L, 2567L, 2568L, 2569L,
2570L, 2571L, 2572L, 2573L, 2574L, 2575L, 2576L, 2577L, 2578L,
2579L, 2580L, 2581L, 2582L, 2583L, 2584L, 2585L, 2586L, 2587L,
2588L, 2589L, 2590L, 2591L, 2592L, 2593L, 2594L, 2595L, 2596L,
2597L, 2598L, 2599L, 2600L, 2601L, 2602L, 2603L, 2604L, 2605L,
2606L, 2607L, 2608L, 2609L, 2610L, 2611L, 2612L, 2613L, 2614L,
2615L, 2616L, 2617L, 2618L, 2619L, 2620L, 2621L, 2622L, 2623L,
2624L, 2625L, 2626L, 2627L, 2628L, 2629L, 2630L, 2631L, 2632L,
2633L, 2634L, 2635L, 2636L, 2637L, 2638L, 2639L, 2640L, 2641L,
2642L, 2643L, 2644L, 2645L, 2646L, 2647L, 2648L, 2649L, 2650L,
2651L, 2652L, 2653L, 2654L, 2655L, 2656L, 2657L, 2658L, 2659L,
2660L, 2661L, 2662L, 2663L, 2664L, 2665L, 2666L, 2667L, 2668L,
2669L, 2670L, 2671L, 2672L, 2673L, 2674L, 2675L, 2676L, 2677L,
2678L, 2679L, 2680L, 2681L, 2682L, 2683L, 2684L, 2685L, 2686L,
2687L, 2688L, 2689L, 2690L, 2691L, 2692L, 2693L, 2694L, 2695L,
2696L, 2697L, 2698L, 2699L, 2700L, 2701L, 2702L, 2703L, 2704L,
2705L, 2706L, 2707L, 2708L, 2709L, 2710L, 2711L, 2712L, 2713L,
2714L, 2715L, 2716L, 2717L, 2718L, 2719L, 2720L, 2721L, 2722L,
2723L, 2724L, 2725L, 2726L, 2727L, 2728L, 2729L, 2730L, 2731L,
2732L, 2733L, 2734L, 2735L, 2736L, 2737L, 2738L, 2739L, 2740L,
2741L, 2742L, 2743L, 2744L, 2745L, 2746L, 2747L, 2748L, 2749L,
2750L, 2751L, 2752L, 2753L, 2754L, 2755L, 2756L, 2757L, 2758L,
2759L, 2760L, 2761L, 2762L, 2763L, 2764L, 2765L, 2766L, 2767L,
2768L, 2769L, 2770L, 2771L, 2772L, 2773L, 2774L, 2775L, 2776L,
2777L, 2778L, 2779L, 2780L, 2781L, 2782L, 2783L, 2784L, 2785L,
2786L, 2787L, 2788L, 2789L, 2790L, 2791L, 2792L, 2793L, 2794L,
2795L, 2796L, 2797L, 2798L, 2799L, 2800L, 2801L, 2802L, 2803L,
2804L, 2805L, 2806L, 2807L, 2808L, 2809L, 2810L, 2811L, 2812L,
2813L, 2814L, 2815L, 2816L, 2817L, 2818L, 2819L, 2820L, 2821L,
2822L, 2823L, 2824L, 2825L, 2826L, 2827L, 2828L, 2829L, 2830L,
2831L, 2832L, 2833L, 2834L, 2835L, 2836L, 2837L, 2838L, 2839L,
2840L, 2841L, 2842L, 2843L, 2844L, 2845L, 2846L, 2847L, 2848L,
2849L, 2850L, 2851L, 2852L, 2853L, 2854L, 2855L, 2856L, 2857L,
2858L, 2859L, 2860L, 2861L, 2862L, 2863L, 2864L, 2865L, 2866L,
2867L, 2868L, 2869L, 2870L, 2871L, 2872L, 2873L, 2874L, 2875L,
2876L, 2877L, 2878L, 2879L, 2880L, 2881L, 2882L, 2883L, 2884L,
2885L, 2886L, 2887L, 2888L, 2889L, 2890L, 2891L, 2892L, 2893L,
2894L, 2895L, 2896L, 2897L, 2898L, 2899L, 2900L, 2901L, 2902L,
2903L, 2904L, 2905L, 2906L, 2907L, 2908L, 2909L, 2910L, 2911L,
2912L, 2913L, 2914L, 2915L, 2916L, 2917L, 2918L, 2919L, 2920L,
2921L, 2922L, 2923L, 2924L, 2925L, 2926L, 2927L, 2928L, 2929L,
2930L, 2931L, 2932L, 2933L, 2934L, 2935L, 2936L, 2937L, 2938L,
2939L, 2940L, 2941L, 2942L, 2943L, 2944L, 2945L, 2946L, 2947L,
2948L, 2949L, 2950L, 2951L, 2952L, 2953L, 2954L, 2955L, 2956L,
2957L, 2958L, 2959L, 2960L, 2961L, 2962L, 2963L, 2964L, 2965L,
2966L, 2967L, 2968L, 2969L, 2970L, 2971L, 2972L, 2973L, 2974L,
2975L, 2976L, 2977L, 2978L, 2979L, 2980L, 2981L, 2982L, 2983L,
2984L, 2985L, 2986L, 2987L, 2988L, 2989L, 2990L, 2991L, 2992L,
2993L, 2994L, 2995L, 2996L, 2997L, 2998L, 2999L, 3000L, 3001L,
3002L, 3003L, 3004L, 3005L, 3006L, 3007L, 3008L, 3009L, 3010L,
3011L, 3012L, 3013L, 3014L, 3015L, 3016L, 3017L, 3018L, 3019L,
3020L, 3021L, 3022L, 3023L, 3024L, 3025L, 3026L, 3027L, 3028L,
3029L, 3030L, 3031L, 3032L, 3033L, 3034L, 3035L, 3036L, 3037L,
3038L, 3039L, 3040L, 3041L, 3042L, 3043L, 3044L, 3045L, 3046L,
3047L, 3048L, 3049L, 3050L, 3051L, 3052L, 3053L, 3054L, 3055L,
3056L, 3057L, 3058L, 3059L, 3060L, 3061L, 3062L, 3063L, 3064L,
3065L, 3066L, 3067L, 3068L, 3069L, 3070L, 3071L, 3072L, 3073L,
3074L, 3075L, 3076L, 3077L, 3078L, 3079L, 3080L, 3081L, 3082L,
3083L, 3084L, 3085L, 3086L, 3087L, 3088L, 3089L, 3090L, 3091L,
3092L, 3093L, 3094L, 3095L, 3096L, 3097L, 3098L, 3099L, 3100L,
3101L, 3102L, 3103L, 3104L, 3105L, 3106L, 3107L, 3108L, 3109L,
3110L, 3111L, 3112L, 3113L, 3114L, 3115L, 3116L, 3117L, 3118L,
3119L, 3120L, 3121L, 3122L, 3123L, 3124L, 3125L, 3126L, 3127L,
3128L, 3129L, 3130L, 3131L, 3132L, 3133L, 3134L, 3135L, 3136L,
3137L, 3138L, 3139L, 3140L, 3141L, 3142L, 3143L, 3144L, 3145L,
3146L, 3147L, 3148L, 3149L, 3150L, 3151L, 3152L, 3153L, 3154L,
3155L, 3156L, 3157L, 3158L, 3159L, 3160L, 3161L, 3162L, 3163L,
3164L, 3165L, 3166L, 3167L, 3168L, 3169L, 3170L, 3171L, 3172L,
3173L, 3174L, 3175L, 3176L, 3177L, 3178L, 3179L, 3180L, 3181L,
3182L, 3183L, 3184L, 3185L, 3186L, 3187L, 3188L, 3189L, 3190L,
3191L, 3192L, 3193L, 3194L, 3195L, 3196L, 3197L, 3198L, 3199L,
3200L, 3201L, 3202L, 3203L, 3204L, 3205L, 3206L, 3207L, 3208L,
3209L, 3210L, 3211L, 3212L, 3213L, 3214L, 3215L, 3216L, 3217L,
3218L, 3219L, 3220L, 3221L, 3222L, 3223L, 3224L, 3225L, 3226L,
3227L, 3228L, 3229L, 3230L, 3231L, 3232L, 3233L, 3234L, 3235L,
3236L, 3237L, 3238L, 3239L, 3240L, 3241L, 3242L, 3243L, 3244L,
3245L, 3246L, 3247L, 3248L, 3249L, 3250L, 3251L, 3252L, 3253L,
3254L, 3255L, 3256L, 3257L, 3258L, 3259L, 3260L, 3261L, 3262L,
3263L, 3264L, 3265L, 3266L, 3267L, 3268L, 3269L, 3270L, 3271L,
3272L, 3273L, 3274L, 3275L, 3276L, 3277L, 3278L, 3279L, 3280L,
3281L, 3282L, 3283L, 3284L, 3285L, 3286L, 3287L, 3288L, 3289L,
3290L, 3291L, 3292L, 3293L, 3294L, 3295L, 3296L, 3297L, 3298L,
3299L, 3300L, 3301L, 3302L, 3303L, 3304L, 3305L, 3306L, 3307L,
3308L, 3309L, 3310L, 3311L, 3312L, 3313L, 3314L, 3315L, 3316L,
3317L, 3318L, 3319L, 3320L, 3321L, 3322L, 3323L, 3324L, 3325L,
3326L, 3327L, 3328L, 3329L, 3330L, 3331L, 3332L, 3333L, 3334L,
3335L, 3336L, 3337L, 3338L, 3339L, 3340L, 3341L, 3342L, 3343L,
3344L, 3345L, 3346L, 3347L, 3348L, 3349L, 3350L, 3351L, 3352L,
3353L, 3354L, 3355L, 3356L, 3357L, 3358L, 3359L, 3360L, 3361L,
3362L, 3363L, 3364L, 3365L, 3366L, 3367L, 3368L, 3369L, 3370L,
3371L, 3372L, 3373L, 3374L, 3375L, 3376L, 3377L, 3378L, 3379L,
3380L, 3381L, 3382L, 3383L, 3384L, 3385L, 3386L, 3387L, 3388L,
3389L, 3390L, 3391L, 3392L, 3393L, 3394L, 3395L, 3396L, 3397L,
3398L, 3399L, 3400L, 3401L, 3402L, 3403L, 3404L, 3405L, 3406L,
3407L, 3408L, 3409L, 3410L, 3411L, 3412L, 3413L, 3414L, 3415L,
3416L, 3417L, 3418L, 3419L, 3420L, 3421L, 3422L, 3423L, 3424L,
3425L, 3426L, 3427L, 3428L, 3429L, 3430L, 3431L, 3432L, 3433L,
3434L, 3435L, 3436L, 3437L, 3438L, 3439L, 3440L, 3441L, 3442L,
3443L, 3444L, 3445L, 3446L, 3447L, 3448L, 3449L, 3450L, 3451L,
3452L, 3453L, 3454L, 3455L, 3456L, 3457L, 3458L, 3459L, 3460L,
3461L, 3462L, 3463L, 3464L, 3465L, 3466L, 3467L, 3468L, 3469L,
3470L, 3471L, 3472L, 3473L, 3474L, 3475L, 3476L, 3477L, 3478L,
3479L, 3480L, 3481L, 3482L, 3483L, 3484L, 3485L, 3486L, 3487L,
3488L, 3489L, 3490L, 3491L, 3492L, 3493L, 3494L, 3495L, 3496L,
3497L, 3498L, 3499L, 3500L, 3501L, 3502L, 3503L, 3504L, 3505L,
3506L, 3507L, 3508L, 3509L, 3510L, 3511L, 3512L, 3513L, 3514L,
3515L, 3516L, 3517L, 3518L, 3519L, 3520L, 3521L, 3522L, 3523L,
3524L, 3525L, 3526L, 3527L, 3528L, 3529L, 3530L, 3531L, 3532L,
3533L, 3534L, 3535L, 3536L, 3537L, 3538L, 3539L, 3540L, 3541L,
3542L, 3543L, 3544L, 3545L, 3546L, 3547L, 3548L, 3549L, 3550L,
3551L, 3552L, 3553L, 3554L, 3555L, 3556L, 3557L, 3558L, 3559L,
3560L, 3561L, 3562L, 3563L, 3564L, 3565L, 3566L, 3567L, 3568L,
3569L, 3570L, 3571L, 3572L, 3573L, 3574L, 3575L, 3576L, 3577L,
3578L, 3579L, 3580L, 3581L, 3582L, 3583L, 3584L, 3585L, 3586L,
3587L, 3588L, 3589L, 3590L, 3591L, 3592L, 3593L, 3594L, 3595L,
3596L, 3597L, 3598L, 3599L, 3600L, 3601L, 3602L, 3603L, 3604L,
3605L, 3606L, 3607L, 3608L, 3609L, 3610L, 3611L, 3612L, 3613L,
3614L, 3615L, 3616L, 3617L, 3618L, 3619L, 3620L, 3621L, 3622L,
3623L, 3624L, 3625L, 3626L, 3627L, 3628L, 3629L, 3630L, 3631L,
3632L, 3633L, 3634L, 3635L, 3636L, 3637L, 3638L, 3639L, 3640L,
3641L, 3642L, 3643L, 3644L, 3645L, 3646L, 3647L, 3648L, 3649L,
3650L, 3651L, 3652L, 3653L, 3654L, 3655L, 3656L, 3657L, 3658L,
3659L, 3660L, 3661L, 3662L, 3663L, 3664L, 3665L, 3666L, 3667L,
3668L, 3669L, 3670L, 3671L, 3672L, 3673L, 3674L, 3675L, 3676L,
3677L, 3678L, 3679L, 3680L, 3681L, 3682L, 3683L, 3684L, 3685L,
3686L, 3687L, 3688L, 3689L, 3690L, 3691L, 3692L, 3693L, 3694L,
3695L, 3696L, 3697L, 3698L, 3699L, 3700L, 3701L, 3702L, 3703L,
3704L, 3705L, 3706L, 3707L, 3708L, 3709L, 3710L, 3711L, 3712L,
3713L, 3714L, 3884L, 3885L, 3886L, 3887L, 3888L, 3889L, 3890L,
3891L, 3892L, 3893L, 3894L, 3895L, 3896L, 3897L, 3898L, 3899L,
3900L, 3901L, 3902L, 3903L, 3904L, 3905L, 3906L, 3907L, 3908L,
3909L, 3910L, 3911L, 3912L, 3913L, 3914L, 3915L, 3916L, 3917L,
3918L, 3919L, 3920L, 3921L, 3922L, 3923L, 3924L, 3925L, 3926L,
3927L, 3928L, 3929L, 3930L, 3931L, 3932L, 3933L, 3934L, 3935L,
3936L, 3937L, 3938L, 3939L, 3940L, 3941L, 3942L, 3943L, 3944L,
3945L, 3946L, 3947L, 3948L, 3949L, 3950L, 3951L, 3952L, 3953L,
3954L, 3955L, 3956L, 3957L, 3958L, 3959L, 3960L, 3961L, 3962L,
3963L, 3964L, 3965L, 3966L, 3967L, 3968L, 3969L, 3970L, 3971L,
3972L, 3973L, 3974L, 3975L, 3976L, 3977L, 3978L, 3979L, 3980L,
3981L, 3982L, 3983L, 3984L, 3985L, 3986L, 3987L, 3988L, 3989L,
3990L, 3991L, 3992L, 3993L, 3994L, 3995L, 3996L, 3997L, 3998L,
3999L, 4000L, 4001L, 4002L, 4003L, 4004L, 4005L, 4006L, 4007L,
4008L, 4009L, 4010L, 4011L, 4012L, 4013L, 4014L, 4015L, 4016L,
4017L, 4018L, 4019L, 4020L, 4021L, 4022L, 4023L, 4024L, 4025L,
4026L, 4027L, 4028L, 4029L, 4030L, 4031L, 4032L, 4033L, 4034L,
4035L, 4036L, 4037L, 4038L, 4039L, 4040L, 4041L, 4042L, 4043L,
4044L, 4045L, 4046L, 4047L, 4048L, 4049L, 4050L, 4051L, 4052L,
4053L, 4054L, 4055L, 4056L, 4057L, 4058L, 4059L, 4060L, 4061L,
4062L, 4063L, 4064L, 4065L, 4066L, 4067L, 4068L, 4069L, 4070L,
4071L, 4072L, 4073L, 4074L, 4075L, 4076L, 4077L, 4078L, 4079L,
4080L, 4081L, 4082L, 4083L, 4084L, 4085L, 4086L, 4087L, 4088L,
4089L, 4090L, 4091L, 4092L, 4093L, 4094L, 4095L, 4096L, 4097L,
4098L, 4099L, 4100L, 4101L, 4102L, 4103L, 4104L, 4105L, 4106L,
4107L, 4108L, 4109L, 4110L, 4111L, 4112L, 4113L, 4114L, 4115L,
4116L, 4117L, 4118L, 4119L, 4120L, 4121L, 4122L, 4123L, 4124L,
4125L, 4126L, 4127L, 4128L, 4129L, 4130L, 4131L, 4132L, 4133L,
4134L, 4135L, 4136L, 4137L, 4138L, 4139L, 4140L, 4141L, 4142L,
4143L, 4144L, 4145L, 4146L, 4147L, 4148L, 4149L, 4150L, 4151L,
4152L, 4153L, 4154L, 4155L, 4156L, 4157L, 4158L, 4159L, 4160L,
4161L, 4162L, 4163L, 4164L, 4165L, 4166L, 4167L, 4168L, 4169L,
4170L, 4171L, 4172L, 4173L, 4174L, 4175L, 4176L, 4177L, 4178L,
4179L, 4180L, 4181L, 4182L, 4183L, 4184L, 4185L, 4186L, 4187L,
4188L, 4189L, 4190L, 4191L, 4192L, 4193L, 4194L, 4195L, 4196L,
4197L, 4198L, 4199L, 4200L, 4201L, 4202L, 4203L, 4204L, 4205L,
4206L, 4207L, 4208L, 4209L, 4210L, 4211L, 4212L, 4213L, 4214L,
4215L, 4216L, 4217L, 4218L, 4219L, 4220L, 4221L, 4222L, 4223L,
4224L, 4225L, 4226L, 4227L, 4228L, 4229L, 4230L, 4231L, 4232L,
4233L, 4234L, 4235L, 4236L, 4237L, 4238L, 4239L, 4240L, 4241L,
4242L, 4243L, 4244L, 4245L, 4246L, 4247L, 4248L, 4249L, 4250L,
4251L, 4252L, 4253L, 4254L, 4255L, 4256L, 4257L, 4258L, 4259L,
4260L, 4261L, 4262L, 4263L, 4264L, 4265L, 4266L, 4267L, 4268L,
4269L, 4270L, 4271L, 4272L, 4273L, 4274L, 4275L, 4276L, 4277L,
4278L, 4279L, 4280L, 4281L, 4282L, 4283L, 4284L, 4285L, 4286L,
4287L, 4288L, 4289L, 4290L, 4291L, 4292L, 4293L, 4294L, 4295L,
4296L, 4297L, 4298L, 4299L, 4300L, 4301L, 4302L, 4303L, 4304L,
4305L, 4306L, 4307L, 4308L, 4309L, 4310L, 4311L, 4312L, 4313L,
4314L, 4315L, 4316L, 4317L, 4318L, 4319L, 4320L, 4321L, 4322L,
4323L, 4324L, 4325L, 4326L, 4327L, 4328L, 4329L, 4330L, 4331L,
4332L, 4333L, 4334L, 4335L, 4336L, 4337L, 4338L, 4339L, 4340L,
4341L, 4342L, 4343L, 4344L, 4345L, 4346L, 4347L, 4348L, 4349L,
4350L, 4351L, 4352L, 4353L, 4354L, 4355L, 4356L, 4357L, 4358L,
4359L, 4360L, 4361L, 4362L, 4363L, 4364L, 4365L, 4366L, 4367L,
4368L, 4369L, 4370L, 4371L, 4372L, 4373L, 4374L, 4375L, 4376L,
4377L, 4378L, 4379L, 4380L, 4381L, 4382L, 4383L, 4384L, 4385L,
4386L, 4387L, 4388L, 4389L, 4390L, 4391L, 4392L, 4393L, 4394L,
4395L, 4396L, 4397L, 4398L, 4399L, 4400L, 4401L, 4402L, 4403L,
4404L, 4405L, 4406L, 4407L, 4408L, 4409L, 4410L, 4411L, 4412L,
4413L, 4414L, 4415L, 4416L, 4417L, 4418L, 4419L, 4420L, 4421L,
4422L, 4423L, 4424L, 4425L, 4426L, 4427L, 4428L, 4429L, 4430L,
4431L, 4432L, 4433L, 4434L, 4435L, 4436L, 4437L, 4438L, 4439L,
4440L, 4441L, 4442L, 4443L, 4444L, 4445L, 4446L, 4447L, 4448L,
4449L, 4450L, 4451L, 4452L, 4453L, 4454L, 4455L, 4456L, 4457L,
4458L, 4459L, 4460L, 4461L, 4462L, 4463L, 4464L, 4465L, 4466L,
4467L, 4468L, 4469L, 4470L, 4471L, 4472L, 4473L, 4474L, 4475L,
4476L, 4477L, 4478L, 4479L, 4480L, 4481L, 4482L, 4483L, 4484L,
4485L, 4486L, 4487L, 4488L, 4489L, 4490L, 4491L, 4492L, 4493L,
4494L, 4495L, 4496L, 4497L, 4498L, 4499L, 4500L, 4501L, 4502L,
4503L, 4504L, 4505L, 4506L, 4507L, 4508L, 4509L, 4510L, 4511L,
4512L, 4513L, 4514L, 4515L, 4516L, 4517L, 4518L, 4519L, 4520L,
4521L, 4522L, 4523L, 4524L, 4525L, 4526L, 4527L, 4528L, 4529L,
4530L, 4531L, 4532L, 4533L, 4534L, 4535L, 4536L, 4537L, 4538L,
4539L, 4540L, 4541L, 4542L, 4543L, 4544L, 4545L, 4546L, 4547L,
4548L, 4549L, 4550L, 4551L, 4552L, 4553L, 4554L, 4555L, 4556L,
4557L, 4558L, 4559L, 4560L, 4561L, 4562L, 4563L, 4564L, 4565L,
4566L, 4567L, 4568L, 4569L, 4570L, 4571L, 4572L, 4573L, 4574L,
4575L, 4576L, 4577L, 4578L, 4579L, 4580L, 4581L, 4582L, 4583L,
4584L, 4585L, 4586L, 4587L, 4588L, 4589L, 4590L, 4591L, 4592L,
4593L, 4594L, 4595L, 4596L, 4597L, 4598L, 4599L, 4600L, 4601L,
4602L, 4603L, 4604L, 4605L, 4606L, 4607L, 4608L, 4609L, 4610L,
4611L, 4612L, 4613L, 4614L, 4615L, 4616L, 4617L, 4618L, 4619L,
4620L, 4621L, 4622L, 4623L, 4624L, 4625L, 4626L, 4627L, 4628L,
4629L, 4630L, 4631L, 4632L, 4633L, 4634L, 4635L, 4636L, 4637L,
4638L, 4639L, 4640L, 4641L, 4642L, 4643L, 4644L, 4645L, 4646L,
4647L, 4648L, 4649L, 4650L, 4651L, 4652L, 4653L, 4654L, 4655L,
4656L, 4657L, 4658L, 4659L, 4660L, 4661L, 4662L, 4663L, 4664L,
4665L, 4666L, 4667L, 4668L, 4669L, 4670L, 4671L, 4672L, 4673L,
4674L, 4675L, 4676L, 4677L, 4678L, 4679L, 4680L, 4681L, 4682L,
4683L, 4684L, 4685L, 4686L, 4687L, 4688L, 4689L, 4690L, 4691L,
4692L, 4693L, 4694L, 4695L, 4696L, 4697L, 4698L, 4699L, 4700L,
4701L, 4702L, 4703L, 4704L, 4705L, 4706L, 4707L, 4708L, 4709L,
4710L, 4711L, 4712L, 4713L, 4714L, 4715L, 4716L, 4717L, 4718L,
4719L, 4720L, 4721L, 4722L, 4723L, 4724L, 4725L, 4726L, 4727L,
4728L, 4729L, 4730L, 4731L, 4732L, 4733L, 4734L, 4735L, 4736L,
4737L, 4738L, 4739L, 4740L, 4741L, 4742L, 4743L, 4744L, 4745L,
4746L, 4747L, 4748L, 4749L, 4750L, 4751L, 4752L, 4753L, 4754L,
4755L, 4756L, 4757L, 4758L, 4759L, 4760L, 4761L, 4762L, 4763L,
4764L, 4765L, 4766L, 4767L, 4768L, 4769L, 4770L, 4771L, 4772L,
4773L, 4774L, 4775L, 4776L, 4777L, 4778L, 4779L, 4780L, 4781L,
4782L, 4783L, 4784L, 4785L, 4786L, 4787L, 4788L, 4789L, 4790L,
4791L, 4792L, 4793L, 4794L, 4795L, 4796L, 4797L, 4798L, 4799L,
4800L, 4801L, 4802L, 4803L, 4804L, 4805L, 4806L, 4807L, 4808L,
4809L, 4810L, 4811L, 4812L, 4813L, 4814L, 4815L, 4816L, 4817L,
4818L, 4819L, 4820L, 4821L, 4822L, 4823L, 4824L, 4825L, 4826L,
4827L, 4828L, 4829L, 4830L, 4831L, 4832L, 4833L, 4834L, 4835L,
4836L, 4837L, 4838L, 4839L, 4840L, 4841L, 4842L, 4843L, 4844L,
4845L, 4846L, 4847L, 4848L, 4849L, 4850L, 4851L, 4852L, 4853L,
4854L, 4855L, 4856L, 4857L, 4858L, 4859L, 4860L, 4861L, 4862L,
4863L, 4864L, 4865L, 4866L, 4867L, 4868L, 4869L, 4870L, 4871L,
4872L, 4873L, 4874L, 4875L, 4876L, 4877L, 4878L, 4879L, 4880L,
4881L, 4882L, 4883L, 4884L, 4885L, 4886L, 4887L, 4888L, 4889L,
4890L, 4891L, 4892L, 4893L, 4894L, 4895L, 4896L, 4897L, 4898L,
4899L, 4900L, 4901L, 4902L, 4903L, 4904L, 4905L, 4906L, 4907L,
4908L, 4909L, 4910L, 4911L, 4912L, 4913L, 4914L, 4915L, 4916L,
4917L, 4918L, 4919L, 4920L, 4921L, 4922L, 4923L, 4924L, 4925L,
4926L, 4927L, 4928L, 4929L, 4930L, 4931L, 4932L, 4933L, 4934L,
4935L, 4936L, 4937L, 4938L, 4939L, 4940L, 4941L, 4942L, 4943L,
4944L, 4945L, 4946L, 4947L, 4948L, 4949L, 4950L, 4951L, 4952L,
4953L, 4954L, 4955L, 4956L, 4957L, 4958L, 4959L, 4960L, 4961L,
4962L, 4963L, 4964L, 4965L, 4966L, 4967L, 4968L, 4969L, 4970L,
4971L, 4972L, 4973L, 4974L, 4975L, 4976L, 4977L, 4978L, 4979L,
4980L, 4981L, 4982L, 4983L, 4984L, 4985L, 4986L, 4987L, 4988L,
4989L, 4990L, 4991L, 4992L, 4993L, 4994L, 4995L, 4996L, 4997L,
4998L, 4999L, 5000L, 5001L, 5002L, 5003L, 5004L, 5005L, 5006L,
5007L, 5008L, 5009L, 5010L, 5011L, 5012L, 5013L, 5014L, 5015L,
5016L, 5017L, 5018L, 5019L, 5020L, 5021L, 5022L, 5023L, 5024L,
5025L, 5026L, 5027L, 5028L, 5029L, 5030L, 5031L, 5032L, 5033L,
5034L, 5035L, 5036L, 5037L, 5038L, 5039L, 5040L, 5041L, 5042L,
5043L, 5044L, 5045L, 5046L, 5047L, 5048L, 5049L, 5050L, 5051L,
5052L, 5053L, 5054L, 5055L, 5056L, 5057L, 5058L, 5059L, 5060L,
5061L, 5062L, 5063L, 5064L, 5065L, 5066L, 5067L, 5068L, 5069L,
5070L, 5071L, 5072L, 5073L, 5074L, 5075L, 5076L, 5077L, 5078L,
5079L, 5080L, 5081L, 5082L, 5083L, 5084L, 5085L, 5086L, 5087L,
5088L, 5089L, 5090L, 5091L, 5092L, 5093L, 5094L, 5095L, 5096L,
5097L, 5098L, 5099L, 5100L, 5101L, 5102L, 5103L, 5104L, 5105L,
5106L, 5107L, 5108L, 5109L, 5110L, 5111L, 5112L, 5113L, 5114L,
5115L, 5116L, 5117L, 5118L, 5119L, 5120L, 5121L, 5122L, 5123L,
5124L, 5125L, 5126L, 5127L, 5128L, 5129L, 5130L, 5131L, 5132L,
5133L, 5134L, 5135L, 5136L, 5137L, 5138L, 5139L, 5140L, 5141L,
5142L, 5143L, 5144L, 5145L, 5146L, 5147L, 5148L, 5149L, 5150L,
5151L, 5152L, 5153L, 5154L, 5155L, 5156L, 5157L, 5158L, 5159L,
5160L, 5161L, 5162L, 5163L, 5164L, 5165L, 5166L, 5167L, 5168L,
5169L, 5170L, 5171L, 5172L, 5173L, 5174L, 5175L, 5176L, 5177L,
5178L, 5179L, 5180L, 5181L, 5182L, 5183L, 5184L, 5185L, 5186L,
5187L, 5188L, 5189L, 5190L, 5191L, 5192L, 5193L, 5194L, 5195L,
5196L, 5197L, 5198L, 5199L, 5200L, 5201L, 5202L, 5203L, 5204L,
5205L, 5206L, 5207L, 5208L, 5209L, 5210L, 5211L, 5212L, 5213L,
5214L, 5215L, 5216L, 5217L, 5218L, 5219L, 5220L, 5221L, 5222L,
5223L, 5224L, 5225L, 5226L, 5227L, 5228L, 5229L, 5230L, 5231L,
5232L, 5233L, 5234L, 5235L, 5236L, 5237L, 5238L, 5239L, 5240L,
5241L, 5242L, 5243L, 5244L, 5245L, 5246L, 5247L, 5248L, 5249L,
5250L, 5251L, 5252L, 5253L, 5254L, 5255L, 5256L, 5257L, 5258L,
5259L, 5260L, 5261L, 5262L, 5263L, 5264L, 5265L, 5266L, 5267L,
5268L, 5269L, 5270L, 5271L, 5272L, 5273L, 5274L, 5275L, 5276L,
5277L, 5278L, 5279L, 5280L, 5281L, 5282L, 5283L, 5284L, 5285L,
5286L, 5287L, 5288L, 5289L, 5290L, 5291L, 5292L, 5293L, 5294L,
5295L, 5296L, 5297L, 5298L, 5299L, 5300L, 5301L, 5302L, 5303L,
5304L, 5305L, 5306L, 5307L, 5308L, 5309L, 5310L, 5311L, 5312L,
5313L, 5314L, 5315L, 5316L, 5317L, 5318L, 5319L, 5320L, 5321L,
5322L, 5323L, 5324L, 5325L, 5326L, 5327L, 5328L, 5329L, 5330L,
5331L, 5332L, 5333L, 5334L, 5335L, 5336L, 5337L, 5338L, 5339L,
5340L, 5341L, 5342L, 5343L, 5344L, 5345L, 5346L, 5347L, 5348L,
5349L, 5350L, 5351L, 5352L, 5353L, 5354L, 5355L, 5356L, 5357L,
5358L, 5359L, 5360L, 5361L, 5362L, 5363L, 5364L, 5365L, 5366L,
5367L, 5368L, 5369L, 5370L, 5371L, 5372L, 5373L, 5374L, 5375L,
5376L, 5377L, 5378L, 5379L, 5380L, 5381L, 5382L, 5383L, 5384L,
5385L, 5386L, 5387L, 5388L, 5389L, 5390L, 5391L, 5392L, 5393L,
5394L, 5395L, 5396L, 5397L, 5398L, 5399L, 5400L, 5401L, 5402L,
5403L, 5404L, 5405L, 5406L, 5407L, 5408L, 5409L, 5410L, 5411L,
5412L, 5413L, 5414L, 5415L, 5416L, 5417L, 5418L, 5419L, 5420L,
5421L, 5422L, 5423L, 5424L, 5425L, 5426L, 5427L, 5428L, 5429L,
5430L, 5431L, 5432L, 5433L, 5434L, 5435L, 5436L, 5437L, 5438L,
5439L, 5440L, 5441L, 5442L, 5443L, 5444L, 5445L, 5446L, 5447L,
5448L, 5449L, 5450L, 5451L, 5452L, 5453L, 5454L, 5455L, 5456L,
5457L, 5458L, 5459L, 5460L, 5461L, 5462L, 5463L, 5464L, 5465L,
5466L, 5467L, 5468L, 5469L, 5470L, 5471L, 5472L, 5473L, 5474L,
5475L, 5476L, 5477L, 5478L, 5479L, 5480L, 5481L, 5482L, 5483L,
5484L, 5485L, 5486L, 5487L, 5488L, 5489L, 5490L, 5491L, 5492L,
5493L, 5494L, 5495L, 5496L, 5497L, 5498L, 5499L, 5500L, 5501L,
5502L, 5503L, 5504L, 5505L, 5506L, 5507L, 5508L, 5509L, 5510L,
5511L, 5512L, 5513L, 5514L, 5515L, 5516L, 5517L, 5518L, 5519L,
5520L, 5521L, 5522L, 5523L, 5524L, 5525L, 5526L, 5527L, 5528L,
5529L, 5530L, 5531L, 5532L, 5533L, 5534L, 5535L, 5536L, 5537L,
5538L, 5539L, 5540L, 5541L, 5542L, 5543L, 5544L, 5545L, 5546L,
5547L, 5548L, 5549L, 5550L, 5551L, 5552L, 5553L, 5554L, 5555L,
5556L, 5557L, 5558L, 5559L, 5560L, 5561L, 5562L, 5563L, 5564L,
5565L, 5566L, 5567L, 5568L, 5569L, 5570L, 5571L, 5572L, 5573L,
5574L, 5575L, 5576L, 5577L, 5578L, 5579L, 5580L, 5581L, 5582L,
5583L, 5584L, 5585L, 5586L, 5587L, 5588L, 5589L, 5590L, 5591L,
5592L, 5593L, 5594L, 5595L, 5596L, 5597L, 5598L, 5599L, 5600L,
5601L, 5602L, 5603L, 5604L, 5605L, 5606L, 5607L, 5608L, 5609L,
5610L, 5611L, 5612L, 5613L, 5614L, 5615L, 5616L, 5617L, 5618L,
5619L, 5620L, 5621L, 5622L, 5623L, 5624L, 5625L, 5626L, 5627L,
5628L, 5629L, 5630L, 5631L, 5632L, 5633L, 5634L, 5635L, 5636L,
5637L, 5638L, 5639L, 5640L, 5641L, 5642L, 5643L, 5644L, 5645L,
5646L, 5647L, 5648L, 5649L, 5650L, 5651L, 5652L, 5653L, 5654L,
5655L, 5656L, 5657L, 5658L, 5659L, 5660L, 5661L, 5662L, 5663L,
5664L, 5665L, 5666L, 5667L, 5668L, 5669L, 5670L, 5671L, 5672L,
5673L, 5674L, 5675L, 5676L, 5677L, 5678L, 5679L, 5680L, 5681L,
5682L, 5683L, 5684L, 5685L, 5686L, 5687L, 5688L, 5689L, 5690L,
5691L, 5692L, 5693L, 5694L, 5695L, 5696L, 5697L, 5698L, 5699L,
5700L, 5701L, 5702L, 5703L, 5704L, 5705L, 5706L, 5707L, 5708L,
5709L, 5710L, 5711L, 5712L, 5713L, 5714L, 5715L, 5716L, 5717L,
5718L, 5719L, 5720L, 5721L, 5722L, 5723L, 5724L, 5725L, 5726L,
5727L, 5728L, 5729L, 5730L, 5731L, 5732L, 5733L, 5734L, 5735L,
5736L, 5737L, 5738L, 5739L, 5740L, 5741L, 5742L, 5743L, 5744L,
5745L, 5746L, 5747L, 5748L, 5749L, 5750L, 5751L, 5752L, 5753L,
5754L, 5755L, 5756L, 5757L, 5758L, 5759L, 5760L, 5761L, 5762L,
5763L, 5764L, 5765L, 5766L, 5767L, 5768L, 5769L, 5770L, 5771L,
5772L, 5773L, 5774L, 5775L, 5776L, 5777L, 5778L, 5779L, 5780L,
5781L, 5782L, 5783L, 5784L, 5785L, 5786L, 5787L, 5788L, 5789L,
5790L, 5791L, 5792L, 5793L, 5794L, 5795L, 5796L, 5797L, 5798L,
5799L, 5800L, 5801L, 5802L, 5803L, 5804L, 5805L, 5806L, 5807L,
5808L, 5809L, 5810L, 5811L, 5812L, 5813L, 5814L, 5815L, 5816L,
5817L, 5818L, 5819L, 5820L, 5821L, 5822L, 5823L, 5824L, 5825L,
5826L, 5827L, 5828L, 5829L, 5830L, 5831L, 5832L, 5833L, 5834L,
5835L, 5836L, 5837L, 5838L, 5839L, 5840L, 5841L, 5842L, 5843L,
5844L, 5845L, 5846L, 5847L, 5848L, 5849L, 5850L, 5851L, 5852L,
5853L, 5854L, 5855L, 5856L, 5857L, 5858L, 5859L, 5860L, 5861L,
5862L, 5863L, 5864L, 5865L, 5866L, 5867L, 5868L, 5869L, 5870L,
5871L, 5872L, 5873L, 5874L, 5875L, 5876L, 5877L, 5878L, 5879L,
5880L, 5881L, 5882L, 5883L, 5884L, 5885L, 5886L, 5887L, 5888L,
5889L, 5890L, 5891L, 5892L, 5893L, 5894L, 5895L, 5896L, 5897L,
5898L, 5899L, 5900L, 5901L, 5902L, 5903L, 5904L, 5905L, 5906L,
5907L, 5908L, 5909L, 5910L, 5911L, 5912L, 5913L, 5914L, 5915L,
5916L, 5917L, 5918L, 5919L, 5920L, 5921L, 5922L, 5923L, 5924L,
5925L, 5926L, 5927L, 5928L, 5929L, 5930L, 5931L, 5932L, 5933L,
5934L, 5935L, 5936L, 5937L, 5938L, 5939L, 5940L, 5941L, 5942L,
5943L, 5944L, 5945L, 5946L, 5947L, 5948L, 5949L, 5950L, 5951L,
5952L, 5953L, 5954L, 5955L, 5956L, 5957L, 5958L, 5959L, 5960L,
5961L, 5962L, 5963L, 5964L, 5965L, 5966L, 5967L, 5968L, 5969L,
5970L, 5971L, 5972L, 5973L, 5974L, 5975L, 5976L, 5977L, 5978L,
5979L, 5980L, 5981L, 5982L, 5983L, 5984L, 5985L, 5986L, 5987L,
5988L, 5989L, 5990L, 5991L, 5992L, 5993L, 5994L, 5995L, 5996L,
5997L, 5998L, 5999L, 6000L, 6001L, 6002L, 6003L, 6004L, 6005L,
6006L, 6007L, 6008L, 6009L, 6010L, 6011L, 6012L, 6013L, 6014L,
6015L, 6016L, 6017L, 6018L, 6019L, 6020L, 6021L, 6022L, 6023L,
6024L, 6025L, 6026L, 6027L, 6028L, 6029L, 6030L, 6031L, 6032L,
6033L, 6034L, 6035L, 6036L, 6037L, 6038L, 6039L, 6040L, 6041L,
6042L, 6043L, 6044L, 6045L, 6046L, 6047L, 6048L, 6049L, 6050L,
6051L, 6052L, 6053L, 6054L, 6055L, 6056L, 6057L, 6058L, 6059L,
6060L, 6061L, 6062L, 6063L, 6064L, 6065L, 6066L, 6067L, 6068L,
6069L, 6070L, 6071L, 6072L, 6073L, 6074L, 6075L, 6076L, 6077L,
6078L, 6079L, 6080L, 6081L, 6082L, 6083L, 6084L, 6085L, 6086L,
6087L, 6088L, 6089L, 6090L, 6091L, 6092L, 6093L, 6094L, 6095L,
6096L, 6097L, 6098L, 6099L, 6100L, 6101L, 6102L, 6103L, 6104L,
6105L, 6106L, 6107L, 6108L, 6109L, 6110L, 6111L, 6112L, 6113L,
6114L, 6115L, 6116L, 6117L, 6118L, 6119L, 6120L, 6121L, 6122L,
6123L, 6124L, 6125L, 6126L, 6127L, 6128L, 6129L, 6130L, 6131L,
6132L, 6133L, 6134L, 6135L, 6136L, 6137L, 6138L, 6139L, 6140L,
6141L, 6142L, 6143L, 6144L, 6145L, 6146L, 6147L, 6148L, 6149L,
6150L, 6151L, 6152L, 6153L, 6154L, 6155L, 6156L, 6157L, 6158L,
6159L, 6160L, 6161L, 6162L, 6163L, 6164L, 6165L, 6166L, 6167L,
6168L, 6169L, 6170L, 6171L, 6172L, 6173L, 6174L, 6175L, 6176L,
6177L, 6178L, 6179L, 6180L, 6181L, 6182L, 6183L, 6184L, 6185L,
6186L, 6187L, 6188L, 6189L, 6190L, 6191L, 6192L, 6193L, 6194L,
6195L, 6196L, 6197L, 6198L, 6199L, 6200L, 6201L, 6202L, 6203L,
6204L, 6205L, 6206L, 6207L, 6208L, 6209L, 6210L, 6211L, 6212L,
6213L, 6214L, 6215L, 6216L, 6217L, 6218L, 6219L, 6220L, 6221L,
6222L, 6223L, 6224L, 6225L, 6226L, 6227L, 6228L, 6229L, 6230L,
6231L, 6232L, 6233L, 6234L, 6235L, 6236L, 6237L, 6238L, 6239L,
6240L, 6241L, 6242L, 6243L, 6244L, 6245L, 6246L, 6247L, 6248L,
6249L, 6250L, 6251L, 6252L, 6253L, 6254L, 6255L, 6256L, 6257L,
6258L, 6259L, 6260L, 6261L, 6262L, 6263L, 6264L, 6265L, 6266L,
6267L, 6268L, 6269L, 6270L, 6271L, 6272L, 6273L, 6274L, 6275L,
6276L, 6277L, 6278L, 6279L, 6280L, 6281L, 6282L, 6283L, 6284L,
6285L, 6286L, 6287L, 6288L, 6289L, 6290L, 6291L, 6292L, 6293L,
6294L, 6295L, 6296L, 6297L, 6298L, 6299L, 6300L, 6301L, 6302L,
6303L, 6304L, 6305L, 6306L, 6307L, 6308L, 6309L, 6310L, 6311L,
6312L, 6313L, 6314L, 6315L, 6316L, 6317L, 6318L, 6319L, 6320L,
6321L, 6322L, 6323L, 6324L, 6325L, 6326L, 6327L, 6328L, 6329L,
6330L, 6331L, 6332L, 6333L, 6334L, 6335L, 6336L, 6337L, 6338L,
6339L, 6340L, 6341L, 6342L, 6343L, 6344L, 6345L, 6346L, 6347L,
6348L, 6349L, 6350L, 6351L, 6352L, 6353L, 6354L, 6355L, 6356L,
6357L, 6358L, 6359L, 6360L, 6361L, 6362L, 6363L, 6364L, 6365L,
6366L, 6367L, 6368L, 6369L, 6370L, 6371L, 6372L, 6373L, 6374L,
6375L, 6376L, 6377L, 6378L, 6379L, 6380L, 6381L, 6382L, 6383L,
6384L, 6385L, 6386L, 6387L, 6388L, 6389L, 6390L, 6391L, 6392L,
6393L, 6394L, 6395L, 6396L, 6397L, 6398L, 6399L, 6400L, 6401L,
6402L, 6403L, 6404L, 6405L, 6406L, 6407L, 6408L, 6409L, 6410L,
6411L, 6412L, 6413L, 6414L, 6415L, 6416L, 6417L, 6418L, 6419L,
6420L, 6421L, 6422L, 6423L, 6424L, 6425L, 6426L, 6427L, 6428L,
6429L, 6430L, 6431L, 6432L, 6433L, 6434L, 6435L, 6436L, 6437L,
6438L, 6439L, 6440L, 6441L, 6442L, 6443L, 6444L, 6445L, 6446L,
6447L, 6448L, 6449L, 6450L, 6451L, 6452L, 6453L, 6454L, 6455L,
6456L, 6457L, 6458L, 6459L, 6460L, 6461L, 6462L, 6463L, 6464L,
6465L, 6466L, 6467L, 6468L, 6469L, 6470L, 6471L, 6472L, 6473L,
6474L, 6475L, 6476L, 6477L, 6478L, 6479L, 6480L, 6481L, 6482L,
6483L, 6484L, 6485L, 6486L, 6487L, 6488L, 6489L, 6490L, 6491L,
6492L, 6493L, 6494L, 6495L, 6496L, 6497L, 6498L, 6499L, 6500L,
6501L, 6502L, 6503L, 6504L, 6505L, 6506L, 6507L, 6508L, 6509L,
6510L, 6511L, 6512L, 6513L, 6514L, 6515L, 6516L, 6517L, 6518L,
6519L, 6520L, 6521L, 6522L, 6523L, 6524L, 6525L, 6526L, 6527L,
6528L, 6529L, 6530L, 6531L, 6532L, 6533L, 6534L, 6535L, 6536L,
6537L, 6538L, 6539L, 6540L, 6541L, 6542L, 6543L, 6544L, 6545L,
6546L, 6547L, 6548L, 6549L, 6550L, 6551L, 6552L, 6553L, 6554L,
6555L, 6556L, 6557L, 6558L, 6559L, 6560L, 6561L, 6562L, 6563L,
6564L, 6565L, 6566L, 6567L, 6568L, 6569L, 6570L, 6571L, 6572L,
6573L, 6574L, 6575L, 6576L, 6577L, 6578L, 6579L, 6580L, 6581L,
6582L, 6583L, 6584L, 6585L, 6586L, 6587L, 6588L, 6589L, 6590L,
6591L, 6592L, 6593L, 6594L, 6595L, 6596L, 6597L, 6598L, 6599L,
6600L, 6601L, 6602L, 6603L, 6604L, 6605L, 6606L, 6607L, 6608L,
6609L, 6610L, 6611L, 6612L, 6613L, 6614L, 6615L, 6616L, 6617L,
6618L, 6619L, 6620L, 6621L, 6622L, 6623L, 6624L, 6625L, 6626L,
6627L, 6628L, 6629L, 6630L, 6631L, 6632L, 6633L, 6634L, 6635L,
6636L, 6637L, 6638L, 6639L, 6640L, 6641L, 6642L, 6643L, 6644L,
6645L, 6646L, 6647L, 6648L, 6649L, 6650L, 6651L, 6652L, 6653L,
6654L, 6655L, 6656L, 6657L, 6658L, 6659L, 6660L, 6661L, 6662L,
6663L, 6664L, 6665L, 6666L, 6667L, 6668L, 6669L, 6670L, 6671L,
6672L, 6673L, 6674L, 6675L, 6676L, 6677L, 6678L, 6679L, 6680L,
6681L, 6682L, 6683L, 6684L, 6685L, 6686L, 6687L, 6688L, 6689L,
6690L, 6691L, 6692L, 6693L, 6694L, 6695L, 6696L, 6697L, 6698L,
6699L, 6700L, 6701L, 6702L, 6703L, 6704L, 6705L, 6706L, 6707L,
6708L, 6709L, 6710L, 6711L, 6712L, 6713L, 6714L, 6715L, 6716L,
6717L, 6718L, 6719L, 6720L, 6721L, 6722L, 6723L, 6724L, 6725L,
6726L, 6727L, 6728L, 6729L, 6730L, 6731L, 6732L, 6733L, 6734L,
6735L, 6736L, 6737L, 6738L, 6739L, 6740L, 6741L, 6742L, 6743L,
6744L, 6745L, 6746L, 6747L, 6748L, 6749L, 6750L, 6751L, 6752L,
6753L, 6754L, 6755L, 6756L, 6757L, 6758L, 6759L, 6760L, 6761L,
6762L, 6763L, 6764L, 6765L, 6766L, 6767L, 6768L, 6769L, 6770L,
6771L, 6772L, 6773L, 6774L, 6775L, 6776L, 6777L, 6778L, 6779L,
6780L, 6781L, 6782L, 6783L, 6784L, 6785L, 6786L, 6787L, 6788L,
6789L, 6790L, 6791L, 6792L, 6793L, 6794L, 6795L, 6796L, 6797L,
6798L, 6799L, 6800L, 6801L, 6802L, 6803L, 6804L, 6805L, 6806L,
6807L, 6808L, 6809L, 6810L, 6811L, 6812L, 6813L, 6814L, 6815L,
6816L, 6817L, 6818L, 6819L, 6820L, 6821L, 6822L, 6823L, 6824L,
6825L, 6826L, 6827L, 6828L, 6829L, 6830L, 6831L, 6832L, 6833L,
6834L, 6835L, 6836L, 6837L, 6838L, 6839L, 6840L, 6841L, 6842L,
6843L, 6844L, 6845L, 6846L, 6847L, 6848L, 6849L, 6850L, 6851L,
6852L, 6853L, 6854L, 6855L, 6856L, 6857L, 6858L, 6859L, 6860L,
6861L, 6862L, 6863L, 6864L, 6865L, 6866L, 6867L, 6868L, 6869L,
6870L, 6871L, 6872L, 6873L, 6874L, 6875L, 6876L, 6877L, 6878L,
6879L, 6880L, 6881L, 6882L, 6883L, 6884L, 6885L, 6886L, 6887L,
6888L, 6889L, 6890L, 6891L, 6892L, 6893L, 6894L, 6895L, 6896L,
6897L, 6898L, 6899L, 6900L, 6901L, 6902L, 6903L, 6904L, 6905L,
6906L, 6907L, 6908L, 6909L, 6910L, 6911L, 6912L, 6913L, 6914L,
6915L, 6916L, 6917L, 6918L, 6919L, 6920L, 6921L, 6922L, 6923L,
6924L, 6925L, 6926L, 6927L, 6928L, 6929L, 6930L, 6931L, 6932L,
6933L, 6934L, 6935L, 6936L, 6937L, 6938L, 6939L, 6940L, 6941L,
6942L, 6943L, 6944L, 6945L, 6946L, 6947L, 6948L, 6949L, 6950L,
6951L, 6952L, 6953L, 6954L, 6955L, 6956L, 6957L, 6958L, 6959L,
6960L, 6961L, 6962L, 6963L, 6964L, 6965L, 6966L, 6967L, 6968L,
6969L, 6970L, 6971L, 6972L, 6973L, 6974L, 6975L, 6976L, 6977L,
6978L, 6979L, 6980L, 6981L, 6982L, 6983L, 6984L, 6985L, 6986L,
6987L, 6988L, 6989L, 6990L, 6991L, 6992L, 6993L, 6994L, 6995L,
6996L, 6997L, 6998L, 6999L, 7000L, 7001L, 7002L, 7003L, 7004L,
7005L, 7006L, 7007L, 7008L, 7009L, 7010L, 7011L, 7012L, 7013L,
7014L, 7015L, 7016L, 7017L, 7018L, 7019L, 7020L, 7021L, 7022L,
7023L, 7024L, 7025L, 7026L, 7027L, 7028L, 7029L, 7030L, 7031L,
7032L, 7033L, 7034L, 7035L, 7036L, 7037L, 7038L, 7039L, 7040L,
7041L, 7042L, 7043L, 7044L, 7045L, 7046L, 7047L, 7048L, 7049L,
7050L, 7051L, 7052L, 7053L, 7054L, 7055L, 7056L, 7057L, 7058L,
7059L, 7060L, 7061L, 7062L, 7063L, 7064L, 7065L, 7066L, 7067L,
7068L, 7069L, 7070L, 7071L, 7072L, 7073L, 7074L, 7075L, 7076L,
7077L, 7078L, 7079L, 7080L, 7081L, 7082L, 7083L, 7084L, 7085L,
7086L, 7087L, 7088L, 7089L, 7090L, 7091L, 7092L, 7093L, 7094L,
7095L, 7096L, 7097L, 7098L, 7099L, 7100L, 7101L, 7102L, 7103L,
7104L, 7105L, 7106L, 7107L, 7108L, 7109L, 7110L, 7111L, 7112L,
7113L, 7114L, 7115L, 7116L, 7117L, 7118L, 7119L, 7120L, 7121L,
7122L, 7123L, 7124L, 7125L, 7126L, 7127L, 7128L, 7129L, 7130L,
7131L, 7132L, 7133L, 7134L, 7135L, 7136L, 7137L, 7138L, 7139L,
7140L, 7141L, 7142L, 7143L, 7144L, 7145L, 7146L, 7147L, 7148L,
7149L, 7150L, 7151L, 7152L, 7153L, 7154L, 7155L, 7156L, 7157L,
7158L, 7159L, 7160L, 7161L, 7162L, 7163L, 7164L, 7165L, 7166L,
7167L, 7168L, 7169L, 7170L, 7171L, 7172L, 7173L, 7174L, 7175L,
7176L, 7177L, 7178L, 7179L, 7180L, 7181L, 7182L, 7183L, 7184L,
7185L, 7186L, 7187L, 7188L, 7189L, 7190L, 7191L, 7192L, 7193L,
7194L, 7195L, 7196L, 7197L, 7198L, 7199L, 7200L, 7201L, 7202L,
7203L, 7204L, 7205L, 7206L, 7207L, 7208L, 7209L, 7210L, 7211L,
7212L, 7213L, 7214L, 7215L, 7216L, 7217L, 7218L, 7219L, 7220L,
7221L, 7222L, 7223L, 7224L, 7225L, 7226L, 7227L, 7228L, 7229L,
7230L, 7231L, 7232L, 7233L, 7234L, 7235L, 7236L, 7237L, 7238L,
7239L, 7240L, 7241L, 7242L, 7243L, 7244L, 7245L, 7246L, 7247L,
7248L, 7249L, 7250L, 7251L, 7252L, 7253L, 7254L, 7255L, 7256L,
7257L, 7258L, 7259L, 7260L, 7261L, 7262L, 7263L, 7264L, 7265L,
7266L, 7267L, 7268L, 7269L, 7270L, 7271L, 7272L, 7273L, 7274L,
7275L, 7276L, 7277L, 7278L, 7279L, 7280L, 7281L, 7282L, 7283L,
7284L, 7285L, 7286L, 7287L, 7288L, 7289L, 7290L, 7291L, 7292L,
7293L, 7294L, 7295L, 7296L, 7297L, 7298L, 7299L, 7300L, 7301L,
7302L, 7303L, 7304L, 7305L, 7306L, 7307L, 7308L, 7309L, 7310L,
7311L, 7312L, 7313L, 7314L, 7315L, 7316L, 7317L, 7318L, 7319L,
7320L, 7321L, 7322L, 7323L, 7324L, 7325L, 7326L, 7327L, 7328L,
7329L, 7330L, 7331L, 7332L, 7333L, 7334L, 7335L, 7336L, 7337L,
7338L, 7339L, 7340L, 7341L, 7342L, 7343L, 7344L, 7345L, 7346L,
7347L, 7348L, 7349L, 7350L, 7351L, 7352L, 7353L, 7354L, 7355L,
7356L, 7357L, 7358L, 7359L, 7360L, 7361L, 7362L, 7363L, 7364L,
7365L, 7366L, 7367L, 7368L, 7369L, 7370L, 7371L, 7372L, 7373L,
7374L, 7375L, 7376L, 7377L, 7378L, 7379L, 7380L, 7381L, 7382L,
7383L, 7384L, 7385L, 7386L, 7387L, 7388L, 7389L, 7390L, 7391L,
7392L, 7393L, 7394L, 7395L, 7396L, 7397L, 7398L, 7399L, 7400L,
7401L, 7402L, 7403L, 7404L, 7405L, 7406L, 7407L, 7408L, 7409L,
7410L, 7411L, 7412L, 7413L, 7414L, 7415L, 7416L, 7417L, 7418L,
7419L, 7420L, 7421L, 7422L, 7423L, 7424L, 7425L, 7426L, 7427L,
7428L, 7429L, 7430L, 7431L, 7432L, 7433L, 7434L, 7435L, 7436L,
7437L, 7438L, 7439L, 7440L, 7441L, 7442L, 7443L, 7444L, 7445L,
7446L, 7447L, 7448L, 7449L, 7450L, 7451L, 7452L, 7453L, 7454L,
7455L, 7456L, 7457L, 7458L, 7459L, 7460L, 7461L, 7462L, 7463L,
7464L, 7465L, 7466L, 7467L, 7468L, 7469L, 7470L, 7471L, 7472L,
7473L, 7474L, 7475L, 7476L, 7477L, 7478L, 7479L, 7480L, 7481L,
7482L, 7483L, 7484L, 7485L, 7486L, 7487L, 7488L, 7489L, 7490L,
7491L, 7492L, 7493L, 7494L, 7495L, 7496L, 7497L, 7498L, 7499L,
7500L, 7501L, 7502L, 7503L, 7504L, 7505L, 7506L, 7507L, 7508L,
7509L, 7510L, 7511L, 7512L, 7513L, 7514L, 7515L, 7516L, 7517L,
7518L, 7519L, 7520L, 7521L, 7522L, 7523L, 7524L, 7525L, 7526L,
7527L, 7528L, 7529L, 7530L, 7531L, 7532L, 7533L, 7534L, 7535L,
7536L, 7537L, 7538L, 7539L, 7540L, 7541L, 7542L, 7543L, 7544L,
7545L, 7546L, 7547L, 7548L, 7549L, 7550L, 7551L, 7552L, 7553L,
7554L, 7555L, 7556L, 7557L, 7558L, 7559L, 7560L, 7561L, 7562L,
7563L, 7564L, 7565L, 7566L, 7567L, 7568L, 7569L, 7570L, 7571L,
7572L, 7573L, 7574L, 7575L, 7576L, 7577L, 7578L, 7579L, 7580L,
7581L, 7582L, 7583L, 7584L, 7585L, 7586L, 7587L, 7588L, 7589L,
7590L, 7591L, 7592L, 7593L, 7594L, 7595L, 7596L, 7597L, 7598L,
7599L, 7600L, 7601L, 7602L, 7603L, 7604L, 7605L, 7606L, 7607L,
7608L, 7609L, 7610L, 7611L, 7612L, 7613L, 7614L, 7615L, 7616L,
7617L, 7618L, 7619L, 7620L, 7621L, 7622L, 7623L, 7624L, 7625L,
7626L, 7627L, 7628L, 7629L, 7630L, 7631L, 7632L, 7633L, 7634L,
7635L, 7636L, 7637L, 7638L, 7639L, 7640L, 7641L, 7642L, 7643L,
7644L, 7645L, 7646L, 7647L, 7648L, 7649L, 7650L, 7651L, 7652L,
7653L, 7654L, 7655L, 7656L, 7657L, 7658L, 7659L, 7660L, 7661L,
7662L, 7663L, 7664L, 7665L, 7666L, 7667L, 7668L, 7669L, 7670L,
7671L, 7672L, 7673L, 7674L, 7675L, 7676L, 7677L, 7678L, 7679L,
7680L, 7681L, 7682L, 7683L, 7684L, 7685L, 7686L, 7687L, 7688L,
7689L, 7690L, 7691L, 7692L, 7693L, 7694L, 7695L, 7696L, 7697L,
7698L, 7699L, 7700L, 7701L, 7702L, 7703L, 7704L, 7705L, 7706L,
7707L, 7708L, 7709L, 7710L, 7711L, 7712L, 7713L, 7714L, 7715L,
7716L, 7717L, 7718L, 7719L, 7720L, 7721L, 7722L, 7723L, 7724L,
7725L, 7726L, 7727L, 7728L, 7729L, 7730L, 7731L, 7732L, 7733L,
7734L, 7735L, 7736L, 7737L, 7738L, 7739L, 7740L, 7741L, 7742L,
7743L, 7744L, 7745L, 7746L, 7747L, 7748L, 7749L, 7750L, 7751L,
7752L, 7753L, 7754L, 7755L, 7756L, 7757L, 7758L, 7759L, 7760L,
7761L, 7762L, 7763L, 7764L, 7765L, 7766L, 8498L, 8499L, 8500L,
8501L, 8502L, 8503L, 8504L, 8505L, 8506L, 8507L, 8508L, 8509L,
8510L, 8511L, 8512L, 8513L, 8514L, 8515L, 8516L, 8517L, 8518L,
8519L, 8520L, 8521L, 8522L, 8523L, 8524L, 8525L, 8526L, 8527L,
8528L, 8529L, 8530L, 8531L, 8532L, 8533L, 8534L, 8535L, 8536L,
8537L, 8538L, 8539L, 8540L, 8541L, 8542L, 8543L, 8544L, 8545L,
8546L, 8547L, 8548L, 8549L, 8550L, 8551L, 8552L, 8553L, 8554L,
8555L, 8556L, 8557L, 8558L, 8559L, 8560L, 8561L, 8562L, 8563L,
8564L, 8565L, 8566L, 8567L, 8568L, 8569L, 8570L, 8571L, 8572L,
8573L, 8574L, 8575L, 8576L, 8577L, 8578L, 8579L, 8580L, 8581L,
8582L, 8583L, 8584L, 8585L, 8586L, 8587L, 8588L, 8589L, 8590L,
8591L, 8592L, 8593L, 8594L, 8595L, 8596L, 8597L, 8598L, 8599L,
8600L, 8601L, 8602L, 8603L, 8604L, 8605L, 8606L, 8607L, 8608L,
8609L, 8610L, 8611L, 8612L, 8613L, 8614L, 8615L, 8616L, 8617L,
8618L, 8619L, 8620L, 8621L, 8622L, 8623L, 8624L, 8625L, 8626L,
8627L, 8628L, 8629L, 8630L, 8631L, 8632L, 8633L, 8634L, 8635L,
8636L, 8637L, 8638L, 8639L, 8640L, 8641L, 8642L, 8643L, 8644L,
8645L, 8646L, 8647L, 8648L, 8649L, 8650L, 8651L, 8652L, 8653L,
8654L, 8655L, 8656L, 8657L, 8658L, 8659L, 8660L, 8661L, 8662L,
8663L, 8664L, 8665L, 8666L, 8667L, 8668L, 8669L, 8670L, 8671L,
8672L, 8673L, 8674L, 8675L, 8676L, 8677L, 8678L, 8679L, 8680L,
8681L, 8682L, 8683L, 8684L, 8685L, 8686L, 8687L, 8688L, 8689L,
8690L, 8691L, 8692L, 8693L, 8694L, 8695L, 8696L, 8697L, 8698L,
8699L, 8700L, 8701L, 8702L, 8703L, 8704L, 8705L, 8706L, 8707L,
8708L, 8709L, 8710L, 8711L, 8712L, 8713L, 8714L, 8715L, 8716L,
8717L, 8718L, 8719L, 8720L, 8721L, 8722L, 8723L, 8724L, 8725L,
8726L, 8727L, 8728L, 8729L, 8730L, 8731L, 8732L, 8733L, 8734L,
8735L, 8736L, 8737L, 8738L, 8739L, 8740L, 8741L, 8742L, 8743L,
8744L, 8745L, 8746L, 8747L, 8748L, 8749L, 8750L, 8751L, 8752L,
8753L, 8754L, 8755L, 8756L, 8757L, 8758L, 8759L, 8760L, 8761L,
8762L, 8763L, 8764L, 8765L, 8766L, 8767L, 8768L, 8769L, 8770L,
8771L, 8772L, 8773L, 8774L, 8775L, 8776L, 8777L, 8778L, 8779L,
8780L, 8781L, 8782L, 8783L, 8784L, 8785L, 8786L, 8787L, 8788L,
8789L, 8790L, 8791L, 8792L, 8793L, 8794L, 8795L, 8796L, 8797L,
8798L, 8799L, 8800L, 8801L, 8802L, 8803L, 8804L, 8805L, 8806L,
8807L, 8808L, 8809L, 8810L, 8811L, 8812L, 8813L, 8814L, 8815L,
8816L, 8817L, 8818L, 8819L, 8820L, 8821L, 8822L, 8823L, 8824L,
8825L, 8826L, 8827L, 8828L, 8829L, 8830L, 8831L, 8832L, 8833L,
8834L, 8835L, 8836L, 8837L, 8838L, 8839L, 8840L, 8841L, 8842L,
8843L, 8844L, 8845L, 8846L, 8847L, 8848L, 8849L, 8850L, 8851L,
8852L, 8853L, 8854L, 8855L, 8856L, 8857L, 8858L, 8859L, 8860L,
8861L, 8862L, 8863L, 8864L, 8865L, 8866L, 8867L, 8868L, 8869L,
8870L, 8871L, 8872L, 8873L, 8874L, 8875L, 8876L, 8877L, 8878L,
8879L, 8880L, 8881L, 8882L, 8883L, 8884L, 8885L, 8886L, 8887L,
8888L, 8889L, 8890L, 8891L, 8892L, 8893L, 8894L, 8895L, 8896L,
8897L, 8898L, 8899L, 8900L, 8901L, 8902L, 8903L, 8904L, 8905L,
8906L, 8907L, 8908L, 8909L, 8910L, 8911L, 8912L, 8913L, 8914L,
8915L, 8916L, 8917L, 8918L, 8919L, 8920L, 8921L, 8922L, 8923L,
8924L, 8925L, 8926L, 8927L, 8928L, 8929L, 8930L, 8931L, 8932L,
8933L, 8934L, 8935L, 8936L, 8937L, 8938L, 8939L, 8940L, 8941L,
8942L, 8943L, 8944L, 8945L, 8946L, 8947L, 8948L, 8949L, 8950L,
8951L, 8952L, 8953L, 8954L, 8955L, 8956L, 8957L, 8958L, 8959L,
8960L, 8961L, 8962L, 8963L, 8964L, 8965L, 8966L, 8967L, 8968L,
8969L, 8970L, 8971L, 8972L, 8973L, 8974L, 8975L, 8976L, 8977L,
8978L, 8979L, 8980L, 8981L, 8982L, 8983L, 8984L, 8985L, 8986L,
8987L, 8988L, 8989L, 8990L, 8991L, 8992L, 8993L, 8994L, 8995L,
8996L, 8997L, 8998L, 8999L, 9000L, 9001L, 9002L, 9003L, 9004L,
9005L, 9006L, 9007L, 9008L, 9009L, 9010L, 9011L, 9012L, 9013L,
9014L, 9015L, 9016L, 9017L, 9018L, 9019L, 9020L, 9021L, 9022L,
9023L, 9024L, 9025L, 9026L, 9027L, 9028L, 9029L, 9030L, 9031L,
9032L, 9033L, 9034L, 9035L, 9036L, 9037L, 9038L, 9039L, 9040L,
9041L, 9042L, 9043L, 9044L, 9045L, 9046L, 9047L, 9048L, 9049L,
9050L, 9051L, 9052L, 9053L, 9054L, 9055L, 9056L, 9057L, 9058L,
9059L, 9060L, 9061L, 9062L, 9063L, 9064L, 9065L, 9066L, 9067L,
9068L, 9069L, 9070L, 9071L, 9072L, 9073L, 9074L, 9075L, 9076L,
9077L, 9078L, 9079L, 9080L, 9081L, 9082L, 9083L, 9084L, 9085L,
9086L, 9087L, 9088L, 9089L, 9090L, 9091L, 9092L, 9093L, 9094L,
9095L, 9096L, 9097L, 9098L, 9099L, 9100L, 9101L, 9102L, 9103L,
9104L, 9105L, 9106L, 9107L, 9108L, 9109L, 9110L, 9111L, 9112L,
9113L, 9114L, 9115L, 9116L, 9117L, 9118L, 9119L, 9120L, 9121L,
9122L, 9123L, 9124L, 9125L, 9126L, 9127L, 9128L, 9129L, 9130L,
9131L, 9132L, 9133L, 9134L, 9135L, 9136L, 9137L, 9138L, 9139L,
9140L, 9141L, 9142L, 9143L, 9144L, 9145L, 9146L, 9147L, 9148L,
9149L, 9150L, 9151L, 9152L, 9153L, 9154L, 9155L, 9156L, 9157L,
9158L, 9159L, 9160L, 9161L, 9162L, 9163L, 9164L, 9165L, 9166L,
9167L, 9168L, 9169L, 9170L, 9171L, 9172L, 9173L, 9174L, 9175L,
9176L, 9177L, 9178L, 9179L, 9180L, 9181L, 9182L, 9183L, 9184L,
9185L, 9186L, 9187L, 9188L, 9189L, 9190L, 9191L, 9192L, 9193L,
9194L, 9195L, 9196L, 9197L, 9198L, 9199L, 9200L, 9201L, 9202L,
9203L, 9204L, 9205L, 9206L, 9207L, 9208L, 9209L, 9210L, 9211L,
9212L, 9213L, 9214L, 9215L, 9216L, 9217L, 9218L, 9219L, 9220L,
9221L, 9222L, 9223L, 9224L, 9225L, 9226L, 9227L, 9228L, 9229L,
9230L, 9231L, 9232L, 9233L, 9234L, 9235L, 9236L, 9237L, 9238L,
9239L, 9240L, 9241L, 9242L, 9243L, 9244L, 9245L, 9246L, 9247L,
9248L, 9249L, 9250L, 9251L, 9252L, 9253L, 9254L, 9255L, 9256L,
9257L, 9258L, 9259L, 9260L, 9261L, 9262L, 9263L, 9264L, 9265L,
9266L, 9267L, 9268L, 9269L, 9270L, 9271L, 9272L, 9273L, 9274L,
9275L, 9276L, 9277L, 9278L, 9279L, 9280L, 9281L, 9282L, 9283L,
9284L, 9285L, 9286L, 9287L, 9288L, 9289L, 9290L, 9291L, 9292L,
9293L, 9294L, 9295L, 9296L, 9297L, 9298L, 9299L, 9300L, 9301L,
9302L, 9303L, 9304L, 9305L, 9306L, 9307L, 9308L, 9309L, 9310L,
9311L, 9312L, 9313L, 9314L, 9315L, 9316L, 9317L, 9318L, 9319L,
9320L, 9321L, 9322L, 9323L, 9324L, 9325L, 9326L, 9327L, 9328L,
9329L, 9330L, 9331L, 9332L, 9333L, 9334L, 9335L, 9336L, 9337L,
9338L, 9339L, 9340L, 9341L, 9342L, 9343L, 9344L, 9345L, 9346L,
9347L, 9348L, 9349L, 9350L, 9351L, 9352L, 9353L, 9354L, 9355L,
9356L, 9357L, 9358L, 9359L, 9360L, 9361L, 9362L, 9363L, 9364L,
9365L, 9366L, 9367L, 9368L, 9369L, 9370L, 9371L, 9372L, 9373L,
9374L, 9375L, 9376L, 9377L, 9378L, 9379L, 9380L, 9381L, 9382L,
9383L, 9384L, 9385L, 9386L, 9387L, 9388L, 9389L, 9390L, 9391L,
9392L, 9393L, 9394L, 9395L, 9396L, 9397L, 9398L, 9399L, 9400L,
9401L, 9402L, 9403L, 9404L, 9405L, 9406L, 9407L, 9408L, 9409L,
9410L, 9411L, 9412L, 9413L, 9414L, 9415L, 9416L, 9417L, 9418L,
9419L, 9420L, 9421L, 9422L, 9423L, 9424L, 9425L, 9426L, 9427L,
9428L, 9429L, 9430L, 9431L, 9432L, 9433L, 9434L, 9435L, 9436L,
9437L, 9438L, 9439L, 9440L, 9441L, 9442L, 9443L, 9444L, 9445L,
9446L, 9447L, 9448L, 9449L, 9450L, 9451L, 9452L, 9453L, 9454L,
9455L, 9456L, 9457L, 9458L, 9459L, 9460L, 9461L, 9462L, 9463L,
9464L, 9465L, 9466L, 9467L, 9468L, 9469L, 9470L, 9471L, 9472L,
9473L, 9474L, 9475L, 9476L, 9477L, 9478L, 9479L, 9480L, 9481L,
9482L, 9483L, 9484L, 9485L, 9486L, 9487L, 9488L, 9489L, 9490L,
9491L, 9492L, 9493L, 9494L, 9495L, 9496L, 9497L, 9498L, 9499L,
9500L, 9501L, 9502L, 9503L, 9504L, 9505L, 9506L, 9507L, 9508L,
9509L, 9510L, 9511L, 9512L, 9513L, 9514L, 9515L, 9516L, 9517L,
9518L, 9519L, 9520L, 9521L, 9522L, 9523L, 9524L, 9525L, 9526L,
9527L, 9528L, 9529L, 9530L, 9531L, 9532L, 9533L, 9534L, 9535L,
9536L, 9537L, 9538L, 9539L, 9540L, 9541L, 9542L, 9543L, 9544L,
9545L, 9546L, 9547L, 9548L, 9549L, 9550L, 9551L, 9552L, 9553L,
9554L, 9555L, 9556L, 9557L, 9558L, 9559L, 9560L, 9561L, 9562L,
9563L, 9564L, 9565L, 9566L, 9567L, 9568L, 9569L, 9570L, 9571L,
9572L, 9573L, 9574L, 9575L, 9576L, 9577L, 9578L, 9579L, 9580L,
9581L, 9582L, 9583L, 9584L, 9585L, 9586L, 9587L, 9588L, 9589L,
9590L, 9591L, 9592L, 9593L, 9594L, 9595L, 9596L, 9597L, 9598L,
9599L, 9600L, 9601L, 9602L, 9603L, 9604L, 9605L, 9606L, 9607L,
9608L, 9609L, 9610L, 9611L, 9612L, 9613L, 9614L, 9615L, 9616L,
9617L, 9618L, 9619L, 9620L, 9621L, 9622L, 9623L, 11481L, 11482L,
11483L, 11484L, 11485L, 11486L, 11487L, 11488L, 11489L, 11490L,
11491L, 11492L, 11493L, 11494L, 11495L, 11496L, 11497L, 11498L,
11499L, 11500L, 11501L, 11502L, 11503L, 11504L, 11505L, 11506L,
11507L, 11508L, 11509L, 11510L, 11511L, 11512L, 11513L, 11514L,
11515L, 11516L, 11517L, 11518L, 11519L, 11520L, 11521L, 11522L,
11523L, 11524L, 11525L, 11526L, 11527L, 11528L, 11529L, 11530L,
11531L, 11532L, 11533L, 11534L, 11535L, 11536L, 11537L, 11538L,
11539L, 11540L, 11541L, 11542L, 11543L, 11544L, 11545L, 11546L,
11547L, 11548L, 11549L, 11550L, 11551L, 11552L, 11553L, 11554L,
11555L, 11556L, 11557L, 11558L, 11559L, 11560L, 11561L, 11562L,
11563L, 11564L, 11565L, 11566L, 11567L, 11568L, 11569L, 11570L,
11571L, 11572L, 11573L, 11574L, 11575L, 11576L, 11577L, 11578L,
11579L, 11580L, 11581L, 11582L, 11583L, 11584L, 11585L, 11586L,
11587L, 11588L, 11589L, 11590L, 11591L, 11592L, 11593L, 11594L,
11595L, 11596L, 11597L, 11598L, 11599L, 11600L, 11601L, 11602L,
11603L, 11604L, 11605L, 11606L, 11607L, 11608L, 11609L, 11610L,
11611L, 11612L, 11613L, 11614L, 11615L, 11616L, 11617L, 11618L,
11619L, 11620L, 11621L, 11622L, 11623L, 11624L, 11625L, 11626L,
11627L, 11628L, 11629L, 11630L, 11631L, 11632L, 11633L, 11634L,
11635L, 11636L, 11637L, 11638L, 11639L, 11640L, 11641L, 11642L,
11643L, 11644L, 11645L, 11646L, 11647L, 11648L, 11649L, 10355L,
10356L, 10357L, 10358L, 10359L, 10360L, 10361L, 10362L, 10363L,
10364L, 10365L, 10366L, 10367L, 10368L, 10369L, 10370L, 10371L,
10372L, 10373L, 10374L, 10375L, 10376L, 10377L, 10378L, 10379L,
10380L, 10381L, 10382L, 10383L, 10384L, 10385L, 10386L, 10387L,
10388L, 10389L, 10390L, 10391L, 10392L, 10393L, 10394L, 10395L,
10396L, 10397L, 10398L, 10399L, 10400L, 10401L, 10402L, 10403L,
10404L, 10405L, 10406L, 10407L, 10408L, 10409L, 10410L, 10411L,
10412L, 10413L, 10414L, 10415L, 10416L, 10417L, 10418L, 10419L,
10420L, 10421L, 10422L, 10423L, 10424L, 10425L, 10426L, 10427L,
10428L, 10429L, 10430L, 10431L, 10432L, 10433L, 10434L, 10435L,
10436L, 10437L, 10438L, 10439L, 10440L, 10441L, 10442L, 10443L,
10444L, 10445L, 10446L, 10447L, 10448L, 10449L, 10450L, 10451L,
10452L, 10453L, 10454L, 10455L, 10456L, 10457L, 10458L, 10459L,
10460L, 10461L, 10462L, 10463L, 10464L, 10465L, 10466L, 10467L,
10468L, 10469L, 10470L, 10471L, 10472L, 10473L, 10474L, 10475L,
10476L, 10477L, 10478L, 10479L, 10480L, 10481L, 10482L, 10483L,
10484L, 10485L, 10486L, 10487L, 10488L, 10489L, 10490L, 10491L,
10492L, 10493L, 10494L, 10495L, 10496L, 10497L, 10498L, 10499L,
10500L, 10501L, 10502L, 10503L, 10504L, 10505L, 10506L, 10507L,
10508L, 10509L, 10510L, 10511L, 10512L, 10513L, 10514L, 10515L,
10516L, 10517L, 10518L, 10519L, 10520L, 10521L, 10522L, 10523L,
10524L, 10525L, 10526L, 10527L, 10528L, 10529L, 10530L, 10531L,
10532L, 10533L, 10534L, 10535L, 10536L, 10537L, 10538L, 10539L,
10540L, 10541L, 10542L, 10543L, 10544L, 10545L, 10546L, 10547L,
10548L, 10549L, 10550L, 10551L, 10552L, 10553L, 10554L, 10555L,
10556L, 10557L, 10558L, 10559L, 10560L, 10561L, 10562L, 10563L,
10564L, 10565L, 10566L, 10567L, 10568L, 10569L, 10570L, 10571L,
10572L, 10573L, 10574L, 10575L, 10576L, 10577L, 10578L, 10579L,
10580L, 10581L, 10582L, 10583L, 10584L, 10585L, 10586L, 10587L,
10588L, 10589L, 10590L, 10591L, 10592L, 10593L, 10594L, 10595L,
10596L, 10597L, 10598L, 10599L, 10600L, 10601L, 10602L, 10603L,
10604L, 10605L, 10606L, 10607L, 10608L, 10609L, 10610L, 10611L,
10612L, 10613L, 10614L, 10615L, 10616L, 10617L, 10618L, 10619L,
10620L, 10621L, 10622L, 10623L, 10624L, 10625L, 10626L, 10627L,
10628L, 10629L, 10630L, 10631L, 10632L, 10633L, 10634L, 10635L,
10636L, 10637L, 10638L, 10639L, 10640L, 10641L, 10642L, 10643L,
10644L, 10645L, 10646L, 10647L, 10648L, 10649L, 10650L, 10651L,
10652L, 10653L, 10654L, 10655L, 10656L, 10657L, 10658L, 10659L,
10660L, 10661L, 10662L, 10663L, 10664L, 10665L, 10666L, 10667L,
10668L, 10669L, 10670L, 10671L, 10672L, 10673L, 10674L, 10675L,
10676L, 10677L, 10678L, 10679L, 10680L, 10681L, 10682L, 10683L,
10684L, 10685L, 10686L, 10687L, 10688L, 10689L, 10690L, 10691L,
10692L, 10693L, 10694L, 10695L, 10696L, 10697L, 10698L, 10699L,
10700L, 10701L, 10702L, 10703L, 10704L, 10705L, 10706L, 10707L,
10708L, 10709L, 10710L, 10711L, 10712L, 10713L, 10714L, 10715L,
10716L, 10717L, 10718L, 10719L, 10720L, 10721L, 10722L, 10723L,
10724L, 10725L, 10726L, 10727L, 10728L, 10729L, 10730L, 10731L,
10732L, 10733L, 10734L, 10735L, 10736L, 10737L, 10738L, 10739L,
10740L, 10741L, 10742L, 10743L, 10744L, 10745L, 10746L, 10747L,
10748L, 10749L, 10750L, 10751L, 10752L, 10753L, 10754L, 10755L,
10756L, 10757L, 10758L, 10759L, 10760L, 10761L, 10762L, 10763L,
10764L, 10765L, 10766L, 10767L, 10768L, 10769L, 10770L, 10771L,
10772L, 10773L, 10774L, 10775L, 10776L, 10777L, 10778L, 10779L,
10780L, 10781L, 10782L, 10783L, 10784L, 10785L, 10786L, 10787L,
10788L, 10789L, 10790L, 10791L, 10792L, 10793L, 10794L, 10795L,
10796L, 10797L, 10798L, 10799L, 10800L, 10801L, 10802L, 10803L,
10804L, 10805L, 10806L, 10807L, 10808L, 10809L, 10810L, 10811L,
10812L, 10813L, 10814L, 10815L, 10816L, 10817L, 10818L, 10819L,
10820L, 10821L, 10822L, 10823L, 10824L, 10825L, 10826L, 10827L,
10828L, 10829L, 10830L, 10831L, 10832L, 10833L, 10834L, 10835L,
10836L, 10837L, 10838L, 10839L, 10840L, 10841L, 10842L, 10843L,
10844L, 10845L, 10846L, 10847L, 10848L, 10849L, 10850L, 10851L,
10852L, 10853L, 10854L, 10855L, 10856L, 10857L, 10858L, 10859L,
10860L, 10861L, 10862L, 10863L, 10864L, 10865L, 10866L, 10867L,
10868L, 10869L, 10870L, 10871L, 10872L, 10873L, 10874L, 10875L,
10876L, 10877L, 10878L, 10879L, 10880L, 10881L, 10882L, 10883L,
10884L, 10885L, 10886L, 10887L, 10888L, 10889L, 10890L, 10891L,
10892L, 10893L, 10894L, 10895L, 10896L, 10897L, 10898L, 10899L,
10900L, 10901L, 10902L, 10903L, 10904L, 10905L, 10906L, 10907L,
10908L, 10909L, 10910L, 10911L, 10912L, 10913L, 10914L, 10915L,
10916L, 10917L, 10918L, 10919L, 10920L, 10921L, 10922L, 10923L,
10924L, 10925L, 10926L, 10927L, 10928L, 10929L, 10930L, 10931L,
10932L, 10933L, 10934L, 10935L, 10936L, 10937L, 10938L, 10939L,
10940L, 10941L, 10942L, 10943L, 10944L, 10945L, 10946L, 10947L,
10948L, 10949L, 10950L, 10951L, 10952L, 10953L, 10954L, 10955L,
10956L, 10957L, 10958L, 10959L, 10960L, 10961L, 10962L, 10963L,
10964L, 10965L, 10966L, 10967L, 10968L, 10969L, 10970L, 10971L,
10972L, 10973L, 10974L, 10975L, 10976L, 10977L, 10978L, 10979L,
10980L, 10981L, 10982L, 10983L, 10984L, 10985L, 10986L, 10987L,
10988L, 10989L, 10990L, 10991L, 10992L, 10993L, 10994L, 10995L,
10996L, 10997L, 10998L, 10999L, 11000L, 11001L, 11002L, 11003L,
11004L, 11005L, 11006L, 11007L, 11008L, 11009L, 11010L, 11011L,
11012L, 11013L, 11014L, 11015L, 11016L, 11017L, 11018L, 11019L,
11020L, 11021L, 11022L, 11023L, 11024L, 11025L, 11026L, 11027L,
11028L, 11029L, 11030L, 11031L, 11032L, 11033L, 11034L, 11035L,
11036L, 11037L, 11038L, 11039L, 11040L, 11041L, 11042L, 11043L,
11044L, 11045L, 11046L, 11047L, 11048L, 11049L, 11050L, 11051L,
11052L, 11053L, 11054L, 11055L, 11056L, 11057L, 11058L, 11059L,
11060L, 11061L, 11062L, 11063L, 11064L, 11065L, 11066L, 11067L,
11068L, 11069L, 11070L, 11071L, 11072L, 11073L, 11074L, 11075L,
11076L, 11077L, 11078L, 11079L, 11080L, 11081L, 11082L, 11083L,
11084L, 11085L, 11086L, 11087L, 11088L, 11089L, 11090L, 11091L,
11092L, 11093L, 11094L, 11095L, 11096L, 11097L, 11098L, 11099L,
11100L, 11101L, 11102L, 11103L, 11104L, 11105L, 11106L, 11107L,
11108L, 11109L, 11110L, 11111L, 11112L, 11113L, 11114L, 11115L,
11116L, 11117L, 11118L, 11119L, 11120L, 11121L, 11122L, 11123L,
11124L, 11125L, 11126L, 11127L, 11128L, 11129L, 11130L, 11131L,
11132L, 11133L, 11134L, 11135L, 11136L, 11137L, 11138L, 11139L,
11140L, 11141L, 11142L, 11143L, 11144L, 11145L, 11146L, 11147L,
11148L, 11149L, 11150L, 11151L, 11152L, 11153L, 11154L, 11155L,
11156L, 11157L, 11158L, 11159L, 11160L, 11161L, 11162L, 11163L,
11164L, 11165L, 11166L, 11167L, 11168L, 11169L, 11170L, 11171L,
11172L, 11173L, 11174L, 11175L, 11176L, 11177L, 11178L, 11179L,
11180L, 11181L, 11182L, 11183L, 11184L, 11185L, 11186L, 11187L,
11188L, 11189L, 11190L, 11191L, 11192L, 11193L, 11194L, 11195L,
11196L, 11197L, 11198L, 11199L, 11200L, 11201L, 11202L, 11203L,
11204L, 11205L, 11206L, 11207L, 11208L, 11209L, 11210L, 11211L,
11212L, 11213L, 11214L, 11215L, 11216L, 11217L, 11218L, 11219L,
11220L, 11221L, 11222L, 11223L, 11224L, 11225L, 11226L, 11227L,
11228L, 11229L, 11230L, 11231L, 11232L, 11233L, 11234L, 11235L,
11236L, 11237L, 11238L, 11239L, 11240L, 11241L, 11242L, 11243L,
11244L, 11245L, 11246L, 11247L, 11248L, 11249L, 11250L, 11251L,
11252L, 11253L, 11254L, 11255L, 11256L, 11257L, 11258L, 11259L,
11260L, 11261L, 11262L, 11263L, 11264L, 11265L, 11266L, 11267L,
11268L, 11269L, 11270L, 11271L, 11272L, 11273L, 11274L, 11275L,
11276L, 11277L, 11278L, 11279L, 11280L, 11281L, 11282L, 11283L,
11284L, 11285L, 11286L, 11287L, 11288L, 11289L, 11290L, 11291L,
11292L, 11293L, 11294L, 11295L, 11296L, 11297L, 11298L, 11299L,
11300L, 11301L, 11302L, 11303L, 11304L, 11305L, 11306L, 11307L,
11308L, 11309L, 11310L, 11311L, 11312L, 11313L, 11314L, 11315L,
11316L, 11317L, 11318L, 11319L, 11320L, 11321L, 11322L, 11323L,
11324L, 11325L, 11326L, 11327L, 11328L, 11329L, 11330L, 11331L,
11332L, 11333L, 11334L, 11335L, 11336L, 11337L, 11338L, 11339L,
11340L, 11341L, 11342L, 11343L, 11344L, 11345L, 11346L, 11347L,
11348L, 11349L, 11350L, 11351L, 11352L, 11353L, 11354L, 11355L,
11356L, 11357L, 11358L, 11359L, 11360L, 11361L, 11362L, 11363L,
11364L, 11365L, 11366L, 11367L, 11368L, 11369L, 11370L, 11371L,
11372L, 11373L, 11374L, 11375L, 11376L, 11377L, 11378L, 11379L,
11380L, 11381L, 11382L, 11383L, 11384L, 11385L, 11386L, 11387L,
11388L, 11389L, 11390L, 11391L, 11392L, 11393L, 11394L, 11395L,
11396L, 11397L, 11398L, 11399L, 11400L, 11401L, 11402L, 11403L,
11404L, 11405L, 11406L, 11407L, 11408L, 11409L, 11410L, 11411L,
11412L, 11413L, 11414L, 11415L, 11416L, 11417L, 11418L, 11419L,
11420L, 11421L, 11422L, 11423L, 11424L, 11425L, 11426L, 11427L,
11428L, 11429L, 11430L, 11431L, 11432L, 11433L, 11434L, 11435L,
11436L, 11437L, 11438L, 11439L, 11440L, 11441L, 11442L, 11443L,
11444L, 11445L, 11446L, 11447L, 11448L, 11449L, 11450L, 11451L,
11452L, 11453L, 11454L, 11455L, 11456L, 11457L, 11458L, 11459L,
11460L, 11461L, 11462L, 11463L, 11464L, 11465L, 11466L, 11467L,
11468L, 11469L, 11470L, 11471L, 11472L, 11473L, 11474L, 11475L,
11476L, 11477L, 11478L, 11479L, 11480L, 11650L, 11651L, 11652L,
11653L, 11654L, 11655L, 11656L, 11657L, 11658L, 11659L, 11660L,
11661L, 11662L, 11663L, 11664L, 11665L, 11666L, 11667L, 11668L,
11669L, 11670L, 11671L, 11672L, 11673L, 11674L, 11675L, 11676L,
11677L, 11678L, 11679L, 11680L, 11681L, 11682L, 11683L, 11684L,
11685L, 11686L, 11687L, 11688L, 11689L, 11690L, 11691L, 11692L,
11693L, 11694L, 11695L, 11696L, 11697L, 11698L, 11699L, 11700L,
11701L, 11702L, 11703L, 11704L, 11705L, 11706L, 11707L, 11708L,
11709L, 11710L, 11711L, 11712L, 11713L, 11714L, 11715L, 11716L,
11717L, 11718L, 11719L, 11720L, 11721L, 11722L, 11723L, 11724L,
11725L, 11726L, 11727L, 11728L, 11729L, 11730L, 11731L, 11732L,
11733L, 11734L, 11735L, 11736L, 11737L, 11738L, 11739L, 11740L,
11741L, 11742L, 11743L, 11744L, 11745L, 11746L, 11747L, 11748L,
11749L, 11750L, 11751L, 11752L, 11753L, 11754L, 11755L, 11756L,
11757L, 11758L, 11759L, 11760L, 11761L, 11762L, 11763L, 11764L,
11765L, 11766L, 11767L, 11768L, 11769L, 11770L, 11771L, 11772L,
11773L, 11774L, 11775L, 11776L, 11777L, 11778L, 11779L, 11780L,
11781L, 11782L, 11783L, 11784L, 11785L, 11786L, 11787L, 11788L,
11789L, 11790L, 11791L, 11792L, 11793L, 11794L, 11795L, 11796L,
11797L, 11798L, 11799L, 11800L, 11801L, 11802L, 11803L, 11804L,
11805L, 11806L, 11807L, 11808L, 11809L, 11810L, 11811L, 11812L,
11813L, 11814L, 11815L, 11816L, 11817L, 11818L, 7767L, 7768L,
7769L, 7770L, 7771L, 7772L, 7773L, 7774L, 7775L, 7776L, 7777L,
7778L, 7779L, 7780L, 7781L, 7782L, 7783L, 7784L, 7785L, 7786L,
7787L, 7788L, 7789L, 7790L, 7791L, 7792L, 7793L, 7794L, 7795L,
7796L, 7797L, 7798L, 7799L, 7800L, 7801L, 7802L, 7803L, 7804L,
7805L, 7806L, 7807L, 7808L, 7809L, 7810L, 7811L, 7812L, 7813L,
7814L, 7815L, 7816L, 7817L, 7818L, 7819L, 7820L, 7821L, 7822L,
7823L, 7824L, 7825L, 7826L, 7827L, 7828L, 7829L, 7830L, 7831L,
7832L, 7833L, 7834L, 7835L, 7836L, 7837L, 7838L, 7839L, 7840L,
7841L, 7842L, 7843L, 7844L, 7845L, 7846L, 7847L, 7848L, 7849L,
7850L, 7851L, 7852L, 7853L, 7854L, 7855L, 7856L, 7857L, 7858L,
7859L, 7860L, 7861L, 7862L, 7863L, 7864L, 7865L, 7866L, 7867L,
7868L, 7869L, 7870L, 7871L, 7872L, 7873L, 7874L, 7875L, 7876L,
7877L, 7878L, 7879L, 7880L, 7881L, 7882L, 7883L, 7884L, 7885L,
7886L, 7887L, 7888L, 7889L, 7890L, 7891L, 7892L, 7893L, 7894L,
7895L, 7896L, 7897L, 7898L, 7899L, 7900L, 7901L, 7902L, 7903L,
7904L, 7905L, 7906L, 7907L, 7908L, 7909L, 7910L, 7911L, 7912L,
7913L, 7914L, 7915L, 7916L, 7917L, 7918L, 7919L, 7920L, 7921L,
7922L, 7923L, 7924L, 7925L, 7926L, 7927L, 7928L, 7929L, 7930L,
7931L, 7932L, 7933L, 7934L, 7935L, 7936L, 7937L, 7938L, 7939L,
7940L, 7941L, 7942L, 7943L, 7944L, 7945L, 7946L, 7947L, 7948L,
7949L, 7950L, 7951L, 7952L, 7953L, 7954L, 7955L, 7956L, 7957L,
7958L, 7959L, 7960L, 7961L, 7962L, 7963L, 7964L, 7965L, 7966L,
7967L, 7968L, 7969L, 7970L, 7971L, 7972L, 7973L, 7974L, 7975L,
7976L, 7977L, 7978L, 7979L, 7980L, 7981L, 7982L, 7983L, 7984L,
7985L, 7986L, 7987L, 7988L, 7989L, 7990L, 7991L, 7992L, 7993L,
7994L, 7995L, 7996L, 7997L, 7998L, 7999L, 8000L, 8001L, 8002L,
8003L, 8004L, 8005L, 8006L, 8007L, 8008L, 8009L, 8010L, 8011L,
8012L, 8013L, 8014L, 8015L, 8016L, 8017L, 8018L, 8019L, 8020L,
8021L, 8022L, 8023L, 8024L, 8025L, 8026L, 8027L, 8028L, 8029L,
8030L, 8031L, 8032L, 8033L, 8034L, 8035L, 8036L, 8037L, 8038L,
8039L, 8040L, 8041L, 8042L, 8043L, 8044L, 8045L, 8046L, 8047L,
8048L, 8049L, 8050L, 8051L, 8052L, 8053L, 8054L, 8055L, 8056L,
8057L, 8058L, 8059L, 8060L, 8061L, 8062L, 8063L, 8064L, 8065L,
8066L, 8067L, 8068L, 8069L, 8070L, 8071L, 8072L, 8073L, 8074L,
8075L, 8076L, 8077L, 8078L, 8079L, 8080L, 8081L, 8082L, 8083L,
8084L, 8085L, 8086L, 8087L, 8088L, 8089L, 8090L, 8091L, 8092L,
8093L, 8094L, 8095L, 8096L, 8097L, 8098L, 8099L, 8100L, 8101L,
8102L, 8103L, 8104L, 8105L, 8106L, 8107L, 8108L, 8109L, 8110L,
8111L, 8112L, 8113L, 8114L, 8115L, 8116L, 8117L, 8118L, 8119L,
8120L, 8121L, 8122L, 8123L, 8124L, 8125L, 8126L, 8127L, 8128L,
8129L, 8130L, 8131L, 8132L, 8133L, 8134L, 8135L, 8136L, 8137L,
8138L, 8139L, 8140L, 8141L, 8142L, 8143L, 8144L, 8145L, 8146L,
8147L, 8148L, 8149L, 8150L, 8151L, 8152L, 8153L, 8154L, 8155L,
8156L, 8157L, 8158L, 8159L, 8160L, 8161L, 8162L, 8163L, 8164L,
8165L, 8166L, 8167L, 8168L, 8169L, 8170L, 8171L, 8172L, 8173L,
8174L, 8175L, 8176L, 8177L, 8178L, 8179L, 8180L, 8181L, 8182L,
8183L, 8184L, 8185L, 8186L, 8187L, 8188L, 8189L, 8190L, 8191L,
8192L, 8193L, 8194L, 8195L, 8196L, 8197L, 8198L, 8199L, 8200L,
8201L, 8202L, 8203L, 8204L, 8205L, 8206L, 8207L, 8208L, 8209L,
8210L, 8211L, 8212L, 8213L, 8214L, 8215L, 8216L, 8217L, 8218L,
8219L, 8220L, 8221L, 8222L, 8223L, 8224L, 8225L, 8226L, 8227L,
8228L, 8229L, 8230L, 8231L, 8232L, 8233L, 8234L, 8235L, 8236L,
8237L, 8238L, 8239L, 8240L, 8241L, 8242L, 8243L, 8244L, 8245L,
8246L, 8247L, 8248L, 8249L, 8250L, 8251L, 8252L, 8253L, 8254L,
8255L, 8256L, 8257L, 8258L, 8259L, 8260L, 8261L, 8262L, 8263L,
8264L, 8265L, 8266L, 8267L, 8268L, 8269L, 8270L, 8271L, 8272L,
8273L, 8274L, 8275L, 8276L, 8277L, 8278L, 8279L, 8280L, 8281L,
8282L, 8283L, 8284L, 8285L, 8286L, 8287L, 8288L, 8289L, 8290L,
8291L, 8292L, 8293L, 8294L, 8295L, 8296L, 8297L, 8298L, 8299L,
8300L, 8301L, 8302L, 8303L, 8304L, 8305L, 8306L, 8307L, 8308L,
8309L, 8310L, 8311L, 8312L, 8313L, 8314L, 8315L, 8316L, 8317L,
8318L, 8319L, 8320L, 8321L, 8322L, 8323L, 8324L, 8325L, 8326L,
8327L, 8328L, 8329L, 8330L, 8331L, 8332L, 8333L, 8334L, 8335L,
8336L, 8337L, 8338L, 8339L, 8340L, 8341L, 8342L, 8343L, 8344L,
8345L, 8346L, 8347L, 8348L, 8349L, 8350L, 8351L, 8352L, 8353L,
8354L, 8355L, 8356L, 8357L, 8358L, 8359L, 8360L, 8361L, 8362L,
8363L, 8364L, 8365L, 8366L, 8367L, 8368L, 8369L, 8370L, 8371L,
8372L, 8373L, 8374L, 8375L, 8376L, 8377L, 8378L, 8379L, 8380L,
8381L, 8382L, 8383L, 8384L, 8385L, 8386L, 8387L, 8388L, 8389L,
8390L, 8391L, 8392L, 8393L, 8394L, 8395L, 8396L, 8397L, 8398L,
8399L, 8400L, 8401L, 8402L, 8403L, 8404L, 8405L, 8406L, 8407L,
8408L, 8409L, 8410L, 8411L, 8412L, 8413L, 8414L, 8415L, 8416L,
8417L, 8418L, 8419L, 8420L, 8421L, 8422L, 8423L, 8424L, 8425L,
8426L, 8427L, 8428L, 8429L, 8430L, 8431L, 8432L, 8433L, 8434L,
8435L, 8436L, 8437L, 8438L, 8439L, 8440L, 8441L, 8442L, 8443L,
8444L, 8445L, 8446L, 8447L, 8448L, 8449L, 8450L, 8451L, 8452L,
8453L, 8454L, 8455L, 8456L, 8457L, 8458L, 8459L, 8460L, 8461L,
8462L, 8463L, 8464L, 8465L, 8466L, 8467L, 8468L, 8469L, 8470L,
8471L, 8472L, 8473L, 8474L, 8475L, 8476L, 8477L, 8478L, 8479L,
8480L, 8481L, 8482L, 8483L, 8484L, 8485L, 8486L, 8487L, 8488L,
8489L, 8490L, 8491L, 8492L, 8493L, 8494L, 8495L, 8496L, 8497L,
9624L, 9625L, 9626L, 9627L, 9628L, 9629L, 9630L, 9631L, 9632L,
9633L, 9634L, 9635L, 9636L, 9637L, 9638L, 9639L, 9640L, 9641L,
9642L, 9643L, 9644L, 9645L, 9646L, 9647L, 9648L, 9649L, 9650L,
9651L, 9652L, 9653L, 9654L, 9655L, 9656L, 9657L, 9658L, 9659L,
9660L, 9661L, 9662L, 9663L, 9664L, 9665L, 9666L, 9667L, 9668L,
9669L, 9670L, 9671L, 9672L, 9673L, 9674L, 9675L, 9676L, 9677L,
9678L, 9679L, 9680L, 9681L, 9682L, 9683L, 9684L, 9685L, 9686L,
9687L, 9688L, 9689L, 9690L, 9691L, 9692L, 9693L, 9694L, 9695L,
9696L, 9697L, 9698L, 9699L, 9700L, 9701L, 9702L, 9703L, 9704L,
9705L, 9706L, 9707L, 9708L, 9709L, 9710L, 9711L, 9712L, 9713L,
9714L, 9715L, 9716L, 9717L, 9718L, 9719L, 9720L, 9721L, 9722L,
9723L, 9724L, 9725L, 9726L, 9727L, 9728L, 9729L, 9730L, 9731L,
9732L, 9733L, 9734L, 9735L, 9736L, 9737L, 9738L, 9739L, 9740L,
9741L, 9742L, 9743L, 9744L, 9745L, 9746L, 9747L, 9748L, 9749L,
9750L, 9751L, 9752L, 9753L, 9754L, 9755L, 9756L, 9757L, 9758L,
9759L, 9760L, 9761L, 9762L, 9763L, 9764L, 9765L, 9766L, 9767L,
9768L, 9769L, 9770L, 9771L, 9772L, 9773L, 9774L, 9775L, 9776L,
9777L, 9778L, 9779L, 9780L, 9781L, 9782L, 9783L, 9784L, 9785L,
9786L, 9787L, 9788L, 9789L, 9790L, 9791L, 9792L, 9793L, 9794L,
9795L, 9796L, 9797L, 9798L, 9799L, 9800L, 9801L, 9802L, 9803L,
9804L, 9805L, 9806L, 9807L, 9808L, 9809L, 9810L, 9811L, 9812L,
9813L, 9814L, 9815L, 9816L, 9817L, 9818L, 9819L, 9820L, 9821L,
9822L, 9823L, 9824L, 9825L, 9826L, 9827L, 9828L, 9829L, 9830L,
9831L, 9832L, 9833L, 9834L, 9835L, 9836L, 9837L, 9838L, 9839L,
9840L, 9841L, 9842L, 9843L, 9844L, 9845L, 9846L, 9847L, 9848L,
9849L, 9850L, 9851L, 9852L, 9853L, 9854L, 9855L, 9856L, 9857L,
9858L, 9859L, 9860L, 9861L, 9862L, 9863L, 9864L, 9865L, 9866L,
9867L, 9868L, 9869L, 9870L, 9871L, 9872L, 9873L, 9874L, 9875L,
9876L, 9877L, 9878L, 9879L, 9880L, 9881L, 9882L, 9883L, 9884L,
9885L, 9886L, 9887L, 9888L, 9889L, 9890L, 9891L, 9892L, 9893L,
9894L, 9895L, 9896L, 9897L, 9898L, 9899L, 9900L, 9901L, 9902L,
9903L, 9904L, 9905L, 9906L, 9907L, 9908L, 9909L, 9910L, 9911L,
9912L, 9913L, 9914L, 9915L, 9916L, 9917L, 9918L, 9919L, 9920L,
9921L, 9922L, 9923L, 9924L, 9925L, 9926L, 9927L, 9928L, 9929L,
9930L, 9931L, 9932L, 9933L, 9934L, 9935L, 9936L, 9937L, 9938L,
9939L, 9940L, 9941L, 9942L, 9943L, 9944L, 9945L, 9946L, 9947L,
9948L, 9949L, 9950L, 9951L, 9952L, 9953L, 9954L, 9955L, 9956L,
9957L, 9958L, 9959L, 9960L, 9961L, 9962L, 9963L, 9964L, 9965L,
9966L, 9967L, 9968L, 9969L, 9970L, 9971L, 9972L, 9973L, 9974L,
9975L, 9976L, 9977L, 9978L, 9979L, 9980L, 9981L, 9982L, 9983L,
9984L, 9985L, 9986L, 9987L, 9988L, 9989L, 9990L, 9991L, 9992L,
9993L, 9994L, 9995L, 9996L, 9997L, 9998L, 9999L, 10000L, 10001L,
10002L, 10003L, 10004L, 10005L, 10006L, 10007L, 10008L, 10009L,
10010L, 10011L, 10012L, 10013L, 10014L, 10015L, 10016L, 10017L,
10018L, 10019L, 10020L, 10021L, 10022L, 10023L, 10024L, 10025L,
10026L, 10027L, 10028L, 10029L, 10030L, 10031L, 10032L, 10033L,
10034L, 10035L, 10036L, 10037L, 10038L, 10039L, 10040L, 10041L,
10042L, 10043L, 10044L, 10045L, 10046L, 10047L, 10048L, 10049L,
10050L, 10051L, 10052L, 10053L, 10054L, 10055L, 10056L, 10057L,
10058L, 10059L, 10060L, 10061L, 10062L, 10063L, 10064L, 10065L,
10066L, 10067L, 10068L, 10069L, 10070L, 10071L, 10072L, 10073L,
10074L, 10075L, 10076L, 10077L, 10078L, 10079L, 10080L, 10081L,
10082L, 10083L, 10084L, 10085L, 10086L, 10087L, 10088L, 10089L,
10090L, 10091L, 10092L, 10093L, 10094L, 10095L, 10096L, 10097L,
10098L, 10099L, 10100L, 10101L, 10102L, 10103L, 10104L, 10105L,
10106L, 10107L, 10108L, 10109L, 10110L, 10111L, 10112L, 10113L,
10114L, 10115L, 10116L, 10117L, 10118L, 10119L, 10120L, 10121L,
10122L, 10123L, 10124L, 10125L, 10126L, 10127L, 10128L, 10129L,
10130L, 10131L, 10132L, 10133L, 10134L, 10135L, 10136L, 10137L,
10138L, 10139L, 10140L, 10141L, 10142L, 10143L, 10144L, 10145L,
10146L, 10147L, 10148L, 10149L, 10150L, 10151L, 10152L, 10153L,
10154L, 10155L, 10156L, 10157L, 10158L, 10159L, 10160L, 10161L,
10162L, 10163L, 10164L, 10165L, 10166L, 10167L, 10168L, 10169L,
10170L, 10171L, 10172L, 10173L, 10174L, 10175L, 10176L, 10177L,
10178L, 10179L, 10180L, 10181L, 10182L, 10183L, 10184L, 10185L,
10186L, 10187L, 10188L, 10189L, 10190L, 10191L, 10192L, 10193L,
10194L, 10195L, 10196L, 10197L, 10198L, 10199L, 10200L, 10201L,
10202L, 10203L, 10204L, 10205L, 10206L, 10207L, 10208L, 10209L,
10210L, 10211L, 10212L, 10213L, 10214L, 10215L, 10216L, 10217L,
10218L, 10219L, 10220L, 10221L, 10222L, 10223L, 10224L, 10225L,
10226L, 10227L, 10228L, 10229L, 10230L, 10231L, 10232L, 10233L,
10234L, 10235L, 10236L, 10237L, 10238L, 10239L, 10240L, 10241L,
10242L, 10243L, 10244L, 10245L, 10246L, 10247L, 10248L, 10249L,
10250L, 10251L, 10252L, 10253L, 10254L, 10255L, 10256L, 10257L,
10258L, 10259L, 10260L, 10261L, 10262L, 10263L, 10264L, 10265L,
10266L, 10267L, 10268L, 10269L, 10270L, 10271L, 10272L, 10273L,
10274L, 10275L, 10276L, 10277L, 10278L, 10279L, 10280L, 10281L,
10282L, 10283L, 10284L, 10285L, 10286L, 10287L, 10288L, 10289L,
10290L, 10291L, 10292L, 10293L, 10294L, 10295L, 10296L, 10297L,
10298L, 10299L, 10300L, 10301L, 10302L, 10303L, 10304L, 10305L,
10306L, 10307L, 10308L, 10309L, 10310L, 10311L, 10312L, 10313L,
10314L, 10315L, 10316L, 10317L, 10318L, 10319L, 10320L, 10321L,
10322L, 10323L, 10324L, 10325L, 10326L, 10327L, 10328L, 10329L,
10330L, 10331L, 10332L, 10333L, 10334L, 10335L, 10336L, 10337L,
10338L, 10339L, 10340L, 10341L, 10342L, 10343L, 10344L, 10345L,
10346L, 10347L, 10348L, 10349L, 10350L, 10351L, 10352L, 10353L,
10354L, 11819L, 11820L, 11821L, 11822L, 11823L, 11824L, 11825L,
11826L, 11827L, 11828L, 11829L, 11830L, 11831L, 11832L, 11833L,
11834L, 11835L, 11836L, 11837L, 11838L, 11839L, 11840L, 11841L,
11842L, 11843L, 11844L, 11845L, 11846L, 11847L, 11848L, 11849L,
11850L, 11851L, 11852L, 11853L, 11854L, 11855L, 11856L, 11857L,
11858L, 11859L, 11860L, 11861L, 11862L, 11863L, 11864L, 11865L,
11866L, 11867L, 11868L, 11869L, 11870L, 11871L, 11872L, 11873L,
11874L, 11875L, 11876L, 11877L, 11878L, 11879L, 11880L, 11881L,
11882L, 11883L, 11884L, 11885L, 11886L, 11887L, 11888L, 11889L,
11890L, 11891L, 11892L, 11893L, 11894L, 11895L, 11896L, 11897L,
11898L, 11899L, 11900L, 11901L, 11902L, 11903L, 11904L, 11905L,
11906L, 11907L, 11908L, 11909L, 11910L, 11911L, 11912L, 11913L,
11914L, 11915L, 11916L, 11917L, 11918L, 11919L, 11920L, 11921L,
11922L, 11923L, 11924L, 11925L, 11926L, 11927L, 11928L, 11929L,
11930L, 11931L, 11932L, 11933L, 11934L, 11935L, 11936L, 11937L,
11938L, 11939L, 11940L, 11941L, 11942L, 11943L, 11944L, 11945L,
11946L, 11947L, 11948L, 11949L, 11950L, 11951L, 11952L, 11953L,
11954L, 11955L, 11956L, 11957L, 11958L, 11959L, 11960L, 11961L,
11962L, 11963L, 11964L, 11965L, 11966L, 11967L, 11968L, 11969L,
11970L, 11971L, 11972L, 11973L, 11974L, 11975L, 11976L, 11977L,
11978L, 11979L, 11980L, 11981L, 11982L, 11983L, 11984L, 11985L,
11986L, 11987L, 11988L, 11989L, 11990L, 11991L, 11992L, 11993L,
11994L, 11995L, 11996L, 11997L, 11998L, 11999L, 12000L, 12001L,
12002L, 12003L, 12004L, 12005L, 12006L, 12007L, 12008L, 12009L,
12010L, 12011L, 12012L, 12013L, 12014L, 12015L, 12016L, 12017L,
12018L, 12019L, 12020L, 12021L, 12022L, 12023L, 12024L, 12025L,
12026L, 12027L, 12028L, 12029L, 12030L, 12031L, 12032L, 12033L,
12034L, 12035L, 12036L, 12037L, 12038L, 12039L, 12040L, 12041L,
12042L, 12043L, 12044L, 12045L, 12046L, 12047L, 12048L, 12049L,
12050L, 12051L, 12052L, 12053L, 12054L, 12055L, 12056L, 12057L,
12058L, 12059L, 12060L, 12061L, 12062L, 12063L, 12064L, 12065L,
12066L, 12067L, 12068L, 12069L, 12070L, 12071L, 12072L, 12073L,
12074L, 12075L, 12076L, 12077L, 12078L, 12079L, 12080L, 12081L,
12082L, 12083L, 12084L, 12085L, 12086L, 12087L, 12088L, 12089L,
12090L, 12091L, 12092L, 12093L, 12094L, 12095L, 12096L, 12097L,
12098L, 12099L, 12100L, 12101L, 12102L, 12103L, 12104L, 12105L,
12106L, 12107L, 12108L, 12109L, 12110L, 12111L, 12112L, 12113L,
12114L, 12115L, 12116L, 12117L, 12118L, 12119L, 12120L, 12121L,
12122L, 12123L, 12124L, 12125L, 12126L, 12127L, 12128L, 12129L,
12130L, 12131L, 12132L, 12133L, 12134L, 12135L, 12136L, 12137L,
12138L, 12139L, 12140L, 12141L, 12142L, 12143L, 12144L, 12145L,
12146L, 12147L, 12148L, 12149L, 12150L, 12151L, 12152L, 12153L,
12154L, 12155L, 12156L, 12157L, 12158L, 12159L, 12160L, 12161L,
12162L, 12163L, 12164L, 12165L, 12166L, 12167L, 12168L, 12169L,
12170L, 12171L, 12172L, 12173L, 12174L, 12175L, 12176L, 12177L,
12178L, 12179L, 12180L, 12181L, 12182L, 12183L, 12184L, 12185L,
12186L, 12187L, 12188L, 12189L, 12190L, 12191L, 12192L, 12193L,
12194L, 12195L, 12196L, 12197L, 12198L, 12199L, 12200L, 12201L,
12202L, 12203L, 12204L, 12205L, 12206L, 12207L, 12208L, 12209L,
12210L, 12211L, 12212L, 12213L, 12214L, 12215L, 12216L, 12217L,
12218L, 12219L, 12220L, 12221L, 12222L, 12223L, 12224L, 12225L,
12226L, 12227L, 12228L, 12229L, 12230L, 12231L, 12232L, 12233L,
12234L, 12235L, 12236L, 12237L, 12238L, 12239L, 12240L, 12241L,
12242L, 12243L, 12244L, 12245L, 12246L, 12247L, 12248L, 12249L,
12250L, 12251L, 12252L, 12253L, 12254L, 12255L, 12256L, 12257L,
12258L, 12259L, 12260L, 12261L, 12262L, 12263L, 12264L, 12265L,
12266L, 12267L, 12268L, 12269L, 12270L, 12271L, 12272L, 12273L,
12274L, 12275L, 12276L, 12277L, 12278L, 12279L, 12280L, 12281L,
12282L, 12283L, 12284L, 12285L, 12286L, 12287L, 12288L, 12289L,
12290L, 12291L, 12292L, 12293L, 12294L, 12295L, 12296L, 12297L,
12298L, 12299L, 12300L, 12301L, 12302L, 12303L, 12304L, 12305L,
12306L, 12307L, 12308L, 12309L, 12310L, 12311L, 12312L, 12313L,
12314L, 12315L, 12316L, 12317L, 12318L, 12319L, 12320L, 12321L,
12322L, 12323L, 12324L, 12325L, 12326L, 12327L, 12328L, 12329L,
12330L, 12331L, 12332L, 12333L, 12334L, 12335L, 12336L, 12337L,
12338L, 12339L, 12340L, 12341L, 12342L, 12343L, 12344L, 12345L,
12346L, 12347L, 12348L, 12349L, 12350L, 12351L, 12352L, 12353L,
12354L, 12355L, 12356L, 12357L, 12358L, 12359L, 12360L, 12361L,
12362L, 12363L, 12364L, 12365L, 12366L, 12367L, 12368L, 12369L,
12370L, 12371L, 12372L, 12373L, 12374L, 12375L, 12376L, 12377L,
12378L, 12379L, 12380L, 12381L, 12382L, 12383L, 12384L, 12385L,
12386L, 12387L, 12388L, 12389L, 12390L, 12391L, 12392L, 12393L,
12394L, 12395L, 12396L, 12397L, 12398L, 12399L, 12400L, 12401L,
12402L, 12403L, 12404L, 12405L, 12406L, 12407L, 12408L, 12409L,
12410L, 12411L, 12412L, 12413L, 12414L, 12415L, 12416L, 12417L,
12418L, 12419L, 12420L, 12421L, 12422L, 12423L, 12424L, 12425L,
12426L, 12427L, 12428L, 12429L, 12430L, 12431L, 12432L, 12433L,
12434L, 12435L, 12436L, 12437L, 12438L, 12439L, 12440L, 12441L,
12442L, 12443L, 12444L, 12445L, 12446L, 12447L, 12448L, 12449L,
12450L, 12451L, 12452L, 12453L, 12454L, 12455L, 12456L, 12457L,
12458L, 12459L, 12460L, 12461L, 12462L, 12463L, 12464L, 12465L,
12466L, 12467L, 12468L, 12469L, 12470L, 12471L, 12472L, 12473L,
12474L, 12475L, 12476L, 12477L, 12478L, 12479L, 12480L, 12481L,
12482L, 12483L, 12484L, 12485L, 12486L, 12487L, 12488L, 12489L,
12490L, 12491L, 12492L, 12493L, 12494L, 12495L, 12496L, 12497L,
12498L, 12499L, 12500L, 12501L, 12502L, 12503L, 12504L, 12505L,
12506L, 12507L, 12508L, 12509L, 12510L, 12511L, 12512L, 12513L,
12514L, 12515L, 12516L, 12517L, 12518L, 12519L, 12520L, 12521L,
12522L, 12523L, 12524L, 12525L, 12526L, 12527L, 12528L, 12529L,
12530L, 12531L, 12532L, 12533L, 12534L, 12535L, 12536L, 12537L,
12538L, 12539L, 12540L, 12541L, 12542L, 12543L, 12544L, 12545L,
12546L, 12547L, 12548L, 12549L, 12550L, 12551L, 12552L, 12553L,
12554L, 12555L, 12556L, 12557L, 12558L, 12559L, 12560L, 12561L,
12562L, 12563L, 12564L, 12565L, 12566L, 12567L, 12568L, 12569L,
12570L, 12571L, 12572L, 12573L, 12574L, 12575L, 12576L, 12577L,
12578L, 12579L, 12580L, 12581L, 12582L, 12583L, 12584L, 12585L,
12586L, 12587L, 12588L, 12589L, 12590L, 12591L, 12592L, 12593L,
12594L, 12595L, 12596L, 12597L, 12598L, 12599L, 12600L, 12601L,
12602L, 12603L, 12604L, 12605L, 12606L, 12607L, 12608L, 12609L,
12610L, 12611L, 12612L, 12613L, 12614L, 12615L, 12616L, 12617L,
12618L, 12619L, 12620L, 12621L, 12622L, 12623L, 12624L, 12625L,
12626L, 12627L, 12628L, 12629L, 12630L, 12631L, 12632L, 12633L,
12634L, 12635L, 12636L, 12637L, 12638L, 12639L, 12640L, 12641L,
12642L, 12643L, 12644L, 12645L, 12646L, 12647L, 12648L, 12649L,
12650L, 12651L, 12652L, 12653L, 12654L, 12655L, 12656L, 12657L,
12658L, 12659L, 12660L, 12661L, 12662L, 12663L, 12664L, 12665L,
12666L, 12667L, 12668L, 12669L, 12670L, 12671L, 12672L, 12673L,
12674L, 12675L, 12676L, 12677L, 12678L, 12679L, 12680L, 12681L,
12682L, 12683L, 12684L, 12685L, 12686L, 12687L, 12688L, 12689L,
12690L, 12691L, 12692L, 12693L, 12694L, 12695L, 12696L, 12697L,
12698L, 12699L, 12700L, 12701L, 12702L, 12703L, 12704L, 12705L,
12706L, 12707L, 12708L, 12709L, 12710L, 12711L, 12712L, 12713L,
12714L, 12715L, 12716L, 12717L, 12718L, 12719L, 12720L, 12721L,
12722L, 12723L, 12724L, 12725L, 12726L, 12727L, 12728L, 12729L,
12730L, 12731L, 12732L, 12733L, 12734L, 12735L, 12736L, 12737L,
12738L, 12739L, 12740L, 12741L, 12742L, 12743L, 12744L, 12745L,
12746L, 12747L, 12748L, 12749L, 12750L, 12751L, 12752L, 12753L,
12754L, 12755L, 12756L, 12757L, 12758L, 12759L, 12760L, 12761L,
12762L, 12763L, 12764L, 12765L, 12766L, 12767L, 12768L, 12769L,
12770L, 12771L, 12772L, 12773L, 12774L, 12775L, 12776L, 12777L,
12778L, 12779L, 12780L, 12781L, 12782L, 12783L, 12784L, 12785L,
12786L, 12787L, 12788L, 12789L, 12790L, 12791L, 12792L, 12793L,
12794L, 12795L, 12796L, 12797L, 12798L, 12799L, 12800L, 12801L,
12802L, 12803L, 12804L, 12805L, 12806L, 12807L, 12808L, 12809L,
12810L, 12811L, 12812L, 12813L, 12814L, 12815L, 12816L, 12817L,
12818L, 12819L, 12820L, 12821L, 12822L, 12823L, 12824L, 12825L,
12826L, 12827L, 12828L, 12829L, 12830L, 12831L, 12832L, 12833L,
12834L, 12835L, 12836L, 12837L, 12838L, 12839L, 12840L, 12841L,
12842L, 12843L, 12844L, 12845L, 12846L, 12847L, 12848L, 12849L,
12850L, 12851L, 12852L, 12853L, 12854L, 12855L, 12856L, 12857L,
12858L, 12859L, 12860L, 12861L, 12862L, 12863L, 12864L, 12865L,
12866L, 12867L, 12868L, 12869L, 12870L, 12871L, 12872L, 12873L,
12874L, 12875L, 12876L, 12877L, 12878L, 12879L, 12880L, 12881L,
12882L, 12883L, 12884L, 12885L, 12886L, 12887L, 12888L, 12889L,
12890L, 12891L, 12892L, 12893L, 12894L, 12895L, 12896L, 12897L,
12898L, 12899L, 12900L, 12901L, 12902L, 12903L, 12904L, 12905L,
12906L, 12907L, 12908L, 12909L, 12910L, 12911L, 12912L, 12913L,
12914L, 12915L, 12916L, 12917L, 12918L, 12919L, 12920L, 12921L,
12922L, 12923L, 12924L, 12925L, 12926L, 12927L, 12928L, 12929L,
12930L, 12931L, 12932L, 12933L, 12934L, 12935L, 12936L, 12937L,
12938L, 12939L, 12940L, 12941L, 12942L, 12943L, 12944L, 12945L,
12946L, 12947L, 12948L, 12949L, 12950L, 12951L, 12952L, 12953L,
12954L, 12955L, 12956L, 12957L, 12958L, 12959L, 12960L, 12961L,
12962L, 12963L, 12964L, 12965L, 12966L, 12967L, 12968L, 12969L,
12970L, 12971L, 12972L, 12973L, 12974L, 12975L, 12976L, 12977L,
12978L, 12979L, 12980L, 12981L, 12982L, 12983L, 12984L, 12985L,
12986L, 12987L, 12988L, 12989L, 12990L, 12991L, 12992L, 12993L,
12994L, 12995L, 12996L, 12997L, 12998L, 12999L, 13000L, 13001L,
13002L, 13003L, 13004L, 13005L, 13006L, 13007L, 13008L, 13009L,
13010L, 13011L, 13012L, 13013L, 13014L, 13015L, 13016L, 13017L,
13018L, 13019L, 13020L, 13021L, 13022L, 13023L, 13024L, 13025L,
13026L, 13027L, 13028L, 13029L, 13030L, 13031L, 13032L, 13033L,
13034L, 13035L, 13036L, 13037L, 13038L, 13039L, 13040L, 13041L,
13042L, 13043L, 13044L, 13045L, 13046L, 13047L, 13048L, 13049L,
13050L, 13051L, 13052L, 13053L, 13054L, 13055L, 13056L, 13057L,
13058L, 13059L, 13060L, 13061L, 13062L, 13063L, 13064L, 13065L,
13066L, 13067L, 13068L, 13069L, 13070L, 13071L, 13072L, 13073L,
13074L, 13075L, 13076L, 13077L, 13078L, 13079L, 13080L, 13081L,
13082L, 13083L, 13084L, 13085L, 13086L, 13087L, 13088L, 13089L,
13090L, 13091L, 13092L, 13093L, 13094L, 13095L, 13096L, 13097L,
13098L, 13099L, 13100L, 13101L, 13102L, 13103L, 13104L, 13105L,
13106L, 13107L, 13108L, 13109L, 13110L, 13111L, 13112L, 13113L,
13114L, 13115L, 13116L, 13117L, 13118L, 13119L, 13120L, 13121L,
13122L, 13123L, 13124L, 13125L, 13126L, 13127L, 13128L, 13129L,
13130L, 13131L, 13132L, 13133L, 13134L, 13135L, 13136L, 13137L,
13138L, 13139L, 13140L, 13141L, 13142L, 13143L, 13144L, 13145L,
13146L, 13147L, 13148L, 13149L, 13150L, 13151L, 13152L, 13153L,
13154L, 13155L, 13156L, 13157L, 13158L, 13159L, 13160L, 13161L,
13162L, 13163L, 13164L, 13165L, 13166L, 13167L, 13168L, 13169L,
13170L, 13171L, 13172L, 13173L, 13174L, 13175L, 13176L, 13177L,
13178L, 13179L, 13180L, 13181L, 13182L, 13183L, 13184L, 13185L,
13186L, 13187L, 13188L, 13189L, 13190L, 13191L, 13192L, 13193L,
13194L, 13195L, 13196L, 13197L, 13198L, 13199L, 13200L, 13201L,
13202L, 13203L, 13204L, 13205L, 13206L, 13207L, 13208L, 13209L,
13210L, 13211L, 13212L, 13213L, 13214L, 13215L, 13216L, 13217L,
13218L, 13219L, 13220L, 13221L, 13222L, 13223L, 13224L, 13225L,
13226L, 13227L, 13228L, 13229L, 13230L, 13231L, 13232L, 13233L,
13234L, 13235L, 13236L, 13237L, 13238L, 13239L, 13240L, 13241L,
13242L, 13243L, 13244L, 13245L, 13246L, 13247L, 13248L, 13249L,
13250L, 13251L, 13252L, 13253L, 13254L, 13255L, 13256L, 13257L,
13258L, 13259L, 13260L, 13261L, 13262L, 13263L, 13264L, 13265L,
13266L, 13267L, 13268L, 13269L, 13270L, 13271L, 13272L, 13273L,
13274L, 13275L, 13276L, 13277L, 13278L, 13279L, 13280L, 13281L,
13282L, 13283L, 13284L, 13285L, 13286L, 13287L, 13288L, 13289L,
13290L, 13291L, 13292L, 13293L, 13294L, 13295L, 13296L, 13297L,
13298L, 13299L, 13300L, 13301L, 13302L, 13303L, 13304L, 13305L,
13306L, 13307L, 13308L, 13309L, 13310L, 13311L, 13312L, 13313L,
13314L, 13315L, 13316L, 13317L, 13318L, 13319L, 13320L, 13321L,
13322L, 13323L, 13324L, 13325L, 13326L, 13327L, 13328L, 13329L,
13330L, 13331L, 13332L, 13333L, 13334L, 13335L, 13336L, 13337L,
13338L, 13339L, 13340L, 13341L, 13342L, 13343L, 13344L, 13345L,
13346L, 13347L, 13348L, 13349L, 13350L, 13351L, 13352L, 13353L,
13354L, 13355L, 13356L, 13357L, 13358L, 13359L, 13360L, 13361L,
13362L, 13363L, 13364L, 13365L, 13366L, 13367L, 13368L, 13369L,
13370L, 13371L, 13372L, 13373L, 13374L, 13375L, 13376L, 13377L,
13378L, 13379L, 13380L, 13381L, 13382L, 13383L, 13384L, 13385L,
13386L, 13387L, 13388L, 13389L, 13390L, 13391L, 13392L, 13393L,
13394L, 13395L, 13396L, 13397L, 13398L, 13399L, 13400L, 13401L,
13402L, 13403L, 13404L, 13405L, 13406L, 13407L, 13408L, 13409L,
13410L, 13411L, 13412L, 13413L, 13414L, 13415L, 13416L, 13417L,
13418L, 13419L, 13420L, 13421L, 13422L, 13423L, 13424L, 13425L,
13426L, 13427L, 13428L, 13429L, 13430L, 13431L, 13432L, 13433L,
13434L, 13435L, 13436L, 13437L, 13438L, 13439L, 13440L, 13441L,
13442L, 13443L, 13444L, 13445L, 13446L, 13447L, 13448L, 13449L,
13450L, 13451L, 13452L, 13453L, 13454L, 13455L, 13456L, 13457L,
13458L, 13459L, 13460L, 13461L, 13462L, 13463L, 13464L, 13465L,
13466L, 13467L, 13468L, 13469L, 13470L, 13471L, 13472L, 13473L,
13474L, 13475L, 13476L, 13477L, 13478L, 13479L, 13480L, 13481L,
13482L, 13483L, 13484L, 13485L, 13486L, 13487L, 13488L, 13489L,
13490L, 13491L, 13492L, 13493L, 13494L, 13495L, 13496L, 13497L,
13498L, 13499L, 13500L, 13501L, 13502L, 13503L, 13504L, 13505L,
13506L, 13507L, 13508L, 13509L, 13510L, 13511L, 13512L, 13513L,
13514L, 13515L, 13516L, 13517L, 13518L, 13519L, 13520L, 13521L,
13522L, 13523L, 13524L, 13525L, 13526L, 13527L, 13528L, 13529L,
13530L, 13531L, 13532L, 13533L, 13534L, 13535L, 13536L, 13537L,
13538L, 13539L, 13540L, 13541L, 13542L, 13543L, 13544L, 13545L,
13546L, 13547L, 13548L, 13549L, 13550L, 13551L, 13552L, 13553L,
15351L, 13554L, 13555L, 13556L, 13557L, 13558L, 13559L, 13560L,
13561L, 13562L, 13563L, 13564L, 13565L, 13566L, 13567L, 13568L,
13569L, 13570L, 13571L, 13572L, 13573L, 13574L, 13575L, 13576L,
13577L, 13578L, 13579L, 13580L, 13581L, 13582L, 13583L, 15352L,
13584L, 15353L, 15354L, 15355L, 15356L, 15357L, 15358L, 15359L,
15360L, 15361L, 15362L, 15363L, 15364L, 15365L, 15366L, 15367L,
15368L, 15369L, 15370L, 15371L, 15372L, 15373L, 15374L, 15375L,
15376L, 15377L, 15378L, 15379L, 15380L, 15381L, 15382L, 15383L,
15384L, 15385L, 15386L, 15387L, 15388L, 15389L, 15390L, 15391L,
15392L, 15393L, 15394L, 15395L, 15396L, 15397L, 15398L, 15399L,
15400L, 15401L, 15402L, 15403L, 15404L, 15405L, 15406L, 15407L,
15408L, 15409L, 15410L, 15411L, 15412L, 15413L, 15414L, 15415L,
15416L, 15417L, 15418L, 15419L, 15420L, 15421L, 15422L, 15423L,
15424L, 15425L, 15426L, 15427L, 15428L, 15429L, 15430L, 15431L,
15432L, 15433L, 15434L, 15435L, 15436L, 15437L, 15438L, 15439L,
15440L, 15441L, 15442L, 15443L, 15444L, 15445L, 15446L, 15447L,
15448L, 15449L, 15450L, 15451L, 15452L, 15453L, 15454L, 15455L,
15456L, 15457L, 15458L, 15459L, 15460L, 15461L, 15462L, 15463L,
15464L, 15465L, 15466L, 15467L, 15468L, 15469L, 15470L, 15471L,
15472L, 15473L, 15474L, 15475L, 15476L, 15477L, 15478L, 15479L,
15480L, 15481L, 15482L, 15483L, 15484L, 15485L, 15486L, 15487L,
15488L, 15489L, 15490L, 15491L, 15492L, 15493L, 15494L, 15495L,
15496L, 15497L, 15498L, 15499L, 15500L, 15501L, 15502L, 15503L,
15504L, 15505L, 15506L, 15507L, 15508L, 15509L, 15510L, 15511L,
15512L, 15513L, 15514L, 15515L, 15516L, 15517L, 15518L, 15519L,
13585L, 13586L, 13587L, 13588L, 13589L, 13590L, 13591L, 13592L,
13593L, 13594L, 13595L, 13596L, 13597L, 13598L, 13599L, 13600L,
13601L, 13602L, 13603L, 13604L, 13605L, 13606L, 13607L, 13608L,
13609L, 13610L, 13611L, 13612L, 13613L, 13614L, 13615L, 13616L,
13617L, 13618L, 13619L, 13620L, 13621L, 13622L, 13623L, 13624L,
13625L, 13626L, 13627L, 13628L, 13629L, 13630L, 13631L, 13632L,
13633L, 13634L, 13635L, 13636L, 13637L, 13638L, 13639L, 13640L,
13641L, 13642L, 13643L, 13644L, 13645L, 13646L, 13647L, 13648L,
13649L, 13650L, 13651L, 13652L, 13653L, 13654L, 13655L, 13656L,
13657L, 13658L, 13659L, 13660L, 13661L, 13662L, 13663L, 13664L,
13665L, 13666L, 13667L, 13668L, 13669L, 13670L, 13671L, 13672L,
13673L, 13674L, 13675L, 13676L, 13677L, 13678L, 13679L, 13680L,
13681L, 13682L, 13683L, 13684L, 13685L, 13686L, 13687L, 13688L,
13689L, 13690L, 13691L, 13692L, 13693L, 13694L, 13695L, 13696L,
13697L, 13698L, 13699L, 13700L, 13701L, 13702L, 13703L, 13704L,
13705L, 13706L, 13707L, 13708L, 13709L, 13710L, 13711L, 13712L,
13713L, 13714L, 13715L, 13716L, 13717L, 13718L, 13719L, 13720L,
13721L, 13722L, 13723L, 13724L, 13725L, 13726L, 13727L, 13728L,
13729L, 13730L, 13731L, 13732L, 13733L, 13734L, 13735L, 13736L,
13737L, 13738L, 13739L, 13740L, 13741L, 13742L, 13743L, 13744L,
13745L, 13746L, 13747L, 13748L, 13749L, 13750L, 13751L, 13752L,
13753L, 13754L, 13755L, 13756L, 13757L, 13758L, 13759L, 13760L,
13761L, 13762L, 13763L, 13764L, 13765L, 13766L, 13767L, 13768L,
13769L, 13770L, 13771L, 13772L, 13773L, 13774L, 13775L, 13776L,
13777L, 13778L, 13779L, 13780L, 13781L, 13782L, 13783L, 13784L,
13785L, 13786L, 13787L, 13788L, 13789L, 13790L, 13791L, 13792L,
13793L, 13794L, 13795L, 13796L, 13797L, 13798L, 13799L, 13800L,
13801L, 13802L, 13803L, 13804L, 13805L, 13806L, 13807L, 13808L,
13809L, 13810L, 13811L, 13812L, 13813L, 13814L, 13815L, 13816L,
13817L, 13818L, 13819L, 13820L, 13821L, 13822L, 13823L, 13824L,
13825L, 13826L, 13827L, 13828L, 13829L, 13830L, 13831L, 13832L,
13833L, 13834L, 13835L, 13836L, 13837L, 13838L, 13839L, 13840L,
13841L, 13842L, 13843L, 13844L, 13845L, 13846L, 13847L, 13848L,
13849L, 13850L, 13851L, 13852L, 13853L, 13854L, 13855L, 13856L,
13857L, 13858L, 13859L, 13860L, 13861L, 13862L, 13863L, 13864L,
13865L, 13866L, 13867L, 13868L, 13869L, 13870L, 13871L, 13872L,
13873L, 13874L, 13875L, 13876L, 13877L, 13878L, 13879L, 13880L,
13881L, 13882L, 13883L, 13884L, 13885L, 13886L, 13887L, 13888L,
13889L, 13890L, 13891L, 13892L, 13893L, 13894L, 13895L, 13896L,
13897L, 13898L, 13899L, 13900L, 13901L, 13902L, 13903L, 13904L,
13905L, 13906L, 13907L, 13908L, 13909L, 13910L, 13911L, 13912L,
13913L, 13914L, 13915L, 13916L, 13917L, 13918L, 13919L, 13920L,
13921L, 13922L, 13923L, 13924L, 13925L, 13926L, 13927L, 13928L,
13929L, 13930L, 13931L, 13932L, 13933L, 13934L, 13935L, 13936L,
13937L, 13938L, 13939L, 13940L, 13941L, 13942L, 13943L, 13944L,
13945L, 13946L, 13947L, 13948L, 13949L, 13950L, 13951L, 13952L,
13953L, 13954L, 13955L, 13956L, 13957L, 13958L, 13959L, 13960L,
13961L, 13962L, 13963L, 13964L, 13965L, 13966L, 13967L, 13968L,
13969L, 13970L, 13971L, 13972L, 13973L, 13974L, 13975L, 13976L,
13977L, 13978L, 13979L, 13980L, 13981L, 13982L, 13983L, 13984L,
13985L, 13986L, 13987L, 13988L, 13989L, 13990L, 13991L, 13992L,
13993L, 13994L, 13995L, 13996L, 13997L, 13998L, 13999L, 14000L,
14001L, 14002L, 14003L, 14004L, 14005L, 14006L, 14007L, 14008L,
14009L, 14010L, 14011L, 14012L, 14013L, 14014L, 14015L, 14016L,
14017L, 14018L, 14019L, 14020L, 14021L, 14022L, 14023L, 14024L,
14025L, 14026L, 14027L, 14028L, 14029L, 14030L, 14031L, 14032L,
14033L, 14034L, 14035L, 14036L, 14037L, 14038L, 14039L, 14040L,
14041L, 14042L, 14043L, 14044L, 14045L, 14046L, 14047L, 14048L,
14049L, 14050L, 14051L, 14052L, 14053L, 14054L, 14055L, 14056L,
14057L, 14058L, 14059L, 14060L, 14061L, 14062L, 14063L, 14064L,
14065L, 14066L, 14067L, 14068L, 14069L, 14070L, 14071L, 14072L,
14073L, 14074L, 14075L, 14076L, 14077L, 14078L, 14079L, 14080L,
14081L, 14082L, 14083L, 14084L, 14085L, 14086L, 14087L, 14088L,
14089L, 14090L, 14091L, 14092L, 14093L, 14094L, 14095L, 14096L,
14097L, 14098L, 14099L, 14100L, 14101L, 14102L, 14103L, 14104L,
14105L, 14106L, 14107L, 14108L, 14109L, 14110L, 14111L, 14112L,
14113L, 14114L, 14115L, 14116L, 14117L, 14118L, 14119L, 14120L,
14121L, 14122L, 14123L, 14124L, 14125L, 14126L, 14127L, 14128L,
14129L, 14130L, 14131L, 14132L, 14133L, 14134L, 14135L, 14136L,
14137L, 14138L, 14139L, 14140L, 14141L, 14142L, 14143L, 14144L,
14145L, 14146L, 14147L, 14148L, 14149L, 14150L, 14151L, 14152L,
14153L, 14154L, 14155L, 14156L, 14157L, 14158L, 14159L, 14160L,
14161L, 14162L, 14163L, 14164L, 14165L, 14166L, 14167L, 14168L,
14169L, 14170L, 14171L, 14172L, 14173L, 14174L, 14175L, 14176L,
14177L, 14178L, 14179L, 14180L, 14181L, 14182L, 14183L, 14184L,
14185L, 14186L, 14187L, 14188L, 14189L, 14190L, 14191L, 14192L,
14193L, 14194L, 14195L, 14196L, 14197L, 14198L, 14199L, 14200L,
14201L, 14202L, 14203L, 14204L, 14205L, 14206L, 14207L, 14208L,
14209L, 14210L, 14211L, 14212L, 14213L, 14214L, 14215L, 14216L,
14217L, 14218L, 14219L, 14220L, 14221L, 14222L, 14223L, 14224L,
14225L, 14226L, 14227L, 14228L, 14229L, 14230L, 14231L, 14232L,
14233L, 14234L, 14235L, 14236L, 14237L, 14238L, 14239L, 14240L,
14241L, 14242L, 14243L, 14244L, 14245L, 14246L, 14247L, 14248L,
14249L, 14250L, 14251L, 14252L, 14253L, 14254L, 14255L, 14256L,
14257L, 14258L, 14259L, 14260L, 14261L, 14262L, 14263L, 14264L,
14265L, 14266L, 14267L, 14268L, 14269L, 14270L, 14271L, 14272L,
14273L, 14274L, 14275L, 14276L, 14277L, 14278L, 14279L, 14280L,
14281L, 14282L, 14283L, 14284L, 14285L, 14286L, 14287L, 14288L,
14289L, 14290L, 14291L, 14292L, 14293L, 14294L, 14295L, 14296L,
14297L, 14298L, 14299L, 14300L, 14301L, 14302L, 14303L, 14304L,
14305L, 14306L, 14307L, 14308L, 14309L, 14310L, 14311L, 14312L,
14313L, 14314L, 14315L, 14316L, 14317L, 14318L, 14319L, 14320L,
14321L, 14322L, 14323L, 14324L, 14325L, 14326L, 14327L, 14328L,
14329L, 14330L, 14331L, 14332L, 14333L, 14334L, 14335L, 14336L,
14337L, 14338L, 14339L, 14340L, 14341L, 14342L, 14343L, 14344L,
14345L, 14346L, 14347L, 14348L, 14349L, 14350L, 14351L, 14352L,
14353L, 14354L, 14355L, 14356L, 14357L, 14358L, 14359L, 14360L,
14361L, 14362L, 14363L, 14364L, 14365L, 14366L, 14367L, 14368L,
14369L, 14370L, 14371L, 14372L, 14373L, 14374L, 14375L, 14376L,
14377L, 14378L, 14379L, 14380L, 14381L, 14382L, 14383L, 14384L,
14385L, 14386L, 14387L, 14388L, 14389L, 14390L, 14391L, 14392L,
14393L, 14394L, 14395L, 14396L, 14397L, 14398L, 14399L, 14400L,
14401L, 14402L, 14403L, 14404L, 14405L, 14406L, 14407L, 14408L,
14409L, 14410L, 14411L, 14412L, 14413L, 14414L, 14415L, 14416L,
14417L, 14418L, 14419L, 14420L, 14421L, 14422L, 14423L, 14424L,
14425L, 14426L, 14427L, 14428L, 14429L, 14430L, 14431L, 14432L,
14433L, 14434L, 14435L, 14436L, 14437L, 14438L, 14439L, 14440L,
14441L, 14442L, 14443L, 14444L, 14445L, 14446L, 14447L, 14448L,
14449L, 14450L, 14451L, 14452L, 14453L, 14454L, 14455L, 14456L,
14457L, 14458L, 14459L, 14460L, 14461L, 14462L, 14463L, 14464L,
14465L, 14466L, 14467L, 14468L, 14469L, 14470L, 14471L, 14472L,
14473L, 14474L, 14475L, 14476L, 14477L, 14478L, 14479L, 14480L,
14481L, 14482L, 14483L, 14484L, 14485L, 14486L, 14487L, 14488L,
14489L, 14490L, 14491L, 14492L, 14493L, 14494L, 14495L, 14496L,
14497L, 14498L, 14499L, 14500L, 14501L, 14502L, 14503L, 14504L,
14505L, 14506L, 14507L, 14508L, 14509L, 14510L, 14511L, 14512L,
14513L, 14514L, 14515L, 14516L, 14517L, 14518L, 14519L, 14520L,
14521L, 14522L, 14523L, 14524L, 14525L, 14526L, 14527L, 14528L,
14529L, 14530L, 14531L, 14532L, 14533L, 14534L, 14535L, 14536L,
14537L, 14538L, 14539L, 14540L, 14541L, 14542L, 14543L, 14544L,
14545L, 14546L, 14547L, 14548L, 14549L, 14550L, 14551L, 14552L,
14553L, 14554L, 14555L, 14556L, 14557L, 14558L, 14559L, 14560L,
14561L, 14562L, 14563L, 14564L, 14565L, 14566L, 14567L, 14568L,
14569L, 14570L, 14571L, 14572L, 14573L, 14574L, 14575L, 14576L,
14577L, 14578L, 14579L, 14580L, 14581L, 14582L, 14583L, 14584L,
14585L, 14586L, 14587L, 14588L, 14589L, 14590L, 14591L, 14592L,
14593L, 14594L, 14595L, 14596L, 14597L, 14598L, 14599L, 14600L,
14601L, 14602L, 14603L, 14604L, 14605L, 14606L, 14607L, 14608L,
14609L, 14610L, 14611L, 14612L, 14613L, 14614L, 14615L, 14616L,
14617L, 14618L, 14619L, 14620L, 14621L, 14622L, 14623L, 14624L,
14625L, 14626L, 14627L, 14628L, 14629L, 14630L, 14631L, 14632L,
14633L, 14634L, 14635L, 14636L, 14637L, 14638L, 14639L, 14640L,
14641L, 14642L, 14643L, 14644L, 14645L, 14646L, 14647L, 14648L,
14649L, 14650L, 14651L, 14652L, 14653L, 14654L, 14655L, 14656L,
14657L, 14658L, 14659L, 14660L, 14661L, 14662L, 14663L, 14664L,
14665L, 14666L, 14667L, 14668L, 14669L, 14670L, 14671L, 14672L,
14673L, 14674L, 14675L, 14676L, 14677L, 14678L, 14679L, 14680L,
14681L, 14682L, 14683L, 14684L, 14685L, 14686L, 14687L, 14688L,
14689L, 14690L, 14691L, 14692L, 14693L, 14694L, 14695L, 14696L,
14697L, 14698L, 14699L, 14700L, 14701L, 14702L, 14703L, 14704L,
14705L, 14706L, 14707L, 14708L, 14709L, 14710L, 14711L, 14712L,
14713L, 14714L, 14715L, 14716L, 14717L, 14718L, 14719L, 14720L,
14721L, 14722L, 14723L, 14724L, 14725L, 14726L, 14727L, 14728L,
14729L, 14730L, 14731L, 14732L, 14733L, 14734L, 14735L, 14736L,
14737L, 14738L, 14739L, 14740L, 14741L, 14742L, 14743L, 14744L,
14745L, 14746L, 14747L, 14748L, 14749L, 14750L, 14751L, 14752L,
14753L, 14754L, 14755L, 14756L, 14757L, 14758L, 14759L, 14760L,
14761L, 14762L, 14763L, 14764L, 14765L, 14766L, 14767L, 14768L,
14769L, 14770L, 14771L, 14772L, 14773L, 14774L, 14775L, 14776L,
14777L, 14778L, 14779L, 14780L, 14781L, 14782L, 14783L, 14784L,
14785L, 14786L, 14787L, 14788L, 14789L, 14790L, 14791L, 14792L,
14793L, 14794L, 14795L, 14796L, 14797L, 14798L, 14799L, 14800L,
14801L, 14802L, 14803L, 14804L, 14805L, 14806L, 14807L, 14808L,
14809L, 14810L, 14811L, 14812L, 14813L, 14814L, 14815L, 14816L,
14817L, 14818L, 14819L, 14820L, 14821L, 14822L, 14823L, 14824L,
14825L, 14826L, 14827L, 14828L, 14829L, 14830L, 14831L, 14832L,
14833L, 14834L, 14835L, 14836L, 14837L, 14838L, 14839L, 14840L,
14841L, 14842L, 14843L, 14844L, 14845L, 14846L, 14847L, 14848L,
14849L, 14850L, 14851L, 14852L, 14853L, 14854L, 14855L, 14856L,
14857L, 14858L, 14859L, 14860L, 14861L, 14862L, 14863L, 14864L,
14865L, 14866L, 14867L, 14868L, 14869L, 14870L, 14871L, 14872L,
14873L, 14874L, 14875L, 14876L, 14877L, 14878L, 14879L, 14880L,
14881L, 14882L, 14883L, 14884L, 14885L, 14886L, 14887L, 14888L,
14889L, 14890L, 14891L, 14892L, 14893L, 14894L, 14895L, 14896L,
14897L, 14898L, 14899L, 14900L, 14901L, 14902L, 14903L, 14904L,
14905L, 14906L, 14907L, 14908L, 14909L, 14910L, 14911L, 14912L,
14913L, 14914L, 14915L, 14916L, 14917L, 14918L, 14919L, 14920L,
14921L, 14922L, 14923L, 14924L, 14925L, 14926L, 14927L, 14928L,
14929L, 14930L, 14931L, 14932L, 14933L, 14934L, 14935L, 14936L,
14937L, 14938L, 14939L, 14940L, 14941L, 14942L, 14943L, 14944L,
14945L, 14946L, 14947L, 14948L, 14949L, 14950L, 14951L, 14952L,
14953L, 14954L, 14955L, 14956L, 14957L, 14958L, 14959L, 14960L,
14961L, 14962L, 14963L, 14964L, 14965L, 14966L, 14967L, 14968L,
14969L, 14970L, 14971L, 14972L, 14973L, 14974L, 14975L, 14976L,
14977L, 14978L, 14979L, 14980L, 14981L, 14982L, 14983L, 14984L,
14985L, 14986L, 14987L, 14988L, 14989L, 14990L, 14991L, 14992L,
14993L, 14994L, 14995L, 14996L, 14997L, 14998L, 14999L, 15000L,
15001L, 15002L, 15003L, 15004L, 15005L, 15006L, 15007L, 15008L,
15009L, 15010L, 15011L, 15012L, 15013L, 15014L, 15015L, 15016L,
15017L, 15018L, 15019L, 15020L, 15021L, 15022L, 15023L, 15024L,
15025L, 15026L, 15027L, 15028L, 15029L, 15030L, 15031L, 15032L,
15033L, 15034L, 15035L, 15036L, 15037L, 15038L, 15039L, 15040L,
15041L, 15042L, 15043L, 15044L, 15045L, 15046L, 15047L, 15048L,
15049L, 15050L, 15051L, 15052L, 15053L, 15054L, 15055L, 15056L,
15057L, 15058L, 15059L, 15060L, 15061L, 15062L, 15063L, 15064L,
15065L, 15066L, 15067L, 15068L, 15069L, 15070L, 15071L, 15072L,
15073L, 15074L, 15075L, 15076L, 15077L, 15078L, 15079L, 15080L,
15081L, 15082L, 15083L, 15084L, 15085L, 15086L, 15087L, 15088L,
15089L, 15090L, 15091L, 15092L, 15093L, 15094L, 15095L, 15096L,
15097L, 15098L, 15099L, 15100L, 15101L, 15102L, 15103L, 15104L,
15105L, 15106L, 15107L, 15108L, 15109L, 15110L, 15111L, 15112L,
15113L, 15114L, 15115L, 15116L, 15117L, 15118L, 15119L, 15120L,
15121L, 15122L, 15123L, 15124L, 15125L, 15126L, 15127L, 15128L,
15129L, 15130L, 15131L, 15132L, 15133L, 15134L, 15135L, 15136L,
15137L, 15138L, 15139L, 15140L, 15141L, 15142L, 15143L, 15144L,
15145L, 15146L, 15147L, 15148L, 15149L, 15150L, 15151L, 15152L,
15153L, 15154L, 15155L, 15156L, 15157L, 15158L, 15159L, 15160L,
15161L, 15162L, 15163L, 15164L, 15165L, 15166L, 15167L, 15168L,
15169L, 15170L, 15171L, 15172L, 15173L, 15174L, 15175L, 15176L,
15177L, 15178L, 15179L, 15180L, 15181L, 15182L, 15183L, 15184L,
15185L, 15186L, 15187L, 15188L, 15189L, 15190L, 15191L, 15192L,
15193L, 15194L, 15195L, 15196L, 15197L, 15198L, 15199L, 15200L,
15201L, 15202L, 15203L, 15204L, 15205L, 15206L, 15207L, 15208L,
15209L, 15210L, 15211L, 15212L, 15213L, 15214L, 15215L, 15216L,
15217L, 15218L, 15219L, 15220L, 15221L, 15222L, 15223L, 15224L,
15225L, 15226L, 15227L, 15228L, 15229L, 15230L, 15231L, 15232L,
15233L, 15234L, 15235L, 15236L, 15237L, 15238L, 15239L, 15240L,
15241L, 15242L, 15243L, 15244L, 15245L, 15246L, 15247L, 15248L,
15249L, 15250L, 15251L, 15252L, 15253L, 15254L, 15255L, 15256L,
15257L, 15258L, 15259L, 15260L, 15261L, 15262L, 15263L, 15264L,
15265L, 15266L, 15267L, 15268L, 15269L, 15270L, 15271L, 15272L,
15273L, 15274L, 15275L, 15276L, 15277L, 15278L, 15279L, 15280L,
15281L, 15282L, 15283L, 15284L, 15285L, 15286L, 15287L, 15288L,
15289L, 15290L, 15291L, 15292L, 15293L, 15294L, 15295L, 15296L,
15297L, 15298L, 15299L, 15300L, 15301L, 15302L, 15303L, 15304L,
15305L, 15306L, 15307L, 15308L, 15309L, 15310L, 15311L, 15312L,
15313L, 15314L, 15315L, 15316L, 15317L, 15318L, 15319L, 15520L,
15320L, 15321L, 15322L, 15323L, 15324L, 15325L, 15326L, 15327L,
15328L, 15329L, 15330L, 15331L, 15332L, 15333L, 15334L, 15335L,
15336L, 15337L, 15338L, 15339L, 15340L, 15341L, 15342L, 15343L,
15344L, 15345L, 15346L, 15347L, 15348L, 15349L, 15521L, 15350L,
15522L, 15523L, 15524L, 15525L, 15526L, 15527L, 15528L, 15529L,
15530L, 15531L, 15532L, 15533L, 15534L, 15535L, 15536L, 15537L,
15538L, 15539L, 15540L, 15541L, 15542L, 15543L, 15544L, 15545L,
15546L, 15547L, 15548L, 15549L, 15550L, 15551L, 15552L, 15553L,
15554L, 15555L, 15556L, 15557L, 15558L, 15559L, 15560L, 15561L,
15562L, 15563L, 15564L, 15565L, 15566L, 15567L, 15568L, 15569L,
15570L, 15571L, 15572L, 15573L, 15574L, 15575L, 15576L, 15577L,
15578L, 15579L, 15580L, 15581L, 15582L, 15583L, 15584L, 15585L,
15586L, 15587L, 15588L, 15589L, 15590L, 15591L, 15592L, 15593L,
15594L, 15595L, 15596L, 15597L, 15598L, 15599L, 15600L, 15601L,
15602L, 15603L, 15604L, 15605L, 15606L, 15607L, 15608L, 15609L,
15610L, 15611L, 15612L, 15613L, 15614L, 15615L, 15616L, 15617L,
15618L, 15619L, 15620L, 15621L, 15622L, 15623L, 15624L, 15625L,
15626L, 15627L, 15628L, 15629L, 15630L, 15631L, 15632L, 15633L,
15634L, 15635L, 15636L, 15637L, 15638L, 15639L, 15640L, 15641L,
15642L, 15643L, 15644L, 15645L, 15646L, 15647L, 15648L, 15649L,
15650L, 15651L, 15652L, 15653L, 15654L, 15655L, 15656L, 15657L,
15658L, 15659L, 15660L, 15661L, 15662L, 15663L, 15664L, 15665L,
15666L, 15667L, 15668L, 15669L, 15670L, 15671L, 15672L, 15673L,
15674L, 15675L, 15676L, 15677L, 15678L, 15679L, 15680L, 15681L,
15682L, 15683L, 15684L, 15685L, 15686L, 15687L, 15688L, 15689L,
15690L, 15691L, 15692L, 15693L, 15694L, 15695L, 15696L, 15697L,
15698L, 15699L, 15700L, 15701L, 15702L, 15703L, 15704L, 15705L,
15706L, 15707L, 15708L, 15709L, 15710L, 15711L, 15712L, 15713L,
15714L, 15715L, 15716L, 15717L, 15718L, 15719L, 15720L, 15721L,
15722L, 15723L, 15724L, 15725L, 15726L, 15727L, 15728L, 15729L,
15730L, 15731L, 15732L, 15733L, 15734L, 15735L, 15736L, 15737L,
15738L, 15739L, 15740L, 15741L, 15742L, 15743L, 15744L, 15745L,
15746L, 15747L, 15748L, 15749L, 15750L, 15751L, 15752L, 15753L,
15754L, 15755L, 15756L, 15757L, 15758L, 15759L, 15760L, 15761L,
15762L, 15763L, 15764L, 15765L, 15766L, 15767L, 15768L, 15769L,
15770L, 15771L, 15772L, 15773L, 15774L, 15775L, 15776L, 15777L,
15778L, 15779L, 15780L, 15781L, 15782L, 15783L, 15784L, 15785L,
15786L, 15787L, 15788L, 15789L, 15790L, 15791L, 15792L, 15793L,
15794L, 15795L, 15796L, 15797L, 15798L, 15799L, 15800L, 15801L,
15802L, 15803L, 15804L, 15805L, 15806L, 15807L, 15808L, 15809L,
15810L, 15811L, 15812L, 15813L, 15814L, 15815L, 15816L, 15817L,
15818L, 15819L, 15820L, 15821L, 15822L, 15823L, 15824L, 15825L,
15826L, 15827L, 15828L, 15829L, 15830L, 15831L, 15832L, 15833L,
15834L, 15835L, 15836L, 15837L, 15838L, 15839L, 15840L, 15841L,
15842L, 15843L, 15844L, 15845L, 15846L, 15847L, 15848L, 15849L,
15850L, 15851L, 15852L, 15853L, 15854L, 15855L, 15856L, 15857L,
15858L, 15859L, 15860L, 15861L, 15862L, 15863L, 15864L, 15865L,
15866L, 15867L, 15868L, 15869L, 15870L, 15871L, 15872L, 15873L,
15874L, 15875L, 15876L, 15877L, 15878L, 15879L, 15880L, 15881L,
15882L, 15883L, 15884L, 15885L, 15886L, 15887L, 15888L, 15889L,
15890L, 15891L, 15892L, 15893L, 15894L, 15895L, 15896L, 15897L,
15898L, 15899L, 15900L, 15901L, 15902L, 15903L, 15904L, 15905L,
15906L, 15907L, 15908L, 15909L, 15910L, 15911L, 15912L, 15913L,
15914L, 15915L, 15916L, 15917L, 15918L, 15919L, 15920L, 15921L,
15922L, 15923L, 15924L, 15925L, 15926L, 15927L, 15928L, 15929L,
15930L, 15931L, 15932L, 15933L, 15934L, 15935L, 15936L, 15937L,
15938L, 15939L, 15940L, 15941L, 15942L, 15943L, 15944L, 15945L,
15946L, 15947L, 15948L, 15949L, 15950L, 15951L, 15952L, 15953L,
15954L, 15955L, 15956L, 15957L, 15958L, 15959L, 15960L, 15961L,
15962L, 15963L, 15964L, 15965L, 15966L, 15967L, 15968L, 15969L,
15970L, 15971L, 15972L, 15973L, 15974L, 15975L, 15976L, 15977L,
15978L, 15979L, 15980L, 15981L, 15982L, 15983L, 15984L, 15985L,
15986L, 15987L, 15988L, 15989L, 15990L, 15991L, 15992L, 15993L,
15994L, 15995L, 15996L, 15997L, 15998L, 15999L, 16000L, 16001L,
16002L, 16003L, 16004L, 16005L, 16006L, 16007L, 16008L, 16009L,
16010L, 16011L, 16012L, 16013L, 16014L, 16015L, 16016L, 16017L,
16018L, 16019L, 16020L, 16021L, 16022L, 16023L, 16024L, 16025L,
16026L, 16027L, 16028L, 16029L, 16030L, 16031L, 16032L, 16033L,
16034L, 16035L, 16036L, 16037L, 16038L, 16039L, 16040L, 16041L,
16042L, 16043L, 16044L, 16045L, 16046L, 16047L, 16048L, 16049L,
16050L, 16051L, 16052L, 16053L, 16054L, 16055L, 16056L, 16057L,
16058L, 16059L, 16060L, 16061L, 16062L, 16063L, 16064L, 16065L,
16066L, 16067L, 16068L, 16069L, 16070L, 16071L, 16072L, 16073L,
16074L, 16075L, 16076L, 16077L, 16078L, 16079L, 16080L, 16081L,
16082L, 16083L, 16084L, 16085L, 16086L, 16087L, 16088L, 16089L,
16090L, 16091L, 16092L, 16093L, 16094L, 16095L, 16096L, 16097L,
16098L, 16099L, 16100L, 16101L, 16102L, 16103L, 16104L, 16105L,
16106L, 16107L, 16108L, 16109L, 16110L, 16111L, 16112L, 16113L,
16114L, 16115L, 16116L, 16117L, 16118L, 16119L, 16120L, 16121L,
16122L, 16123L, 16124L, 16125L, 16126L, 16127L, 16128L, 16129L,
16130L, 16131L, 16132L, 16133L, 16134L, 16135L, 16136L, 16137L,
16138L, 16139L, 16140L, 16141L, 16142L, 16143L, 16144L, 16145L,
16146L, 16147L, 16148L, 16149L, 16150L, 16151L, 16152L, 16153L,
16154L, 16155L, 16156L, 16157L, 16158L, 16159L, 16160L, 16161L,
16162L, 16163L, 16164L, 16165L, 16166L, 16167L, 16168L, 16169L,
16170L, 16171L, 16172L, 16173L, 16174L, 16175L, 16176L, 16177L,
16178L, 16179L, 16180L, 16181L, 16182L, 16183L, 16184L, 16185L,
16186L, 16187L, 16188L, 16189L, 16190L, 16191L, 16192L, 16193L,
16194L, 16195L, 16196L, 16197L, 16198L, 16199L, 16200L, 16201L,
16202L, 16203L, 16204L, 16205L, 16206L, 16207L, 16208L, 16209L,
16210L, 16211L, 16212L, 16213L, 16214L, 16215L, 16216L, 16217L,
16218L, 16219L, 16220L, 16221L, 16222L, 16223L, 16224L, 16225L,
16226L, 16227L, 16228L, 16229L, 16230L, 16231L, 16232L, 16233L,
16234L, 16235L, 16236L, 16237L, 16238L, 16239L, 16240L, 16241L,
16242L, 16243L, 16244L, 16245L, 16246L, 16247L, 16248L, 16249L,
16250L, 16251L, 16252L, 16253L, 16254L, 16255L, 16256L, 16257L,
16258L, 16259L, 16260L, 16261L, 16262L, 16263L, 16264L, 16265L,
16266L, 16267L, 16268L, 16269L, 16270L, 16271L, 16272L, 16273L,
16274L, 16275L, 16276L, 16277L, 16278L, 16279L, 16280L, 16281L,
16282L, 16283L, 16284L, 16285L, 16286L, 16287L, 16288L, 16289L,
16290L, 16291L, 16292L, 16293L, 16294L, 16295L, 16296L, 16297L,
16298L, 16299L, 16300L, 16301L, 16302L, 16303L, 16304L, 16305L,
16306L, 16307L, 16308L, 16309L, 16310L, 16311L, 16312L, 16313L,
16314L, 16315L, 16316L, 16317L, 16318L, 16319L, 16320L, 16321L,
16322L, 16323L, 16324L, 16325L, 16326L, 16327L, 16328L, 16329L,
16330L, 16331L, 16332L, 16333L, 16334L, 16335L, 16336L, 16337L,
16338L, 16339L, 16340L, 16341L, 16342L, 16343L, 16344L, 16345L,
16346L, 16347L, 16348L, 16349L, 16350L, 16351L, 16352L, 16353L,
16354L, 16355L, 16356L, 16357L, 16358L, 16359L, 16360L, 16361L,
16362L, 16363L, 16364L, 16365L, 16366L, 16367L, 16368L, 16369L,
16370L, 16371L, 16372L, 16373L, 16374L, 16375L, 16376L, 16377L,
16378L, 16379L, 16380L, 16381L, 16382L, 16383L, 16384L, 16385L,
16386L, 16387L, 16388L, 16389L, 16390L, 16391L, 16392L, 16393L,
16394L, 16395L, 16396L, 16397L, 16398L, 16399L, 16400L, 16401L,
16402L, 16403L, 16404L, 16405L, 16406L, 16407L, 16408L, 16409L,
16410L, 16411L, 16412L, 16413L, 16414L, 16415L, 16416L, 16417L,
16418L, 16419L, 16420L, 16421L, 16422L, 16423L, 16424L, 16425L,
16426L, 16427L, 16428L, 16429L, 16430L, 16431L, 16432L, 16433L,
16434L, 16435L, 16436L, 16437L, 16438L, 16439L, 16440L, 16441L,
16442L, 16443L, 16444L, 16445L, 16446L, 16447L, 16448L, 16449L,
16450L, 16451L, 16452L, 16453L, 16454L, 16455L, 16456L, 16457L,
16458L, 16459L, 16460L, 16461L, 16462L, 16463L, 16464L, 16465L,
16466L, 16467L, 16468L, 16469L, 16470L, 16471L, 16472L, 16473L,
16474L, 16475L, 16476L, 16477L, 16478L, 16479L, 16480L, 16481L,
16482L, 16483L, 16484L, 16485L, 16486L, 16487L, 16488L, 16489L,
16490L, 16491L, 16492L, 16493L, 16494L, 16495L, 16496L, 16497L,
16498L, 16499L, 16500L, 16501L, 16502L, 16503L, 16504L, 16505L,
16506L, 16507L, 16508L, 16509L, 16510L, 16511L, 16512L, 16513L,
16514L, 16515L, 16516L, 16517L, 16518L, 16519L, 16520L, 16521L,
16522L, 16523L, 16524L, 16525L, 16526L, 16527L, 16528L, 16529L,
16530L, 16531L, 16532L, 16533L, 16534L, 16535L, 16536L, 16537L,
16538L, 16539L, 16540L, 16541L, 16542L, 16543L, 16544L, 16545L,
16546L, 16547L, 16548L, 16549L, 16550L, 16551L, 16552L, 16553L,
16554L, 16555L, 16556L, 16557L, 16558L, 16559L, 16560L, 16561L,
16562L, 16563L, 16564L, 16565L, 16566L, 16567L, 16568L, 16569L,
16570L, 16571L, 16572L, 16573L, 16574L, 16575L, 16576L, 16577L,
16578L, 16579L, 16580L, 16581L, 16582L, 16583L, 16584L, 16585L,
16586L, 16587L, 16588L, 16589L, 16590L, 16591L, 16592L, 16593L,
16594L, 16595L, 16596L, 16597L, 16598L, 16599L, 16600L, 16601L,
16602L, 16603L, 16604L, 16605L, 16606L, 16607L, 16608L, 16609L,
16610L, 16611L, 16612L, 16613L, 16614L, 16615L, 16616L, 16617L,
16618L, 16619L, 16620L, 16621L, 16622L, 16623L, 16624L, 16625L,
16626L, 16627L, 16628L, 16629L, 16630L, 16631L, 16632L, 16633L,
16634L, 16635L, 16636L, 16637L, 16638L, 16639L, 16640L, 16641L,
16642L, 16643L, 16644L, 16645L, 16646L, 16647L, 16648L, 16649L,
16650L, 16651L, 16652L, 16653L, 16654L, 16655L, 16656L, 16657L,
16658L, 16659L, 16660L, 16661L, 16662L, 16663L, 16664L, 16665L,
16666L, 16667L, 16668L, 16669L, 16670L, 16671L, 16672L, 16673L,
16674L, 16675L, 16676L, 16677L, 16678L, 16679L, 16680L, 16681L,
16682L, 16683L, 16684L, 16685L, 16686L, 16687L, 16688L, 16689L,
16690L, 16691L, 16692L, 16693L, 16694L, 16695L, 16696L, 16697L,
16698L, 16699L, 16700L, 16701L, 16702L, 16703L, 16704L, 16705L,
16706L, 16707L, 16708L, 16709L, 16710L, 16711L, 16712L, 16713L,
16714L, 16715L, 16716L, 16717L, 16718L, 16719L, 16720L, 16721L,
16722L, 16723L, 16724L, 16725L, 16726L, 16727L, 16728L, 16729L,
16730L, 16731L, 16732L, 16733L, 16734L, 16735L, 16736L, 16737L,
16738L, 16739L, 16740L, 16741L, 16742L, 16743L, 16744L, 16745L,
16746L, 16747L, 16748L, 16749L, 16750L, 16751L, 16752L, 16753L,
16754L, 16755L, 16756L, 16757L, 16758L, 16759L, 16760L, 16761L,
16762L, 16763L, 16764L, 16765L, 16766L, 16767L, 16768L, 16769L,
16770L, 16771L, 16772L, 16773L, 16774L, 16775L, 16776L, 16777L,
16778L, 16779L, 16780L, 16781L, 16782L, 16783L, 16784L, 16785L,
16786L, 16787L, 16788L, 16789L, 16790L, 16791L, 16792L, 16793L,
16794L, 16795L, 16796L, 16797L, 16798L, 16799L, 16800L, 16801L,
16802L, 16803L, 16804L, 16805L, 16806L, 16807L, 16808L, 16809L,
16810L, 16811L, 16812L, 16813L, 16814L, 16815L, 16816L, 16817L,
16818L, 16819L, 16820L, 16821L, 16822L, 16823L, 16824L, 16825L,
16826L, 16827L, 16828L, 16829L, 16830L, 16831L, 16832L, 16833L,
16834L, 16835L, 16836L, 16837L, 16838L, 16839L, 16840L, 16841L,
16842L, 16843L, 16844L, 16845L, 16846L, 16847L, 16848L, 16849L,
16850L, 16851L, 16852L, 16853L, 16854L, 16855L, 16856L, 16857L,
16858L, 16859L, 16860L, 16861L, 16862L, 16863L, 16864L, 16865L,
16866L, 16867L, 16868L, 16869L, 16870L, 16871L, 16872L, 16873L,
16874L, 16875L, 16876L, 16877L, 16878L, 16879L, 16880L, 16881L,
16882L, 16883L, 16884L, 16885L, 16886L, 16887L, 16888L, 16889L,
16890L, 16891L, 16892L, 16893L, 16894L, 16895L, 16896L, 16897L,
16898L, 16899L, 16900L, 16901L, 16902L, 16903L, 16904L, 16905L,
16906L, 16907L, 16908L, 16909L, 16910L, 16911L, 16912L, 16913L,
16914L, 16915L, 16916L, 16917L, 16918L, 16919L, 16920L, 16921L,
16922L, 16923L, 16924L, 16925L, 16926L, 16927L, 16928L, 16929L,
16930L, 16931L, 16932L, 16933L, 16934L, 16935L, 16936L, 16937L,
16938L, 16939L, 16940L, 16941L, 16942L, 16943L, 16944L, 16945L,
16946L, 16947L, 16948L, 16949L, 16950L, 16951L, 16952L, 16953L,
16954L, 16955L, 16956L, 16957L, 16958L, 16959L, 16960L, 16961L,
16962L, 16963L, 16964L, 16965L, 16966L, 16967L, 16968L, 16969L,
16970L, 16971L, 16972L, 16973L, 16974L, 16975L, 16976L, 16977L,
16978L, 16979L, 16980L, 16981L, 16982L, 16983L, 16984L, 16985L,
16986L, 16987L, 16988L, 16989L, 16990L, 16991L, 16992L, 16993L,
16994L, 16995L, 16996L, 16997L, 16998L, 16999L, 17000L, 17001L,
17002L, 17003L, 17004L, 17005L, 17006L, 17007L, 17008L, 17009L,
17010L, 17011L, 17012L, 17013L, 17014L, 17015L, 17016L, 17017L,
17018L, 17019L, 17020L, 17021L, 17022L, 17023L, 17024L, 17025L,
17026L, 17027L, 17028L, 17029L, 17030L, 17031L, 17032L, 17033L,
17034L, 17035L, 17036L, 17037L, 17038L, 17039L, 17040L, 17041L,
17042L, 17043L, 17044L, 17045L, 17046L, 17047L, 17048L, 17049L,
17050L, 17051L, 17052L, 17053L, 17054L, 17055L, 17056L, 17057L,
17058L, 17059L, 17060L, 17061L, 17062L, 17063L, 17064L, 17065L,
17066L, 17067L, 17068L, 17069L, 17070L, 17071L, 17072L, 17073L,
17074L, 17075L, 17076L, 17077L, 17078L, 17079L, 17080L, 17081L,
17082L, 17083L, 17084L, 17085L, 17086L, 17087L, 17088L, 17089L,
17090L, 17091L, 17092L, 17093L, 17094L, 17095L, 17096L, 17097L,
17098L, 17099L, 17100L, 17101L, 17102L, 17103L, 17104L, 17105L,
17106L, 17107L, 17108L, 17109L, 17110L, 17111L, 17112L, 17113L,
17114L, 17115L, 17116L, 17117L, 17118L, 17119L, 17120L, 17121L,
17122L, 17123L, 17124L, 17125L, 17126L, 17127L, 17128L, 17129L,
17130L, 17131L, 17132L, 17133L, 17134L, 17135L, 17136L, 17137L,
17138L, 17139L, 17140L, 17141L, 17142L, 17143L, 17144L, 17145L,
17146L, 17147L, 17148L, 17149L, 17150L, 17151L, 17152L, 17153L,
17154L, 17155L, 17156L, 17157L, 17158L, 17159L, 17160L, 17161L,
17162L, 17163L, 17164L, 17165L, 17166L, 17167L, 17168L, 17169L,
17170L, 17171L, 17172L, 17173L, 17174L, 17175L, 17176L, 17177L,
17178L, 17179L, 17180L, 17181L, 17182L, 17183L, 17184L, 17185L,
17186L, 17187L, 17188L, 17189L, 17190L, 17191L, 17192L, 17193L,
17194L, 17195L, 17196L, 17197L, 17198L, 17199L, 17200L, 17201L,
17202L, 17203L, 17204L, 17205L, 17206L, 17207L, 17208L, 17209L,
17210L, 17211L, 17212L, 17213L, 17214L, 17215L, 17216L, 17217L,
17218L, 17219L, 17220L, 17221L, 17222L, 17223L, 17224L, 17225L,
17226L, 17227L, 17228L, 17229L, 17230L, 17231L, 17232L, 17233L,
17234L, 17235L, 17236L, 17237L, 17238L, 17239L, 17240L, 17241L,
17242L, 17243L, 17244L, 17245L, 17246L, 17247L, 17248L, 17249L,
17250L, 17251L, 17252L, 17253L, 17254L, 17255L, 17256L, 17257L,
17258L, 17259L, 17260L, 17261L, 17262L, 17263L, 17264L, 17265L,
17266L, 17267L, 17268L, 17269L, 17270L, 17271L, 17272L, 17273L,
17274L, 17275L, 17276L, 17277L, 17278L, 17279L, 17280L, 17281L,
17282L, 17283L, 17284L, 17285L, 17286L, 17287L, 17288L, 17289L,
17290L, 17291L, 17292L, 17293L, 17294L, 17295L, 17296L, 17297L,
17298L, 17299L, 17300L, 17301L, 17302L, 17303L, 17304L, 17305L,
17306L, 17307L, 17308L, 17309L, 17310L, 17311L, 17312L, 17313L,
17314L, 17315L, 17316L, 17317L, 17318L, 17319L, 17320L, 17321L,
17322L, 17323L, 17324L, 17325L, 17326L, 17327L, 17328L, 17329L,
17330L, 17331L, 17332L, 17333L, 17334L, 17335L, 17336L, 17337L,
17338L, 17339L, 17340L, 17341L, 17342L, 17343L, 17344L, 17345L,
17346L, 17347L, 17348L, 17349L, 17350L, 17351L, 17352L, 17353L,
17354L, 17355L, 17356L, 17357L, 17358L, 17359L, 17360L, 17361L,
17362L, 17363L, 17364L, 17365L, 17366L, 17367L, 17368L, 17369L,
17370L, 17371L, 17372L, 17373L, 17374L, 17375L, 17376L, 17377L,
17378L, 17379L, 17380L, 17381L, 17382L, 17383L, 17384L, 17385L,
17386L, 17387L, 17388L, 17389L, 17390L, 17391L, 17392L, 17393L,
17394L, 17395L, 17396L, 17397L, 17398L, 17399L, 17400L, 17401L,
17402L, 17403L, 17404L, 17405L, 17406L, 17407L, 17408L, 17409L,
17410L, 17411L, 17412L, 17413L, 17414L, 17415L, 17416L, 17417L,
17418L, 17419L, 17420L, 17421L, 17422L, 17423L, 17424L, 17425L,
17426L, 17427L, 17428L, 17429L, 17430L, 17431L, 17432L, 17433L,
17434L, 17435L, 17436L, 17437L, 17438L, 17439L, 17440L, 17441L,
17442L, 17443L, 17444L, 17445L, 17446L, 17447L, 17448L, 17449L,
17450L, 17451L, 17452L, 17453L, 17454L, 17455L, 17456L, 17457L,
17458L, 17459L, 17460L, 17461L, 17462L, 17463L, 17464L, 17465L,
17466L, 17467L, 17468L, 17469L, 17470L, 17471L, 17472L, 17473L,
17474L, 17475L, 17476L, 17477L, 17478L, 17479L, 17480L, 17481L,
17482L, 17483L, 17484L, 17485L, 17486L, 17487L, 17488L, 17489L,
17490L, 17491L, 17492L, 17493L, 17494L, 17495L, 17496L, 17497L,
17498L, 17499L, 17500L, 17501L, 17502L, 17503L, 17504L, 17505L,
17506L, 17507L, 17508L, 17509L, 17510L, 17511L, 17512L, 17513L,
17514L, 17515L, 17516L, 17517L, 17518L, 17519L, 17520L, 17521L,
17522L, 17523L, 17524L, 17525L, 17526L, 17527L, 17528L, 17529L,
17530L, 17531L, 17532L, 17533L, 17534L, 17535L, 17536L, 17537L,
17538L, 17539L, 17540L, 17541L, 17542L, 17543L, 17544L, 17545L,
17546L, 17547L, 17548L, 17549L, 17550L, 17551L, 17552L, 17553L,
17554L, 17555L, 17556L, 17557L, 17558L, 17559L, 17560L, 17561L,
17562L, 17563L, 17564L, 17565L, 17566L, 17567L, 17568L, 17569L,
17570L, 17571L, 17572L, 17573L, 17574L, 17575L, 17576L, 17577L,
17578L, 17579L, 17580L, 17581L, 17582L, 17583L, 17584L, 17585L,
17586L, 17587L, 17588L, 17589L, 17590L, 17591L, 17592L, 17593L,
17594L, 17595L, 17596L, 17597L, 17598L, 17599L, 17600L, 17601L,
17602L, 17603L, 17604L, 17605L, 17606L, 17607L, 17608L, 17609L,
17610L, 17611L, 17612L, 17613L, 17614L, 17615L, 17616L, 17617L,
17618L, 17619L, 17620L, 17621L, 17622L, 17623L, 17624L, 17625L,
17626L, 17627L, 17628L, 17629L, 17630L, 17631L, 17632L, 17633L,
17634L, 17635L, 17636L, 17637L, 17638L, 17639L, 17640L, 17641L,
17642L, 17643L, 17644L, 17645L, 17646L, 17647L, 17648L, 17649L,
17650L, 17651L, 17652L, 17653L, 17654L, 17655L, 17656L, 17657L,
17658L, 17659L, 17660L, 17661L, 17662L, 17663L, 17664L, 17665L,
17666L, 17667L, 17668L, 17669L, 17670L, 17671L, 17672L, 17673L,
17674L, 17675L, 17676L, 17677L, 17678L, 17679L, 17680L, 17681L,
17682L, 17683L, 17684L, 17685L, 17686L, 17687L, 17688L, 17689L,
17690L, 17691L, 17692L, 17693L, 17694L, 17695L, 17696L, 17697L,
17698L, 17699L, 17700L, 17701L, 17702L, 17703L, 17704L, 17705L,
17706L, 17707L, 17708L, 17709L, 17710L, 17711L, 17712L, 17713L,
17714L, 17715L, 17716L, 17717L, 17718L, 17719L, 17720L, 17721L,
17722L, 17723L, 17724L, 17725L, 17726L, 17727L, 17728L, 17729L,
17730L, 17731L, 17732L, 17733L, 17734L, 17735L, 17736L, 17737L,
17738L, 17739L, 17740L, 17741L, 17742L, 17743L, 17744L, 17745L,
17746L, 17747L, 17748L, 17749L, 17750L, 17751L, 17752L, 17753L,
17754L, 17755L, 17756L, 17757L, 17758L, 17759L, 17760L, 17761L,
17762L, 17763L, 17764L, 17765L, 17766L, 17767L, 17768L, 17769L,
17770L, 17771L, 17772L, 17773L, 17774L, 17775L, 17776L, 17777L,
17778L, 17779L, 17780L, 17781L, 17782L, 17783L, 17784L, 17785L,
17786L, 17787L, 17788L, 17789L, 17790L, 17791L, 17792L, 17793L,
17794L, 17795L, 17796L, 17797L, 17798L, 17799L, 17800L, 17801L,
17802L, 17803L, 17804L, 17805L, 17806L, 17807L, 17808L, 17809L,
17810L, 17811L, 17812L, 17813L, 17814L, 17815L, 17816L, 17817L,
17818L, 17819L, 17820L, 17821L, 17822L, 17823L, 17824L, 17825L,
17826L, 17827L, 17828L, 17829L, 17830L, 17831L, 17832L, 17833L,
17834L, 17835L, 17836L, 17837L, 17838L, 17839L, 17840L, 17841L,
17842L, 17843L, 17844L, 17845L, 17846L, 17847L, 17848L, 17849L,
17850L, 17851L, 17852L, 17853L, 17854L, 17855L, 17856L, 17857L,
17858L, 17859L, 17860L, 17861L, 17862L, 17863L, 17864L, 17865L,
17866L, 17867L, 17868L, 17869L, 17870L, 17871L, 17872L, 17873L,
17874L, 17875L, 17876L, 17877L, 17878L, 17879L, 17880L, 17881L,
17882L, 17883L, 17884L, 17885L, 17886L, 17887L, 17888L, 17889L,
17890L, 17891L, 17892L, 17893L, 17894L, 17895L, 17896L, 17897L,
17898L, 17899L, 17900L, 17901L, 17902L, 17903L, 17904L, 17905L,
17906L, 17907L, 17908L, 17909L, 17910L, 17911L, 17912L, 17913L,
17914L, 17915L, 17916L, 17917L, 17918L, 17919L, 17920L, 17921L,
17922L, 17923L, 17924L, 17925L, 17926L, 17927L, 17928L, 17929L,
17930L, 17931L, 17932L, 17933L, 17934L, 17935L, 17936L, 17937L,
17938L, 17939L, 17940L, 17941L, 17942L, 17943L, 17944L, 17945L,
17946L, 17947L, 17948L, 17949L, 17950L, 17951L, 17952L, 17953L,
17954L, 17955L, 17956L, 17957L, 17958L, 17959L, 17960L, 17961L,
17962L, 17963L, 17964L, 17965L, 17966L, 17967L, 17968L, 17969L,
17970L, 17971L, 17972L, 17973L, 17974L, 17975L, 17976L, 17977L,
17978L, 17979L, 17980L, 17981L, 17982L, 17983L, 17984L, 17985L,
17986L, 17987L, 17988L, 17989L, 17990L, 17991L, 17992L, 17993L,
17994L, 17995L, 17996L, 17997L, 17998L, 17999L, 18000L, 18001L,
18002L, 18003L, 18004L, 18005L, 18006L, 18007L, 18008L, 18009L,
18010L, 18011L, 18012L, 18013L, 18014L, 18015L, 18016L, 18017L,
18018L, 18019L, 18020L, 18021L, 18022L, 18023L, 18024L, 18025L,
18026L, 18027L, 18028L, 18029L, 18030L, 18031L, 18032L, 18033L,
18034L, 18035L, 18036L, 18037L, 18038L, 18039L, 18040L, 18041L,
18042L, 18043L, 18044L, 18045L, 18046L, 18047L, 18048L, 18049L,
18050L, 18051L, 18052L, 18053L, 18054L, 18055L, 18056L, 18057L,
18058L, 18059L, 18060L, 18061L, 18062L, 18063L, 18064L, 18065L,
18066L, 18067L, 18068L, 18069L, 18070L, 18071L, 18072L, 18073L,
18074L, 18075L, 18076L, 18077L, 18078L, 18079L, 18080L, 18081L,
18082L, 18083L, 18084L, 18085L, 18086L, 18087L, 18088L, 18089L,
18090L, 18091L, 18092L, 18093L, 18094L, 18095L, 18096L, 18097L,
18098L, 18099L, 18100L, 18101L, 18102L, 18103L, 18104L, 18105L,
18106L, 18107L, 18108L, 18109L, 18110L, 18111L, 18112L, 18113L,
18114L, 18115L, 18116L, 18117L, 18118L, 18119L, 18120L, 18121L,
18122L, 18123L, 18124L, 18125L, 18126L, 18127L, 18128L, 18129L,
18130L, 18131L, 18132L, 18133L, 18134L, 18135L, 18136L, 18137L,
18138L, 18139L, 18140L, 18141L, 18142L, 18143L, 18144L, 18145L,
18146L, 18147L, 18148L, 18149L, 18150L, 18151L, 18152L, 18153L,
18154L, 18155L, 18156L, 18157L, 18158L, 18159L, 18160L, 18161L,
18162L, 18163L, 18164L, 18165L, 18166L, 18167L, 18168L, 18169L,
18170L, 18171L, 18172L, 18173L, 18174L, 18175L, 18176L, 18177L,
18178L, 18179L, 18180L, 18181L, 18182L, 18183L, 18184L, 18185L,
18186L, 18187L, 18188L, 18189L, 18190L, 18191L, 18192L, 18193L,
18194L, 18195L, 18196L, 18197L, 18198L, 18199L, 18200L, 18201L,
18202L, 18203L, 18204L, 18205L, 18206L, 18207L, 18208L, 18209L,
18210L, 18211L, 18212L, 18213L, 18214L, 18215L, 18216L, 18217L,
18218L, 18219L, 18220L, 18221L, 18222L, 18223L, 18224L, 18225L,
18226L, 18227L, 18228L, 18229L, 18230L, 18231L, 18232L, 18233L,
18234L, 18235L, 18236L, 18237L, 18238L, 18239L, 18240L, 18241L,
18242L, 18243L, 18244L, 18245L, 18246L, 18247L, 18248L, 18249L,
18250L, 18251L, 18252L, 18253L, 18254L, 18255L, 18256L, 18257L,
18258L, 18259L, 18260L, 18261L, 18262L, 18263L, 18264L, 18265L,
18266L, 18267L, 18268L, 18269L, 18270L, 18271L, 18272L, 18273L,
18274L, 18275L, 18276L, 18277L, 18278L, 18279L, 18280L, 18281L,
18282L, 18283L, 18284L, 18285L, 18286L, 18287L, 18288L, 18289L,
18290L, 18291L, 18292L, 18293L, 18294L, 18295L, 18296L, 18297L,
18298L, 18299L, 18300L, 18301L, 18302L, 18303L, 18304L, 18305L,
18306L, 18307L, 18308L, 18309L, 18310L, 18311L, 18312L, 18313L,
18314L, 18315L, 18316L, 18317L, 18318L, 18319L, 18320L, 18321L,
18322L, 18323L, 18324L, 18325L, 18326L, 18327L, 18328L, 18329L,
18330L, 18331L, 18332L, 18333L, 18334L, 18335L, 18336L, 18337L,
18338L, 18339L, 18340L, 18341L, 18342L, 18343L, 18344L, 18345L,
18346L, 18347L, 18348L, 18349L, 18350L, 18351L, 18352L, 18353L,
18354L, 18355L, 18356L, 18357L, 18358L, 18359L, 18360L, 18361L,
18362L, 18363L, 18364L, 18365L, 18366L, 18367L, 18368L, 18369L,
18370L, 18371L, 18372L, 18373L, 18374L, 18375L, 18376L, 18377L,
18378L, 18379L, 18380L, 18381L, 18382L, 18383L, 18384L, 18385L,
18386L, 18387L, 18388L, 18389L, 18390L, 18391L, 18392L, 18393L,
18394L, 18395L, 18396L, 18397L, 18398L, 18399L, 18400L, 18401L,
18402L, 18403L, 18404L, 18405L, 18406L, 18407L, 18408L, 18409L,
18410L, 18411L, 18412L, 18413L, 18414L, 18415L, 18416L, 18417L,
18418L, 18419L, 18420L, 18421L, 18422L, 18423L, 18424L, 18425L,
18426L, 18427L, 18428L, 18429L, 18430L, 18431L, 18432L, 18433L,
18434L, 18435L, 18436L, 18437L, 18438L, 18439L, 18440L, 18441L,
18442L, 18443L, 18444L, 18445L, 18446L, 18447L, 18448L, 18449L,
18450L, 18451L, 18452L, 18453L, 18454L, 18455L, 18456L, 18457L,
18458L, 18459L, 18460L, 18461L, 18462L, 18463L, 18464L, 18465L,
18466L, 18467L, 18468L, 18469L, 18470L, 18471L, 18472L, 18473L,
18474L, 18475L, 18476L, 18477L, 18478L, 18479L, 18480L, 18481L,
18482L, 18483L, 18484L, 18485L, 18486L, 18487L, 18488L, 18489L,
18490L, 18491L, 18492L, 18493L, 18494L, 18495L, 18496L, 18497L,
18498L, 18499L, 18500L, 18501L, 18502L, 18503L, 18504L, 18505L,
18506L, 18507L, 18508L, 18509L, 18510L, 18511L, 18512L, 18513L,
18514L, 18515L, 18516L, 18517L, 18518L, 18519L, 18520L, 18521L,
18522L, 18523L, 18524L, 18525L, 18526L, 18527L, 18528L, 18529L,
18530L, 18531L, 18532L, 18533L, 18534L, 18535L, 18536L, 18537L,
18538L, 18539L, 18540L, 18541L, 18542L, 18543L, 18544L, 18545L,
18546L, 18547L, 18548L, 18549L, 18550L, 18551L, 18552L, 18553L,
18554L, 18555L, 18556L, 18557L, 18558L, 18559L, 18560L, 18561L,
18562L, 18563L, 18564L, 18565L, 18566L, 18567L, 18568L, 18569L,
18570L, 18571L, 18572L, 18573L, 18574L, 18575L, 18576L, 18577L,
18578L, 18579L, 18580L, 18581L, 18582L, 18583L, 18584L, 18585L,
18586L, 18587L, 18588L, 18589L, 18590L, 18591L, 18592L, 18593L,
18594L, 18595L, 18596L, 18597L, 18598L, 18599L, 18600L, 18601L,
18602L, 18603L, 18604L, 18605L, 18606L, 18607L, 18608L, 18609L,
18610L, 18611L, 18612L, 18613L, 18614L, 18615L, 18616L, 18617L,
18618L, 18619L, 18620L, 18621L, 18622L, 18623L, 18624L, 18625L,
18626L, 18627L, 18628L, 18629L, 18630L, 18631L, 18632L, 18633L,
18634L, 18635L, 18636L, 18637L, 18638L, 18639L, 18640L, 18641L,
18642L, 18643L, 18644L, 18645L, 18646L, 18647L, 18648L, 18649L,
18650L, 18651L, 18652L, 18653L, 18654L, 18655L, 18656L, 18657L,
18658L, 18659L, 18660L, 18661L, 18662L, 18663L, 18664L, 18665L,
18666L, 18667L, 18668L, 18669L, 18670L, 18671L, 18672L, 18673L,
18674L, 18675L, 18676L, 18677L, 18678L, 18679L, 18680L, 18681L,
18682L, 18683L, 18684L, 18685L, 18686L, 18687L, 18688L, 18689L,
18690L, 18691L, 18692L, 18693L, 18694L, 18695L, 18696L, 18697L,
18698L, 18699L, 18700L, 18701L, 18702L, 18703L, 18704L, 18705L,
18706L, 18707L, 18708L, 18709L, 18710L, 18711L, 18712L, 18713L,
18714L, 18715L, 18716L, 18717L, 18718L, 18719L, 18720L, 18721L,
18722L, 18723L, 18724L, 18725L, 18726L, 18727L, 18728L, 18729L,
18730L, 18731L, 18732L, 18733L, 18734L, 18735L, 18736L, 18737L,
18738L, 18739L, 18740L, 18741L, 18742L, 18743L, 18744L, 18745L,
18746L, 18747L, 18748L, 18749L, 18750L, 18751L, 18752L, 18753L,
18754L, 18755L, 18756L, 18757L, 18758L, 18759L, 18760L, 18761L,
18762L, 18763L, 18764L, 18765L, 18766L, 18767L, 18768L, 18769L,
18770L, 18771L, 18772L, 18773L, 18774L, 18775L, 18776L, 18777L,
18778L, 18779L, 18780L, 18781L, 18782L, 18783L, 18784L, 18785L,
18786L, 18787L, 18788L, 18789L, 18790L, 18791L, 18792L, 18793L,
18794L, 18795L, 18796L, 18797L, 18798L, 18799L, 18800L, 18801L,
18802L, 18803L, 18804L, 18805L, 18806L, 18807L, 18808L, 18809L,
18810L, 18811L, 18812L, 18813L, 18814L, 18815L, 18816L, 18817L,
18818L, 18819L, 18820L, 18821L, 18822L, 18823L, 18824L, 18825L,
18826L, 18827L, 18828L, 18829L, 18830L, 18831L, 18832L, 18833L,
18834L, 18835L, 18836L, 18837L, 18838L, 18839L, 18840L, 18841L,
18842L, 18843L, 18844L, 18845L, 18846L, 18847L, 18848L, 18849L,
18850L, 18851L, 18852L, 18853L, 18854L, 18855L, 18856L, 18857L,
18858L, 18859L, 18860L, 18861L, 18862L, 18863L, 18864L, 18865L,
18866L, 18867L, 18868L, 18869L, 18870L, 18871L, 18872L, 18873L,
18874L, 18875L, 18876L, 18877L, 18878L, 18879L, 18880L, 18881L,
18882L, 18883L, 18884L, 18885L, 18886L, 18887L, 18888L, 18889L,
18890L, 18891L, 18892L, 18893L, 18894L, 18895L, 18896L, 18897L,
18898L, 18899L, 18900L, 18901L, 18902L, 18903L, 18904L, 18905L,
18906L, 18907L, 18908L, 18909L, 18910L, 18911L, 18912L, 18913L,
18914L, 18915L, 18916L, 18917L, 18918L, 18919L, 18920L, 18921L,
18922L, 18923L, 18924L, 18925L, 18926L, 18927L, 18928L, 18929L,
18930L, 18931L, 18932L, 18933L, 18934L, 18935L, 18936L, 18937L,
18938L, 18939L, 18940L, 18941L, 18942L, 18943L, 18944L, 18945L,
18946L, 18947L, 18948L, 18949L, 18950L, 18951L, 18952L, 18953L,
18954L, 18955L, 18956L, 18957L, 18958L, 18959L, 18960L, 18961L,
18962L, 18963L, 18964L, 18965L, 18966L, 18967L, 18968L, 18969L,
18970L, 18971L, 18972L, 18973L, 18974L, 18975L, 18976L, 18977L,
18978L, 18979L, 18980L, 18981L, 18982L, 18983L, 18984L, 18985L,
18986L, 18987L, 18988L, 18989L, 18990L, 18991L, 18992L, 18993L,
18994L, 18995L, 18996L, 18997L, 18998L, 18999L, 19000L, 19001L,
19002L, 19003L, 19004L, 19005L, 19006L, 19007L, 19008L, 19009L,
19010L, 19011L, 19012L, 19013L, 19014L, 19015L, 19016L, 19017L,
19018L, 19019L, 19020L, 19021L, 19022L, 19023L, 19024L, 19025L,
19026L, 19027L, 19028L, 19029L, 19030L, 19031L, 19032L, 19033L,
19034L, 19035L, 19036L, 19037L, 19038L, 19039L, 19040L, 19041L,
19042L, 19043L, 19044L, 19045L, 19046L, 19047L, 19048L, 19049L,
19050L, 19051L, 19052L, 19053L, 19054L, 19055L, 19056L, 19057L,
19058L, 19059L, 19060L, 19061L, 19062L, 19063L, 19064L, 19065L,
19066L, 19067L, 19068L, 19069L, 19070L, 19071L, 19072L, 19073L,
19074L, 19075L, 19076L, 19077L, 19078L, 19079L, 19080L, 19081L,
19082L, 19083L, 19084L, 19085L, 19086L, 19087L, 19088L, 19089L,
19090L, 19091L, 19092L, 19093L, 19094L, 19095L, 19096L, 19097L,
19098L, 19099L, 19100L, 19101L, 19102L, 19103L, 19104L, 19105L,
19106L, 19107L, 19108L, 19109L, 19110L, 19111L, 19112L, 19113L,
19114L, 19115L, 19116L, 19117L, 19118L, 19119L, 19120L, 19121L,
19122L, 19123L, 19124L, 19125L, 19126L, 19127L, 19128L, 19129L,
19130L, 19131L, 19132L, 19133L, 19134L, 19135L, 19136L, 19137L,
19138L, 19139L, 19140L, 19141L, 19142L, 19143L, 19144L, 19145L,
19146L, 19147L, 19148L, 19149L, 19150L, 19151L, 19152L, 19153L,
19154L, 19155L, 19156L, 19157L, 19158L, 19159L, 19160L, 19161L,
19162L, 19163L, 19164L, 19165L, 19166L, 19167L, 19168L, 19169L,
19170L, 19171L, 19172L, 19173L, 19174L, 19175L, 19176L, 19177L,
19178L, 19179L, 19180L, 19181L, 19182L, 19183L, 19184L, 19185L,
19186L, 19187L, 19188L, 19189L, 19190L, 19191L, 19192L, 19193L,
19194L, 19195L, 19196L, 19197L, 19198L, 19199L, 19200L, 19201L,
19202L, 19203L, 19204L, 19205L, 19206L, 19207L, 19208L, 19209L,
19210L, 19211L, 19212L, 19213L, 19214L, 19215L, 19216L, 19217L,
19218L, 19219L, 19220L, 19221L, 19222L, 19223L, 19224L, 19225L,
19226L, 19227L, 19228L, 19229L, 19230L, 19231L, 19232L, 19233L,
19234L, 19235L, 19236L, 19237L, 19238L, 19239L, 19240L, 19241L,
19242L, 19243L, 19244L, 19245L, 19246L, 19247L, 19248L, 19249L,
19250L, 19251L, 19252L, 19253L, 19254L, 19255L, 19256L, 19257L,
19258L, 19259L, 19260L, 19261L, 19262L, 19263L, 19264L, 19265L,
19266L, 19267L, 19268L, 19269L, 19270L, 19271L, 19272L, 19273L,
19274L, 19275L, 19276L, 19277L, 19278L, 19279L, 19280L, 19281L,
19282L, 19283L, 19284L, 19285L, 19286L, 19287L, 19288L, 19289L,
19290L, 19291L, 19292L, 19293L, 19294L, 19295L, 19296L, 19297L,
19298L, 19299L, 19300L, 19301L, 19302L, 19303L, 19304L, 19305L,
19306L, 19307L, 19308L, 19309L, 19310L, 19311L, 19312L, 19313L,
19314L, 19315L, 19316L, 19317L, 19318L, 19319L, 19320L, 19321L,
19322L, 19323L, 19324L, 19325L, 19326L, 19327L, 19328L, 19329L,
19330L, 19331L, 19332L, 19333L, 19334L, 19335L, 19336L, 19337L,
19338L, 19339L, 19340L, 19341L, 19342L, 19343L, 19344L, 19345L,
19346L, 19347L, 19348L, 19349L, 19350L, 19351L, 19352L, 19353L,
19354L, 19355L, 19356L, 19357L, 19358L, 19359L, 19360L, 19361L,
19362L, 19363L, 19364L, 19365L, 19366L, 19367L, 19368L, 19369L,
19370L, 19371L, 19372L, 19373L, 19374L, 19375L, 19376L, 19377L,
19378L, 19379L, 19380L, 19381L, 19382L, 19383L, 19384L, 19385L,
19386L, 19387L, 19388L, 19389L, 19390L, 19391L, 19392L, 19393L,
19394L, 19395L, 19396L, 19397L, 19398L, 19399L, 19400L, 19401L,
19402L, 19403L, 19404L, 19405L, 19406L, 19407L, 19408L, 19409L,
19410L, 19411L, 19412L, 19413L, 19414L, 19415L, 19416L, 19417L,
19418L, 19419L, 19420L, 19421L, 19422L, 19423L, 19424L, 19425L,
19426L, 19427L, 19428L, 19429L, 19430L, 19431L, 19432L, 19433L,
19434L, 19435L, 19436L, 19437L, 19438L, 19439L, 19440L, 19441L,
19442L, 19443L, 19444L, 19445L, 19446L, 19447L, 19448L, 19449L,
19450L, 19451L, 19452L, 19453L, 19454L, 19455L, 19456L, 19457L,
19458L, 19459L, 19460L, 19461L, 19462L, 19463L, 19464L, 19465L,
19466L, 19467L, 19468L, 19469L, 19470L, 19471L, 19472L, 19473L,
19474L, 19475L, 19476L, 19477L, 19478L, 19479L, 19480L, 19481L,
19482L, 19483L, 19484L, 19485L, 19486L, 19487L, 19488L, 19489L,
19490L, 19491L, 19492L, 19493L, 19494L, 19495L, 19496L, 19497L,
19498L, 19499L, 19500L, 19501L, 19502L, 19503L, 19504L, 19505L,
19506L, 19507L, 19508L, 19509L, 19510L, 19511L, 19512L, 19513L,
19514L, 19515L, 19516L, 19517L, 19518L, 19519L, 19520L, 19521L,
19522L, 19523L, 19524L, 19525L, 19526L, 19527L, 19528L, 19529L,
19530L, 19531L, 19532L, 19533L, 19534L, 19535L, 19536L, 19537L,
19538L, 19539L, 19540L, 19541L, 19542L, 19543L, 19544L, 19545L,
19546L, 19547L, 19548L, 19549L, 19550L, 19551L, 19552L, 19553L,
19554L, 19555L, 19556L, 19557L, 19558L, 19559L, 19560L, 19561L,
19562L, 19563L, 19564L, 19565L, 19566L, 19567L, 19568L, 19569L,
19570L, 19571L, 19572L, 19573L, 19574L, 19575L, 19576L, 19577L,
19578L, 19579L, 19580L, 19581L, 19582L, 19583L, 19584L, 19585L,
19586L, 19587L, 19588L, 19589L, 19590L, 19591L, 19592L, 19593L,
19594L, 19595L, 19596L, 19597L, 19598L, 19599L, 19600L, 19601L,
19602L, 19603L, 19604L, 19605L, 19606L, 19607L, 19608L, 19609L,
19610L, 19611L, 19612L, 19613L, 19614L, 19615L, 19616L, 19617L,
19618L, 19619L, 19620L, 19621L, 19622L, 19623L, 19624L, 19625L,
19626L, 19627L, 19628L, 19629L, 19630L, 19631L, 19632L, 19633L,
19634L, 19635L, 19636L, 19637L, 19638L, 19639L, 19640L, 19641L,
19642L, 19643L, 19644L, 19645L, 19646L, 19647L, 19648L, 19649L,
19650L, 19651L, 19652L, 19653L, 19654L, 19655L, 19656L, 19657L,
19658L, 19659L, 19660L, 19661L, 19662L, 19663L, 19664L, 19665L,
19666L, 19667L, 19668L, 19669L, 19670L, 19671L, 19672L, 19673L,
19674L, 19675L, 19676L, 19677L, 19678L, 19679L, 19680L, 19681L,
19682L, 19683L, 19684L, 19685L, 19686L, 19687L, 19688L, 19689L,
19690L, 19691L, 19692L, 19693L, 19694L, 19695L, 19696L, 19697L,
19698L, 19699L, 19700L, 19701L, 19702L, 19703L, 19704L, 19705L,
19706L, 19707L, 19708L, 19709L, 19710L, 19711L, 19712L, 19713L,
19714L, 19715L, 19716L, 19717L, 19718L, 19719L, 19720L, 19721L,
19722L, 19723L, 19724L, 19725L, 19726L, 19727L, 19728L, 19729L,
19730L, 19731L, 19732L, 19733L, 19734L, 19735L, 19736L, 19737L,
19738L, 19739L, 19740L, 19741L, 19742L, 19743L, 19744L, 19745L,
19746L, 19747L, 19748L, 19749L, 19750L, 19751L, 19752L, 19753L,
19754L, 19755L, 19756L, 19757L, 19758L, 19759L, 19760L, 19761L,
19762L, 19763L, 19764L, 19765L, 19766L, 19767L, 19768L, 19769L,
19770L, 19771L, 19772L, 19773L, 19774L, 19775L, 19776L, 19777L,
19778L, 19779L, 19780L, 19781L, 19782L, 19783L, 19784L, 19785L,
19786L, 19787L, 19788L, 19789L, 19790L, 19791L, 19792L, 19793L,
19794L, 19795L, 19796L, 19797L, 19798L, 19799L, 19800L, 19801L,
19802L, 19803L, 19804L, 19805L, 19806L, 19807L, 19808L, 19809L,
19810L, 19811L, 19812L, 19813L, 19814L, 19815L, 19816L, 19817L,
19818L, 19819L, 19820L, 19821L, 19822L, 19823L, 19824L, 19825L,
19826L, 19827L, 19828L, 19829L, 19830L, 19831L, 19832L, 19833L,
19834L, 19835L, 19836L, 19837L, 19838L, 19839L, 19840L, 19841L,
19842L, 19843L, 19844L, 19845L, 19846L, 19847L, 19848L, 19849L,
19850L, 19851L, 19852L, 19853L, 19854L, 19855L, 19856L, 19857L,
19858L, 19859L, 19860L, 19861L, 19862L, 19863L, 19864L, 19865L,
19866L, 19867L, 19868L, 19869L, 19870L, 19871L, 19872L, 19873L,
19874L, 19875L, 19876L, 19877L, 19878L, 19879L, 19880L, 19881L,
19882L, 19883L, 19884L, 19885L, 19886L, 19887L, 19888L, 19889L,
19890L, 19891L, 19892L, 19893L, 19894L, 19895L, 19896L, 19897L,
19898L, 19899L, 19900L, 19901L, 19902L, 19903L, 19904L, 19905L,
19906L, 19907L, 19908L, 19909L, 19910L, 19911L, 19912L, 19913L,
19914L, 19915L, 19916L, 19917L, 19918L, 19919L, 19920L, 19921L,
19922L, 19923L, 19924L, 19925L, 19926L, 19927L, 19928L, 19929L,
19930L, 19931L, 19932L, 19933L, 19934L, 19935L, 19936L, 19937L,
19938L, 19939L, 19940L, 19941L, 19942L, 19943L, 19944L, 19945L,
19946L, 19947L, 19948L, 19949L, 19950L, 19951L, 19952L, 19953L,
19954L, 19955L, 19956L, 19957L, 19958L, 19959L, 19960L, 19961L,
19962L, 19963L, 19964L, 19965L, 19966L, 19967L, 19968L, 19969L,
19970L, 19971L, 19972L, 19973L, 19974L, 19975L, 19976L, 19977L,
19978L, 19979L, 19980L, 19981L, 19982L, 19983L, 19984L, 19985L,
19986L, 19987L, 19988L, 19989L, 19990L, 19991L, 19992L, 19993L,
19994L, 19995L, 19996L, 19997L, 19998L, 19999L, 20000L, 20001L,
20002L, 20003L, 20004L, 20005L, 20006L, 20007L, 20008L, 20009L,
20010L, 20011L, 20012L, 20013L, 20014L, 20015L, 20016L, 20017L,
20018L, 20019L, 20020L, 20021L, 20022L, 20023L, 20024L, 20025L,
20026L, 20027L, 20028L, 20029L, 20030L, 20031L, 20032L, 20033L,
20034L, 20035L, 20036L, 20037L, 20038L, 20039L, 20040L, 20041L,
20042L, 20043L, 20044L, 20045L, 20046L, 20047L, 20048L, 20049L,
20050L, 20051L, 20052L, 20053L, 20054L, 20055L, 20056L, 20057L,
20058L, 20059L, 20060L, 20061L, 20062L, 20063L, 20064L, 20065L,
20066L, 20067L, 20068L, 20069L, 20070L, 20071L, 20072L, 20073L,
20074L, 20075L, 20076L, 20077L, 20078L, 20079L, 20080L, 20081L,
20082L, 20083L, 20084L, 20085L, 20086L, 20087L, 20088L, 20089L,
20090L, 20091L, 20092L, 20093L, 20094L, 20095L, 20096L, 20097L,
20098L, 20099L, 20100L, 20101L, 20102L, 20103L, 20104L, 20105L,
20106L, 20107L, 20108L, 20109L, 20110L, 20111L, 20112L, 20113L,
20114L, 20115L, 20116L, 20117L, 20118L, 20119L, 20120L, 20121L,
20122L, 20123L, 20124L, 20125L, 20126L, 20127L, 20128L, 20129L,
20130L, 20131L, 20132L, 20133L, 20134L, 20135L, 20136L, 20137L,
20138L, 20139L, 20140L, 20141L, 20142L, 20143L, 20144L, 20145L,
20146L, 20147L, 20148L, 20149L, 20150L, 20151L, 20152L, 20153L,
20154L, 20155L, 20156L, 20157L, 20158L, 20159L, 20160L, 20161L,
20162L, 20163L, 20164L, 20165L, 20166L, 20167L, 20168L, 20169L,
20170L, 20171L, 20172L, 20173L, 20174L, 20175L, 20176L, 20177L,
20178L, 20179L, 20180L, 20181L, 20182L, 20183L, 20184L, 20185L,
20186L, 20187L, 20188L, 20189L, 20190L, 20191L, 20192L, 20193L,
20194L, 20195L, 20196L, 20197L, 20198L, 20199L, 20200L, 20201L,
20202L, 20203L, 20204L, 20205L, 20206L, 20207L, 20208L, 20209L,
20210L, 20211L, 20212L, 20213L, 20214L, 20215L, 20216L, 20217L,
20218L, 20219L, 20220L, 20221L, 20222L, 20223L, 20224L, 20225L,
20226L, 20227L, 20228L, 20229L, 20230L, 20231L, 20232L, 20233L,
20234L, 20235L, 20236L, 20237L, 20238L, 20239L, 20240L, 20241L,
20242L, 20243L, 20244L, 20245L, 20246L, 20247L, 20248L, 20249L,
20250L, 20251L, 20252L, 20253L, 20254L, 20255L, 20256L, 20257L,
20258L, 20259L, 20260L, 20261L, 20262L, 20263L, 20264L, 20265L,
20266L, 20267L, 20268L, 20269L, 20270L, 20271L, 20272L, 20273L,
20274L, 20275L, 20276L, 20277L, 20278L, 20279L, 20280L, 20281L,
20282L, 20283L, 20284L, 20285L, 20286L, 20287L, 20288L, 20289L,
20290L, 20291L, 20292L, 20293L, 20294L, 20295L, 20296L, 20297L,
20298L, 20299L, 20300L, 20301L, 20302L, 20303L, 20304L, 20305L,
20306L, 20307L, 20308L, 20309L, 20310L, 20311L, 20312L, 20313L,
20314L, 20315L, 20316L, 20317L, 20318L, 20319L, 20320L, 20321L,
20322L, 20323L, 20324L, 20325L, 20326L, 20327L, 20328L, 20329L,
20330L, 20331L, 20332L, 20333L, 20334L, 20335L, 20336L, 20337L,
20338L, 20339L, 20340L, 20341L, 20342L, 20343L, 20344L, 20345L,
20346L, 20347L, 20348L, 20349L, 20350L, 20351L, 20352L, 20353L,
20354L, 20355L, 20356L, 20357L, 20358L, 20359L, 20360L, 20361L,
20362L, 20363L, 20364L, 20365L, 20366L, 20367L, 20368L, 20369L,
20370L, 20371L, 20372L, 20373L, 20374L, 20375L, 20376L, 20377L,
20378L, 20379L, 20380L, 20381L, 20382L, 20383L, 20384L, 20385L,
20386L, 20387L, 20388L, 20389L, 20390L, 20391L, 20392L, 20393L,
20394L, 20395L, 20396L, 20397L, 20398L, 20399L, 20400L, 20401L,
20402L, 20403L, 20404L, 20405L, 20406L, 20407L, 20408L, 20409L,
20410L, 20411L, 20412L, 20413L, 20414L, 20415L, 20416L, 20417L,
20418L, 20419L, 20420L, 20421L, 20422L, 20423L, 20424L, 20425L,
20426L, 20427L, 20428L, 20429L, 20430L, 20431L, 20432L, 20433L,
20434L, 20435L, 20436L, 20437L, 20438L, 20439L, 20440L, 20441L,
20442L, 20443L, 20444L, 20445L, 20446L, 20447L, 20448L, 20449L,
20450L, 20451L, 20452L, 20453L, 20454L, 20455L, 20456L, 20457L,
20458L, 20459L, 20460L, 20461L, 20462L, 20463L, 20464L, 20465L,
20466L, 20467L, 20468L, 20469L, 20470L, 20471L, 20472L, 20473L,
20474L, 20475L, 20476L, 20477L, 20478L, 20479L, 20480L, 20481L,
20482L, 20483L, 20484L, 20485L, 20486L, 20487L, 20488L, 20489L,
20490L, 20491L, 20492L, 20493L, 20494L, 20495L, 20496L, 20497L,
20498L, 20499L, 20500L, 20501L, 20502L, 20503L, 20504L, 20505L,
20506L, 20507L, 20508L, 20509L, 20510L, 20511L, 20512L, 20513L,
20514L, 20515L, 20516L, 20517L, 20518L, 20519L, 20520L, 20521L,
20522L, 20523L, 20524L, 20525L, 20526L, 20527L, 20528L, 20529L,
20530L, 20531L, 20532L, 20533L, 20534L, 20535L, 20536L, 20537L,
20538L, 20539L, 20540L, 20541L, 20542L, 20543L, 20544L, 20545L,
20546L, 20547L, 20548L, 20549L, 20550L, 20551L, 20552L, 20553L,
20554L, 20555L, 20556L, 20557L, 20558L, 20559L, 20560L, 20561L,
20562L, 20563L, 20564L, 20565L, 20566L, 20567L, 20568L, 20569L,
20570L, 20571L, 20572L, 20573L, 20574L, 20575L, 20576L, 20577L,
20578L, 20579L, 20580L, 20581L, 20582L, 20583L, 20584L, 20585L,
20586L, 20587L, 20588L, 20589L, 20590L, 20591L, 20592L, 20593L,
20594L, 20595L, 20596L, 20597L, 20598L, 20599L, 20600L, 20601L,
20602L, 20603L, 20604L, 20605L, 20606L, 20607L, 20608L, 20609L,
20610L, 20611L, 20612L, 20613L, 20614L, 20615L, 20616L, 20617L,
20618L, 20619L, 20620L, 20621L, 20622L, 20623L, 20624L, 20625L,
20626L, 20627L, 20628L, 20629L, 20630L, 20631L, 20632L, 20633L,
20634L, 20635L, 20636L, 20637L, 20638L, 20639L, 20640L, 20641L,
20642L, 20643L, 20644L, 20645L, 20646L, 20647L, 20648L, 20649L,
20650L, 20651L, 20652L, 20653L, 20654L, 20655L, 20656L, 20657L,
20658L, 20659L, 20660L, 20661L, 20662L, 20663L, 20664L, 20665L,
20666L, 20667L, 20668L, 20669L, 20670L, 20671L, 20672L, 20673L,
20674L, 20675L, 20676L, 20677L, 20678L, 20679L, 20680L, 20681L,
20682L, 20683L, 20684L, 20685L, 20686L, 20687L, 20688L, 20689L,
20690L, 20691L, 20692L, 20693L, 20694L, 20695L, 20696L, 20697L,
20698L, 20699L, 20700L, 20701L, 20702L, 20703L, 20704L, 20705L,
20706L, 20707L, 20708L, 20709L, 20710L, 20711L, 20712L, 20713L,
20714L, 20715L, 20716L, 20717L, 20718L, 20719L, 20720L, 20721L,
20722L, 20723L, 20724L, 20725L, 20726L, 20727L, 20728L, 20729L,
20730L, 20731L, 20732L, 20733L, 20734L, 20735L, 20736L, 20737L,
20738L, 20739L, 20740L, 20741L, 20742L, 20743L, 20744L, 20745L,
20746L, 20747L, 20748L, 20749L, 20750L, 20751L, 20752L, 20753L,
20754L, 20755L, 20756L, 20757L, 20758L, 20759L, 20760L, 20761L,
20762L, 20763L, 20764L, 20765L, 20766L, 20767L, 20768L, 20769L,
20770L, 20771L, 20772L, 20773L, 20774L, 20775L, 20776L, 20777L,
20778L, 20779L, 20780L, 20781L, 20782L, 20783L, 20784L, 20785L,
20786L, 20787L, 20788L, 20789L, 20790L, 20791L, 20792L, 20793L,
20794L, 20795L, 20796L, 20797L, 20798L, 20799L, 20800L, 20801L,
20802L, 20803L, 20804L, 20805L, 20806L, 20807L, 20808L, 20809L,
20810L, 20811L, 20812L, 20813L, 20814L, 20815L, 20816L, 20817L,
20818L, 20819L, 20820L, 20821L, 20822L, 20823L, 20824L, 20825L,
20826L, 20827L, 20828L, 20829L, 20830L, 20831L, 20832L, 20833L,
20834L, 20835L, 20836L, 20837L, 20838L, 20839L, 20840L, 20841L,
20842L, 20843L, 20844L, 20845L, 20846L, 20847L, 20848L, 20849L,
20850L, 20851L, 20852L, 20853L, 20854L, 20855L, 20856L, 20857L,
20858L, 20859L, 20860L, 20861L, 20862L, 20863L, 20864L, 20865L,
20866L, 20867L, 20868L, 20869L, 20870L, 20871L, 20872L, 20873L,
20874L, 20875L, 20876L, 20877L, 20878L, 20879L, 20880L, 20881L,
20882L, 20883L, 20884L, 20885L, 20886L, 20887L, 20888L, 20889L,
20890L, 20891L, 20892L, 20893L, 20894L, 20895L, 20896L, 20897L,
20898L, 20899L, 20900L, 20901L, 20902L, 20903L, 20904L, 20905L,
20906L, 20907L, 20908L, 20909L, 20910L, 20911L, 20912L, 20913L,
20914L, 20915L, 20916L, 20917L, 20918L, 20919L, 20920L, 20921L,
20922L, 20923L, 20924L, 20925L, 20926L, 20927L, 20928L, 20929L,
20930L, 20931L, 20932L, 20933L, 20934L, 20935L, 20936L, 20937L,
20938L, 20939L, 20940L, 20941L, 20942L, 20943L, 20944L, 20945L,
20946L, 20947L, 20948L, 20949L, 20950L, 20951L, 20952L, 20953L,
20954L, 20955L, 20956L, 20957L, 20958L, 20959L, 20960L, 20961L,
20962L, 20963L, 20964L, 20965L, 20966L, 20967L, 20968L, 20969L,
20970L, 20971L, 20972L, 20973L, 20974L, 20975L, 20976L, 20977L,
20978L, 20979L, 20980L, 20981L, 20982L, 20983L, 20984L, 20985L,
20986L, 20987L, 20988L, 20989L, 20990L, 20991L, 20992L, 20993L,
20994L, 20995L, 20996L, 20997L, 20998L, 20999L, 21000L, 21001L,
21002L, 21003L, 21004L, 21005L, 21006L, 21007L, 21008L, 21009L,
21010L, 21011L, 21012L, 21013L, 21014L, 21015L, 21016L, 21017L,
21018L, 21019L, 21020L, 21021L, 21022L, 21023L, 21024L, 21025L,
21026L, 21027L, 21028L, 21029L, 21030L, 21031L, 21032L, 21033L,
21034L, 21035L, 21036L, 21037L, 21038L, 21039L, 21040L, 21041L,
21042L, 21043L, 21044L, 21045L, 21046L, 21047L, 21048L, 21049L,
21050L, 21051L, 21052L, 21053L, 21054L, 21055L, 21056L, 21057L,
21058L, 21059L, 21060L, 21061L, 21062L, 21063L, 21064L, 21065L,
21066L, 21067L, 21068L, 21069L, 21070L, 21071L, 21072L, 21073L,
21074L, 21075L, 21076L, 21077L, 21078L, 21079L, 21080L, 21081L,
21082L, 21083L, 21084L, 21085L, 21086L, 21087L, 21088L, 21089L,
21090L, 21091L, 21092L, 21093L, 21094L, 21095L, 21096L, 21097L,
21098L, 21099L, 21100L, 21101L, 21102L, 21103L, 21104L, 21105L,
21106L, 21107L, 21108L, 21109L, 21110L, 21111L, 21112L, 21113L,
21114L, 21115L, 21116L, 21117L, 21118L, 21119L, 21120L, 21121L,
21122L, 21123L, 21124L, 21125L, 21126L, 21127L, 21128L, 21129L,
21130L, 21131L, 21132L, 21133L, 21134L, 21135L, 21136L, 21137L,
21138L, 21139L, 21140L, 21141L, 21142L, 21143L, 21144L, 21145L,
21146L, 21147L, 21148L, 21149L, 21150L, 21151L, 21152L, 21153L,
21154L, 21155L, 21156L, 21157L, 21158L, 21159L, 21160L, 21161L,
21162L, 21163L, 21164L, 21165L, 21166L, 21167L, 21168L, 21169L,
21170L, 21171L, 21172L, 21173L, 21174L, 21175L, 21176L, 21177L,
21178L, 21179L, 21180L, 21181L, 21182L, 21183L, 21184L, 21185L,
21186L, 21187L, 21188L, 21189L, 21190L, 21191L, 21192L, 21193L,
21194L, 21195L, 21196L, 21197L, 21198L, 21199L, 21200L, 21201L,
21202L, 21203L, 21204L, 21205L, 21206L, 21207L, 21208L, 21209L,
21210L, 21211L, 21212L, 21213L, 21214L, 21215L, 21216L, 21217L,
21218L, 21219L, 21220L, 21221L, 21222L, 21223L, 21224L, 21225L,
21226L, 21227L, 21228L, 21229L, 21230L, 21231L, 21232L, 21233L,
21234L, 21235L, 21236L, 21237L, 21238L, 21239L, 21240L, 21241L,
21242L, 21243L, 21244L, 21245L, 21246L, 21247L, 21248L, 21249L,
21250L, 21251L, 21252L, 21253L, 21254L, 21255L, 21256L, 21257L,
21258L, 21259L, 21260L, 21261L, 21262L, 21263L, 21264L, 21265L,
21266L, 21267L, 21268L, 21269L, 21270L, 21271L, 21272L, 21273L,
21274L, 21275L, 21276L, 21277L, 21278L, 21279L, 21280L, 21281L,
21282L, 21283L, 21284L, 21285L, 21286L, 21287L, 21288L, 21289L,
21290L, 21291L, 21292L, 21293L, 21294L, 21295L, 21296L, 21297L,
21298L, 21299L, 21300L, 21301L, 21302L, 21303L, 21304L, 21305L,
21306L, 21307L, 21308L, 21309L, 21310L, 21311L, 21312L, 21313L,
21314L, 21315L, 21316L, 21317L, 21318L, 21319L, 21320L, 21321L,
21322L, 21323L, 21324L, 21325L, 21326L, 21327L, 21328L, 21329L,
21330L, 21331L, 21332L, 21333L, 21334L, 21335L, 21336L, 21337L,
21338L, 21339L, 21340L, 21341L, 21342L, 21343L, 21344L, 21345L,
21346L, 21347L, 21348L, 21349L, 21350L, 21351L, 21352L, 21353L,
21354L, 21355L, 21356L, 21357L, 21358L, 21359L, 21360L, 21361L,
21362L, 21363L, 21364L, 21365L, 21366L, 21367L, 21368L, 21369L,
21370L, 21371L, 21372L, 21373L, 21374L, 21375L, 21376L, 21377L,
21378L, 21379L, 21380L, 21381L, 21382L, 21383L, 21384L, 21385L,
21386L, 21387L, 21388L, 21389L, 21390L, 21391L, 21392L, 21393L,
21394L, 21395L, 21396L, 21397L, 21398L, 21399L, 21400L, 21401L,
21402L, 21403L, 21404L, 21405L, 21406L, 21407L, 21408L, 21409L,
21410L, 21411L, 21412L, 21413L, 21414L, 21415L, 21416L, 21417L,
21418L, 21419L, 21420L, 21421L, 21422L, 21423L, 21424L, 21425L,
21426L, 21427L, 21428L, 21429L, 21430L, 21431L, 21432L, 21433L,
21434L, 21435L, 21436L, 21437L, 21438L, 21439L, 21440L, 21441L,
21442L, 21443L, 21444L, 21445L, 21446L, 21447L, 21448L, 21449L,
21450L, 21451L, 21452L, 21453L, 21454L, 21455L, 21456L, 21457L,
21458L, 21459L, 21460L, 21461L, 21462L, 21463L, 21464L, 21465L,
21466L, 21467L, 21468L, 21469L, 21470L, 21471L, 21472L, 21473L,
21474L, 21475L, 21476L, 21477L, 21478L, 21479L, 21480L, 21481L,
21482L, 21483L, 21484L, 21485L, 21486L, 21487L, 21488L, 21489L,
21490L, 21491L, 21492L, 21493L, 21494L, 21495L, 21496L, 21497L,
21498L, 21499L, 21500L, 21501L, 21502L, 21503L, 21504L, 21505L,
21506L, 21507L, 21508L, 21509L, 21510L, 21511L, 21512L, 21513L,
21514L, 21515L, 21516L, 21517L, 21518L, 21519L, 21520L, 21521L,
21522L, 21523L, 21524L, 21525L, 21526L, 21527L, 21528L, 21529L,
21530L, 21531L, 21532L, 21533L, 21534L, 21535L, 21536L, 21537L,
21538L, 21539L, 21540L, 21541L, 21542L, 21543L, 21544L, 21545L,
21546L, 21547L, 21548L, 21549L, 21550L, 21551L, 21552L, 21553L,
21554L, 21555L, 21556L, 21557L, 21558L, 21559L, 21560L, 21561L,
21562L, 21563L, 21564L, 21565L, 21566L, 21567L, 21568L, 21569L,
21570L, 21571L, 21572L, 21573L, 21574L, 21575L, 21576L, 21577L,
21578L, 21579L, 21580L, 21581L, 21582L, 21583L, 21584L, 21585L,
21586L, 21587L, 21588L, 21589L, 21590L, 21591L, 21592L, 21593L,
21594L, 21595L, 21596L, 21597L, 21598L, 21599L, 21600L, 21601L,
21602L, 21603L, 21604L, 21605L, 21606L, 21607L, 21608L, 21609L,
21610L, 21611L, 21612L, 21613L, 21614L, 21615L, 21616L, 21617L,
21618L, 21619L, 21620L, 21621L, 21622L, 21623L, 21624L, 21625L,
21626L, 21627L, 21628L, 21629L, 21630L, 21631L, 21632L, 21633L,
21634L, 21635L, 21636L, 21637L, 21638L, 21639L, 21640L, 21641L,
21642L, 21643L, 21644L, 21645L, 21646L, 21647L, 21648L, 21649L,
21650L, 21651L, 21652L, 21653L, 21654L, 21655L, 21656L, 21657L,
21658L, 21659L, 21660L, 21661L, 21662L, 21663L, 21664L, 21665L,
21666L, 21667L, 21668L, 21669L, 21670L, 21671L, 21672L, 21673L,
21674L, 21675L, 21676L, 21677L, 21678L, 21679L, 21680L, 21681L,
21682L, 21683L, 21684L, 21685L, 21686L, 21687L, 21688L, 21689L,
21690L, 21691L, 21692L, 21693L, 21694L, 21695L, 21696L, 21697L,
21698L, 21699L, 21700L, 21701L, 21702L, 21703L, 21704L, 21705L,
21706L, 21707L, 21708L, 21709L, 21710L, 21711L, 21712L, 21713L,
21714L, 21715L, 21716L, 21717L, 21718L, 21719L, 21720L, 21721L,
21722L, 21723L, 21724L, 21725L, 21726L, 21727L, 21728L, 21729L,
21730L, 21731L, 21732L, 21733L, 21734L, 21735L, 21736L, 21737L,
21738L, 21739L, 21740L, 21741L, 21742L, 21743L, 21744L, 21745L,
21746L, 21747L, 21748L, 21749L, 21750L, 21751L, 21752L, 21753L,
21754L, 21755L, 21756L, 21757L, 21758L, 21759L, 21760L, 21761L,
21762L, 21763L, 21764L, 21765L, 21766L, 21767L, 21768L, 21769L,
21770L, 21771L, 21772L, 21773L, 21774L, 21775L, 21776L, 21777L,
21778L, 21779L, 21780L, 21781L, 21782L, 21783L, 21784L, 21785L,
21786L, 21787L, 21788L, 21789L, 21790L, 21791L, 21792L, 21793L,
21794L, 21795L, 21796L, 21797L, 21798L, 21799L, 21800L, 21801L,
21802L, 21803L, 21804L, 21805L, 21806L, 21807L, 21808L, 21809L,
21810L, 21811L, 21812L, 21813L, 21814L, 21815L, 21816L, 21817L,
21818L, 21819L, 21820L, 21821L, 21822L, 21823L, 21824L, 21825L,
21826L, 21827L, 21828L, 21829L, 21830L, 21831L, 21832L, 21833L,
21834L, 21835L, 21836L, 21837L, 21838L, 21839L, 21840L, 21841L,
21842L, 21843L, 21844L, 21845L, 21846L, 21847L, 21848L, 21849L,
21850L, 21851L, 21852L, 21853L, 21854L, 21855L, 21856L, 21857L,
21858L, 21859L, 21860L, 21861L, 21862L, 21863L, 21864L, 21865L,
21866L, 21867L, 21868L, 21869L, 21870L, 21871L, 21872L, 21873L,
21874L, 21875L, 21876L, 21877L, 21878L, 21879L, 21880L, 21881L,
21882L, 21883L, 21884L, 21885L, 21886L, 21887L, 21888L, 21889L,
21890L, 21891L, 21892L, 21893L, 21894L, 21895L, 21896L, 21897L,
21898L, 21899L, 21900L, 21901L, 21902L, 21903L, 21904L, 21905L,
21906L, 21907L, 21908L, 21909L, 21910L, 21911L, 21912L, 21913L,
21914L, 21915L, 21916L, 21917L, 21918L, 21919L, 21920L, 21921L,
21922L, 21923L, 21924L, 21925L, 21926L, 21927L, 21928L, 21929L,
21930L, 21931L, 21932L, 21933L, 21934L, 21935L, 21936L, 21937L,
21938L, 21939L, 21940L, 21941L, 21942L, 21943L, 21944L, 21945L,
21946L, 21947L, 21948L, 21949L, 21950L, 21951L, 21952L, 21953L,
21954L, 21955L, 21956L, 21957L, 21958L, 21959L, 21960L, 21961L,
21962L, 21963L, 21964L, 21965L, 21966L, 21967L, 21968L, 21969L,
21970L, 21971L, 21972L, 21973L, 21974L, 21975L, 21976L, 21977L,
21978L, 21979L, 21980L, 21981L, 21982L, 21983L, 21984L, 21985L,
21986L, 21987L, 21988L, 21989L, 21990L, 21991L, 21992L, 21993L,
21994L, 21995L, 21996L, 21997L, 21998L, 21999L, 22000L, 22001L,
22002L, 22003L, 22004L, 22005L, 22006L, 22007L, 22008L, 22009L,
22010L, 22011L, 22012L, 22013L, 22014L, 22015L, 22016L, 22017L,
22018L, 22019L, 22020L, 22021L, 22022L, 22023L, 22024L, 22025L,
22026L, 22027L, 22028L, 22029L, 22030L, 22031L, 22032L, 22033L,
22034L, 22035L, 22036L, 22037L, 22038L, 22039L, 22040L, 22041L,
22042L, 22043L, 22044L, 22045L, 22046L, 22047L, 22048L, 22049L,
22050L, 22051L, 22052L, 22053L, 22054L, 22055L, 22056L, 22057L,
22058L, 22059L, 22060L, 22061L, 22062L, 22063L, 22064L, 22065L,
22066L, 22067L, 22068L, 22069L, 22070L, 22071L, 22072L, 22073L,
22074L, 22075L, 22076L, 22077L, 22078L, 22079L, 22080L, 22081L,
22082L, 22083L, 22084L, 22085L, 22086L, 22087L, 22088L, 22089L,
22090L, 22091L, 22092L, 22093L, 22094L, 22095L, 22096L, 22097L,
22098L, 22099L, 22100L, 22101L, 22102L, 22103L, 22104L, 22105L,
22106L, 22107L, 22108L, 22109L, 22110L, 22111L, 22112L, 22113L,
22114L, 22115L, 22116L, 22117L, 22118L, 22119L, 22120L, 22121L,
22122L, 22123L, 22124L, 22125L, 22126L, 22127L, 22128L, 22129L,
22130L, 22131L, 22132L, 22133L, 22134L, 22135L, 22136L, 22137L,
22138L, 22139L, 22140L, 22141L, 22142L, 22143L, 22144L, 22145L,
22146L, 22147L, 22148L, 22149L, 22150L, 22151L, 22152L, 22153L,
22154L, 22155L, 22156L, 22157L, 22158L, 22159L, 22160L, 22161L,
22162L, 22163L, 22164L, 22165L, 22166L, 22167L, 22168L, 22169L,
22170L, 22171L, 22172L, 22173L, 22174L, 22175L, 22176L, 22177L,
22178L, 22179L, 22180L, 22181L, 22182L, 22183L, 22184L, 22185L,
22186L, 22187L, 22188L, 22189L, 22190L, 22191L, 22192L, 22193L,
22194L, 22195L, 22196L, 22197L, 22198L, 22199L, 22200L, 22201L,
22202L, 22203L, 22204L, 22205L, 22206L, 22207L, 22208L, 22209L,
22210L, 22211L, 22212L, 22213L, 22214L, 22215L, 22216L, 22217L,
22218L, 22219L, 22220L, 22221L, 22222L, 22223L, 22224L, 22225L,
22226L, 22227L, 22228L, 22229L, 22230L, 22231L, 22232L, 22233L,
22234L, 22235L, 22236L, 22237L, 22238L, 22239L, 22240L, 22241L,
22242L, 22243L, 22244L, 22245L, 22246L, 22247L, 22248L, 22249L,
22250L, 22251L, 22252L, 22253L, 22254L, 22255L, 22256L, 22257L,
22258L, 22259L, 22260L, 22261L, 22262L, 22263L, 22264L, 22265L,
22266L, 22267L, 22268L, 22269L, 22270L, 22271L, 22272L, 22273L,
22274L, 22275L, 22276L, 22277L, 22278L, 22279L, 22280L, 22281L,
22282L, 22283L, 22284L, 22285L, 22286L, 22287L, 22288L, 22289L,
22290L, 22291L, 22292L, 22293L, 22294L, 22295L, 22296L, 22297L,
22298L, 22299L, 22300L, 22301L, 22302L, 22303L, 22304L, 22305L,
22306L, 22307L, 22308L, 22309L, 22310L, 22311L, 22312L, 22313L,
22314L, 22315L, 22316L, 22317L, 22318L, 22319L, 22320L, 22321L,
22322L, 22323L, 22324L, 22325L, 22326L, 22327L, 22328L, 22329L,
22330L, 22331L, 22332L, 22333L, 22334L, 22335L, 22336L, 22337L,
22338L, 22339L, 22340L, 22341L, 22342L, 22343L, 22344L, 22345L,
22346L, 22347L, 22348L, 22349L, 22350L, 22351L, 22352L, 22353L,
22354L, 22355L, 22356L, 22357L, 22358L, 22359L, 22360L, 22361L,
22362L, 22363L, 22364L, 22365L, 22366L, 22367L, 22368L, 22369L,
22370L, 22371L, 22372L, 22373L, 22374L, 22375L, 22376L, 22377L,
22378L, 22379L, 22380L, 22381L, 22382L, 22383L, 22384L, 22385L,
22386L, 22387L, 22388L, 22389L, 22390L, 22391L, 22392L, 22393L,
22394L, 22395L, 22396L, 22397L, 22398L, 22399L, 22400L, 22401L,
22402L, 22403L, 22404L, 22405L, 22406L, 22407L, 22408L, 22409L,
22410L, 22411L, 22412L, 22413L, 22414L, 22415L, 22416L, 22417L,
22418L, 22419L, 22420L, 22421L, 22422L, 22423L, 22424L, 22425L,
22426L, 22427L, 22428L, 22429L, 22430L, 22431L, 22432L, 22433L,
22434L, 22435L, 22436L, 22437L, 22438L, 22439L, 22440L, 22441L,
22442L, 22443L, 22444L, 22445L, 22446L, 22447L, 22448L, 22449L,
22450L, 22451L, 22452L, 22453L, 22454L, 22455L, 22456L, 22457L,
22458L, 22459L, 22460L, 22461L, 22462L, 22463L, 22464L, 22465L,
22466L, 22467L, 22468L, 22469L, 22470L, 22471L, 22472L, 22473L,
22474L, 22475L, 22476L, 22477L, 22478L, 22479L, 22480L, 22481L,
22482L, 22483L, 22484L, 22485L, 22486L, 22487L, 22488L, 22489L,
22490L, 22491L, 22492L, 22493L, 22494L, 22495L, 22496L, 22497L,
22498L, 22499L, 22500L, 22501L, 22502L, 22503L, 22504L, 22505L,
22506L, 22507L, 22508L, 22509L, 22510L, 22511L, 22512L, 22513L,
22514L, 22515L, 22516L, 22517L, 22518L, 22519L, 22520L, 22521L,
22522L, 22523L, 22524L, 22525L, 22526L, 22527L, 22528L, 22529L,
22530L, 22531L, 22532L, 22533L, 22534L, 22535L, 22536L, 22537L,
22538L, 22539L, 22540L, 22541L, 22542L, 22543L, 22544L, 22545L,
22546L, 22547L, 22548L, 22549L, 22550L, 22551L, 22552L, 22553L,
22554L, 22555L, 22556L, 22557L, 22558L, 22559L, 22560L, 22561L,
22562L, 22563L, 22564L, 22565L, 22566L, 22567L, 22568L, 22569L,
22570L, 22571L, 22572L, 22573L, 22574L, 22575L, 22576L, 22577L,
22578L, 22579L, 22580L, 22581L, 22582L, 22583L, 22584L, 22585L,
22586L, 22587L, 22588L, 22589L, 22590L, 22591L, 22592L, 22593L,
22594L, 22595L, 22596L, 22597L, 22598L, 22599L, 22600L, 22601L,
22602L, 22603L, 22604L, 22605L, 22606L, 22607L, 22608L, 22609L,
22610L, 22611L, 22612L, 22613L, 22614L, 22615L, 22616L, 22617L,
22618L, 22619L, 22620L, 22621L, 22622L, 22623L, 22624L, 22625L,
22626L, 22627L, 22628L, 22629L, 22630L, 22631L, 22632L, 22633L,
22634L, 22635L, 22636L, 22637L, 22638L, 22639L, 22640L, 22641L,
22642L, 22643L, 22644L, 22645L, 22646L, 22647L, 22648L, 22649L,
22650L, 22651L, 22652L, 22653L, 22654L, 22655L, 22656L, 22657L,
22658L, 22659L, 22660L, 22661L, 22662L, 22663L, 22664L, 22665L,
22666L, 22667L, 22668L, 22669L, 22670L, 22671L, 22672L, 22673L,
22674L, 22675L, 22676L, 22677L, 22678L, 22679L, 22680L, 22681L,
22682L, 22683L, 22684L, 22685L, 22686L, 22687L, 22688L, 22689L,
22690L, 22691L, 22692L, 22693L, 22694L, 22695L, 22696L, 22697L,
22698L, 22699L, 22700L, 22701L, 22702L, 22703L, 22704L, 22705L,
22706L, 22707L, 22708L, 22709L, 22710L, 22711L, 22712L, 22713L,
22714L, 22715L, 22716L, 22717L, 22718L, 22719L, 22720L, 22721L,
22722L, 22723L, 22724L, 22725L, 22726L, 22727L, 22728L, 22729L,
22730L, 22731L, 22732L, 22733L, 22734L, 22735L, 22736L, 22737L,
22738L, 22739L, 22740L, 22741L, 22742L, 22743L, 22744L, 22745L,
22746L, 22747L, 22748L, 22749L, 22750L, 22751L, 22752L, 22753L,
22754L, 22755L, 22756L, 22757L, 22758L, 22759L, 22760L, 22761L,
22762L, 22763L, 22764L, 22765L, 22766L, 22767L, 22768L, 22769L,
22770L, 22771L, 22772L, 22773L, 22774L, 22775L, 22776L, 22777L,
22778L, 22779L, 22780L, 22781L, 22782L, 22783L, 22784L, 22785L,
22786L, 22787L, 22788L, 22789L, 22790L, 22791L, 22792L, 22793L,
22794L, 22795L, 22796L, 22797L, 22798L, 22799L, 22800L, 22801L,
22802L, 22803L, 22804L, 22805L, 22806L, 22807L, 22808L, 22809L,
22810L, 22811L, 22812L, 22813L, 22814L, 22815L, 22816L, 22817L,
22818L, 22819L, 22820L, 22821L, 22822L, 22823L, 22824L, 22825L,
22826L, 22827L, 22828L, 22829L, 22830L, 22831L, 22832L, 22833L,
22834L, 22835L, 22836L, 22837L, 22838L, 22839L, 22840L, 22841L,
22842L, 22843L, 22844L, 22845L, 22846L, 22847L, 22848L, 22849L,
22850L, 22851L, 22852L, 22853L, 22854L, 22855L, 22856L, 22857L,
22858L, 22859L, 22860L, 22861L, 22862L, 22863L, 22864L, 22865L,
22866L, 22867L, 22868L, 22869L, 22870L, 22871L, 22872L, 22873L,
22874L, 22875L, 22876L, 22877L, 22878L, 22879L, 22880L, 22881L,
22882L, 22883L, 22884L, 22885L, 22886L, 22887L, 22888L, 22889L,
22890L, 22891L, 22892L, 22893L, 22894L, 22895L, 22896L, 22897L,
22898L, 22899L, 22900L, 22901L, 22902L, 22903L, 22904L, 22905L,
22906L, 22907L, 22908L, 22909L, 22910L, 22911L, 22912L, 22913L,
22914L, 22915L, 22916L, 22917L, 22918L, 22919L, 22920L, 22921L,
22922L, 22923L, 22924L, 22925L, 22926L, 22927L, 22928L, 22929L,
22930L, 22931L, 22932L, 22933L, 22934L, 22935L, 22936L, 22937L,
22938L, 22939L, 22940L, 22941L, 22942L, 22943L, 22944L, 22945L,
22946L, 22947L, 22948L, 22949L, 22950L, 22951L, 22952L, 22953L,
22954L, 22955L, 22956L, 22957L, 22958L, 22959L, 22960L, 22961L,
22962L, 22963L, 22964L, 22965L, 22966L, 22967L, 22968L, 22969L,
22970L, 22971L, 22972L, 22973L, 22974L, 22975L, 22976L, 22977L,
22978L, 22979L, 22980L, 22981L, 22982L, 22983L, 22984L, 22985L,
22986L, 22987L, 22988L, 22989L, 22990L, 22991L, 22992L, 22993L,
22994L, 22995L, 22996L, 22997L, 22998L, 22999L, 23000L, 23001L,
23002L, 23003L, 23004L, 23005L, 23006L, 23007L, 23008L, 23009L,
23010L, 23011L, 23012L, 23013L, 23014L, 23015L, 23016L, 23017L,
23018L, 23019L, 23020L, 23021L, 23022L, 23023L, 23024L, 23025L,
23026L, 23027L, 23028L, 23029L, 23030L, 23031L, 23032L, 23033L,
23034L, 23035L, 23036L, 23037L, 23038L, 23039L, 23040L, 23041L,
23042L, 23043L, 23044L, 23045L, 23046L, 23047L, 23048L, 23049L,
23050L, 23051L, 23052L, 23053L, 23054L, 23055L, 23056L, 23057L,
23058L, 23059L, 23060L, 23061L, 23062L, 23063L, 23064L, 23065L,
23066L, 23067L, 23068L, 23069L, 23070L, 23071L, 23072L, 23073L,
23074L, 23075L, 23076L, 23077L, 23078L, 23079L, 23080L, 23081L,
23082L, 23083L, 23084L, 23085L, 23086L, 23087L, 23088L, 23089L,
23090L, 23091L, 23092L, 23093L, 23094L, 23095L, 23096L, 23097L,
23098L, 23099L, 23100L, 23101L, 23102L, 23103L, 23104L, 23105L,
23106L, 23107L, 23108L, 23109L, 23110L, 23111L, 23112L, 23113L,
23114L, 23115L, 23116L, 23117L, 23118L, 23119L, 23120L, 23121L,
23122L, 23123L, 23124L, 23125L, 23126L, 23127L, 23128L, 23129L,
23130L, 23131L, 23132L, 23133L, 23134L, 23135L, 23136L, 23137L,
23138L, 23139L, 23140L, 23141L, 23142L, 23143L, 23144L, 23145L,
23146L, 23147L, 23148L, 23149L, 23150L, 23151L, 23152L, 23153L,
23154L, 23155L, 23156L, 23157L, 23158L, 23159L, 23160L, 23161L,
23162L, 23163L, 23164L, 23165L, 23166L, 23167L, 23168L, 23169L,
23170L, 23171L, 23172L, 23173L, 23174L, 23175L, 23176L, 23177L,
23178L, 23179L, 23180L, 23181L, 23182L, 23183L, 23184L, 23185L,
23186L, 23187L, 23188L, 23189L, 23190L, 23191L, 23192L, 23193L,
23194L, 23195L, 23196L, 23197L, 23198L, 23199L, 23200L, 23201L,
23202L, 23203L, 23204L, 23205L, 23206L, 23207L, 23208L, 23209L,
23210L, 23211L, 23212L, 23213L, 23214L, 23215L, 23216L, 23217L,
23218L, 23219L, 23220L, 23221L, 23222L, 23223L, 23224L, 23225L,
23226L, 23227L, 23228L, 23229L, 23230L, 23231L, 23232L, 23233L,
23234L, 23235L, 23236L, 23237L, 23238L, 23239L, 23240L, 23241L,
23242L, 23243L, 23244L, 23245L, 23246L, 23247L, 23248L, 23249L,
23250L, 23251L, 23252L, 23253L, 23254L, 23255L, 23256L, 23257L,
23258L, 23259L, 23260L, 23261L, 23262L, 23263L, 23264L, 23265L,
23266L, 23267L, 23268L, 23269L, 23270L, 23271L, 23272L, 23273L,
23274L, 23275L, 23276L, 23277L, 23278L, 23279L, 23280L, 23281L,
23282L, 23283L, 23284L, 23285L, 23286L, 23287L, 23288L, 23289L,
23290L, 23291L, 23292L, 23293L, 23294L, 23295L, 23296L, 23297L,
23298L, 23299L, 23300L, 23301L, 23302L, 23303L, 23304L, 23305L,
23306L, 23307L, 23308L, 23309L, 23310L, 23311L, 23312L, 23313L,
23314L, 23315L, 23316L, 23317L, 23318L, 23319L, 23320L, 23321L,
23322L, 23323L, 23324L, 23325L, 23326L, 23327L, 23328L, 23329L,
23330L, 23331L, 23332L, 23333L, 23334L, 23335L, 23336L, 23337L,
23338L, 23339L, 23340L, 23341L, 23342L, 23343L, 23344L, 23345L,
23346L, 23347L, 23348L, 23349L, 23350L, 23351L, 23352L, 23353L,
23354L, 23355L, 23356L, 23357L, 23358L, 23359L, 23360L, 23361L,
23362L, 23363L, 23364L, 23365L, 23366L, 23367L, 23368L, 23369L,
23370L, 23371L, 23372L, 23373L, 23374L, 23375L, 23376L, 23377L,
23378L, 23379L, 23380L, 23381L, 23382L, 23383L, 23384L, 23385L,
23386L, 23387L, 23388L, 23389L, 23390L, 23391L, 23392L, 23393L,
23394L, 23395L, 23396L, 23397L, 23398L, 23399L, 23400L, 23401L,
23402L, 23403L, 23404L, 23405L, 23406L, 23407L, 23408L, 23409L,
23410L, 23411L, 23412L, 23413L, 23414L, 23415L, 23416L, 23417L,
23418L, 23419L, 23420L, 23421L, 23422L, 23423L, 23424L, 23425L,
23426L, 23427L, 23428L, 23429L, 23430L, 23431L, 23432L, 23433L,
23434L, 23435L, 23436L, 23437L, 23438L, 23439L, 23440L, 23441L,
23442L, 23443L, 23444L, 23445L, 23446L, 23447L, 23448L, 23449L,
23450L, 23451L, 23452L, 23453L, 23454L, 23455L, 23456L, 23457L,
23458L, 23459L, 23460L, 23461L, 23462L, 23463L, 23464L, 23465L,
23466L, 23467L, 23468L, 23469L, 23470L, 23471L, 23472L, 23473L,
23474L, 23475L, 23476L, 23477L, 23478L, 23479L, 23480L, 23481L,
23482L, 23483L, 23484L, 23485L, 23486L, 23487L, 23488L, 23489L,
23490L, 23491L, 23492L, 23493L, 23494L, 23495L, 23496L, 23497L,
23498L, 23499L, 23500L, 23501L, 23502L, 23503L, 23504L, 23505L,
23506L, 23507L, 23508L, 23509L, 23510L, 23511L, 23512L, 23513L,
23514L, 23515L, 23516L, 23517L, 23518L, 23519L, 23520L, 23521L,
23522L, 23523L, 23524L, 23525L, 23526L, 23527L, 23528L, 23529L,
23530L, 23531L, 23532L, 23533L, 23534L, 23535L, 23536L, 23537L,
23538L, 23539L, 23540L, 23541L, 23542L, 23543L, 23544L, 23545L,
23546L, 23547L, 23548L, 23549L, 23550L, 23551L, 23552L, 23553L,
23554L, 23555L, 23556L, 23557L, 23558L, 23559L, 23560L, 23561L,
23562L, 23563L, 23564L, 23565L, 23566L, 23567L, 23568L, 23569L,
23570L, 23571L, 23572L, 23573L, 23574L, 23575L, 23576L, 23577L,
23578L, 23579L, 23580L, 23581L, 23582L, 23583L, 23584L, 23585L,
23586L, 23587L, 23588L, 23589L, 23590L, 23591L, 23592L, 23593L,
23594L, 23595L, 23596L, 23597L, 23598L, 23599L, 23600L, 23601L,
23602L, 23603L, 23604L, 23605L, 23606L, 23607L, 23608L, 23609L,
23610L, 23611L, 23612L, 23613L, 23614L, 23615L, 23616L, 23617L,
23618L, 23619L, 23620L, 23621L, 23622L, 23623L, 23624L, 23625L,
23626L, 23627L, 23628L, 23629L, 23630L, 23631L, 23632L, 23633L,
23634L, 23635L, 23636L, 23637L, 23638L, 23639L, 23640L, 23641L,
23642L, 23643L, 23644L, 23645L, 23646L, 23647L, 23648L, 23649L,
23650L, 23651L, 23652L, 23653L, 23654L, 23655L, 23656L, 23657L,
23658L, 23659L, 23660L, 23661L, 23662L, 23663L, 23664L, 23665L,
23666L, 23667L, 23668L, 23669L, 23670L, 23671L, 23672L, 23673L,
23674L, 23675L, 23676L, 23677L, 23678L, 23679L, 23680L, 23681L,
23682L, 23683L, 23684L, 23685L, 23686L, 23687L, 23688L, 23689L,
23690L, 23691L, 23692L, 23693L, 23694L, 23695L, 23696L, 23697L,
23698L, 23699L, 23700L, 23701L, 23702L, 23703L, 23704L, 23705L,
23706L, 23707L, 23708L, 23709L, 23710L, 23711L, 23712L, 23713L,
23714L, 23715L, 23716L, 23717L, 23718L, 23719L, 23720L, 23721L,
23722L, 23723L, 23724L, 23725L, 23726L, 23727L, 23728L, 23729L,
23730L, 23731L, 23732L, 23733L, 23734L, 23735L, 23736L, 23737L,
23738L, 23739L, 23740L, 23741L, 23742L, 23743L, 23744L, 23745L,
23746L, 23747L, 23748L, 23749L, 23750L, 23751L, 23752L, 23753L,
23754L, 23755L, 23756L, 23757L, 23758L, 23759L, 23760L, 23761L,
23762L, 23763L, 23764L, 23765L, 23766L, 23767L, 23768L, 23769L,
23770L, 23771L, 23772L, 23773L, 23774L, 23775L, 23776L, 23777L,
23778L, 23779L, 23780L, 23781L, 23782L, 23783L, 23784L, 23785L,
23786L, 23787L, 23788L, 23789L, 23790L, 23791L, 23792L, 23793L,
23794L, 23795L, 23796L, 23797L, 23798L, 23799L, 23800L, 23801L,
23802L, 23803L, 23804L, 23805L, 23806L, 23807L, 23808L, 23809L,
23810L, 23811L, 23812L, 23813L, 23814L, 23815L, 23816L, 23817L,
23818L, 23819L, 23820L, 23821L, 23822L, 23823L, 23824L, 23825L,
23826L, 23827L, 23828L, 23829L, 23830L, 23831L, 23832L, 23833L,
23834L, 23835L, 23836L, 23837L, 23838L, 23839L, 23840L, 23841L,
23842L, 23843L, 23844L, 23845L, 23846L, 23847L, 23848L, 23849L,
23850L, 23851L, 23852L, 23853L, 23854L, 23855L, 23856L, 23857L,
23858L, 23859L, 23860L, 23861L, 23862L, 23863L, 23864L, 23865L,
23866L, 23867L, 23868L, 23869L, 23870L, 23871L, 23872L, 23873L,
23874L, 23875L, 23876L, 23877L, 23878L, 23879L, 23880L, 23881L,
23882L, 23883L, 23884L, 23885L, 23886L, 23887L, 23888L, 23889L,
23890L, 23891L, 23892L, 23893L, 23894L, 23895L, 23896L, 23897L,
23898L, 23899L, 23900L, 23901L, 23902L, 23903L, 23904L, 23905L,
23906L, 23907L, 23908L, 23909L, 23910L, 23911L, 23912L, 23913L,
23914L, 23915L, 23916L, 23917L, 23918L, 23919L, 23920L, 23921L,
23922L, 23923L, 23924L, 23925L, 23926L, 23927L, 23928L, 23929L,
23930L, 23931L, 23932L, 23933L, 23934L, 23935L, 23936L, 23937L,
23938L, 23939L, 23940L, 23941L, 23942L, 23943L, 23944L, 23945L,
23946L, 23947L, 23948L, 23949L, 23950L, 23951L, 23952L, 23953L,
23954L, 23955L, 23956L, 23957L, 23958L, 23959L, 23960L, 23961L,
23962L, 23963L, 23964L, 23965L, 23966L, 23967L, 23968L, 23969L,
23970L, 23971L, 23972L, 23973L, 23974L, 23975L, 23976L, 23977L,
23978L, 23979L, 23980L, 23981L, 23982L, 23983L, 23984L, 23985L,
23986L, 23987L, 23988L, 23989L, 23990L, 23991L, 23992L, 23993L,
23994L, 23995L, 23996L, 23997L, 23998L, 23999L, 24000L, 24001L,
24002L, 24003L, 24004L, 24005L, 24006L, 24007L, 24008L, 24009L,
24010L, 24011L, 24012L, 24013L, 24014L, 24015L, 24016L, 24017L,
24018L, 24019L, 24020L, 24021L, 24022L, 24023L, 24024L, 24025L,
24026L, 24027L, 24028L, 24029L, 24030L, 24031L, 24032L, 24033L,
24034L, 24035L, 24036L, 24037L, 24038L, 24039L, 24040L, 24041L,
24042L, 24043L, 24044L, 24045L, 24046L, 24047L, 24048L, 24049L,
24050L, 24051L, 24052L, 24053L, 24054L, 24055L, 24056L, 24057L,
24058L, 24059L, 24060L, 24061L, 24062L, 24063L, 24064L, 24065L,
24066L, 24067L, 24068L, 24069L, 24070L, 24071L, 24072L, 24073L,
24074L, 24075L, 24076L, 24077L, 24078L, 24079L, 24080L, 24081L,
24082L, 24083L, 24084L, 24085L, 24086L, 24087L, 24088L, 24089L,
24090L, 24091L, 24092L, 24093L, 24094L, 24095L, 24096L, 24097L,
24098L, 24099L, 24100L, 24101L, 24102L, 24103L, 24104L, 24105L,
24106L, 24107L, 24108L, 24109L, 24110L, 24111L, 24112L, 24113L,
24114L, 24115L, 24116L, 24117L, 24118L, 24119L, 24120L, 24121L,
24122L, 24123L, 24124L, 24125L, 24126L, 24127L, 24128L, 24129L,
24130L, 24131L, 24132L, 24133L, 24134L, 24135L, 24136L, 24137L,
24138L, 24139L, 24140L, 24141L, 24142L, 24143L, 24144L, 24145L,
24146L, 24147L, 24148L, 24149L, 24150L, 24151L, 24152L, 24153L,
24154L, 24155L, 24156L, 24157L, 24158L, 24159L, 24160L, 24161L,
24162L, 24163L, 24164L, 24165L, 24166L, 24167L, 24168L, 24169L,
24170L, 24171L, 24172L, 24173L, 24174L, 24175L, 24176L, 24177L,
24178L, 24179L, 24180L, 24181L, 24182L, 24183L, 24184L, 24185L,
24186L, 24187L, 24188L, 24189L, 24190L, 24191L, 24192L, 24193L,
24194L, 24195L, 24196L, 24197L, 24198L, 24199L, 24200L, 24201L,
24202L, 24203L, 24204L, 24205L, 24206L, 24207L, 24208L, 24209L,
24210L, 24211L, 24212L, 24213L, 24214L, 24215L, 24216L, 24217L,
24218L, 24219L, 24220L, 24221L, 24222L, 24223L, 24224L, 24225L,
24226L, 24227L, 24228L, 24229L, 24230L, 24231L, 24232L, 24233L,
24234L, 24235L, 24236L, 24237L, 24238L, 24239L, 24240L, 24241L,
24242L, 24243L, 24244L, 24245L, 24246L, 24247L, 24248L, 24249L,
24250L, 24251L, 24252L, 24253L, 24254L, 24255L, 24256L, 24257L,
24258L, 24259L, 24260L, 24261L, 24262L, 24263L, 24264L, 24265L,
24266L, 24267L, 24268L, 24269L, 24270L, 24271L, 24272L, 24273L,
24274L, 24275L, 24276L, 24277L, 24278L, 24279L, 24280L, 24281L,
24282L, 24283L, 24284L, 24285L, 24286L, 24287L, 24288L, 24289L,
24290L, 24291L, 24292L, 24293L, 24294L, 24295L, 24296L, 24297L,
24298L, 24299L, 24300L, 24301L, 24302L, 24303L, 24304L, 24305L,
24306L, 24307L, 24308L, 24309L, 24310L, 24311L, 24312L, 24313L,
24314L, 24315L, 24316L, 24317L, 24318L, 24319L, 24320L, 24321L,
24322L, 24323L, 24324L, 24325L, 24326L, 24327L, 24328L, 24329L,
24330L, 24331L, 24332L, 24333L, 24334L, 24335L, 24336L, 24337L,
24338L, 24339L, 24340L, 24341L, 24342L, 24343L, 24344L, 24345L,
24346L, 24347L, 24348L, 24349L, 24350L, 24351L, 24352L, 24353L,
24354L, 24355L, 24356L, 24357L, 24358L, 24359L, 24360L, 24361L,
24362L, 24363L, 24364L, 24365L, 24366L, 24367L, 24368L, 24369L,
24370L, 24371L, 24372L, 24373L, 24374L, 24375L, 24376L, 24377L,
24378L, 24379L, 24380L, 24381L, 24382L, 24383L, 24384L, 24385L,
24386L, 24387L, 24388L, 24389L, 24390L, 24391L, 24392L, 24393L,
24394L, 24395L, 24396L, 24397L, 24398L, 24399L, 24400L, 24401L,
24402L, 24403L, 24404L, 24405L, 24406L, 24407L, 24408L, 24409L,
24410L, 24411L, 24412L, 24413L, 24414L, 24415L, 24416L, 24417L,
24418L, 24419L, 24420L, 24421L, 24422L, 24423L, 24424L, 24425L,
24426L, 24427L, 24428L, 24429L, 24430L, 24431L, 24432L, 24433L,
24434L, 24435L, 24436L, 24437L, 24438L, 24439L, 24440L, 24441L,
24442L, 24443L, 24444L, 24445L, 24446L, 24447L, 24448L, 24449L,
24450L, 24451L, 24452L, 24453L, 24454L, 24455L, 24456L, 24457L,
24458L, 24459L, 24460L, 24461L, 24462L, 24463L, 24464L, 24465L,
24466L, 24467L, 24468L, 24469L, 24470L, 24471L, 24472L, 24473L,
24474L, 24475L, 24476L, 24477L, 24478L, 24479L, 24480L, 24481L,
24482L, 24483L, 24484L, 24485L, 24486L, 24487L, 24488L, 24489L,
24490L, 24491L, 24492L, 24493L, 24494L, 24495L, 24496L, 24497L,
24498L, 24499L, 24500L, 24501L, 24502L, 24503L, 24504L, 24505L,
24506L, 24507L, 24508L, 24509L, 24510L, 24511L, 24512L, 24513L,
24514L, 24515L, 24516L, 24517L, 24518L, 24519L, 24520L, 24521L,
24522L, 24523L, 24524L, 24525L, 24526L, 24527L, 24528L, 24529L,
24530L, 24531L, 24532L, 24533L, 24534L, 24535L, 24536L, 24537L,
24538L, 24539L, 24540L, 24541L, 24542L, 24543L, 24544L, 24545L,
24546L, 24547L, 24548L, 24549L, 24550L, 24551L, 24552L, 24553L,
24554L, 24555L, 24556L, 24557L, 24558L, 24559L, 24560L, 24561L,
24562L, 24563L, 24564L, 24565L, 24566L, 24567L, 24568L, 24569L,
24570L, 24571L, 24572L, 24573L, 24574L, 24575L, 24576L, 24577L,
24578L, 24579L, 24580L, 24581L, 24582L, 24583L, 24584L, 24585L,
24586L, 24587L, 24588L, 24589L, 24590L, 24591L, 24592L, 24593L,
24594L, 24595L, 24596L, 24597L, 24598L, 24599L, 24600L, 24601L,
24602L, 24603L, 24604L, 24605L, 24606L, 24607L, 24608L, 24609L,
26467L, 26468L, 26469L, 26470L, 26471L, 26472L, 26473L, 26474L,
26475L, 26476L, 26477L, 26478L, 26479L, 26480L, 26481L, 26482L,
26483L, 26484L, 26485L, 26486L, 26487L, 26488L, 26489L, 26490L,
26491L, 26492L, 26493L, 26494L, 26495L, 26496L, 26497L, 26498L,
26499L, 26500L, 26501L, 26502L, 26503L, 26504L, 26505L, 26506L,
26507L, 26508L, 26509L, 26510L, 26511L, 26512L, 26513L, 26514L,
26515L, 26516L, 26517L, 26518L, 26519L, 26520L, 26521L, 26522L,
26523L, 26524L, 26525L, 26526L, 26527L, 24610L, 24611L, 24612L,
24613L, 24614L, 24615L, 24616L, 24617L, 24618L, 24619L, 24620L,
24621L, 24622L, 24623L, 24624L, 24625L, 24626L, 24627L, 24628L,
24629L, 24630L, 24631L, 24632L, 24633L, 24634L, 24635L, 24636L,
24637L, 24638L, 24639L, 24640L, 24641L, 24642L, 24643L, 24644L,
24645L, 24646L, 24647L, 24648L, 24649L, 24650L, 24651L, 24652L,
24653L, 24654L, 24655L, 24656L, 24657L, 24658L, 24659L, 24660L,
24661L, 24662L, 24663L, 24664L, 24665L, 24666L, 24667L, 24668L,
24669L, 24670L, 24671L, 24672L, 24673L, 24674L, 24675L, 24676L,
24677L, 24678L, 24679L, 24680L, 24681L, 24682L, 24683L, 24684L,
24685L, 24686L, 24687L, 24688L, 24689L, 24690L, 24691L, 24692L,
24693L, 24694L, 24695L, 24696L, 24697L, 24698L, 24699L, 24700L,
24701L, 24702L, 24703L, 24704L, 24705L, 24706L, 24707L, 24708L,
24709L, 24710L, 24711L, 24712L, 24713L, 24714L, 24715L, 24716L,
24717L, 24718L, 24719L, 24720L, 24721L, 24722L, 24723L, 24724L,
24725L, 24726L, 24727L, 24728L, 24729L, 24730L, 24731L, 24732L,
24733L, 24734L, 24735L, 24736L, 24737L, 24738L, 24739L, 24740L,
24741L, 24742L, 24743L, 24744L, 24745L, 24746L, 24747L, 24748L,
24749L, 24750L, 24751L, 24752L, 24753L, 24754L, 24755L, 24756L,
24757L, 24758L, 24759L, 24760L, 24761L, 24762L, 24763L, 24764L,
24765L, 24766L, 24767L, 24768L, 24769L, 24770L, 24771L, 24772L,
24773L, 24774L, 24775L, 24776L, 24777L, 24778L, 24779L, 24780L,
24781L, 24782L, 24783L, 24784L, 24785L, 24786L, 24787L, 24788L,
24789L, 24790L, 24791L, 24792L, 24793L, 24794L, 24795L, 24796L,
24797L, 24798L, 24799L, 24800L, 24801L, 24802L, 24803L, 24804L,
24805L, 24806L, 24807L, 24808L, 24809L, 24810L, 24811L, 24812L,
24813L, 24814L, 24815L, 24816L, 24817L, 24818L, 24819L, 24820L,
24821L, 24822L, 24823L, 24824L, 24825L, 24826L, 24827L, 24828L,
24829L, 24830L, 24831L, 24832L, 24833L, 24834L, 24835L, 24836L,
24837L, 24838L, 24839L, 24840L, 24841L, 24842L, 24843L, 24844L,
24845L, 24846L, 24847L, 24848L, 24849L, 24850L, 24851L, 24852L,
24853L, 24854L, 24855L, 24856L, 24857L, 24858L, 24859L, 24860L,
24861L, 24862L, 24863L, 24864L, 24865L, 24866L, 24867L, 24868L,
24869L, 24870L, 24871L, 24872L, 24873L, 24874L, 24875L, 24876L,
24877L, 24878L, 24879L, 24880L, 24881L, 24882L, 24883L, 24884L,
24885L, 24886L, 24887L, 24888L, 24889L, 24890L, 24891L, 24892L,
24893L, 24894L, 24895L, 24896L, 24897L, 24898L, 24899L, 24900L,
24901L, 24902L, 24903L, 24904L, 24905L, 24906L, 24907L, 24908L,
24909L, 24910L, 24911L, 24912L, 24913L, 24914L, 24915L, 24916L,
24917L, 24918L, 24919L, 24920L, 24921L, 24922L, 24923L, 24924L,
24925L, 24926L, 24927L, 24928L, 24929L, 24930L, 24931L, 24932L,
24933L, 24934L, 24935L, 24936L, 24937L, 24938L, 24939L, 24940L,
24941L, 24942L, 24943L, 24944L, 24945L, 24946L, 24947L, 24948L,
24949L, 24950L, 24951L, 24952L, 24953L, 24954L, 24955L, 24956L,
24957L, 24958L, 24959L, 24960L, 24961L, 24962L, 24963L, 24964L,
24965L, 24966L, 24967L, 24968L, 24969L, 24970L, 24971L, 24972L,
24973L, 24974L, 24975L, 24976L, 24977L, 24978L, 24979L, 24980L,
24981L, 24982L, 24983L, 24984L, 24985L, 24986L, 24987L, 24988L,
24989L, 24990L, 24991L, 24992L, 24993L, 24994L, 24995L, 24996L,
24997L, 24998L, 24999L, 25000L, 25001L, 25002L, 25003L, 25004L,
25005L, 25006L, 25007L, 25008L, 25009L, 25010L, 25011L, 25012L,
25013L, 25014L, 25015L, 25016L, 25017L, 25018L, 25019L, 25020L,
25021L, 25022L, 25023L, 25024L, 25025L, 25026L, 25027L, 25028L,
25029L, 25030L, 25031L, 25032L, 25033L, 25034L, 25035L, 25036L,
25037L, 25038L, 25039L, 25040L, 25041L, 25042L, 25043L, 25044L,
25045L, 25046L, 25047L, 25048L, 25049L, 25050L, 25051L, 25052L,
25053L, 25054L, 25055L, 25056L, 25057L, 25058L, 25059L, 25060L,
25061L, 25062L, 25063L, 25064L, 25065L, 25066L, 25067L, 25068L,
25069L, 25070L, 25071L, 25072L, 25073L, 25074L, 25075L, 25076L,
25077L, 25078L, 25079L, 25080L, 25081L, 25082L, 25083L, 25084L,
25085L, 25086L, 25087L, 25088L, 25089L, 25090L, 25091L, 25092L,
25093L, 25094L, 25095L, 25096L, 25097L, 25098L, 25099L, 25100L,
25101L, 25102L, 25103L, 25104L, 25105L, 25106L, 25107L, 25108L,
25109L, 25110L, 25111L, 25112L, 25113L, 25114L, 25115L, 25116L,
25117L, 25118L, 25119L, 25120L, 25121L, 25122L, 25123L, 25124L,
25125L, 25126L, 25127L, 25128L, 25129L, 25130L, 25131L, 25132L,
25133L, 25134L, 25135L, 25136L, 25137L, 25138L, 25139L, 25140L,
25141L, 25142L, 25143L, 25144L, 25145L, 25146L, 25147L, 25148L,
25149L, 25150L, 25151L, 25152L, 25153L, 25154L, 25155L, 25156L,
25157L, 25158L, 25159L, 25160L, 25161L, 25162L, 25163L, 25164L,
25165L, 25166L, 25167L, 25168L, 25169L, 25170L, 25171L, 25172L,
25173L, 25174L, 25175L, 25176L, 25177L, 25178L, 25179L, 25180L,
25181L, 25182L, 25183L, 25184L, 25185L, 25186L, 25187L, 25188L,
25189L, 25190L, 25191L, 25192L, 25193L, 25194L, 25195L, 25196L,
25197L, 25198L, 25199L, 25200L, 25201L, 25202L, 25203L, 25204L,
25205L, 25206L, 25207L, 25208L, 25209L, 25210L, 25211L, 25212L,
25213L, 25214L, 25215L, 25216L, 25217L, 25218L, 25219L, 25220L,
25221L, 25222L, 25223L, 25224L, 25225L, 25226L, 25227L, 25228L,
25229L, 25230L, 25231L, 25232L, 25233L, 25234L, 25235L, 25236L,
25237L, 25238L, 25239L, 25240L, 25241L, 25242L, 25243L, 25244L,
25245L, 25246L, 25247L, 25248L, 25249L, 25250L, 25251L, 25252L,
25253L, 25254L, 25255L, 25256L, 25257L, 25258L, 25259L, 25260L,
25261L, 25262L, 25263L, 25264L, 25265L, 25266L, 25267L, 25268L,
25269L, 25270L, 25271L, 25272L, 25273L, 25274L, 25275L, 25276L,
25277L, 25278L, 25279L, 25280L, 25281L, 25282L, 25283L, 25284L,
25285L, 25286L, 25287L, 25288L, 25289L, 25290L, 25291L, 25292L,
25293L, 25294L, 25295L, 25296L, 25297L, 25298L, 25299L, 25300L,
25301L, 25302L, 25303L, 25304L, 25305L, 25306L, 25307L, 25308L,
25309L, 25310L, 25311L, 25312L, 25313L, 25314L, 25315L, 25316L,
25317L, 25318L, 25319L, 25320L, 25321L, 25322L, 25323L, 25324L,
25325L, 25326L, 25327L, 25328L, 25329L, 25330L, 25331L, 25332L,
25333L, 25334L, 25335L, 25336L, 25337L, 25338L, 25339L, 25340L,
25341L, 25342L, 25343L, 25344L, 25345L, 25346L, 25347L, 25348L,
25349L, 25350L, 25351L, 25352L, 25353L, 25354L, 25355L, 25356L,
25357L, 25358L, 25359L, 25360L, 25361L, 25362L, 25363L, 25364L,
25365L, 25366L, 25367L, 25368L, 25369L, 25370L, 25371L, 25372L,
25373L, 25374L, 25375L, 25376L, 25377L, 25378L, 25379L, 25380L,
25381L, 25382L, 25383L, 25384L, 25385L, 25386L, 25387L, 25388L,
25389L, 25390L, 25391L, 25392L, 25393L, 25394L, 25395L, 25396L,
25397L, 25398L, 25399L, 25400L, 25401L, 25402L, 25403L, 25404L,
25405L, 25406L, 25407L, 25408L, 25409L, 25410L, 25411L, 25412L,
25413L, 25414L, 25415L, 25416L, 25417L, 25418L, 25419L, 25420L,
25421L, 25422L, 25423L, 25424L, 25425L, 25426L, 25427L, 25428L,
25429L, 25430L, 25431L, 25432L, 25433L, 25434L, 25435L, 25436L,
25437L, 25438L, 25439L, 25440L, 25441L, 25442L, 25443L, 25444L,
25445L, 25446L, 25447L, 25448L, 25449L, 25450L, 25451L, 25452L,
25453L, 25454L, 25455L, 25456L, 25457L, 25458L, 25459L, 25460L,
25461L, 25462L, 25463L, 25464L, 25465L, 25466L, 25467L, 25468L,
25469L, 25470L, 25471L, 25472L, 25473L, 25474L, 25475L, 25476L,
25477L, 25478L, 25479L, 25480L, 25481L, 25482L, 25483L, 25484L,
25485L, 25486L, 25487L, 25488L, 25489L, 25490L, 25491L, 25492L,
25493L, 25494L, 25495L, 25496L, 25497L, 25498L, 25499L, 25500L,
25501L, 25502L, 25503L, 25504L, 25505L, 25506L, 25507L, 25508L,
25509L, 25510L, 25511L, 25512L, 25513L, 25514L, 25515L, 25516L,
25517L, 25518L, 25519L, 25520L, 25521L, 25522L, 25523L, 25524L,
25525L, 25526L, 25527L, 25528L, 25529L, 25530L, 25531L, 25532L,
25533L, 25534L, 25535L, 25536L, 25537L, 25538L, 25539L, 25540L,
25541L, 25542L, 25543L, 25544L, 25545L, 25546L, 25547L, 25548L,
25549L, 25550L, 25551L, 25552L, 25553L, 25554L, 25555L, 25556L,
25557L, 25558L, 25559L, 25560L, 25561L, 25562L, 25563L, 25564L,
25565L, 25566L, 25567L, 25568L, 25569L, 25570L, 25571L, 25572L,
25573L, 25574L, 25575L, 25576L, 25577L, 25578L, 25579L, 25580L,
25581L, 25582L, 25583L, 25584L, 25585L, 25586L, 25587L, 25588L,
25589L, 25590L, 25591L, 25592L, 25593L, 25594L, 25595L, 25596L,
25597L, 25598L, 25599L, 25600L, 25601L, 25602L, 25603L, 25604L,
25605L, 25606L, 25607L, 25608L, 25609L, 25610L, 25611L, 25612L,
25613L, 25614L, 25615L, 25616L, 25617L, 25618L, 25619L, 25620L,
25621L, 25622L, 25623L, 25624L, 25625L, 25626L, 25627L, 25628L,
25629L, 25630L, 25631L, 25632L, 25633L, 25634L, 25635L, 25636L,
25637L, 25638L, 25639L, 25640L, 25641L, 25642L, 25643L, 25644L,
25645L, 25646L, 25647L, 25648L, 25649L, 25650L, 25651L, 25652L,
25653L, 25654L, 25655L, 25656L, 25657L, 25658L, 25659L, 25660L,
25661L, 25662L, 25663L, 25664L, 25665L, 25666L, 25667L, 25668L,
25669L, 25670L, 25671L, 25672L, 25673L, 25674L, 25675L, 25676L,
25677L, 25678L, 25679L, 25680L, 25681L, 25682L, 25683L, 25684L,
25685L, 25686L, 25687L, 25688L, 25689L, 25690L, 25691L, 25692L,
25693L, 25694L, 25695L, 25696L, 25697L, 25698L, 25699L, 25700L,
25701L, 25702L, 25703L, 25704L, 25705L, 25706L, 25707L, 25708L,
25709L, 25710L, 25711L, 25712L, 25713L, 25714L, 25715L, 25716L,
25717L, 25718L, 25719L, 25720L, 25721L, 25722L, 25723L, 25724L,
25725L, 25726L, 25727L, 25728L, 25729L, 25730L, 25731L, 25732L,
25733L, 25734L, 25735L, 25736L, 25737L, 25738L, 25739L, 25740L,
25741L, 25742L, 25743L, 25744L, 25745L, 25746L, 25747L, 25748L,
25749L, 25750L, 25751L, 25752L, 25753L, 25754L, 25755L, 25756L,
25757L, 25758L, 25759L, 25760L, 25761L, 25762L, 25763L, 25764L,
25765L, 25766L, 25767L, 25768L, 25769L, 25770L, 25771L, 25772L,
25773L, 25774L, 25775L, 25776L, 25777L, 25778L, 25779L, 25780L,
25781L, 25782L, 25783L, 25784L, 25785L, 25786L, 25787L, 25788L,
25789L, 25790L, 25791L, 25792L, 25793L, 25794L, 25795L, 25796L,
25797L, 25798L, 25799L, 25800L, 25801L, 25802L, 25803L, 25804L,
25805L, 25806L, 25807L, 25808L, 25809L, 25810L, 25811L, 25812L,
25813L, 25814L, 25815L, 25816L, 25817L, 25818L, 25819L, 25820L,
25821L, 25822L, 25823L, 25824L, 25825L, 25826L, 25827L, 25828L,
25829L, 25830L, 25831L, 25832L, 25833L, 25834L, 25835L, 25836L,
25837L, 25838L, 25839L, 25840L, 25841L, 25842L, 25843L, 25844L,
25845L, 25846L, 25847L, 25848L, 25849L, 25850L, 25851L, 25852L,
25853L, 25854L, 25855L, 25856L, 25857L, 25858L, 25859L, 25860L,
25861L, 25862L, 25863L, 25864L, 25865L, 25866L, 25867L, 25868L,
25869L, 25870L, 25871L, 25872L, 25873L, 25874L, 25875L, 25876L,
25877L, 25878L, 25879L, 25880L, 25881L, 25882L, 25883L, 25884L,
25885L, 25886L, 25887L, 25888L, 25889L, 25890L, 25891L, 25892L,
25893L, 25894L, 25895L, 25896L, 25897L, 25898L, 25899L, 25900L,
25901L, 25902L, 25903L, 25904L, 25905L, 25906L, 25907L, 25908L,
25909L, 25910L, 25911L, 25912L, 25913L, 25914L, 25915L, 25916L,
25917L, 25918L, 25919L, 25920L, 25921L, 25922L, 25923L, 25924L,
25925L, 25926L, 25927L, 25928L, 25929L, 25930L, 25931L, 25932L,
25933L, 25934L, 25935L, 25936L, 25937L, 25938L, 25939L, 25940L,
25941L, 25942L, 25943L, 25944L, 25945L, 25946L, 25947L, 25948L,
25949L, 25950L, 25951L, 25952L, 25953L, 25954L, 25955L, 25956L,
25957L, 25958L, 25959L, 25960L, 25961L, 25962L, 25963L, 25964L,
25965L, 25966L, 25967L, 25968L, 25969L, 25970L, 25971L, 25972L,
25973L, 25974L, 25975L, 25976L, 25977L, 25978L, 25979L, 25980L,
25981L, 25982L, 25983L, 25984L, 25985L, 25986L, 25987L, 25988L,
25989L, 25990L, 25991L, 25992L, 25993L, 25994L, 25995L, 25996L,
25997L, 25998L, 25999L, 26000L, 26001L, 26002L, 26003L, 26004L,
26005L, 26006L, 26007L, 26008L, 26009L, 26010L, 26011L, 26012L,
26013L, 26014L, 26015L, 26016L, 26017L, 26018L, 26019L, 26020L,
26021L, 26022L, 26023L, 26024L, 26025L, 26026L, 26027L, 26028L,
26029L, 26030L, 26031L, 26032L, 26033L, 26034L, 26035L, 26036L,
26037L, 26038L, 26039L, 26040L, 26041L, 26042L, 26043L, 26044L,
26045L, 26046L, 26047L, 26048L, 26049L, 26050L, 26051L, 26052L,
26053L, 26054L, 26055L, 26056L, 26057L, 26058L, 26059L, 26060L,
26061L, 26062L, 26063L, 26064L, 26065L, 26066L, 26067L, 26068L,
26069L, 26070L, 26071L, 26072L, 26073L, 26074L, 26075L, 26076L,
26077L, 26078L, 26079L, 26080L, 26081L, 26082L, 26083L, 26084L,
26085L, 26086L, 26087L, 26088L, 26089L, 26090L, 26091L, 26092L,
26093L, 26094L, 26095L, 26096L, 26097L, 26098L, 26099L, 26100L,
26101L, 26102L, 26103L, 26104L, 26105L, 26106L, 26107L, 26108L,
26109L, 26110L, 26111L, 26112L, 26113L, 26114L, 26115L, 26116L,
26117L, 26118L, 26119L, 26120L, 26121L, 26122L, 26123L, 26124L,
26125L, 26126L, 26127L, 26128L, 26129L, 26130L, 26131L, 26132L,
26133L, 26134L, 26135L, 26136L, 26137L, 26138L, 26139L, 26140L,
26141L, 26142L, 26143L, 26144L, 26145L, 26146L, 26147L, 26148L,
26149L, 26150L, 26151L, 26152L, 26153L, 26154L, 26155L, 26156L,
26157L, 26158L, 26159L, 26160L, 26161L, 26162L, 26163L, 26164L,
26165L, 26166L, 26167L, 26168L, 26169L, 26170L, 26171L, 26172L,
26173L, 26174L, 26175L, 26176L, 26177L, 26178L, 26179L, 26180L,
26181L, 26182L, 26183L, 26184L, 26185L, 26186L, 26187L, 26188L,
26189L, 26190L, 26191L, 26192L, 26193L, 26194L, 26195L, 26196L,
26197L, 26198L, 26199L, 26200L, 26201L, 26202L, 26203L, 26204L,
26205L, 26206L, 26207L, 26208L, 26209L, 26210L, 26211L, 26212L,
26213L, 26214L, 26215L, 26216L, 26217L, 26218L, 26219L, 26220L,
26221L, 26222L, 26223L, 26224L, 26225L, 26226L, 26227L, 26228L,
26229L, 26230L, 26231L, 26232L, 26233L, 26234L, 26235L, 26236L,
26237L, 26238L, 26239L, 26240L, 26241L, 26242L, 26243L, 26244L,
26245L, 26246L, 26247L, 26248L, 26249L, 26250L, 26251L, 26252L,
26253L, 26254L, 26255L, 26256L, 26257L, 26258L, 26259L, 26260L,
26261L, 26262L, 26263L, 26264L, 26265L, 26266L, 26267L, 26268L,
26269L, 26270L, 26271L, 26272L, 26273L, 26274L, 26275L, 26276L,
26277L, 26278L, 26279L, 26280L, 26281L, 26282L, 26283L, 26284L,
26285L, 26286L, 26287L, 26288L, 26289L, 26290L, 26291L, 26292L,
26293L, 26294L, 26295L, 26296L, 26297L, 26298L, 26299L, 26300L,
26301L, 26302L, 26303L, 26304L, 26305L, 26306L, 26307L, 26308L,
26309L, 26310L, 26311L, 26312L, 26313L, 26314L, 26315L, 26316L,
26317L, 26318L, 26319L, 26320L, 26321L, 26322L, 26323L, 26324L,
26325L, 26326L, 26327L, 26328L, 26329L, 26330L, 26331L, 26332L,
26333L, 26334L, 26335L, 26336L, 26337L, 26338L, 26339L, 26340L,
26341L, 26342L, 26343L, 26344L, 26345L, 26346L, 26347L, 26348L,
26349L, 26350L, 26351L, 26352L, 26353L, 26354L, 26355L, 26356L,
26357L, 26358L, 26359L, 26360L, 26361L, 26362L, 26363L, 26364L,
26365L, 26366L, 26367L, 26368L, 26369L, 26370L, 26371L, 26372L,
26373L, 26374L, 26375L, 26376L, 26377L, 26378L, 26379L, 26380L,
26381L, 26382L, 26383L, 26384L, 26385L, 26386L, 26387L, 26388L,
26389L, 26390L, 26391L, 26392L, 26393L, 26394L, 26395L, 26396L,
26397L, 26398L, 26399L, 26400L, 26401L, 26402L, 26403L, 26404L,
26405L, 26406L, 26407L, 26408L, 26409L, 26410L, 26411L, 26412L,
26413L, 26414L, 26415L, 26416L, 26417L, 26418L, 26419L, 26420L,
26421L, 26422L, 26423L, 26424L, 26425L, 26426L, 26427L, 26428L,
26429L, 26430L, 26431L, 26432L, 26433L, 26434L, 26435L, 26436L,
26437L, 26438L, 26439L, 26440L, 26441L, 26442L, 26443L, 26444L,
26445L, 26446L, 26447L, 26448L, 26449L, 26450L, 26451L, 26452L,
26453L, 26454L, 26455L, 26456L, 26457L, 26458L, 26459L, 26460L,
26461L, 26462L, 26463L, 26464L, 26465L, 26466L, 26528L, 26529L,
26530L, 26531L, 26532L, 26533L, 26534L, 26535L, 26536L, 26537L,
26538L, 26539L, 26540L, 26541L, 26542L, 26543L, 26544L, 26545L,
26546L, 26547L, 26548L, 26549L, 26550L, 26551L, 26552L, 26553L,
26554L, 26555L, 26556L, 26557L, 26558L, 26559L, 26560L, 26561L,
26562L, 26563L, 26564L, 26565L, 26566L, 26567L, 26568L, 26569L,
26570L, 26571L, 26572L, 26573L, 26574L, 26575L, 26576L, 26577L,
26578L, 26579L, 26580L, 26581L, 26582L, 26583L, 26584L, 26585L,
26586L, 26587L, 26588L, 26589L, 26590L, 26591L, 26592L, 26593L,
26594L, 26595L, 26596L, 26597L, 26598L, 26599L, 26600L, 26601L,
26602L, 26603L, 26604L, 26605L, 26606L, 26607L, 26608L, 26609L,
26610L, 26611L, 26612L, 26613L, 26614L, 26615L, 26616L, 26617L,
26618L, 26619L, 26620L, 26621L, 26622L, 26623L, 26624L, 26625L,
26626L, 26627L, 26628L, 26629L, 26630L, 26631L, 26632L, 26633L,
26634L, 26635L, 26636L, 26637L, 26638L, 26639L, 26640L, 26641L,
26642L, 26643L, 26644L, 26645L, 26646L, 26647L, 26648L, 26649L,
26650L, 26651L, 26652L, 26653L, 26654L, 26655L, 26656L, 26657L,
26658L, 26659L, 26660L, 26661L, 26662L, 26663L, 26664L, 26665L,
26666L, 26667L, 26668L, 26669L, 26670L, 26671L, 26672L, 26673L,
26674L, 26675L, 26676L, 26677L, 26678L, 26679L, 26680L, 26681L,
26682L, 26683L, 26684L, 26685L, 26686L, 26687L, 26688L, 26689L,
26690L, 26691L, 26692L, 26693L, 26694L, 26695L, 26696L, 26697L,
26698L, 26699L, 26700L, 26701L, 26702L, 26703L, 26704L, 26705L,
26706L, 26707L, 26708L, 26709L, 26710L, 26711L, 26712L, 26713L,
26714L, 26715L, 26716L, 26717L, 26718L, 26719L, 26720L, 26721L,
26722L, 26723L, 26724L, 26725L, 26726L, 26727L, 26728L, 26729L,
26730L, 26731L, 26732L, 26733L, 26734L, 26735L, 26736L, 26737L,
26738L, 26739L, 26740L, 26741L, 26742L, 26743L, 26744L, 26745L,
26746L, 26747L, 26748L, 26749L, 26750L, 26751L, 26752L, 26753L,
26754L, 26755L, 26756L, 26757L, 26758L, 26759L, 26760L, 26761L,
26762L, 26763L, 26764L, 26765L, 26766L, 26767L, 26768L, 26769L,
26770L, 26771L, 26772L, 26773L, 26774L, 26775L, 26776L, 26777L,
26778L, 26779L, 26780L, 26781L, 26782L, 26783L, 26784L, 26785L,
26786L, 26787L, 26788L, 26789L, 26790L, 26791L, 26792L, 26793L,
26794L, 26795L, 26796L, 26797L, 26798L, 26799L, 26800L, 26801L,
26802L, 26803L, 26804L, 26805L, 26806L, 26807L, 26808L, 26809L,
26810L, 26811L, 26812L, 26813L, 26814L, 26815L, 26816L, 26817L,
26818L, 26819L, 26820L, 26821L, 26822L, 26823L, 26824L, 26825L,
26826L, 26827L, 26828L, 26829L, 26830L, 26831L, 26832L, 26833L,
26834L, 26835L, 26836L, 26837L, 26838L, 26839L, 26840L, 26841L,
26842L, 26843L, 26844L, 26845L, 26846L, 26847L, 26848L, 26849L,
26850L, 26851L, 26852L, 26853L, 26854L, 26855L, 26856L, 26857L,
26858L, 26859L, 26860L, 26861L, 26862L, 26863L, 26864L, 26865L,
26866L, 26867L, 26868L, 26869L, 26870L, 26871L, 26872L, 26873L,
26874L, 26875L, 26876L, 26877L, 26878L, 26879L, 26880L, 26881L,
26882L, 26883L, 26884L, 26885L, 26886L, 26887L, 26888L, 26889L,
26890L, 26891L, 26892L, 26893L, 26894L, 26895L, 26896L, 26897L,
26898L, 26899L, 26900L, 26901L, 26902L, 26903L, 26904L, 26905L,
26906L, 26907L, 26908L, 26909L, 26910L, 26911L, 26912L, 26913L,
26914L, 26915L, 26916L, 26917L, 26918L, 26919L, 26920L, 26921L,
26922L, 26923L, 26924L, 26925L, 26926L, 26927L, 26928L, 26929L,
26930L, 26931L, 26932L, 26933L, 26934L, 26935L, 26936L, 26937L,
26938L, 26939L, 26940L, 26941L, 26942L, 26943L, 26944L, 26945L,
26946L, 26947L, 26948L, 26949L, 26950L, 26951L, 26952L, 26953L,
26954L, 26955L, 26956L, 26957L, 26958L, 26959L, 26960L, 26961L,
26962L, 26963L, 26964L, 26965L, 26966L, 26967L, 26968L, 26969L,
26970L, 26971L, 26972L, 26973L, 26974L, 26975L, 26976L, 26977L,
26978L, 26979L, 26980L, 26981L, 26982L, 26983L, 26984L, 26985L,
26986L, 26987L, 26988L, 26989L, 26990L, 26991L, 26992L, 26993L,
26994L, 26995L, 26996L, 26997L, 26998L, 26999L, 27000L, 27001L,
27002L, 27003L, 27004L, 27005L, 27006L, 27007L, 27008L, 27009L,
27010L, 27011L, 27012L, 27013L, 27014L, 27015L, 27016L, 27017L,
27018L, 27019L, 27020L, 27021L, 27022L, 27023L, 27024L, 27025L,
27026L, 27027L, 27028L, 27029L, 27030L, 27031L, 27032L, 27033L,
27034L, 27035L, 27036L, 27037L, 27038L, 27039L, 27040L, 27041L,
27042L, 27043L, 27044L, 27045L, 27046L, 27047L, 27048L, 27049L,
27050L, 27051L, 27052L, 27053L, 27054L, 27055L, 27056L, 27057L,
27058L, 27059L, 27060L, 27061L, 27062L, 27063L, 27064L, 27065L,
27066L, 27067L, 27068L, 27069L, 27070L, 27071L, 27072L, 27073L,
27074L, 27075L, 27076L, 27077L, 27078L, 27079L, 27080L, 27081L,
27082L, 27083L, 27084L, 27085L, 27086L, 27087L, 27088L, 27089L,
27090L, 27091L, 27092L, 27093L, 27094L, 27095L, 27096L, 27097L,
27098L, 27099L, 27100L, 27101L, 27102L, 27103L, 27104L, 27105L,
27106L, 27107L, 27108L, 27109L, 27110L, 27111L, 27112L, 27113L,
27114L, 27115L, 27116L, 27117L, 27118L, 27119L, 27120L, 27121L,
27122L, 27123L, 27124L, 27125L, 27126L, 27127L, 27128L, 27129L,
27130L, 27131L, 27132L, 27133L, 27134L, 27135L, 27136L, 27137L,
27138L, 27139L, 27140L, 27141L, 27142L, 27143L, 27144L, 27145L,
27146L, 27147L, 27148L, 27149L, 27150L, 27151L, 27152L, 27153L,
27154L, 27155L, 27156L, 27157L, 27158L, 27159L, 27160L, 27161L,
27162L, 27163L, 27164L, 27165L, 27166L, 27167L, 27168L, 27169L,
27170L, 27171L, 27172L, 27173L, 27174L, 27175L, 27176L, 27177L,
27178L, 27179L, 27180L, 27181L, 27182L, 27183L, 27184L, 27185L,
27186L, 27187L, 27188L, 27189L, 27190L, 27191L, 27192L, 27193L,
27194L, 27195L, 27196L, 27197L, 27198L, 27199L, 27200L, 27201L,
27202L, 27203L, 27204L, 27205L, 27206L, 27207L, 27208L, 27209L,
27210L, 27211L, 27212L, 27213L, 27214L, 27215L, 27216L, 27217L,
27218L, 27219L, 27220L, 27221L, 27222L, 27223L, 27224L, 27225L,
27226L, 27227L, 27228L, 27229L, 27230L, 27231L, 27232L, 27233L,
27234L, 27235L, 27236L, 27237L, 27238L, 27239L, 27240L, 27241L,
27242L, 27243L, 27244L, 27245L, 27246L, 27247L, 27248L, 27249L,
27250L, 27251L, 27252L, 27253L, 27254L, 27255L, 27256L, 27257L,
27258L, 27259L, 27260L, 27261L, 27262L, 27263L, 27264L, 27265L,
27266L, 27267L, 27268L, 27269L, 27270L, 27271L, 27272L, 27273L,
27274L, 27275L, 27276L, 27277L, 27278L, 27279L, 27280L, 27281L,
27282L, 27283L, 27284L, 27285L, 27286L, 27287L, 27288L, 27289L,
27290L, 27291L, 27292L, 27293L, 27294L, 27295L, 27296L, 27297L,
27298L, 27299L, 27300L, 27301L, 27302L, 27303L, 27304L, 27305L,
27306L, 27307L, 27308L, 27309L, 27310L, 27311L, 27312L, 27313L,
27314L, 27315L, 27316L, 27317L, 27318L, 27319L, 27320L, 27321L,
27322L, 27323L, 27324L, 27325L, 27326L, 27327L, 27328L, 27329L,
27330L, 27331L, 27332L, 27333L, 27334L, 27335L, 27336L, 27337L,
27338L, 27339L, 27340L, 27341L, 27342L, 27343L, 27344L, 27345L,
27346L, 27347L, 27348L, 27349L, 27350L, 27351L, 27352L, 27353L,
27354L, 27355L, 27356L, 27357L, 27358L, 27359L, 27360L, 27361L,
27362L, 27363L, 27364L, 27365L, 27366L, 27367L, 27368L, 27369L,
27370L, 27371L, 27372L, 27373L, 27374L, 27375L, 27376L, 27377L,
27378L, 27379L, 27380L, 27381L, 27382L, 27383L, 27384L, 27385L,
27386L, 27387L, 27388L, 27389L, 27390L, 27391L, 27392L, 27393L,
27394L, 27395L, 27396L, 27397L, 27398L, 27399L, 27400L, 27401L,
27402L, 27403L, 27404L, 27405L, 27406L, 27407L, 27408L, 27409L,
27410L, 27411L, 27412L, 27413L, 27414L, 27415L, 27416L, 27417L,
27418L, 27419L, 27420L, 27421L, 27422L, 27423L, 27424L, 27425L,
27426L, 27427L, 27428L, 27429L, 27430L, 27431L, 27432L, 27433L,
27434L, 27435L, 27436L, 27437L, 27438L, 27439L, 27440L, 27441L,
27442L, 27443L, 27444L, 27445L, 27446L, 27447L, 27448L, 27449L,
27450L, 27451L, 27452L, 27453L, 27454L, 27455L, 27456L, 27457L,
27458L, 27459L, 27460L, 27461L, 27462L, 27463L, 27464L, 27465L,
27466L, 27467L, 27468L, 27469L, 27470L, 27471L, 27472L, 27473L,
27474L, 27475L, 27476L, 27477L, 27478L, 27479L, 27480L, 27481L,
27482L, 27483L, 27484L, 27485L, 27486L, 27487L, 27488L, 27489L,
27490L, 27491L, 27492L, 27493L, 27494L, 27495L, 27496L, 27497L,
27498L, 27499L, 27500L, 27501L, 27502L, 27503L, 27504L, 27505L,
27506L, 27507L, 27508L, 27509L, 27510L, 27511L, 27512L, 27513L,
27514L, 27515L, 27516L, 27517L, 27518L, 27519L, 27520L, 27521L,
27522L, 27523L, 27524L, 27525L, 27526L, 27527L, 27528L, 27529L,
27530L, 27531L, 27532L, 27533L, 27534L, 27535L, 27536L, 27537L,
27538L, 27539L, 27540L, 27541L, 27542L, 27543L, 27544L, 27545L,
27546L, 27547L, 27548L, 27549L, 27550L, 27551L, 27552L, 27553L,
27554L, 27555L, 27556L, 27557L, 27558L, 27559L, 27560L, 27561L,
27562L, 27563L, 27564L, 27565L, 27566L, 27567L, 27568L, 27569L,
27570L, 27571L, 27572L, 27573L, 27574L, 27575L, 27576L, 27577L,
27578L, 27579L, 27580L, 27581L, 27582L, 27583L, 27584L, 27585L,
27586L, 27587L, 27588L, 27589L, 27590L, 27591L, 27592L, 27593L,
27594L, 27595L, 27596L, 27597L, 27598L, 27599L, 27600L, 27601L,
27602L, 27603L, 27604L, 27605L, 27606L, 27607L, 27608L, 27609L,
27610L, 27611L, 27612L, 27613L, 27614L, 27615L, 27616L, 27617L,
27618L, 27619L, 27620L, 27621L, 27622L, 27623L, 27624L, 27625L,
27626L, 27627L, 27628L, 27629L, 27630L, 27631L, 27632L, 27633L,
27634L, 27635L, 27636L, 27637L, 27638L, 27639L, 27640L, 27641L,
27642L, 27643L, 27644L, 27645L, 27646L, 27647L, 27648L, 27649L,
27650L, 27651L, 27652L, 27653L, 27654L, 27655L, 27656L, 27657L,
27658L, 27659L, 27660L, 27661L, 27662L, 27663L, 27664L, 27665L,
27666L, 27667L, 27668L, 27669L, 27670L, 27671L, 27672L, 27673L,
27674L, 27675L, 27676L, 27677L, 27678L, 27679L, 27680L, 27681L,
27682L, 27683L, 27684L, 27685L, 27686L, 27687L, 27688L, 27689L,
27690L, 27691L, 27692L, 27693L, 27694L, 27695L, 27696L, 27697L,
27698L, 27699L, 27700L, 27701L, 27702L, 27703L, 27704L, 27705L,
27706L, 27707L, 27708L, 27709L, 27710L, 27711L, 27712L, 27713L,
27714L, 27715L, 27716L, 27717L, 27718L, 27719L, 27720L, 27721L,
27722L, 27723L, 27724L, 27725L, 27726L, 27727L, 27728L, 27729L,
27730L, 27731L, 27732L, 27733L, 27734L, 27735L, 27736L, 27737L,
27738L, 27739L, 27740L, 27741L, 27742L, 27743L, 27744L, 27745L,
27746L, 27747L, 27748L, 27749L, 27750L, 27751L, 27752L, 27753L,
27754L, 27755L, 27756L, 27757L, 27758L, 27759L, 27760L, 27761L,
27762L, 27763L, 27764L, 27765L, 27766L, 27767L, 27768L, 27769L,
27770L, 27771L, 27772L, 27773L, 27774L, 27775L, 27776L, 27777L,
27778L, 27779L, 27780L, 27781L, 27782L, 27783L, 27784L, 27785L,
27786L, 27787L, 27788L, 27789L, 27790L, 27791L, 27792L, 27793L,
27794L, 27795L, 27796L, 27797L, 27798L, 27799L, 27800L, 27801L,
27802L, 27803L, 27804L, 27805L, 27806L, 27807L, 27808L, 27809L,
27810L, 27811L, 27812L, 27813L, 27814L, 27815L, 27816L, 27817L,
27818L, 27819L, 27820L, 27821L, 27822L, 27823L, 27824L, 27825L,
27826L, 27827L, 27828L, 27829L, 27830L, 27831L, 27832L, 27833L,
27834L, 27835L, 27836L, 27837L, 27838L, 27839L, 27840L, 27841L,
27842L, 27843L, 27844L, 27845L, 27846L, 27847L, 27848L, 27849L,
27850L, 27851L, 27852L, 27853L, 27854L, 27855L, 27856L, 27857L,
27858L, 27859L, 27860L, 27861L, 27862L, 27863L, 27864L, 27865L,
27866L, 27867L, 27868L, 27869L, 27870L, 27871L, 27872L, 27873L,
27874L, 27875L, 27876L, 27877L, 27878L, 27879L, 27880L, 27881L,
27882L, 27883L, 27884L, 27885L, 27886L, 27887L, 27888L, 27889L,
27890L, 27891L, 27892L, 27893L, 27894L, 27895L, 27896L, 27897L,
27898L, 27899L, 27900L, 27901L, 27902L, 27903L, 27904L, 27905L,
27906L, 27907L, 27908L, 27909L, 27910L, 27911L, 27912L, 27913L,
27914L, 27915L, 27916L, 27917L, 27918L, 27919L, 27920L, 27921L,
27922L, 27923L, 27924L, 27925L, 27926L, 27927L, 27928L, 27929L,
27930L, 27931L, 27932L, 27933L, 27934L, 27935L, 27936L, 27937L,
27938L, 27939L, 27940L, 27941L, 27942L, 27943L, 27944L, 27945L,
27946L, 27947L, 27948L, 27949L, 27950L, 27951L, 27952L, 27953L,
27954L, 27955L, 27956L, 27957L, 27958L, 27959L, 27960L, 27961L,
27962L, 27963L, 27964L, 27965L, 27966L, 27967L, 27968L, 27969L,
27970L, 27971L, 27972L, 27973L, 27974L, 27975L, 27976L, 27977L,
27978L, 27979L, 27980L, 27981L, 27982L, 27983L, 27984L, 27985L,
27986L, 27987L, 27988L, 27989L, 27990L, 27991L, 27992L, 27993L,
27994L, 27995L, 27996L, 27997L, 27998L, 27999L, 28000L, 28001L,
28002L, 28003L, 28004L, 28005L, 28006L, 28007L, 28008L, 28009L,
28010L, 28011L, 28012L, 28013L, 28014L, 28015L, 28016L, 28017L,
28018L, 28019L, 28020L, 28021L, 28022L, 28023L, 28024L, 28025L,
28026L, 28027L, 28028L, 28029L, 28030L, 28031L, 28032L, 28033L,
28034L, 28035L, 28036L, 28037L, 28038L, 28039L, 28040L, 28041L,
28042L, 28043L, 28044L, 28045L, 28046L, 28047L, 28048L, 28049L,
28050L, 28051L, 28052L, 28053L, 28054L, 28055L, 28056L, 28057L,
28058L, 28059L, 28060L, 28061L, 28062L, 28063L, 28064L, 28065L,
28066L, 28067L, 28068L, 28069L, 28070L, 28071L, 28072L, 28073L,
28074L, 28075L, 28076L, 28077L, 28078L, 28079L, 28080L, 28081L,
28082L, 28083L, 28084L, 28085L, 28086L, 28087L, 28088L, 28089L,
28090L, 28091L, 28092L, 28093L, 28094L, 28095L, 28096L, 28097L,
28098L, 28099L, 28100L, 28101L, 28102L, 28103L, 28104L, 28105L,
28106L, 28107L, 28108L, 28109L, 28110L, 28111L, 28112L, 28113L,
28114L, 28115L, 28116L, 28117L, 28118L, 28119L, 28120L, 28121L,
28122L, 28123L, 28124L, 28125L, 28126L, 28127L, 28128L, 28129L,
28130L, 28131L, 28132L, 28133L, 28134L, 28135L, 28136L, 28137L,
28138L, 28139L, 28140L, 28141L, 28142L, 28143L, 28144L, 28145L,
28146L, 28147L, 28148L, 28149L, 28150L, 28151L, 28152L, 28153L,
28154L, 28155L, 28156L, 28157L, 28158L, 28159L, 28160L, 28161L,
28162L, 28163L, 28164L, 28165L, 28166L, 28167L, 28168L, 28169L,
28170L, 28171L, 28172L, 28173L, 28174L, 28175L, 28176L, 28177L,
28178L, 28179L, 28180L, 28181L, 28182L, 28183L, 28184L, 28185L,
28186L, 28187L, 28188L, 28189L, 28190L, 28191L, 28192L, 28193L,
28194L, 28195L, 28196L, 28197L, 28198L, 28199L, 28200L, 28201L,
28202L, 28203L, 28204L, 28205L, 28206L, 28207L, 28208L, 28209L,
28210L, 28211L, 28212L, 28213L, 28214L, 28215L, 28216L, 28217L,
28218L, 28219L, 28220L, 28221L, 28222L, 28223L, 28224L, 28225L,
28226L, 28227L, 28228L, 28229L, 28230L, 28231L, 28232L, 28233L,
28234L, 28235L, 28236L, 28237L, 28238L, 28239L, 28240L, 28241L,
28242L, 28243L, 28244L, 28245L, 28246L, 28247L, 28248L, 28249L,
28250L, 28251L, 28252L, 28253L, 28254L, 28255L, 28256L, 28257L,
28258L, 28259L, 28260L, 28261L, 28262L, 28263L, 28264L, 28265L,
28266L, 28267L, 28268L, 28269L, 28270L, 28271L, 28272L, 28273L,
28274L, 28275L, 28276L, 28277L, 28278L, 28279L, 28280L, 28281L,
28282L, 28283L, 28284L, 28285L, 28286L, 28287L, 28288L, 28289L,
28290L, 28291L, 28292L, 28293L, 28294L, 28295L, 28296L, 28297L,
28298L, 28299L, 28300L, 28301L, 28302L, 28303L, 28304L, 28305L,
28306L, 28307L, 28308L, 28309L, 28310L, 28311L, 28312L, 28313L,
28314L, 28315L, 28316L, 28317L, 28318L, 28319L, 28320L, 28321L,
28322L, 28323L, 28324L, 28325L, 28326L, 28327L, 28328L, 28329L,
28330L, 28331L, 28332L, 28333L, 28334L, 28335L, 28336L, 28337L,
28338L, 28339L, 28340L, 28341L, 28342L, 28343L, 28344L, 28345L,
28346L, 28347L, 28348L, 28349L, 28350L, 28351L, 28352L, 28353L,
28354L, 28355L, 28356L, 28357L, 28358L, 28359L, 28360L, 28361L,
28362L, 28363L, 28364L, 28365L, 28366L, 28367L, 28368L, 28369L,
28370L, 28371L, 28372L, 28373L, 28374L, 28375L, 28376L, 28377L,
28378L, 28379L, 28380L, 28381L, 28382L, 28383L, 28384L, 28385L,
28386L, 28387L, 28388L, 28389L, 28390L, 28391L, 28392L, 28393L,
28394L, 28395L, 28396L, 28397L, 28398L, 28399L, 28400L, 28401L,
28402L, 28403L, 28404L, 28405L, 28406L, 28407L, 28408L, 28409L,
28410L, 28411L, 28412L, 28413L, 28414L, 28415L, 28416L, 28417L,
28418L, 28419L, 28420L, 28421L, 28422L, 28423L, 28424L, 28425L,
28426L, 28427L, 28428L, 28429L, 28430L, 28431L, 28432L, 28433L,
28434L, 28435L, 28436L, 28437L, 28438L, 28439L, 28440L, 28441L,
28442L, 28443L, 28444L, 28445L, 28446L, 28447L, 28448L, 28449L,
28450L, 28451L, 28452L, 28453L, 28454L, 28455L, 28456L, 28457L,
28458L, 28459L, 28460L, 28461L, 28462L, 28463L, 28464L, 28465L,
28466L, 28467L, 28468L, 28469L, 28470L, 28471L, 28472L, 28473L,
28474L, 28475L, 28476L, 28477L, 28478L, 28479L, 28480L, 28481L,
28482L, 28483L, 28484L, 28485L, 28486L, 28487L, 28488L, 28489L,
28490L, 28491L, 28492L, 28493L, 28494L, 28495L, 28496L, 28497L,
28498L, 28499L, 28500L, 28501L, 28502L, 28503L, 28504L, 28505L,
28506L, 28507L, 28508L, 28509L, 28510L, 28511L, 28512L, 28513L,
28514L, 28515L, 28516L, 28517L, 28518L, 28519L, 28520L, 28521L,
28522L, 28523L, 28524L, 28525L, 28526L, 28527L, 28528L, 28529L,
28530L, 28531L, 28532L, 28533L, 28534L, 28535L, 28536L, 28537L,
28538L, 28539L, 28540L, 28541L, 28542L, 28543L, 28544L, 28545L,
28546L, 28547L, 28548L, 28549L, 28550L, 28551L, 28552L, 28553L,
28554L, 28555L, 28556L, 28557L, 28558L, 28559L, 28560L, 28561L,
28562L, 28563L, 28564L, 28565L, 28566L, 28567L, 28568L, 28569L,
28570L, 28571L, 28572L, 28573L, 28574L, 28575L, 28576L, 28577L,
28578L, 28579L, 28580L, 28581L, 28582L, 28583L, 28584L, 28585L,
28586L, 28587L, 28588L, 28589L, 28590L, 28591L, 28592L, 28593L,
28594L, 28595L, 28596L, 28597L, 28598L, 28599L, 28600L, 28601L,
28602L, 28603L, 28604L, 28605L, 28606L, 28607L, 28608L, 28609L,
28610L, 28611L, 28612L, 28613L, 28614L, 28615L, 28616L, 28617L,
28618L, 28619L, 28620L, 28621L, 28622L, 28623L, 28624L, 28625L,
28626L, 28627L, 28628L, 28629L, 28630L, 28631L, 28632L, 28633L,
28634L, 28635L, 28636L, 28637L, 28638L, 28639L, 28640L, 28641L,
28642L, 28643L, 28644L, 28645L, 28646L, 28647L, 28648L, 28649L,
28650L, 28651L, 28652L, 28653L, 28654L, 28655L, 28656L, 28657L,
28658L, 28659L, 28660L, 28661L, 28662L, 28663L, 28664L, 28665L,
28666L, 28667L, 28668L, 28669L, 28670L, 28671L, 28672L, 28673L,
28674L, 28675L, 28676L, 28677L, 28678L, 28679L, 28680L, 28681L,
28682L, 28683L, 28684L, 28685L, 28686L, 28687L, 28688L, 28689L,
28690L, 28691L, 28692L, 28693L, 28694L, 28695L, 28696L, 28697L,
28698L, 28699L, 28700L, 28701L, 28702L, 28703L, 28704L, 28705L,
28706L, 28707L, 28708L, 28709L, 28710L, 28711L, 28712L, 28713L,
28714L, 28715L, 28716L, 28717L, 28718L, 28719L, 28720L, 28721L,
28722L, 28723L, 28724L, 28725L, 28726L, 28727L, 28728L, 28729L,
28730L, 28731L, 28732L, 28733L, 28734L, 28735L, 28736L, 28737L,
28738L, 28739L, 28740L, 28741L, 28742L, 28743L, 28744L, 28745L,
28746L, 28747L, 28748L, 28749L, 28750L, 28751L, 28752L, 28753L,
28754L, 28755L, 28756L, 28757L, 28758L, 28759L, 28760L, 28761L,
28762L, 28763L, 28764L, 28765L, 28766L, 28767L, 28768L, 28769L,
28770L, 28771L, 28772L, 28773L, 28774L, 28775L, 28776L, 28777L,
28778L, 28779L, 28780L, 28781L, 28782L, 28783L, 28784L, 28785L,
28786L, 28787L, 28788L, 28789L, 28790L, 28791L, 28792L, 28793L,
28794L, 28795L, 28796L, 28797L, 28798L, 28799L, 28800L, 28801L,
28802L, 28803L, 28804L, 28805L, 28806L, 28807L, 28808L, 28809L,
28810L, 28811L, 28812L, 28813L, 28814L, 28815L, 28816L, 28817L,
28818L, 28819L, 28820L, 28821L, 28822L, 28823L, 28824L, 28825L,
28826L, 28827L, 28828L, 28829L, 28830L, 28831L, 28832L, 28833L,
28834L, 28835L, 28836L, 28837L, 28838L, 28839L, 28840L, 28841L,
28842L, 28843L, 28844L, 28845L, 28846L, 28847L, 28848L, 28849L,
28850L, 28851L, 28852L, 28853L, 28854L, 28855L, 28856L, 28857L,
28858L, 28859L, 28860L, 28861L, 28862L, 28863L, 28864L, 28865L,
28866L, 28867L, 28868L, 28869L, 28870L, 28871L, 28872L, 28873L,
28874L, 28875L, 28876L, 28877L, 28878L, 28879L, 28880L, 28881L,
28882L, 28883L, 28884L, 28885L, 28886L, 28887L, 28888L, 28889L,
28890L, 28891L, 28892L, 28893L, 28894L, 28895L, 28896L, 28897L,
28898L, 28899L, 28900L, 28901L, 28902L, 28903L, 28904L, 28905L,
28906L, 28907L, 28908L, 28909L, 28910L, 28911L, 28912L, 28913L,
28914L, 28915L, 28916L, 28917L, 28918L, 28919L, 28920L, 28921L,
28922L, 28923L, 28924L, 28925L, 28926L, 28927L, 28928L, 28929L,
28930L, 28931L, 28932L, 28933L, 28934L, 28935L, 28936L, 28937L,
28938L, 28939L, 28940L, 28941L, 28942L, 28943L, 28944L, 28945L,
28946L, 28947L, 28948L, 28949L, 28950L, 28951L, 28952L, 28953L,
28954L, 28955L, 28956L, 28957L, 28958L, 28959L, 28960L, 28961L,
28962L, 28963L, 28964L, 28965L, 28966L, 28967L, 28968L, 28969L,
28970L, 28971L, 28972L, 28973L, 28974L, 28975L, 28976L, 28977L,
28978L, 28979L, 28980L, 28981L, 28982L, 28983L, 28984L, 28985L,
28986L, 28987L, 28988L, 28989L, 28990L, 28991L, 28992L), class = "data.frame")

################################################################################
#                                                                              #
#                            Do NOT alter this data                            #
#                                                                              #
################################################################################
#                                                                              #
#                                                                              #
#         #######                       ######                                 #
#         #        #    #  #####        #     #    ##    #####    ##           #
#         #        ##   #  #    #       #     #   #  #     #     #  #          #
#         #####    # #  #  #    #       #     #  #    #    #    #    #         #
#         #        #  # #  #    #       #     #  ######    #    ######         #
#         #        #   ##  #    #       #     #  #    #    #    #    #         #
#         #######  #    #  #####        ######   #    #    #    #    #         #
#                                                                              #
#                                                                              #
################################################################################
#                                                                              #
#                            Do NOT alter this data                            #
#                                                                              #
################################################################################
